using System;
using System.Collections.Generic;
using System.Linq;
using System.Xml;
using System.Text.RegularExpressions;
using Au.Gov.Sbr.Xbrl.Document;
using DataContracts;
using Au.Gov.Sbr.Xbrl.Metadata;
using System.Runtime.CompilerServices;
using System.IO;
using System.Text;
using System.Xml.Schema;
using System.Reflection;
using System.Runtime.Serialization; 

namespace Ato.EN.IntegrationServices.CodeGenerationIDS
{

    public partial class IDS2017Validator
    {
        /// <summary>
        /// The max parameter name length is restricted by the SBR1 and SBR2 schemas - the lowest common denominator of SBR 1 is used as the default
        /// </summary>
        private int _maxParameterNameLength;

        /// <summary>
        /// The max parameter value length is restricted by the SBR1 and SBR2 schemas
        /// </summary>
        private int _maxParameterValueLength;

        /// <summary>
        /// The SBR1 and ebms3 schemas do not allow parameter names or values to be the empty string
        /// </summary>
        private string _emptyParameterValue;

        /// <summary>
        /// Initializes a new instance of the <see cref="IDS2017Validator" /> class.
        /// </summary>
        /// <param name="maxParameterNameLength">Maximum length of the parameter name.</param>
        /// <param name="maxParameterValueLength">Maximum length of the parameter value.</param>
        /// <param name="emptyParameterValue">This value will be used in place of any parameter values that result in a null or empty value.</param>
        public IDS2017Validator(int maxParameterNameLength = 20, int maxParameterValueLength = 4096, string emptyParameterValue = "EMPTY")
        {
            _maxParameterNameLength = maxParameterNameLength;
            _maxParameterValueLength = maxParameterValueLength;
            _emptyParameterValue = emptyParameterValue;
        }

        #region Functions
        private static IEnumerable<string> Union(IEnumerable<string> list1, IEnumerable<string> list2)
        {
            IEnumerable<string> response;

            if (list1 == null && list2 == null)
            {
                response = null;
            }
            else if (list1 == null)
            {
                response = list2.Distinct();
            }
            else if (list2 == null)
            {
                response = list1.Distinct();
            }
            else
            {
                response = list1.Union(list2);
            }

            return response;
        }

        private static bool IsMatch(int? field, string expression, RegexOptions options = RegexOptions.None)
        {
            if (field == null)
                return false;
            else
                return Regex.IsMatch(Convert.ToString(field.Value), expression, options);
        }

        private static bool IsMatch(string field, string expression, RegexOptions options = RegexOptions.None)
        {
            if (field == null)
                return false;
            else
                return Regex.IsMatch(field, expression, options);
        }

        // This is just context and tuple counts where they are integer values - easier that changing the parsing logic to just return the value
        private static int Count(int count)
        {
            return count;
        }


        private static int Count<T>(IEnumerable<T> values)
        {
            return values == null ? 0 : values.Where(f => f != null).Count();
        }


        private static int Count<T>(ICollection<T> values)
        {
            return values == null ? 0 : values.Where(f => f != null).Count();
        }


        private static bool exists(bool value)
        {
            return value;
        }

        private static string GetValueOrEmpty(bool? val)
        {
            return (val.HasValue) ? val.ToString() : string.Empty;
        }

        private static string GetValueOrEmpty(DateTime? val)
        {
            return (val.HasValue) ? val.ToString() : string.Empty;
        }

        /// <summary>
        /// Get string value between [first] a and [last] b.
        /// </summary>
        public static string Between(string value, string a, string b)
        {
            int posA = value.IndexOf(a);
            int posB = value.LastIndexOf(b);
            if (posA == -1)
            {
                return "";
            }
            if (posB == -1)
            {
                return "";
            }
            int adjustedPosA = posA + a.Length;
            if (adjustedPosA >= posB)
            {
                return "";
            }
            return value.Substring(adjustedPosA, posB - adjustedPosA);
        }

        /// <summary>
        /// Get string value after [first] a.
        /// </summary>
        public static string Before(string value, string a)
        {
            int posA = value.IndexOf(a);
            if (posA == -1)
            {
                return "";
            }
            return value.Substring(0, posA);
        }

        /// <summary>
        /// Get string value after [last] a.
        /// </summary>
        public static string After(string value, string a)
        {
            int posA = value.LastIndexOf(a);
            if (posA == -1)
            {
                return "";
            }
            int adjustedPosA = posA + a.Length;
            if (adjustedPosA >= value.Length)
            {
                return "";
            }
            return value.Substring(adjustedPosA);
        }

        private static int Length(object field)
        {
            if (field == null)
                return 0;
            else
                return field.ToString().Trim().Length;
        }

        private static bool NotSameValues(IEnumerable<object> nodes)
        {
            if (nodes == null)
                return false;

            object[] nodesArray = nodes.Cast<object>().ToArray();
            return NotSameValues(nodesArray);
        }

        private static bool NotSameValues(params object[] nodes)
        {
            if (nodes == null)
                return false;

            return ((from x in nodes select x).Distinct().Count() == nodes.Count());
        }

        private static bool HasDuplicateValues(IEnumerable<object> nodes)
        {
            if (nodes == null)
                return false;

            object[] nodesArray = nodes.Cast<object>().ToArray();
            return HasDuplicateValues(nodesArray);
        }

        private static bool HasDuplicateValues(params object[] nodes)
        {
            if (nodes == null)
                return false;

            nodes = nodes.Where(x => x != null).ToArray();

            return !((from x in nodes select x).Distinct().Count() == nodes.Count());

        }

        private int DuplicateValueIndex(IEnumerable<object> values)
        {
            int response = 0;
            var hashset = new HashSet<object>();
            foreach (var value in values)
            {
                if (!hashset.Add(value))
                {
                    return response;
                }
                response++;
            }
            return response;
        }

        private int DuplicateValueIndex<T>(IEnumerable<T?> values) where T : struct
        {
            int response = 0;
            var hashset = new HashSet<T?>();
            foreach (var value in values)
            {
                if (!hashset.Add(value))
                {
                    return response;
                }
                response++;
            }
            return response;
        }

        private static bool IsDate(object value)
        {
            DateTime dateValue;
            return (value != null && DateTime.TryParse(value.ToString(), out dateValue));
        }

        public DateTime AsDate(string dateAsString)
        {
            DateTime response = DateTime.MinValue;
            DateTime date;

            if (DateTime.TryParse(dateAsString, out date))
            {
                response = date;
            }

            return response;
        }
        //The logic in After function expects "---" for day and "--" for month. 
        //Since hyphen was missing the date always returned null
        public DateTime? ConvertToDate(int day, int month, int year)
        {
            return ConvertToDate(day == 0 ? null : "---" + day.ToString(), month == 0 ? null : "--" + month.ToString(), year == 0 ? null : year.ToString());
        }

        public DateTime? ConvertToDate(string day, string month, string year)
        {
            DateTime? response;
            DateTime result;

            if (year == null || month == null || day == null)
            {
                return null;
            }
            string dateAsString = year + "-" + After(month, "--") + "-" + After(day, "---");
            if (DateTime.TryParse(dateAsString, out result))
            {
                response = result;
            }
            else
            {
                response = null;
            }
            return response;
        }


        public DateTime? ConvertToDate(string day, string month, int year)
        {
            DateTime? response;
            DateTime result;

            if (year == 0 || month == null || day == null)
            {
                return null;
            }
            string dateAsString = year.ToString() + "-" + After(month, "--") + "-" + After(day, "---");
            if (DateTime.TryParse(dateAsString, out result))
            {
                response = result;
            }
            else
            {
                response = null;
            }
            return response;
        }


        private static int Day(string dateAsString)
        {
            int response = 0;
            DateTime date;

            if (DateTime.TryParse(dateAsString, out date))
            {
                response = date.Day;
            }

            return response;
        }


        private static int Day(DateTime? date)
        {
            if (date == null)
                return 0;
            else
                return date.Value.Day;

        }


        private static string Month(string dateAsString)
        {
            string response = null;
            DateTime date;

            if (DateTime.TryParse(dateAsString, out date))
            {
                response = date.ToString("MMMM");
            }
            else
            {
                return "NotAMonth";
            }

            return response;
        }

        private static string Month(DateTime? date)
        {
            if (date == null)
                return "NotAMonth";
            else
                return date.Value.ToString("MMMM");
        }


        private static int MonthAsInt(string dateAsString)
        {
            int response = 0;
            DateTime date;

            if (DateTime.TryParse(dateAsString, out date))
            {
                response = date.Month;
            }

            return response;
        }

        private static int MonthAsInt(DateTime? date)
        {
            if (date == null)
            {
                return 0;
            }
            return date.Value.Month;
        }


        private static int Year(string dateAsString)
        {
            int response = 0;
            DateTime date;

            if (DateTime.TryParse(dateAsString, out date))
            {
                response = date.Year;
            }

            return response;
        }

        private static int Year(DateTime? date)
        {
            if (date == null)
                return 0;
            else
                return date.Value.Year;
        }


        private static int CurrentFinancialYear()
        {
            return DateToFinancialYear(DateTime.Now, 7);
        }

        private static int FinancialYear(string dateAsString)
        {
            return DateToFinancialYear(dateAsString, 7);
        }

        private static int FinancialYear(DateTime? date)
        {
            return DateToFinancialYear(date, 7);
        }

        private static int DateToFinancialYear(string dateAsString, int startingMonth)
        {
            int response = 0;
            DateTime date;
            if (DateTime.TryParse(dateAsString, out date))
            {
                response = DateToFinancialYear(date, startingMonth);
            }

            return response;
        }
        private static int DateToFinancialYear(DateTime? date, int startingMonth)
        {
            int response;
            if (date == null)
            {
                response = 0;
            }
            else
            {
                int year = date.Value.Year;
                int month = date.Value.Month;

                if (startingMonth > month)
                    response = year;
                else
                    response = year + 1;
            }
            return response;
        }


        private static int FBTYear(string dateAsString)
        {
            int response = 0;
            DateTime date;

            if (DateTime.TryParse(dateAsString, out date))
                response = FBTYear(date);
            return response;
        }

        private static int FBTYear(DateTime? date)
        {
            if (date == null)
            {
                return 0;
            }
            else
            {
                if (date.Value.Month > 3)
                    return date.Value.Year + 1;
                else
                    return date.Value.Year;
            }
        }

        private static DateTime? AddMonthsToDate(DateTime? dateTime, int months)
        {
            return dateTime == null ? null : (DateTime?)dateTime.Value.AddMonths(months);
        }

        private static bool IsNumeric(object value)
        {
            decimal numbervalue;
            return (value != null && decimal.TryParse(value.ToString(), out numbervalue));
        }

        private static bool NotMonetary(decimal? field, string sign, int digits, int decimals)
        {
            if (field == null)
            {
                return false;
            }
            else
            {
                string signExpression;
                string decimalExpression;
                int digitsToUse = digits - decimals;

                if (sign == "U")
                    signExpression = "^";
                else
                    signExpression = "^-?";

                if (decimals > 0)
                    decimalExpression = @"(\.\d{1," + decimals + "})?$";
                else
                    decimalExpression = @"$";

                return !(Regex.IsMatch(field.Value.ToString("0.#########################"), signExpression + @"\d{1," + digitsToUse + "}" + decimalExpression));
            }
        }

        private static bool NotNumeric(decimal? field, string sign, int digits, int decimals)
        {
            if (field == null)
            {
                return false;
            }
            else
            {
                string signExpression;
                string decimalExpression;
                int digitsToUse = digits - decimals;

                if (sign == "U")
                    signExpression = "^";
                else
                    signExpression = "^-?";

                if (decimals > 0)
                    decimalExpression = @"(\.\d{1," + decimals + "})?$";
                else
                    decimalExpression = @"$";

                return !(Regex.IsMatch(field.Value.ToString("0.#########################"), signExpression + @"\d{1," + digitsToUse + "}" + decimalExpression));
            }
        }

        private static bool NotNumeric(int? field, string sign, int digits, int decimals = 0)
        {
            if (field == null)
            {
                return false;
            }
            else
            {
                string signExpression;

                if (sign == "U")
                    signExpression = "^";
                else
                    signExpression = "^-?";

                return !(Regex.IsMatch(field.Value.ToString(), signExpression + @"\d{1," + digits + "}$"));
            }
        }

        private static bool NotNumeric(long? field, string sign, int digits, int decimals = 0)
        {
            if (field == null)
            {
                return false;
            }
            else
            {
                string signExpression;

                if (sign == "U")
                    signExpression = "^";
                else
                    signExpression = "^-?";

                return !(Regex.IsMatch(field.Value.ToString(), signExpression + @"\d{1," + digits + "}$"));
            }
        }


        private static bool OutsideRange(decimal field, decimal expression, int range)
        {
            bool response;

            response = (field < (expression - range)) || (field > (expression + range));

            return response;
        }


        private static bool FailsUSIAlgorithm(string usi, string abn)
        {
            bool response;
            if (usi == null || abn == null)
            {
                response = false;
            }
            else
            {
                usi = usi.Trim();
                abn = abn.Trim();
                if (usi.Length < 13 || abn.Length < 11)
                {
                    response = false;
                }
                else
                {
                    int numeric;
                    if (usi.Substring(0, 11) == abn && int.TryParse(usi.Substring(11, 2), out numeric))
                        response = false;
                    else if (Regex.IsMatch(usi, @"^[a-zA-Z]{3}\d{4}[a-zA-Z]{2}"))
                        response = false;
                    else
                        response = true;
                }
            }
            return response;
        }


        private static bool FailsTANAlgorithm(string tan)
        {
            bool response;
            decimal decimalTan;

            if (tan == null)
                return false;

            tan = tan.Trim();

            if (!decimal.TryParse(tan, out decimalTan))
                return true;

            if (tan.Length != 8)
                return true;

            decimal tanSum =
                7 * int.Parse(tan.Substring(0, 1)) +
                9 * int.Parse(tan.Substring(1, 1)) +
                8 * int.Parse(tan.Substring(2, 1)) +
                4 * int.Parse(tan.Substring(3, 1)) +
                6 * int.Parse(tan.Substring(4, 1)) +
                3 * int.Parse(tan.Substring(5, 1)) +
                5 * int.Parse(tan.Substring(6, 1)) +
                1 * int.Parse(tan.Substring(7, 1));

            if ((tanSum % 11) == 0)
                response = false;
            else
                response = true;

            return response;
        }


        private static bool FailsABNAlgorithm(string abn)
        {
            bool response;
            decimal decimalAbn;

            if (abn == null)
                return false;

            abn = abn.Trim();

            if (!decimal.TryParse(abn, out decimalAbn))
                return true;

            if (abn.Length != 11)
                return true;

            decimal abnSum =
                10 * (int.Parse(abn.Substring(0, 1)) - 1) +
                1 * int.Parse(abn.Substring(1, 1)) +
                3 * int.Parse(abn.Substring(2, 1)) +
                5 * int.Parse(abn.Substring(3, 1)) +
                7 * int.Parse(abn.Substring(4, 1)) +
                9 * int.Parse(abn.Substring(5, 1)) +
                11 * int.Parse(abn.Substring(6, 1)) +
                13 * int.Parse(abn.Substring(7, 1)) +
                15 * int.Parse(abn.Substring(8, 1)) +
                17 * int.Parse(abn.Substring(9, 1)) +
                19 * int.Parse(abn.Substring(10, 1));

            if ((abnSum % 89) == 0)
                response = false;
            else
                response = true;

            return response;
        }
        private static bool FailsACNAlgorithm(string acn)
        {
            bool response;
            decimal decimalAbn;
            if (acn == null)
                return false;

            acn = acn.Trim();

            if (!decimal.TryParse(acn, out decimalAbn))
                return true;

            if (acn.Length != 9)
                return true;

            decimal abnSum =
                8 * int.Parse(acn.Substring(0, 1)) +
                7 * int.Parse(acn.Substring(1, 1)) +
                6 * int.Parse(acn.Substring(2, 1)) +
                5 * int.Parse(acn.Substring(3, 1)) +
                4 * int.Parse(acn.Substring(4, 1)) +
                3 * int.Parse(acn.Substring(5, 1)) +
                2 * int.Parse(acn.Substring(6, 1)) +
                1 * int.Parse(acn.Substring(7, 1));

            decimal checkDigit = int.Parse(acn.Substring(8, 1));
            decimal acnRemainder = abnSum % 10;

            if (((10 - acnRemainder) % 10) == checkDigit)
                response = false;
            else
                response = true;

            return response;
        }


        private static bool FailsTFNAlgorithm(string tfn)
        {
            bool response;
            decimal decimalTfn;

            if (tfn == null)
                return false;

            tfn = tfn.Trim();
            tfn = Regex.Replace(tfn, "^0+", "");

            if (!decimal.TryParse(tfn, out decimalTfn))
                return true;

            if (tfn.Length < 8)
                return true;


            decimal tfn1To7Sum =
                1 * int.Parse(tfn.Substring(0, 1)) +
                4 * int.Parse(tfn.Substring(1, 1)) +
                3 * int.Parse(tfn.Substring(2, 1)) +
                7 * int.Parse(tfn.Substring(3, 1)) +
                5 * int.Parse(tfn.Substring(4, 1)) +
                8 * int.Parse(tfn.Substring(5, 1)) +
                6 * int.Parse(tfn.Substring(6, 1));

            decimal tfn8 = 9 * int.Parse(tfn.Substring(7, 1));

            if (tfn.Length == 8)
            {
                decimal tFNLg8WSum9 = 10 * int.Parse(tfn.Substring(7, 1));
                decimal tFNLg8WSum = tfn1To7Sum + tFNLg8WSum9;

                if ((tFNLg8WSum % 11) == 0)
                    response = false;
                else
                    response = true;
            }
            else if (tfn.Length == 9)
            {
                decimal tfn9 = 10 * int.Parse(tfn.Substring(8, 1));
                decimal tFNLg9WSum = tfn1To7Sum + tfn8 + tfn9;

                if ((tFNLg9WSum % 11) == 0)
                    response = false;
                else
                    response = true;
            }
            else
            {
                response = true;
            }

            return response;
        }


        private static decimal ConditionalValue(bool expression, decimal? trueVal, decimal? falseVal)
        {
            return expression ? trueVal.GetValueOrDefault() : falseVal.GetValueOrDefault();
        }

        private static decimal AsNumeric(string value)
        {
            decimal numberValue;
            decimal.TryParse(value, out numberValue);
            return numberValue;
        }

        private static bool RegexMatch(int? field, string expression, string flags = "")
        {
            return IsMatch(field, expression, GetRegexOption(flags));
        }

        private static bool RegexMatch(string field, string expression, string flags = "")
        {
            return IsMatch(field, expression, GetRegexOption(flags));
        }

        private static RegexOptions GetRegexOption(string flags)
        {
            RegexOptions options = RegexOptions.None;

            char[] characters = flags.ToCharArray();

            foreach (char character in characters)
            {
                switch (character)
                {
                    case 'i':
                        options = options | RegexOptions.IgnoreCase;
                        break;
                    case 'm':
                        options = options | RegexOptions.Multiline;
                        break;
                    case 's':
                        options = options | RegexOptions.Singleline;
                        break;
                    case 'n':
                        options = options | RegexOptions.ExplicitCapture;
                        break;
                    case 'x':
                        options = options | RegexOptions.IgnorePatternWhitespace;
                        break;
                }
            }

            return options;
        }

        /// <summary>
        /// Returns an occurrence index as [occurrenceIndex] of occurrenceIndex > 0, otherwise the empty string
        /// </summary>
        /// <param name="occurrenceIndex">Index of the occurrence.</param>
        /// <returns>Occurrence in XPath [#] format</returns>
        public string OccurrenceIndex(int occurrenceIndex)
        {
            return occurrenceIndex > 0 ? "[" + occurrenceIndex + "]" : "";
        }

        #endregion // Functions

        public IDS2017 ConsumedReport { get; private set; }

        private static Dictionary<string, ProcessMessageDocument> _processMessageDocuments = new Dictionary<string, ProcessMessageDocument>();

        [MethodImpl(MethodImplOptions.AggressiveInlining)]
        public List<ProcessMessageDocument> ValidateReport(IDS2017 report)
        {

            List<ProcessMessageDocument> response = new List<ProcessMessageDocument>();
            ProcessMessageDocument processMessage;
            ProcessMessageParameter parameter;
            bool assertion;

            this.ConsumedReport = report;

            // ------------------------------------------------------------------------------
            // Validations are now done in code.
            // This version supports full validation of a report - for those rules that have successfully parsed and could be generated.
            // Generated Validations include:
            //   - Validation logic in C#.
            //   - Production of errors in EBMS, SBR and SWS format.
            // 
            // The generation at this stage does not support the following - and has to be completed manually (later versions of the generation will do this for you)
            //   - Business Rules that did not parse.  The ESR team will help support you where this happens as an effort is being made to rectify these
            //   - You will get TODO tasks for those that the parser could not cope with
            // ------------------------------------------------------------------------------

            #region Manual Rules - Rules marked for manual coding

            #region VR.ATO.IDS.440003

            /*  VR.ATO.IDS.440003
                If the foreign country codes have been completed then the response to 'Did you have dealings with international related parties, apart from dealings with related parties located in specified countries?' must be 'Yes'.

            Legacy Rule Format:
                IF [IDS2] <> TRUE AND COUNT(SET(RP.{ForeignCountry}.{ActivityCode},RP.{ForeignCountry}):ANY ELEMENT <> NULL) > 0
                 RETURN VALIDATION MESSAGE
                ENDIF

                [IDS2] = IDS:RP:rvctc4.02.05:InternationalDealings.RelatedPartiesTransactions.Indicator

            Technical Business Rule Format:
                ^IDS2 <> TRUE AND (Count(^ForeignCountry) > 0 OR Count(^ForeignCountry2) > 0)

            Data Elements:

                RP:^IDS2 = rvctc4.02.05:InternationalDealings.RelatedPartiesTransactions.Indicator

                RP:^ForeignCountry = RP.{ForeignCountry}.{ActivityCode}

                RP:^ForeignCountry2 = RP.{ForeignCountry}
                */
            VRATOIDS440003(response, report);
            #endregion // VR.ATO.IDS.440003

            #region VR.ATO.IDS.440004

            /*  VR.ATO.IDS.440004
                        If there is a 'Yes' response to 'Did you have dealings with international related parties, apart from dealings with related parties located in specified countries?' then a foreign country code must be completed.

                    Legacy Rule Format:
                        IF [IDS2] = TRUE AND COUNT(SET(RP.{ForeignCountry}.{ActivityCode},RP.{ForeignCountry}):ANY ELEMENT <> NULL) = 0
                         RETURN VALIDATION MESSAGE
                        ENDIF

                        [IDS2] = IDS:RP:rvctc4.02.05:InternationalDealings.RelatedPartiesTransactions.Indicator

                Technical Business Rule Format:
                        ^IDS2 = TRUE AND Count(^ForeignCountry) = 0 AND Count(^ForeignCountry2) = 0

            Data Elements:

                        RP:^IDS2 = rvctc4.02.05:InternationalDealings.RelatedPartiesTransactions.Indicator

                        RP:^ForeignCountry = RP.{ForeignCountry}.{ActivityCode}

                        RP:^ForeignCountry2 = RP.{ForeignCountry}
                        */
            VRATOIDS440004(response, report);
            #endregion // VR.ATO.IDS.440004

            #region VR.ATO.IDS.440005

            /*  VR.ATO.IDS.440005
                        If an expenditure or revenue amount is completed at 'Did you have dealing with international related parties, apart from the dealings with related parties located in specified countries?' or 'Did you have dealings with international related parties located in specifed countries?', there must be at least one expenditure or revenue amount greater than zero at one of Questions 5, 6, 7, 8, 9, 10, 11 or 12.

                    Legacy Rule Format:
                        IF ANY OCCURRENCE OF ([IDS5] > 0 OR [IDS6] > 0 OR [IDS12] > 0 OR [IDS13] > 0) AND (([IDS17] = NULL OR [IDS17] =  0) AND ([IDS18] = NULL OR [IDS18] =  0) AND ([IDS22] = NULL OR [IDS22] =  0) AND ([IDS23] = NULL OR [IDS23] =  0) AND ([IDS26] = NULL OR [IDS26] =  0) AND ([IDS27] = NULL OR [IDS27] =  0) AND ([IDS31] = NULL OR [IDS31] =  0) AND ([IDS32] = NULL OR [IDS32] =  0) AND ([IDS36] = NULL OR [IDS36] =  0) AND ([IDS37] = NULL OR [IDS37] =  0) AND ([IDS40] = NULL OR [IDS40] =  0) AND ([IDS41] = NULL OR [IDS41] =  0) AND ([IDS44] = NULL OR [IDS44] =  0) AND ([IDS45] = NULL OR [IDS45] =  0) AND ([IDS48] = NULL OR [IDS48] =  0) AND ([IDS49] = NULL OR [IDS49] =  0) AND ([IDS52] = NULL OR [IDS52] =  0) AND ([IDS53] = NULL OR [IDS53] =  0) AND ([IDS56] = NULL OR [IDS56] =  0) AND ([IDS57] = NULL OR [IDS57] =  0) AND ([IDS60] = NULL OR [IDS60] =  0) AND ([IDS61] = NULL OR [IDS61] =  0) AND ([IDS64] = NULL OR [IDS64] =  0) AND ([IDS65] = NULL OR [IDS65] =  0) AND ([IDS68] = NULL OR [IDS68] =  0) AND ([IDS69] = NULL OR [IDS69] =  0) AND ([IDS72] = NULL OR [IDS72] =  0) AND ([IDS73] = NULL OR [IDS73] =  0) AND ([IDS76] = NULL OR [IDS76] =  0) AND ([IDS77] = NULL OR [IDS77] =  0) AND ([IDS82] = NULL OR [IDS82] =  0) AND ([IDS83] = NULL OR [IDS83] =  0) AND ([IDS89] = NULL OR [IDS89] =  0) AND ([IDS90] = NULL OR [IDS90] =  0) AND ([IDS93] = NULL OR [IDS93] =  0) AND ([IDS94] = NULL OR [IDS94] =  0) AND ([IDS102] = NULL OR [IDS102] =  0) AND ([IDS103] = NULL OR [IDS103] =  0) AND ([IDS106] = NULL OR [IDS106] =  0) AND ([IDS107] = NULL OR [IDS107] =  0) AND ([IDS110] = NULL OR [IDS110] =  0) AND ([IDS111] = NULL OR [IDS111] =  0) AND ([IDS114] = NULL OR [IDS114] =  0) AND ([IDS115] = NULL OR [IDS115] =  0) AND ([IDS118] = NULL OR [IDS118] =  0) AND ([IDS119] = NULL OR [IDS119] =  0) AND ([IDS124] = NULL OR [IDS124] =  0) AND ([IDS125] = NULL OR [IDS125] =  0))
                           RETURN VALIDATION MESSAGE
                        ENDIF

                        [IDS5] = IDS:RP.{ForeignCountry}.{ActivityCode}:bafpr1.02.16:Expense.Total.Amount
                        [IDS6] = IDS:RP.{ForeignCountry}.{ActivityCode}:bafpr1.02.26:Revenue.Total.Amount
                        [IDS12] = IDS:RP.{SpecifiedCountry}.{ActivityCode}:bafpr1.02.16:Expense.Total.Amount
                        [IDS13] = IDS:RP.{SpecifiedCountry}.{ActivityCode}:bafpr1.02.26:Revenue.Total.Amount
                        [IDS17] = IDS:RP.TangibleRevenue:bafpr1.02.16:Expense.Total.Amount
                        [IDS18] = IDS:RP.TangibleRevenue:bafpr1.02.26:Revenue.Total.Amount
                        [IDS22] = IDS:RP.Royalties:bafpr1.02.12:Expense.DeductionsTotal.Amount
                        [IDS23] = IDS:RP.Royalties:bafpr1.02.12:Income.IncludedInAssessableTotal.Amount
                        [IDS26] = IDS:RP.LicenceFees:bafpr1.02.12:Expense.DeductionsTotal.Amount
                        [IDS27] = IDS:RP.LicenceFees:bafpr1.02.12:Income.IncludedInAssessableTotal.Amount
                        [IDS31] = IDS:RP.RentLease:bafpr1.02.16:Expense.Total.Amount
                        [IDS32] = IDS:RP.RentLease:bafpr1.02.26:Revenue.Total.Amount
                        [IDS36] = IDS:RP.TreasuryRelated:bafpr1.02.16:Expense.Total.Amount
                        [IDS37] = IDS:RP.TreasuryRelated:bafpr1.02.26:Revenue.Total.Amount
                        [IDS40] = IDS:RP.ManagementAndAdmin:bafpr1.02.16:Expense.Total.Amount
                        [IDS41] = IDS:RP.ManagementAndAdmin:bafpr1.02.26:Revenue.Total.Amount
                        [IDS44] = IDS:RP.Insurance:bafpr1.02.16:Expense.Total.Amount
                        [IDS45] = IDS:RP.Insurance:bafpr1.02.26:Revenue.Total.Amount
                        [IDS48] = IDS:RP.Reinsurance:bafpr1.02.16:Expense.Total.Amount
                        [IDS49] = IDS:RP.Reinsurance:bafpr1.02.26:Revenue.Total.Amount
                        [IDS52] = IDS:RP.ResearchAndDevelopment:bafpr1.02.16:Expense.Total.Amount
                        [IDS53] = IDS:RP.ResearchAndDevelopment:bafpr1.02.26:Revenue.Total.Amount
                        [IDS56] = IDS:RP.SalesAndMarketing:bafpr1.02.16:Expense.Total.Amount
                        [IDS57] = IDS:RP.SalesAndMarketing:bafpr1.02.26:Revenue.Total.Amount
                        [IDS60] = IDS:RP.SoftwareAndITServices:bafpr1.02.16:Expense.Total.Amount
                        [IDS61] = IDS:RP.SoftwareAndITServices:bafpr1.02.26:Revenue.Total.Amount
                        [IDS64] = IDS:RP.Technical:bafpr1.02.16:Expense.Total.Amount
                        [IDS65] = IDS:RP.Technical:bafpr1.02.26:Revenue.Total.Amount
                        [IDS68] = IDS:RP.Logistics:bafpr1.02.16:Expense.Total.Amount
                        [IDS69] = IDS:RP.Logistics:bafpr1.02.26:Revenue.Total.Amount
                        [IDS72] = IDS:RP.AssetManagement:bafpr1.02.16:Expense.Total.Amount
                        [IDS73] = IDS:RP.AssetManagement:bafpr1.02.26:Revenue.Total.Amount
                        [IDS76] = IDS:RP.OtherServices:bafpr1.02.16:Expense.Total.Amount
                        [IDS77] = IDS:RP.OtherServices:bafpr1.02.26:Revenue.Total.Amount
                        [IDS82] = IDS:RP.Derivatives:bafpr1.02.16:Expense.Total.Amount
                        [IDS83] = IDS:RP.Derivatives:bafpr1.02.26:Revenue.Total.Amount
                        [IDS89] = IDS:RP.DebtFactoring:bafpr1.02.12:Expense.BookValue.Amount
                        [IDS90] = IDS:RP.DebtFactoring:bafpr1.02.12:Expense.Consideration.Amount
                        [IDS93] = IDS:RP.Securitisation:bafpr1.02.12:Expense.BookValue.Amount
                        [IDS94] = IDS:RP.Securitisation:bafpr1.02.12:Expense.Consideration.Amount
                        [IDS102] = IDS:RP.OtherInterest:bafpr1.02.16:Expense.Total.Amount
                        [IDS103] = IDS:RP.OtherInterest:bafpr1.02.26:Revenue.Total.Amount
                        [IDS106] = IDS:RP.OtherGuarantees:bafpr1.02.16:Expense.Total.Amount
                        [IDS107] = IDS:RP.OtherGuarantees:bafpr1.02.26:Revenue.Total.Amount
                        [IDS110] = IDS:RP.OtherInsurance:bafpr1.02.16:Expense.Total.Amount
                        [IDS111] = IDS:RP.OtherInsurance:bafpr1.02.26:Revenue.Total.Amount
                        [IDS114] = IDS:RP.OtherReinsurance:bafpr1.02.16:Expense.Total.Amount
                        [IDS115] = IDS:RP.OtherReinsurance:bafpr1.02.26:Revenue.Total.Amount
                        [IDS118] = IDS:RP.OtherFinancialDealings:bafpr1.02.16:Expense.Total.Amount
                        [IDS119] = IDS:RP.OtherFinancialDealings:bafpr1.02.26:Revenue.Total.Amount
                        [IDS124] = IDS:RP.OtherNotReportedRevenue:bafpr1.02.16:Expense.Total.Amount
                        [IDS125] = IDS:RP.OtherNotReportedRevenue:bafpr1.02.26:Revenue.Total.Amount

                Technical Business Rule Format:
                        (AnyOccurrence(^IDS5, ^IDS5 > 0) OR AnyOccurrence(^IDS6, ^IDS6 > 0) OR AnyOccurrence(^IDS12, ^IDS12 > 0) OR AnyOccurrence(^IDS13, ^IDS13 > 0)) AND ((^IDS17 = NULL OR ^IDS17 =  0) AND (^IDS18 = NULL OR ^IDS18 =  0) AND (^IDS22 = NULL OR ^IDS22 =  0) AND (^IDS23 = NULL OR ^IDS23 =  0) AND (^IDS26 = NULL OR ^IDS26 =  0) AND (^IDS27 = NULL OR ^IDS27 =  0) AND (^IDS31 = NULL OR ^IDS31 =  0) AND (^IDS32 = NULL OR ^IDS32 =  0) AND (^IDS36 = NULL OR ^IDS36 =  0) AND (^IDS37 = NULL OR ^IDS37 =  0) AND (^IDS40 = NULL OR ^IDS40 =  0) AND (^IDS41 = NULL OR ^IDS41 =  0) AND (^IDS44 = NULL OR ^IDS44 =  0) AND (^IDS45 = NULL OR ^IDS45 =  0) AND (^IDS48 = NULL OR ^IDS48 =  0) AND (^IDS49 = NULL OR ^IDS49 =  0) AND (^IDS52 = NULL OR ^IDS52 =  0) AND (^IDS53 = NULL OR ^IDS53 =  0) AND (^IDS56 = NULL OR ^IDS56 =  0) AND (^IDS57 = NULL OR ^IDS57 =  0) AND (^IDS60 = NULL OR ^IDS60 =  0) AND (^IDS61 = NULL OR ^IDS61 =  0) AND (^IDS64 = NULL OR ^IDS64 =  0) AND (^IDS65 = NULL OR ^IDS65 =  0) AND (^IDS68 = NULL OR ^IDS68 =  0) AND (^IDS69 = NULL OR ^IDS69 =  0) AND (^IDS72 = NULL OR ^IDS72 =  0) AND (^IDS73 = NULL OR ^IDS73 =  0) AND (^IDS76 = NULL OR ^IDS76 =  0) AND (^IDS77 = NULL OR ^IDS77 =  0) AND (^IDS82 = NULL OR ^IDS82 =  0) AND (^IDS83 = NULL OR ^IDS83 =  0) AND (^IDS89 = NULL OR ^IDS89 =  0) AND (^IDS90 = NULL OR ^IDS90 =  0) AND (^IDS93 = NULL OR ^IDS93 =  0) AND (^IDS94 = NULL OR ^IDS94 =  0) AND (^IDS102 = NULL OR ^IDS102 =  0) AND (^IDS103 = NULL OR ^IDS103 =  0) AND (^IDS106 = NULL OR ^IDS106 =  0) AND (^IDS107 = NULL OR ^IDS107 =  0) AND (^IDS110 = NULL OR ^IDS110 =  0) AND (^IDS111 = NULL OR ^IDS111 =  0) AND (^IDS114 = NULL OR ^IDS114 =  0) AND (^IDS115 = NULL OR ^IDS115 =  0) AND (^IDS118 = NULL OR ^IDS118 =  0) AND (^IDS119 = NULL OR ^IDS119 =  0) AND (^IDS124 = NULL OR ^IDS124 =  0) AND (^IDS125 = NULL OR ^IDS125 =  0))

            Data Elements:

                        RP.{ForeignCountry}.{ActivityCode}:^IDS5 = bafpr1.02.16:Expense.Total.Amount

                        RP.{ForeignCountry}.{ActivityCode}:^IDS6 = bafpr1.02.26:Revenue.Total.Amount

                        RP.{SpecifiedCountry}.{ActivityCode}:^IDS12 = bafpr1.02.16:Expense.Total.Amount

                        RP.{SpecifiedCountry}.{ActivityCode}:^IDS13 = bafpr1.02.26:Revenue.Total.Amount

                        RP.TangibleRevenue:^IDS17 = bafpr1.02.16:Expense.Total.Amount

                        RP.TangibleRevenue:^IDS18 = bafpr1.02.26:Revenue.Total.Amount

                        RP.Royalties:^IDS22 = bafpr1.02.12:Expense.DeductionsTotal.Amount

                        RP.Royalties:^IDS23 = bafpr1.02.12:Income.IncludedInAssessableTotal.Amount

                        RP.LicenceFees:^IDS26 = bafpr1.02.12:Expense.DeductionsTotal.Amount

                        RP.LicenceFees:^IDS27 = bafpr1.02.12:Income.IncludedInAssessableTotal.Amount

                        RP.RentLease:^IDS31 = bafpr1.02.16:Expense.Total.Amount

                        RP.RentLease:^IDS32 = bafpr1.02.26:Revenue.Total.Amount

                        RP.TreasuryRelated:^IDS36 = bafpr1.02.16:Expense.Total.Amount

                        RP.TreasuryRelated:^IDS37 = bafpr1.02.26:Revenue.Total.Amount

                        RP.ManagementAndAdmin:^IDS40 = bafpr1.02.16:Expense.Total.Amount

                        RP.ManagementAndAdmin:^IDS41 = bafpr1.02.26:Revenue.Total.Amount

                        RP.Insurance:^IDS44 = bafpr1.02.16:Expense.Total.Amount

                        RP.Insurance:^IDS45 = bafpr1.02.26:Revenue.Total.Amount

                        RP.Reinsurance:^IDS48 = bafpr1.02.16:Expense.Total.Amount

                        RP.Reinsurance:^IDS49 = bafpr1.02.26:Revenue.Total.Amount

                        RP.ResearchAndDevelopment:^IDS52 = bafpr1.02.16:Expense.Total.Amount

                        RP.ResearchAndDevelopment:^IDS53 = bafpr1.02.26:Revenue.Total.Amount

                        RP.SalesAndMarketing:^IDS56 = bafpr1.02.16:Expense.Total.Amount

                        RP.SalesAndMarketing:^IDS57 = bafpr1.02.26:Revenue.Total.Amount

                        RP.SoftwareAndITServices:^IDS60 = bafpr1.02.16:Expense.Total.Amount

                        RP.SoftwareAndITServices:^IDS61 = bafpr1.02.26:Revenue.Total.Amount

                        RP.Technical:^IDS64 = bafpr1.02.16:Expense.Total.Amount

                        RP.Technical:^IDS65 = bafpr1.02.26:Revenue.Total.Amount

                        RP.Logistics:^IDS68 = bafpr1.02.16:Expense.Total.Amount

                        RP.Logistics:^IDS69 = bafpr1.02.26:Revenue.Total.Amount

                        RP.AssetManagement:^IDS72 = bafpr1.02.16:Expense.Total.Amount

                        RP.AssetManagement:^IDS73 = bafpr1.02.26:Revenue.Total.Amount

                        RP.OtherServices:^IDS76 = bafpr1.02.16:Expense.Total.Amount

                        RP.OtherServices:^IDS77 = bafpr1.02.26:Revenue.Total.Amount

                        RP.Derivatives:^IDS82 = bafpr1.02.16:Expense.Total.Amount

                        RP.Derivatives:^IDS83 = bafpr1.02.26:Revenue.Total.Amount

                        RP.DebtFactoring:^IDS89 = bafpr1.02.12:Expense.BookValue.Amount

                        RP.DebtFactoring:^IDS90 = bafpr1.02.12:Expense.Consideration.Amount

                        RP.Securitisation:^IDS93 = bafpr1.02.12:Expense.BookValue.Amount

                        RP.Securitisation:^IDS94 = bafpr1.02.12:Expense.Consideration.Amount

                        RP.OtherInterest:^IDS102 = bafpr1.02.16:Expense.Total.Amount

                        RP.OtherInterest:^IDS103 = bafpr1.02.26:Revenue.Total.Amount

                        RP.OtherGuarantees:^IDS106 = bafpr1.02.16:Expense.Total.Amount

                        RP.OtherGuarantees:^IDS107 = bafpr1.02.26:Revenue.Total.Amount

                        RP.OtherInsurance:^IDS110 = bafpr1.02.16:Expense.Total.Amount

                        RP.OtherInsurance:^IDS111 = bafpr1.02.26:Revenue.Total.Amount

                        RP.OtherReinsurance:^IDS114 = bafpr1.02.16:Expense.Total.Amount

                        RP.OtherReinsurance:^IDS115 = bafpr1.02.26:Revenue.Total.Amount

                        RP.OtherFinancialDealings:^IDS118 = bafpr1.02.16:Expense.Total.Amount

                        RP.OtherFinancialDealings:^IDS119 = bafpr1.02.26:Revenue.Total.Amount

                        RP.OtherNotReportedRevenue:^IDS124 = bafpr1.02.16:Expense.Total.Amount

                        RP.OtherNotReportedRevenue:^IDS125 = bafpr1.02.26:Revenue.Total.Amount
                        */
            VRATOIDS440005(response, report);
            #endregion // VR.ATO.IDS.440005

            #region VR.ATO.IDS.440010

            /*  VR.ATO.IDS.440010
                        If the specified country codes have been completed then the response to 'Did you have dealings with international related parties located in specified countries?' must be 'Yes'.

                    Legacy Rule Format:
                        IF [IDS9] <> TRUE AND COUNT(SET(RP.{SpecifiedCountry}.{ActivityCode},RP.{SpecifiedCountry}):ANY ELEMENT <> NULL) > 0
                         RETURN VALIDATION MESSAGE
                        ENDIF

                        [IDS9] = IDS:RP:rvctc4.02.05:InternationalDealings.SpecifiedCountriesTransactions.Indicator

                Technical Business Rule Format:
                        ^IDS9 <> TRUE AND (Count(^SpecifiedCountry) > 0 OR Count(^SpecifiedCountry2) > 0)

            Data Elements:

                        RP:^IDS9 = rvctc4.02.05:InternationalDealings.SpecifiedCountriesTransactions.Indicator

                        RP:^SpecifiedCountry = RP.{SpecifiedCountry}.{ActivityCode}

                        RP:^SpecifiedCountry2 = RP.{SpecifiedCountry}
                        */
            VRATOIDS440010(response, report);
            #endregion // VR.ATO.IDS.440010

            #region VR.ATO.IDS.440011

            /*  VR.ATO.IDS.440011
                        If there is a 'Yes' response to 'Did you have dealings with international related parties located in specified countries?' then the specified country code must be completed.

                    Legacy Rule Format:
                        IF [IDS9] = TRUE AND COUNT(SET(RP.{SpecifiedCountry}.{ActivityCode},RP.{SpecifiedCountry}):ANY ELEMENT <> NULL) = 0
                         RETURN VALIDATION MESSAGE
                        ENDIF

                        [IDS9] = IDS:RP:rvctc4.02.05:InternationalDealings.SpecifiedCountriesTransactions.Indicator

                Technical Business Rule Format:
                        ^IDS9 = TRUE AND Count(^SpecifiedCountry) = 0 AND Count(^SpecifiedCountry2) = 0

            Data Elements:

                        RP:^IDS9 = rvctc4.02.05:InternationalDealings.SpecifiedCountriesTransactions.Indicator

                        RP:^SpecifiedCountry = RP.{SpecifiedCountry}.{ActivityCode}

                        RP:^SpecifiedCountry2 = RP.{SpecifiedCountry}
                        */
            VRATOIDS440011(response, report);
            #endregion // VR.ATO.IDS.440011

            #region VR.ATO.IDS.440045

            /*  VR.ATO.IDS.440045
                        If International related party dealings information has been completed for financial dealings for amounts borrowed, amounts loaned, interest, guarantees, insurance, reinsurance, foreign exchange or other financial dealings then the response to 'Did you have any dealings of a financial nature with international related parties?' must be 'True'.

                    Legacy Rule Format:
                        IF [IDS97] <> TRUE AND ([IDS98] <> NULL OR [IDS99] <> NULL OR [IDS100] <> NULL OR [IDS101] <> NULL OR [IDS102] <> NULL OR [IDS103] <> NULL OR [IDS104] <> NULL OR [IDS105] <> NULL OR [IDS106] <> NULL OR [IDS107] <> NULL OR [IDS108] <> NULL OR [IDS109] <> NULL OR [IDS110] <>NULL OR [IDS111] <> NULL OR [IDS112] <> NULL OR [IDS113] <> NULL OR [IDS114] <> NULL OR [IDS115] <> NULL OR [IDS116] <> NULL OR [IDS117] <> NULL OR [IDS118] <> NULL OR [IDS119] <> NULL OR [IDS120] <> NULL OR [IDS121] <> NULL OR [IDS122] <> NULL OR [IDS333] <> NULL OR [IDS336] <> NULL OR [IDS337] <> NULL OR [IDS338] <> NULL OR [IDS339] <> NULL)
                         RETURN VALIDATION MESSAGE
                        ENDIF

                        [IDS97] = IDS:RP:rvctc4.02.05:InternationalDealings.OtherFinancialDealings.Indicator
                        [IDS98] = IDS:RP.OtherFinancialDealings.InterestBearing:bafpo1.02.11:Liabilities.BorrowedAverageBalance.Amount
                        [IDS99] = IDS:RP.OtherFinancialDealings.InterestFree:bafpo1.02.11:Liabilities.BorrowedAverageBalance.Amount
                        [IDS100] = IDS:RP.OtherFinancialDealings.InterestBearing:bafpo1.02.11:Assets.LoanedAverageBalance.Amount
                        [IDS101] = IDS:RP.OtherFinancialDealings.InterestFree:bafpo1.02.11:Assets.LoanedAverageBalance.Amount
                        [IDS102] = IDS:RP.OtherInterest:bafpr1.02.16:Expense.Total.Amount
                        [IDS103] = IDS:RP.OtherInterest:bafpr1.02.26:Revenue.Total.Amount
                        [IDS104] = IDS:RP.OtherInterest:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
                        [IDS105] = IDS:RP.OtherInterest:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
                        [IDS106] = IDS:RP.OtherGuarantees:bafpr1.02.16:Expense.Total.Amount
                        [IDS107] = IDS:RP.OtherGuarantees:bafpr1.02.26:Revenue.Total.Amount
                        [IDS108] = IDS:RP.OtherGuarantees:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
                        [IDS109] = IDS:RP.OtherGuarantees:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
                        [IDS110] = IDS:RP.OtherInsurance:bafpr1.02.16:Expense.Total.Amount
                        [IDS111] = IDS:RP.OtherInsurance:bafpr1.02.26:Revenue.Total.Amount
                        [IDS112] = IDS:RP.OtherInsurance:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
                        [IDS113] = IDS:RP.OtherInsurance:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
                        [IDS114] = IDS:RP.OtherReinsurance:bafpr1.02.16:Expense.Total.Amount
                        [IDS115] = IDS:RP.OtherReinsurance:bafpr1.02.26:Revenue.Total.Amount
                        [IDS116] = IDS:RP.OtherReinsurance:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
                        [IDS117] = IDS:RP.OtherReinsurance:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
                        [IDS118] = IDS:RP.OtherFinancialDealings:bafpr1.02.16:Expense.Total.Amount
                        [IDS119] = IDS:RP.OtherFinancialDealings:bafpr1.02.26:Revenue.Total.Amount
                        [IDS120] = IDS:RP.OtherFinancialDealings:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
                        [IDS121] = IDS:RP.OtherFinancialDealings:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
                        [IDS122] = IDS:RP.OtherFinancialDealings:rvctc4.02.05:InternationalDealings.Description.Text
                        [IDS333] = IDS:RP:rvctc4.02.13:InternationalDealings.ForeignExchangeGainLoss.Indicator
                        [IDS336] = IDS:RP.{TransactionType}.{CurrencyCode}:rvctc4.02.13:InternationalDealings.ForeignExchangeLossesHighestNominal.Amount
                        [IDS337] = IDS:RP.{TransactionType}.{CurrencyCode}:rvctc4.02.13:InternationalDealings.ForeignExchangeGainsHighestNominal.Amount
                        [IDS338] = IDS:RP.{TransactionType}:rvctc4.02.13:InternationalDealings.ForeignExchangeLossesOther.Amount
                        [IDS339] = IDS:RP.{TransactionType}:rvctc4.02.13:InternationalDealings.ForeignExchangeGainsOther.Amount

                Technical Business Rule Format:
                        ^IDS97 <> TRUE AND (^IDS98 <> NULL OR ^IDS99 <> NULL OR ^IDS100 <> NULL OR ^IDS101 <> NULL OR ^IDS102 <> NULL OR ^IDS103 <> NULL OR ^IDS104 <> NULL OR ^IDS105 <> NULL OR ^IDS106 <> NULL OR ^IDS107 <> NULL OR ^IDS108 <> NULL OR ^IDS109 <> NULL OR ^IDS110 <> NULL OR ^IDS111 <> NULL OR ^IDS112 <> NULL OR ^IDS113 <> NULL OR ^IDS114 <> NULL OR ^IDS115 <> NULL OR ^IDS116 <> NULL OR ^IDS117 <> NULL OR ^IDS118 <> NULL OR ^IDS119 <> NULL OR ^IDS120 <> NULL OR ^IDS121 <> NULL OR ^IDS122 <> NULL OR ^IDS333 <> NULL OR ^IDS336 <> NULL OR ^IDS337 <> NULL OR ^IDS338 <> NULL OR ^IDS339 <> NULL)

            Data Elements:

                        RP:^IDS97 = rvctc4.02.05:InternationalDealings.OtherFinancialDealings.Indicator

                        RP.OtherFinancialDealings.InterestBearing:^IDS98 = bafpo1.02.11:Liabilities.BorrowedAverageBalance.Amount

                        RP.OtherFinancialDealings.InterestFree:^IDS99 = bafpo1.02.11:Liabilities.BorrowedAverageBalance.Amount

                        RP.OtherFinancialDealings.InterestBearing:^IDS100 = bafpo1.02.11:Assets.LoanedAverageBalance.Amount

                        RP.OtherFinancialDealings.InterestFree:^IDS101 = bafpo1.02.11:Assets.LoanedAverageBalance.Amount

                        RP.OtherInterest:^IDS102 = bafpr1.02.16:Expense.Total.Amount

                        RP.OtherInterest:^IDS103 = bafpr1.02.26:Revenue.Total.Amount

                        RP.OtherInterest:^IDS104 = bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code

                        RP.OtherInterest:^IDS105 = bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code

                        RP.OtherGuarantees:^IDS106 = bafpr1.02.16:Expense.Total.Amount

                        RP.OtherGuarantees:^IDS107 = bafpr1.02.26:Revenue.Total.Amount

                        RP.OtherGuarantees:^IDS108 = bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code

                        RP.OtherGuarantees:^IDS109 = bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code

                        RP.OtherInsurance:^IDS110 = bafpr1.02.16:Expense.Total.Amount

                        RP.OtherInsurance:^IDS111 = bafpr1.02.26:Revenue.Total.Amount

                        RP.OtherInsurance:^IDS112 = bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code

                        RP.OtherInsurance:^IDS113 = bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code

                        RP.OtherReinsurance:^IDS114 = bafpr1.02.16:Expense.Total.Amount

                        RP.OtherReinsurance:^IDS115 = bafpr1.02.26:Revenue.Total.Amount

                        RP.OtherReinsurance:^IDS116 = bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code

                        RP.OtherReinsurance:^IDS117 = bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code

                        RP.OtherFinancialDealings:^IDS118 = bafpr1.02.16:Expense.Total.Amount

                        RP.OtherFinancialDealings:^IDS119 = bafpr1.02.26:Revenue.Total.Amount

                        RP.OtherFinancialDealings:^IDS120 = bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code

                        RP.OtherFinancialDealings:^IDS121 = bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code

                        RP.OtherFinancialDealings:^IDS122 = rvctc4.02.05:InternationalDealings.Description.Text

                        RP:^IDS333 = rvctc4.02.13:InternationalDealings.ForeignExchangeGainLoss.Indicator

                        RP.{TransactionType}.{CurrencyCode}:^IDS336 = rvctc4.02.13:InternationalDealings.ForeignExchangeLossesHighestNominal.Amount

                        RP.{TransactionType}.{CurrencyCode}:^IDS337 = rvctc4.02.13:InternationalDealings.ForeignExchangeGainsHighestNominal.Amount

                        RP.{TransactionType}:^IDS338 = rvctc4.02.13:InternationalDealings.ForeignExchangeLossesOther.Amount

                        RP.{TransactionType}:^IDS339 = rvctc4.02.13:InternationalDealings.ForeignExchangeGainsOther.Amount
                        */
            VRATOIDS440045(response, report);
            #endregion // VR.ATO.IDS.440045

            #region VR.ATO.IDS.440046

            /*  VR.ATO.IDS.440046
                        If securitisation information has been completed then book value or consideration, main pricing methodology code and percentage of dealings with documentation code must be completed

                    Legacy Rule Format:
                        IF ([IDS97] = TRUE AND [IDS98] = NULL AND [IDS99] = NULL AND [IDS100] = NULL AND [IDS101] = NULL AND [IDS102] = NULL AND [IDS103] = NULL AND [IDS104] = NULL AND [IDS105] = NULL AND [IDS106] = NULL AND [IDS107] = NULL AND [IDS108] = NULL AND [IDS109] = NULL AND [IDS110] = NULL AND [IDS111] = NULL AND [IDS112] = NULL AND [IDS113] = NULL AND [IDS114] = NULL AND [IDS115] = NULL AND [IDS116] = NULL AND [IDS117] = NULL AND [IDS118] = NULL AND [IDS119] = NULL AND [IDS120] = NULL AND [IDS121] = NULL AND [IDS122] = NULL AND [IDS333] = NULL AND [IDS336] = NULL AND [IDS337] = NULL AND [IDS338] = NULL AND [IDS339] = NULL)
                         RETURN VALIDATION MESSAGE
                        ENDIF

                        [IDS97] = IDS:RP:rvctc4.02.05:InternationalDealings.OtherFinancialDealings.Indicator
                        [IDS98] = IDS:RP.OtherFinancialDealings.InterestBearing:bafpo1.02.11:Liabilities.BorrowedAverageBalance.Amount
                        [IDS99] = IDS:RP.OtherFinancialDealings.InterestFree:bafpo1.02.11:Liabilities.BorrowedAverageBalance.Amount
                        [IDS100] = IDS:RP.OtherFinancialDealings.InterestBearing:bafpo1.02.11:Assets.LoanedAverageBalance.Amount
                        [IDS101] = IDS:RP.OtherFinancialDealings.InterestFree:bafpo1.02.11:Assets.LoanedAverageBalance.Amount
                        [IDS102] = IDS:RP.OtherInterest:bafpr1.02.16:Expense.Total.Amount
                        [IDS103] = IDS:RP.OtherInterest:bafpr1.02.26:Revenue.Total.Amount
                        [IDS104] = IDS:RP.OtherInterest:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
                        [IDS105] = IDS:RP.OtherInterest:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
                        [IDS106] = IDS:RP.OtherGuarantees:bafpr1.02.16:Expense.Total.Amount
                        [IDS107] = IDS:RP.OtherGuarantees:bafpr1.02.26:Revenue.Total.Amount
                        [IDS108] = IDS:RP.OtherGuarantees:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
                        [IDS109] = IDS:RP.OtherGuarantees:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
                        [IDS110] = IDS:RP.OtherInsurance:bafpr1.02.16:Expense.Total.Amount
                        [IDS111] = IDS:RP.OtherInsurance:bafpr1.02.26:Revenue.Total.Amount
                        [IDS112] = IDS:RP.OtherInsurance:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
                        [IDS113] = IDS:RP.OtherInsurance:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
                        [IDS114] = IDS:RP.OtherReinsurance:bafpr1.02.16:Expense.Total.Amount
                        [IDS115] = IDS:RP.OtherReinsurance:bafpr1.02.26:Revenue.Total.Amount
                        [IDS116] = IDS:RP.OtherReinsurance:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
                        [IDS117] = IDS:RP.OtherReinsurance:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
                        [IDS118] = IDS:RP.OtherFinancialDealings:bafpr1.02.16:Expense.Total.Amount
                        [IDS119] = IDS:RP.OtherFinancialDealings:bafpr1.02.26:Revenue.Total.Amount
                        [IDS120] = IDS:RP.OtherFinancialDealings:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
                        [IDS121] = IDS:RP.OtherFinancialDealings:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
                        [IDS122] = IDS:RP.OtherFinancialDealings:rvctc4.02.05:InternationalDealings.Description.Text
                        [IDS333] = IDS:RP:rvctc4.02.13:InternationalDealings.ForeignExchangeGainLoss.Indicator
                        [IDS336] = IDS:RP.{TransactionType}.{CurrencyCode}:rvctc4.02.13:InternationalDealings.ForeignExchangeLossesHighestNominal.Amount
                        [IDS337] = IDS:RP.{TransactionType}.{CurrencyCode}:rvctc4.02.13:InternationalDealings.ForeignExchangeGainsHighestNominal.Amount
                        [IDS338] = IDS:RP.{TransactionType}:rvctc4.02.13:InternationalDealings.ForeignExchangeLossesOther.Amount
                        [IDS339] = IDS:RP.{TransactionType}:rvctc4.02.13:InternationalDealings.ForeignExchangeGainsOther.Amount

                Technical Business Rule Format:
                        ^IDS97 = TRUE AND ^IDS98 = NULL AND ^IDS99 = NULL AND ^IDS100 = NULL AND ^IDS101 = NULL AND ^IDS102 = NULL AND ^IDS103 = NULL AND ^IDS104 = NULL AND ^IDS105 = NULL AND ^IDS106 = NULL AND ^IDS107 = NULL AND ^IDS108 = NULL AND ^IDS109 = NULL AND ^IDS110 = NULL AND ^IDS111 = NULL AND ^IDS112 = NULL AND ^IDS113 = NULL AND ^IDS114 = NULL AND ^IDS115 = NULL AND ^IDS116 = NULL AND ^IDS117 = NULL AND ^IDS118 = NULL AND ^IDS119 = NULL AND ^IDS120 = NULL AND ^IDS121 = NULL AND ^IDS122 = NULL AND ^IDS333 = NULL AND AnyOccurrence(^IDS336, ^IDS336 = NULL) AND AnyOccurrence(^IDS337, ^IDS337 = NULL) AND AnyOccurrence(^IDS338, ^IDS338 = NULL) AND AnyOccurrence(^IDS339, ^IDS339 = NULL)

            Data Elements:

                        RP:^IDS97 = rvctc4.02.05:InternationalDealings.OtherFinancialDealings.Indicator

                        RP.OtherFinancialDealings.InterestBearing:^IDS98 = bafpo1.02.11:Liabilities.BorrowedAverageBalance.Amount

                        RP.OtherFinancialDealings.InterestFree:^IDS99 = bafpo1.02.11:Liabilities.BorrowedAverageBalance.Amount

                        RP.OtherFinancialDealings.InterestBearing:^IDS100 = bafpo1.02.11:Assets.LoanedAverageBalance.Amount

                        RP.OtherFinancialDealings.InterestFree:^IDS101 = bafpo1.02.11:Assets.LoanedAverageBalance.Amount

                        RP.OtherInterest:^IDS102 = bafpr1.02.16:Expense.Total.Amount

                        RP.OtherInterest:^IDS103 = bafpr1.02.26:Revenue.Total.Amount

                        RP.OtherInterest:^IDS104 = bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code

                        RP.OtherInterest:^IDS105 = bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code

                        RP.OtherGuarantees:^IDS106 = bafpr1.02.16:Expense.Total.Amount

                        RP.OtherGuarantees:^IDS107 = bafpr1.02.26:Revenue.Total.Amount

                        RP.OtherGuarantees:^IDS108 = bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code

                        RP.OtherGuarantees:^IDS109 = bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code

                        RP.OtherInsurance:^IDS110 = bafpr1.02.16:Expense.Total.Amount

                        RP.OtherInsurance:^IDS111 = bafpr1.02.26:Revenue.Total.Amount

                        RP.OtherInsurance:^IDS112 = bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code

                        RP.OtherInsurance:^IDS113 = bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code

                        RP.OtherReinsurance:^IDS114 = bafpr1.02.16:Expense.Total.Amount

                        RP.OtherReinsurance:^IDS115 = bafpr1.02.26:Revenue.Total.Amount

                        RP.OtherReinsurance:^IDS116 = bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code

                        RP.OtherReinsurance:^IDS117 = bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code

                        RP.OtherFinancialDealings:^IDS118 = bafpr1.02.16:Expense.Total.Amount

                        RP.OtherFinancialDealings:^IDS119 = bafpr1.02.26:Revenue.Total.Amount

                        RP.OtherFinancialDealings:^IDS120 = bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code

                        RP.OtherFinancialDealings:^IDS121 = bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code

                        RP.OtherFinancialDealings:^IDS122 = rvctc4.02.05:InternationalDealings.Description.Text

                        RP:^IDS333 = rvctc4.02.13:InternationalDealings.ForeignExchangeGainLoss.Indicator

                        RP.{TransactionType}.{CurrencyCode}:^IDS336 = rvctc4.02.13:InternationalDealings.ForeignExchangeLossesHighestNominal.Amount

                        RP.{TransactionType}.{CurrencyCode}:^IDS337 = rvctc4.02.13:InternationalDealings.ForeignExchangeGainsHighestNominal.Amount

                        RP.{TransactionType}:^IDS338 = rvctc4.02.13:InternationalDealings.ForeignExchangeLossesOther.Amount

                        RP.{TransactionType}:^IDS339 = rvctc4.02.13:InternationalDealings.ForeignExchangeGainsOther.Amount
                        */
            VRATOIDS440046(response, report);
            #endregion // VR.ATO.IDS.440046

            #region VR.ATO.IDS.440075

            /*  VR.ATO.IDS.440075
                        If there is a 'No' response to 'Did a restructuring event occur in the current year involving international related parties or your branch operations?' then restructuring event information should not be completed.

                    Legacy Rule Format:
                        IF [IDS151] = FALSE AND COUNT(RP.{RestructuringEvent}:ANY ELEMENT <> NULL) > 0
                         RETURN VALIDATION MESSAGE
                        ENDIF

                        [IDS151] = IDS:RP:rvctc4.02.05:InternationalDealings.RestructuringEvents.Indicator

                Technical Business Rule Format:
                        ^IDS151 = FALSE AND Count(^RestructuringEvent) > 0

            Data Elements:

                        RP:^IDS151 = rvctc4.02.05:InternationalDealings.RestructuringEvents.Indicator

                        RP:^RestructuringEvent = RP.{RestructuringEvent}
                        */
            VRATOIDS440075(response, report);
            #endregion // VR.ATO.IDS.440075

            #region VR.ATO.IDS.440076

            /*  VR.ATO.IDS.440076
                        If there is a 'Yes' response to 'Did a restructuring event occur in the current year involving international related parties or your branch operations?' then restructuring event information must be completed.

                    Legacy Rule Format:
                        IF [IDS151] = TRUE AND COUNT(SET(RP.{RestructuringEvent}):ANY ELEMENT <> NULL) = 0
                         RETURN VALIDATION MESSAGE
                        ENDIF

                        [IDS151] = IDS:RP:rvctc4.02.05:InternationalDealings.RestructuringEvents.Indicator

                Technical Business Rule Format:
                        ^IDS151 = TRUE AND Count(^RestructuringEvent) = 0

            Data Elements:

                        RP:^IDS151 = rvctc4.02.05:InternationalDealings.RestructuringEvents.Indicator

                        RP:^RestructuringEvent = RP.{RestructuringEvent}
                        */
            VRATOIDS440076(response, report);
            #endregion // VR.ATO.IDS.440076

            #region VR.ATO.IDS.440080

            /*  VR.ATO.IDS.440080
                        If there is a 'No' response to 'Do you have any branch operations (including Australian branch operations if you are a non-resident)?' then amounts claimed or returned for internally recorded dealings with branch operations should not be completed.

                    Legacy Rule Format:
                        IF [IDS160] = FALSE AND ([IDS161] <> NULL AND [IDS162] <> NULL AND [IDS163] <> NULL AND [IDS164] <> NULL AND [IDS165] <> NULL AND [IDS166] <> NULL AND [IDS167] <> NULL AND [IDS168] <> NULL) AND COUNT(RP.BranchOperations.{InternallyRecordedDealings}:ANY ELEMENT <> NULL) > 0 
                         RETURN VALIDATION MESSAGE
                        ENDIF

                        [IDS160] = IDS:RP:rvctc4.02.05:InternationalDealings.BranchOperations.Indicator
                        [IDS161] = IDS:RP.BranchOperations.InterestBearing:bafpo1.02.11:Liabilities.BorrowedAverageBalance.Amount
                        [IDS162] = IDS:RP.BranchOperations.InterestBearing:bafpo1.02.11:Assets.LoanedAverageBalance.Amount
                        [IDS163] = IDS:RP.BranchOperations.InterestBearing:bafpr1.02.12:Expense.InterestBorrowedTotal.Amount
                        [IDS164] = IDS:RP.BranchOperations.InterestBearing:bafpr1.02.12:Income.InterestLoanedTotal.Amount
                        [IDS165] = IDS:RP.BranchOperations.InterestFree:bafpo1.02.11:Liabilities.BorrowedAverageBalance.Amount
                        [IDS166] = IDS:RP.BranchOperations.InterestFree:bafpo1.02.11:Assets.LoanedAverageBalance.Amount
                        [IDS167] = IDS:RP.BranchOperations:bafpr1.02.12:Expense.TradingStockPurchaseCosts.Amount
                        [IDS168] = IDS:RP.BranchOperations:bafpr1.02.12:Income.TradingStockSalesTotal.Amount

                Technical Business Rule Format:
                        ^IDS160 = FALSE AND (^IDS161 <> NULL AND ^IDS162 <> NULL AND ^IDS163 <> NULL AND ^IDS164 <>  NULL AND ^IDS165 <> NULL AND ^IDS166 <> NULL AND ^IDS167 <> NULL AND ^IDS168 <> NULL) AND (Count(^InternallyRecordedDealings) > 0)

            Data Elements:

                        RP:^IDS160 = rvctc4.02.05:InternationalDealings.BranchOperations.Indicator

                        RP.BranchOperations.InterestBearing:^IDS161 = bafpo1.02.11:Liabilities.BorrowedAverageBalance.Amount

                        RP.BranchOperations.InterestBearing:^IDS162 = bafpo1.02.11:Assets.LoanedAverageBalance.Amount

                        RP.BranchOperations.InterestBearing:^IDS163 = bafpr1.02.12:Expense.InterestBorrowedTotal.Amount

                        RP.BranchOperations.InterestBearing:^IDS164 = bafpr1.02.12:Income.InterestLoanedTotal.Amount

                        RP.BranchOperations.InterestFree:^IDS165 = bafpo1.02.11:Liabilities.BorrowedAverageBalance.Amount

                        RP.BranchOperations.InterestFree:^IDS166 = bafpo1.02.11:Assets.LoanedAverageBalance.Amount

                        RP.BranchOperations:^IDS167 = bafpr1.02.12:Expense.TradingStockPurchaseCosts.Amount

                        RP.BranchOperations:^IDS168 = bafpr1.02.12:Income.TradingStockSalesTotal.Amount

                        RP.BranchOperations:^InternallyRecordedDealings = RP.BranchOperations.{InternallyRecordedDealings}
                        */
            VRATOIDS440080(response, report);
            #endregion // VR.ATO.IDS.440080

            #region VR.ATO.IDS.440081

            /*  VR.ATO.IDS.440081
                        If there is a 'Yes' response to 'Do you have any branch operations (including Australian branch operations if you are a non-resident)?' then amounts claimed or returned for internally recorded dealings with branch operations must be completed.

                    Legacy Rule Format:
                        IF [IDS160] = TRUE AND ([IDS161] = NULL AND [IDS162] = NULL AND [IDS163] = NULL AND [IDS164] = NULL AND [IDS165] = NULL AND [IDS166] = NULL AND [IDS167] = NULL AND [IDS168] = NULL) AND COUNT (RP.BranchOperations.{InternallyRecordedDealings}:ANY ELEMENT <> NULL) = 0 
                         RETURN VALIDATION MESSAGE
                        ENDIF

                        [IDS160] = IDS:RP:rvctc4.02.05:InternationalDealings.BranchOperations.Indicator
                        [IDS161] = IDS:RP.BranchOperations.InterestBearing:bafpo1.02.11:Liabilities.BorrowedAverageBalance.Amount
                        [IDS162] = IDS:RP.BranchOperations.InterestBearing:bafpo1.02.11:Assets.LoanedAverageBalance.Amount
                        [IDS163] = IDS:RP.BranchOperations.InterestBearing:bafpr1.02.12:Expense.InterestBorrowedTotal.Amount
                        [IDS164] = IDS:RP.BranchOperations.InterestBearing:bafpr1.02.12:Income.InterestLoanedTotal.Amount
                        [IDS165] = IDS:RP.BranchOperations.InterestFree:bafpo1.02.11:Liabilities.BorrowedAverageBalance.Amount
                        [IDS166] = IDS:RP.BranchOperations.InterestFree:bafpo1.02.11:Assets.LoanedAverageBalance.Amount
                        [IDS167] = IDS:RP.BranchOperations:bafpr1.02.12:Expense.TradingStockPurchaseCosts.Amount
                        [IDS168] = IDS:RP.BranchOperations:bafpr1.02.12:Income.TradingStockSalesTotal.Amount

                Technical Business Rule Format:
                        ^IDS160 = TRUE AND (^IDS161 = NULL AND ^IDS162 = NULL AND ^IDS163 = NULL AND    ^IDS164 = NULL AND ^IDS165 = NULL AND ^IDS166 = NULL AND ^IDS167 = NULL AND ^IDS168 = NULL) AND (Count(^InternallyRecordedDealings) = 0)

            Data Elements:

                        RP:^IDS160 = rvctc4.02.05:InternationalDealings.BranchOperations.Indicator

                        RP.BranchOperations.InterestBearing:^IDS161 = bafpo1.02.11:Liabilities.BorrowedAverageBalance.Amount

                        RP.BranchOperations.InterestBearing:^IDS162 = bafpo1.02.11:Assets.LoanedAverageBalance.Amount

                        RP.BranchOperations.InterestBearing:^IDS163 = bafpr1.02.12:Expense.InterestBorrowedTotal.Amount

                        RP.BranchOperations.InterestBearing:^IDS164 = bafpr1.02.12:Income.InterestLoanedTotal.Amount

                        RP.BranchOperations.InterestFree:^IDS165 = bafpo1.02.11:Liabilities.BorrowedAverageBalance.Amount

                        RP.BranchOperations.InterestFree:^IDS166 = bafpo1.02.11:Assets.LoanedAverageBalance.Amount

                        RP.BranchOperations:^IDS167 = bafpr1.02.12:Expense.TradingStockPurchaseCosts.Amount

                        RP.BranchOperations:^IDS168 = bafpr1.02.12:Income.TradingStockSalesTotal.Amount

                        RP.BranchOperations:^InternallyRecordedDealings = RP.BranchOperations.{InternallyRecordedDealings}
                        */
            VRATOIDS440081(response, report);
            #endregion // VR.ATO.IDS.440081

            #region VR.ATO.IDS.440283

            /*  VR.ATO.IDS.440283
                        Count activity codes per foreign country

                    Legacy Rule Format:
                        FOR EACH ForeignCountry IN SET (RP.{ForeignCountry}.{ActivityCode})
                        IF COUNT (RP.{ForeignCountry}.{ActivityCode}) > 3
                         RETURN VALIDATION MESSAGE
                        ENDIF

                Technical Business Rule Format:
                        Count(^IDS353) > 3

            Data Elements:

                        RP.{ForeignCountry}.{ActivityCode}:^IDS353 = pyde.02.08:Residency.TaxPurposesCountry.Code
                        */
            VRATOIDS440283(response, report);
            #endregion // VR.ATO.IDS.440283

            #region VR.ATO.IDS.440286

            /*  VR.ATO.IDS.440286
                        Count activity codes per specified foreign country

                    Legacy Rule Format:
                        FOR EACH SpecifiedCountry IN SET (RP.{SpecifiedCountry}.{ActivityCode})
                        IF COUNT (RP.{SpecifiedCountry}.{ActivityCode}) > 3
                         RETURN VALIDATION MESSAGE
                        ENDIF

                Technical Business Rule Format:
                        Count(^IDS354) > 3

            Data Elements:

                        RP.{SpecifiedCountry}.{ActivityCode}:^IDS354 = pyde.02.08:Residency.TaxPurposesCountry.Code
                        */
            VRATOIDS440286(response, report);
            #endregion // VR.ATO.IDS.440286

            #region VR.ATO.IDS.440296

            /*  VR.ATO.IDS.440296
                        If Interests in foreign entities information has been completed for transfers of property, money or services then the response to 'During the last three income years, including the current income year, did you directly or indirectly transfer property, money or services to a non-resident trust, where that non-resident trust was still in existence during that income year?' must be 'Yes'.

                    Legacy Rule Format:
                        IF [IDS213] <> TRUE AND (COUNT(SET(RP.{TrustExemptionCode}):ANY ELEMENT <> NULL) > 0)
                         RETURN VALIDATION MESSAGE
                        ENDIF

                        [IDS213] = IDS:RP:bafot.02.11:Miscellaneous.TransferPropertyMoneyOrServices.Indicator

                Technical Business Rule Format:
                        ^IDS213 <> TRUE AND Count(^Context) > 0

            Data Elements:

                        RP:^IDS213 = bafot.02.11:Miscellaneous.TransferPropertyMoneyOrServices.Indicator

                        RP:^Context = RP.{TrustExemptionCode}
                        */
            VRATOIDS440296(response, report);
            #endregion // VR.ATO.IDS.440296

            #region VR.ATO.IDS.440423

            /*  VR.ATO.IDS.440423
                        If the currency codes have been completed then the response to 'Have you returned a foreign exchange gain or deducted a foreign exchange loss in relation to dealings with international related parties?' must be 'Yes'.

                    Legacy Rule Format:
                        IF [IDS333] <> TRUE AND COUNT(SET(RP.{TransactionType}.{CurrencyCode},RP.{TransactionType}):ANY ELEMENT <> NULL) > 0
                         RETURN VALIDATION MESSAGE
                        ENDIF

                        [IDS333] = IDS:RP:rvctc4.02.13:InternationalDealings.ForeignExchangeGainLoss.Indicator

                Technical Business Rule Format:
                        ^IDS333 <> TRUE AND (Count(^TransactionType) > 0 OR Count(^TransactionType2) > 0)

            Data Elements:

                        RP:^IDS333 = rvctc4.02.13:InternationalDealings.ForeignExchangeGainLoss.Indicator

                        RP:^TransactionType = RP.{TransactionType}.{CurrencyCode}

                        RP:^TransactionType2 = RP.{TransactionType}
                        */
            VRATOIDS440423(response, report);
            #endregion // VR.ATO.IDS.440423

            #region VR.ATO.IDS.440424

            /*  VR.ATO.IDS.440424
                        If there is a 'Yes' response to 'Have you returned a foreign exchange gain or deducted a foreign exchange loss in relation to dealings with international related parties? then at least one transaction type and one currency for the gain or loss must be completed.

                    Legacy Rule Format:
                        IF [IDS333] = TRUE AND COUNT(SET(RP.{TransactionType}.{CurrencyCode},RP.{TransactionType}):ANY ELEMENT <> NULL) = 0
                         RETURN VALIDATION MESSAGE
                        ENDIF

                        [IDS333] = IDS:RP:rvctc4.02.13:InternationalDealings.ForeignExchangeGainLoss.Indicator

                Technical Business Rule Format:
                        ^IDS333 = TRUE AND (Count(^TransactionType) > 0 OR Count(^TransactionType2) > 0)

            Data Elements:

                        RP:^IDS333 = rvctc4.02.13:InternationalDealings.ForeignExchangeGainLoss.Indicator

                        RP:^TransactionType = RP.{TransactionType}.{CurrencyCode}

                        RP:^TransactionType2 = RP.{TransactionType}
                        */
            VRATOIDS440424(response, report);
            #endregion // VR.ATO.IDS.440424

            #region VR.ATO.IDS.440425

            /*  VR.ATO.IDS.440425
                        In derivative transactions information the same principal derivative type code has been entered more than once. Each derivative code can only appear once.

                    Legacy Rule Format:
                        IF [IDS332] = ANY OTHER OCCURRENCE OF [IDS332] 
                         RETURN VALIDATION MESSAGE
                        ENDIF

                        [IDS332] = IDS:RP.Derivatives:rvctc4.02.13:InternationalDealings.RelatedPartyTransactionType.Code

                Technical Business Rule Format:
                        HasDuplicateValues(^IDS332)

            Data Elements:

                        RP.Derivatives:^IDS332 = rvctc4.02.13:InternationalDealings.RelatedPartyTransactionType.Code
                        */
            VRATOIDS440425(response, report);
            #endregion // VR.ATO.IDS.440425

            #region VR.ATO.IDS.440427

            /*  VR.ATO.IDS.440427
                        Can only have one occurrence of other currencies per transaction type

                    Legacy Rule Format:
                        IF CONTEXT(RP.TransactionType) = ANY OTHER OCCURRENCE OF CONTEXT(RP.TransactionType)
                         RETURN VALIDATION MESSAGE
                        ENDIF

                Technical Business Rule Format:
                        HasDuplicateValues(^IDS334)

            Data Elements:

                        RP.{TransactionType}:^IDS334 = rvctc4.02.13:InternationalDealings.TransactionType.Code
                        */
            VRATOIDS440427(response, report);
            #endregion // VR.ATO.IDS.440427

            #region VR.ATO.IDS.440431

            /*  VR.ATO.IDS.440431
                        Count currency codes per transaction type

                    Legacy Rule Format:
                        FOR EACH TransactionType IN SET (RP.{TransactionType}.{CurrencyCode})
                        IF COUNT (RP.{TransactionType}.{CurrencyCode}) > 3
                         RETURN VALIDATION MESSAGE
                        ENDIF

                Technical Business Rule Format:
                        Count(^IDS335) > 3

            Data Elements:

                        RP.{TransactionType}.{CurrencyCode}:^IDS335 = bafot.02.14:Miscellaneous.FunctionalCurrency.Code
                        */
            VRATOIDS440431(response, report);
            #endregion // VR.ATO.IDS.440431

            #region VR.ATO.IDS.440433

            /*  VR.ATO.IDS.440433
                        A foreign exchange gain or a loss must be provided for each currency reported.

                    Legacy Rule Format:
                        FOR EACH CurrencyCode IN SET (RP.{TransactionType}.{CurrencyCode}) IF ([IDS336] = 0 OR [IDS336] =NULL ) AND ([IDS337] = 0 OR [IDS337] = NULL)
                         RETURN VALIDATION MESSAGE
                        ENDIF

                        [IDS336] = IDS:RP.{TransactionType}.{CurrencyCode}:rvctc4.02.13:InternationalDealings.ForeignExchangeLossesHighestNominal.Amount
                        [IDS337] = IDS:RP.{TransactionType}.{CurrencyCode}:rvctc4.02.13:InternationalDealings.ForeignExchangeGainsHighestNominal.Amount

                Technical Business Rule Format:
                        (^IDS336 = 0 OR ^IDS336 = NULL) AND (^IDS337 = 0 OR ^IDS337 = NULL)

            Data Elements:

                        RP.{TransactionType}.{CurrencyCode}:^IDS336 = rvctc4.02.13:InternationalDealings.ForeignExchangeLossesHighestNominal.Amount

                        RP.{TransactionType}.{CurrencyCode}:^IDS337 = rvctc4.02.13:InternationalDealings.ForeignExchangeGainsHighestNominal.Amount
                        */
            VRATOIDS440433(response, report);
            #endregion // VR.ATO.IDS.440433

            #region VR.ATO.IDS.440434

            /*  VR.ATO.IDS.440434
                        Monetary field, must be unsigned, maximum of 11 chars, no decimals

                    Legacy Rule Format:
                        IF [IDS336] <> NULL AND [IDS336] <> MONETARY(U,11,0) 
                         RETURN VALIDATION MESSAGE
                        ENDIF

                        [IDS336] = IDS:RP.{TransactionType}.{CurrencyCode}:rvctc4.02.13:InternationalDealings.ForeignExchangeLossesHighestNominal.Amount

                Technical Business Rule Format:
                        NotMonetary(^IDS336, 'U', 11, 0)

            Data Elements:

                        RP.{TransactionType}.{CurrencyCode}:^IDS336 = rvctc4.02.13:InternationalDealings.ForeignExchangeLossesHighestNominal.Amount
                        */
            VRATOIDS440434(response, report);
            #endregion // VR.ATO.IDS.440434

            #region VR.ATO.IDS.440435

            /*  VR.ATO.IDS.440435
                        Monetary field, must be unsigned, maximum of 11 chars, no decimals

                    Legacy Rule Format:
                        IF [IDS337] <> NULL AND [IDS337] <> MONETARY(U,11,0) 
                         RETURN VALIDATION MESSAGE
                        ENDIF

                        [IDS337] = IDS:RP.{TransactionType}.{CurrencyCode}:rvctc4.02.13:InternationalDealings.ForeignExchangeGainsHighestNominal.Amount

                Technical Business Rule Format:
                        NotMonetary(^IDS337, 'U', 11, 0)

            Data Elements:

                        RP.{TransactionType}.{CurrencyCode}:^IDS337 = rvctc4.02.13:InternationalDealings.ForeignExchangeGainsHighestNominal.Amount
                        */
            VRATOIDS440435(response, report);
            #endregion // VR.ATO.IDS.440435

            #region VR.ATO.IDS.440449

            /*  VR.ATO.IDS.440449
                        The total of All other currencies - losses deducted cannot be zero and only one total amount can to be reported for each transaction type.

                    Legacy Rule Format:
                        FOR EACH TransactionType in SET(RP.{TransactionType})
                        IF ([IDS338] <> NULL) AND ([IDS338] = 0 OR COUNT([IDS338]) > 1)
                           RETURN VALIDATION MESSAGE
                        ENDIF

                        [IDS338] = IDS:RP.{TransactionType}:rvctc4.02.13:InternationalDealings.ForeignExchangeLossesOther.Amount

                Technical Business Rule Format:
                        FOR EACH TransactionType in SET(RP.{TransactionType})IF (^IDS338 <> NULL) AND (^IDS338 = 0 OR Count(^IDS338) > 1)

            Data Elements:

                        RP.{TransactionType}:^IDS338 = rvctc4.02.13:InternationalDealings.ForeignExchangeLossesOther.Amount
                        */
            VRATOIDS440449(response, report);
            #endregion // VR.ATO.IDS.440449

            #region VR.ATO.IDS.440450

            /*  VR.ATO.IDS.440450
                        The total of All other currencies - gains returned cannot be zero and only one total amount can to be reported for each transaction type.

                    Legacy Rule Format:
                        FOR EACH TransactionType in SET(RP.{TransactionType})
                        IF ([IDS339] <> NULL) AND ([IDS339] = 0 OR COUNT([IDS339]) > 1)
                           RETURN VALIDATION MESSAGE
                        ENDIF

                        [IDS339] = IDS:RP.{TransactionType}:rvctc4.02.13:InternationalDealings.ForeignExchangeGainsOther.Amount

                Technical Business Rule Format:
                        FOR EACH TransactionType in SET(RP.{TransactionType})IF (^IDS339 <> NULL) AND (^IDS339 = 0 OR Count(^IDS339) > 1)

            Data Elements:

                        RP.{TransactionType}:^IDS339 = rvctc4.02.13:InternationalDealings.ForeignExchangeGainsOther.Amount
                        */
            VRATOIDS440450(response, report);
            #endregion // VR.ATO.IDS.440450
            #endregion Manual Rules - Rules marked for manual coding

            #region VR.ATO.GEN.000209

            /*  VR.ATO.GEN.000209
            Invalid context. The number of ReportingParty contexts must equal 1
    
            Legacy Rule Format:
            IF COUNT(RP) <> 1
            RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Count(^Context) <> 1
    
            Data Elements:
    
            ^Context = RP
            */
            assertion = (Count(report.RPCount) != 1);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.430296",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid context. The number of Reporting party contexts must equal 1",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPLastOccurrenceIndex),
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.000209" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.000209

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP
    
            ^Context = RP
            */
            assertion = (report.RPExists != false && report.RPIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.Advisory
    
            ^Context = RP:RP.Advisory
            */
            assertion = (report.RPAdvisoryExists != false && report.RPAdvisoryIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPAdvisoryOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP.Advisory:RP.Advisory.RelatedParty
    
            ^Context = RP.Advisory:RP.Advisory.RelatedParty
            */
            assertion = (report.RPAdvisoryRelatedPartyExists != false && report.RPAdvisoryRelatedPartyIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPAdvisoryRelatedPartyOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.AssetManagement
    
            ^Context = RP:RP.AssetManagement
            */
            assertion = (report.RPAssetManagementExists != false && report.RPAssetManagementIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPAssetManagementOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.Borrowing
    
            ^Context = RP:RP.Borrowing
            */
            assertion = (report.RPBorrowingExists != false && report.RPBorrowingIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPBorrowingOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP.Borrowing:RP.Borrowing.RelatedParty
    
            ^Context = RP.Borrowing:RP.Borrowing.RelatedParty
            */
            assertion = (report.RPBorrowingRelatedPartyExists != false && report.RPBorrowingRelatedPartyIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPBorrowingRelatedPartyOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.BranchOperations
    
            ^Context = RP:RP.BranchOperations
            */
            assertion = (report.RPBranchOperationsExists != false && report.RPBranchOperationsIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPBranchOperationsOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP.BranchOperations:RP.BranchOperations.InterestBearing
    
            ^Context = RP.BranchOperations:RP.BranchOperations.InterestBearing
            */
            assertion = (report.RPBranchOperationsInterestBearingExists != false && report.RPBranchOperationsInterestBearingIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPBranchOperationsInterestBearingOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP.BranchOperations:RP.BranchOperations.InterestFree
    
            ^Context = RP.BranchOperations:RP.BranchOperations.InterestFree
            */
            assertion = (report.RPBranchOperationsInterestFreeExists != false && report.RPBranchOperationsInterestFreeIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPBranchOperationsInterestFreeOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.CapitalNonMonetaryPayment
    
            ^Context = RP:RP.CapitalNonMonetaryPayment
            */
            assertion = (report.RPCapitalNonMonetaryPaymentExists != false && report.RPCapitalNonMonetaryPaymentIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPCapitalNonMonetaryPaymentOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.CapitalNoPayment
    
            ^Context = RP:RP.CapitalNoPayment
            */
            assertion = (report.RPCapitalNoPaymentExists != false && report.RPCapitalNoPaymentIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPCapitalNoPaymentOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.CFCLC
    
            ^Context = RP:RP.CFCLC
            */
            assertion = (report.RPCFCLCExists != false && report.RPCFCLCIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPCFCLCOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.CFCSP
    
            ^Context = RP:RP.CFCSP
            */
            assertion = (report.RPCFCSPExists != false && report.RPCFCSPIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPCFCSPOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.CFCUC
    
            ^Context = RP:RP.CFCUC
            */
            assertion = (report.RPCFCUCExists != false && report.RPCFCUCIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPCFCUCOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.DebtFactoring
    
            ^Context = RP:RP.DebtFactoring
            */
            assertion = (report.RPDebtFactoringExists != false && report.RPDebtFactoringIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPDebtFactoringOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.Derivatives
    
            ^Context = RP:RP.Derivatives
            */
            assertion = (report.RPDerivativesExists != false && report.RPDerivativesIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPDerivativesOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.Division770
    
            ^Context = RP:RP.Division770
            */
            assertion = (report.RPDivision770Exists != false && report.RPDivision770IdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPDivision770OccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.DTA
    
            ^Context = RP:RP.DTA
            */
            assertion = (report.RPDTAExists != false && report.RPDTAIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPDTAOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.EligibleContract
    
            ^Context = RP:RP.EligibleContract
            */
            assertion = (report.RPEligibleContractExists != false && report.RPEligibleContractIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPEligibleContractOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP.EligibleContract:RP.EligibleContract.RelatedParty
    
            ^Context = RP.EligibleContract:RP.EligibleContract.RelatedParty
            */
            assertion = (report.RPEligibleContractRelatedPartyExists != false && report.RPEligibleContractRelatedPartyIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPEligibleContractRelatedPartyOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.GeneralDeduction
    
            ^Context = RP:RP.GeneralDeduction
            */
            assertion = (report.RPGeneralDeductionExists != false && report.RPGeneralDeductionIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPGeneralDeductionOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.GuaranteeType
    
            ^Context = RP:RP.GuaranteeType
            */
            assertion = (report.RPGuaranteeTypeExists != false && report.RPGuaranteeTypeIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPGuaranteeTypeOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP.GuaranteeType:RP.GuaranteeType.RelatedParty
    
            ^Context = RP.GuaranteeType:RP.GuaranteeType.RelatedParty
            */
            assertion = (report.RPGuaranteeTypeRelatedPartyExists != false && report.RPGuaranteeTypeRelatedPartyIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPGuaranteeTypeRelatedPartyOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.Hedging
    
            ^Context = RP:RP.Hedging
            */
            assertion = (report.RPHedgingExists != false && report.RPHedgingIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPHedgingOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP.Hedging:RP.Hedging.RelatedParty
    
            ^Context = RP.Hedging:RP.Hedging.RelatedParty
            */
            assertion = (report.RPHedgingRelatedPartyExists != false && report.RPHedgingRelatedPartyIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPHedgingRelatedPartyOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.Insurance
    
            ^Context = RP:RP.Insurance
            */
            assertion = (report.RPInsuranceExists != false && report.RPInsuranceIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPInsuranceOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.Investment
    
            ^Context = RP:RP.Investment
            */
            assertion = (report.RPInvestmentExists != false && report.RPInvestmentIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPInvestmentOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP.Investment:RP.Investment.RelatedParty
    
            ^Context = RP.Investment:RP.Investment.RelatedParty
            */
            assertion = (report.RPInvestmentRelatedPartyExists != false && report.RPInvestmentRelatedPartyIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPInvestmentRelatedPartyOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.Leasing
    
            ^Context = RP:RP.Leasing
            */
            assertion = (report.RPLeasingExists != false && report.RPLeasingIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPLeasingOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP.Leasing:RP.Leasing.RelatedParty
    
            ^Context = RP.Leasing:RP.Leasing.RelatedParty
            */
            assertion = (report.RPLeasingRelatedPartyExists != false && report.RPLeasingRelatedPartyIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPLeasingRelatedPartyOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.Lending
    
            ^Context = RP:RP.Lending
            */
            assertion = (report.RPLendingExists != false && report.RPLendingIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPLendingOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP.Lending:RP.Lending.RelatedParty
    
            ^Context = RP.Lending:RP.Lending.RelatedParty
            */
            assertion = (report.RPLendingRelatedPartyExists != false && report.RPLendingRelatedPartyIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPLendingRelatedPartyOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.LicenceFees
    
            ^Context = RP:RP.LicenceFees
            */
            assertion = (report.RPLicenceFeesExists != false && report.RPLicenceFeesIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPLicenceFeesOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.Logistics
    
            ^Context = RP:RP.Logistics
            */
            assertion = (report.RPLogisticsExists != false && report.RPLogisticsIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPLogisticsOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.ManagementAndAdmin
    
            ^Context = RP:RP.ManagementAndAdmin
            */
            assertion = (report.RPManagementAndAdminExists != false && report.RPManagementAndAdminIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPManagementAndAdminOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.Other
    
            ^Context = RP:RP.Other
            */
            assertion = (report.RPOtherExists != false && report.RPOtherIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOtherOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP.Other:RP.Other.RelatedParty
    
            ^Context = RP.Other:RP.Other.RelatedParty
            */
            assertion = (report.RPOtherRelatedPartyExists != false && report.RPOtherRelatedPartyIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOtherRelatedPartyOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.OtherFinancialDealings
    
            ^Context = RP:RP.OtherFinancialDealings
            */
            assertion = (report.RPOtherFinancialDealingsExists != false && report.RPOtherFinancialDealingsIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOtherFinancialDealingsOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP.OtherFinancialDealings:RP.OtherFinancialDealings.InterestBearing
    
            ^Context = RP.OtherFinancialDealings:RP.OtherFinancialDealings.InterestBearing
            */
            assertion = (report.RPOtherFinancialDealingsInterestBearingExists != false && report.RPOtherFinancialDealingsInterestBearingIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOtherFinancialDealingsInterestBearingOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP.OtherFinancialDealings:RP.OtherFinancialDealings.InterestFree
    
            ^Context = RP.OtherFinancialDealings:RP.OtherFinancialDealings.InterestFree
            */
            assertion = (report.RPOtherFinancialDealingsInterestFreeExists != false && report.RPOtherFinancialDealingsInterestFreeIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOtherFinancialDealingsInterestFreeOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.OtherGuarantees
    
            ^Context = RP:RP.OtherGuarantees
            */
            assertion = (report.RPOtherGuaranteesExists != false && report.RPOtherGuaranteesIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOtherGuaranteesOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.OtherInsurance
    
            ^Context = RP:RP.OtherInsurance
            */
            assertion = (report.RPOtherInsuranceExists != false && report.RPOtherInsuranceIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOtherInsuranceOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.OtherInterest
    
            ^Context = RP:RP.OtherInterest
            */
            assertion = (report.RPOtherInterestExists != false && report.RPOtherInterestIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOtherInterestOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.OtherNotReportedAssignmentOfIntangibleNonRevenue
    
            ^Context = RP:RP.OtherNotReportedAssignmentOfIntangibleNonRevenue
            */
            assertion = (report.RPOtherNotReportedAssignmentOfIntangibleNonRevenueExists != false && report.RPOtherNotReportedAssignmentOfIntangibleNonRevenueIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOtherNotReportedAssignmentOfIntangibleNonRevenueOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.OtherNotReportedAssignmentOfLoansOrDebtsNonRevenue
    
            ^Context = RP:RP.OtherNotReportedAssignmentOfLoansOrDebtsNonRevenue
            */
            assertion = (report.RPOtherNotReportedAssignmentOfLoansOrDebtsNonRevenueExists != false && report.RPOtherNotReportedAssignmentOfLoansOrDebtsNonRevenueIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOtherNotReportedAssignmentOfLoansOrDebtsNonRevenueOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.OtherNotReportedAssignmentOfSharesOrEquityInterestsNonRevenue
    
            ^Context = RP:RP.OtherNotReportedAssignmentOfSharesOrEquityInterestsNonRevenue
            */
            assertion = (report.RPOtherNotReportedAssignmentOfSharesOrEquityInterestsNonRevenueExists != false && report.RPOtherNotReportedAssignmentOfSharesOrEquityInterestsNonRevenueIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOtherNotReportedAssignmentOfSharesOrEquityInterestsNonRevenueOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.OtherNotReportedIntangibleNonRevenue
    
            ^Context = RP:RP.OtherNotReportedIntangibleNonRevenue
            */
            assertion = (report.RPOtherNotReportedIntangibleNonRevenueExists != false && report.RPOtherNotReportedIntangibleNonRevenueIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOtherNotReportedIntangibleNonRevenueOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.OtherNotReportedRevenue
    
            ^Context = RP:RP.OtherNotReportedRevenue
            */
            assertion = (report.RPOtherNotReportedRevenueExists != false && report.RPOtherNotReportedRevenueIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOtherNotReportedRevenueOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.OtherNotReportedTangibleNonRevenue
    
            ^Context = RP:RP.OtherNotReportedTangibleNonRevenue
            */
            assertion = (report.RPOtherNotReportedTangibleNonRevenueExists != false && report.RPOtherNotReportedTangibleNonRevenueIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOtherNotReportedTangibleNonRevenueOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.OtherReinsurance
    
            ^Context = RP:RP.OtherReinsurance
            */
            assertion = (report.RPOtherReinsuranceExists != false && report.RPOtherReinsuranceIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOtherReinsuranceOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.OtherServices
    
            ^Context = RP:RP.OtherServices
            */
            assertion = (report.RPOtherServicesExists != false && report.RPOtherServicesIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOtherServicesOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.Quarterly
    
            ^Context = RP:RP.Quarterly
            */
            assertion = (report.RPQuarterlyExists != false && report.RPQuarterlyIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPQuarterlyOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.RechargeAmounts
    
            ^Context = RP:RP.RechargeAmounts
            */
            assertion = (report.RPRechargeAmountsExists != false && report.RPRechargeAmountsIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPRechargeAmountsOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.Reinsurance
    
            ^Context = RP:RP.Reinsurance
            */
            assertion = (report.RPReinsuranceExists != false && report.RPReinsuranceIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPReinsuranceOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.RentLease
    
            ^Context = RP:RP.RentLease
            */
            assertion = (report.RPRentLeaseExists != false && report.RPRentLeaseIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPRentLeaseOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.ResearchAndDevelopment
    
            ^Context = RP:RP.ResearchAndDevelopment
            */
            assertion = (report.RPResearchAndDevelopmentExists != false && report.RPResearchAndDevelopmentIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPResearchAndDevelopmentOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.RevenueNonMonetaryPayment
    
            ^Context = RP:RP.RevenueNonMonetaryPayment
            */
            assertion = (report.RPRevenueNonMonetaryPaymentExists != false && report.RPRevenueNonMonetaryPaymentIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPRevenueNonMonetaryPaymentOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.RevenueNoPayment
    
            ^Context = RP:RP.RevenueNoPayment
            */
            assertion = (report.RPRevenueNoPaymentExists != false && report.RPRevenueNoPaymentIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPRevenueNoPaymentOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.Royalties
    
            ^Context = RP:RP.Royalties
            */
            assertion = (report.RPRoyaltiesExists != false && report.RPRoyaltiesIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPRoyaltiesOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.s128F
    
            ^Context = RP:RP.s128F
            */
            assertion = (report.RPs128FExists != false && report.RPs128FIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPs128FOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.s128FA
    
            ^Context = RP:RP.s128FA
            */
            assertion = (report.RPs128FAExists != false && report.RPs128FAIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPs128FAOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.SalesAndMarketing
    
            ^Context = RP:RP.SalesAndMarketing
            */
            assertion = (report.RPSalesAndMarketingExists != false && report.RPSalesAndMarketingIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPSalesAndMarketingOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.Securitisation
    
            ^Context = RP:RP.Securitisation
            */
            assertion = (report.RPSecuritisationExists != false && report.RPSecuritisationIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPSecuritisationOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.SoftwareAndITServices
    
            ^Context = RP:RP.SoftwareAndITServices
            */
            assertion = (report.RPSoftwareAndITServicesExists != false && report.RPSoftwareAndITServicesIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPSoftwareAndITServicesOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.TangibleRevenue
    
            ^Context = RP:RP.TangibleRevenue
            */
            assertion = (report.RPTangibleRevenueExists != false && report.RPTangibleRevenueIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPTangibleRevenueOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.Technical
    
            ^Context = RP:RP.Technical
            */
            assertion = (report.RPTechnicalExists != false && report.RPTechnicalIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPTechnicalOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.TotalNet
    
            ^Context = RP:RP.TotalNet
            */
            assertion = (report.RPTotalNetExists != false && report.RPTotalNetIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPTotalNetOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP.TotalNet:RP.TotalNet.RelatedParty
    
            ^Context = RP.TotalNet:RP.TotalNet.RelatedParty
            */
            assertion = (report.RPTotalNetRelatedPartyExists != false && report.RPTotalNetRelatedPartyIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPTotalNetRelatedPartyOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.Trading
    
            ^Context = RP:RP.Trading
            */
            assertion = (report.RPTradingExists != false && report.RPTradingIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPTradingOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP.Trading:RP.Trading.RelatedParty
    
            ^Context = RP.Trading:RP.Trading.RelatedParty
            */
            assertion = (report.RPTradingRelatedPartyExists != false && report.RPTradingRelatedPartyIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPTradingRelatedPartyOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001021

            /*  VR.ATO.GEN.001021
            Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
            Legacy Rule Format:
            IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.TreasuryRelated
    
            ^Context = RP:RP.TreasuryRelated
            */
            assertion = (report.RPTreasuryRelatedExists != false && report.RPTreasuryRelatedIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid identifier scheme.",
                    LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPTreasuryRelatedOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001021

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.Advisory
    
            ^OtherTFN = RP:RP.Advisory
    
            ^TFN = RP
            */
            assertion = (report.RPAdvisoryExists != false && report.RPAdvisoryIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPAdvisoryOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP.Advisory:RP.Advisory.RelatedParty
    
            ^OtherTFN = RP.Advisory:RP.Advisory.RelatedParty
    
            ^TFN = RP
            */
            assertion = (report.RPAdvisoryRelatedPartyExists != false && report.RPAdvisoryRelatedPartyIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPAdvisoryRelatedPartyOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.AssetManagement
    
            ^OtherTFN = RP:RP.AssetManagement
    
            ^TFN = RP
            */
            assertion = (report.RPAssetManagementExists != false && report.RPAssetManagementIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPAssetManagementOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.Borrowing
    
            ^OtherTFN = RP:RP.Borrowing
    
            ^TFN = RP
            */
            assertion = (report.RPBorrowingExists != false && report.RPBorrowingIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPBorrowingOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP.Borrowing:RP.Borrowing.RelatedParty
    
            ^OtherTFN = RP.Borrowing:RP.Borrowing.RelatedParty
    
            ^TFN = RP
            */
            assertion = (report.RPBorrowingRelatedPartyExists != false && report.RPBorrowingRelatedPartyIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPBorrowingRelatedPartyOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.BranchOperations
    
            ^OtherTFN = RP:RP.BranchOperations
    
            ^TFN = RP
            */
            assertion = (report.RPBranchOperationsExists != false && report.RPBranchOperationsIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPBranchOperationsOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP.BranchOperations:RP.BranchOperations.InterestBearing
    
            ^OtherTFN = RP.BranchOperations:RP.BranchOperations.InterestBearing
    
            ^TFN = RP
            */
            assertion = (report.RPBranchOperationsInterestBearingExists != false && report.RPBranchOperationsInterestBearingIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPBranchOperationsInterestBearingOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP.BranchOperations:RP.BranchOperations.InterestFree
    
            ^OtherTFN = RP.BranchOperations:RP.BranchOperations.InterestFree
    
            ^TFN = RP
            */
            assertion = (report.RPBranchOperationsInterestFreeExists != false && report.RPBranchOperationsInterestFreeIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPBranchOperationsInterestFreeOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.CapitalNonMonetaryPayment
    
            ^OtherTFN = RP:RP.CapitalNonMonetaryPayment
    
            ^TFN = RP
            */
            assertion = (report.RPCapitalNonMonetaryPaymentExists != false && report.RPCapitalNonMonetaryPaymentIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPCapitalNonMonetaryPaymentOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.CapitalNoPayment
    
            ^OtherTFN = RP:RP.CapitalNoPayment
    
            ^TFN = RP
            */
            assertion = (report.RPCapitalNoPaymentExists != false && report.RPCapitalNoPaymentIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPCapitalNoPaymentOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.CFCLC
    
            ^OtherTFN = RP:RP.CFCLC
    
            ^TFN = RP
            */
            assertion = (report.RPCFCLCExists != false && report.RPCFCLCIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPCFCLCOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.CFCSP
    
            ^OtherTFN = RP:RP.CFCSP
    
            ^TFN = RP
            */
            assertion = (report.RPCFCSPExists != false && report.RPCFCSPIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPCFCSPOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.CFCUC
    
            ^OtherTFN = RP:RP.CFCUC
    
            ^TFN = RP
            */
            assertion = (report.RPCFCUCExists != false && report.RPCFCUCIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPCFCUCOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.DebtFactoring
    
            ^OtherTFN = RP:RP.DebtFactoring
    
            ^TFN = RP
            */
            assertion = (report.RPDebtFactoringExists != false && report.RPDebtFactoringIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPDebtFactoringOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.Derivatives
    
            ^OtherTFN = RP:RP.Derivatives
    
            ^TFN = RP
            */
            assertion = (report.RPDerivativesExists != false && report.RPDerivativesIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPDerivativesOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.Division770
    
            ^OtherTFN = RP:RP.Division770
    
            ^TFN = RP
            */
            assertion = (report.RPDivision770Exists != false && report.RPDivision770IdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPDivision770OccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.DTA
    
            ^OtherTFN = RP:RP.DTA
    
            ^TFN = RP
            */
            assertion = (report.RPDTAExists != false && report.RPDTAIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPDTAOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.EligibleContract
    
            ^OtherTFN = RP:RP.EligibleContract
    
            ^TFN = RP
            */
            assertion = (report.RPEligibleContractExists != false && report.RPEligibleContractIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPEligibleContractOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP.EligibleContract:RP.EligibleContract.RelatedParty
    
            ^OtherTFN = RP.EligibleContract:RP.EligibleContract.RelatedParty
    
            ^TFN = RP
            */
            assertion = (report.RPEligibleContractRelatedPartyExists != false && report.RPEligibleContractRelatedPartyIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPEligibleContractRelatedPartyOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.GeneralDeduction
    
            ^OtherTFN = RP:RP.GeneralDeduction
    
            ^TFN = RP
            */
            assertion = (report.RPGeneralDeductionExists != false && report.RPGeneralDeductionIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPGeneralDeductionOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.GuaranteeType
    
            ^OtherTFN = RP:RP.GuaranteeType
    
            ^TFN = RP
            */
            assertion = (report.RPGuaranteeTypeExists != false && report.RPGuaranteeTypeIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPGuaranteeTypeOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP.GuaranteeType:RP.GuaranteeType.RelatedParty
    
            ^OtherTFN = RP.GuaranteeType:RP.GuaranteeType.RelatedParty
    
            ^TFN = RP
            */
            assertion = (report.RPGuaranteeTypeRelatedPartyExists != false && report.RPGuaranteeTypeRelatedPartyIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPGuaranteeTypeRelatedPartyOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.Hedging
    
            ^OtherTFN = RP:RP.Hedging
    
            ^TFN = RP
            */
            assertion = (report.RPHedgingExists != false && report.RPHedgingIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPHedgingOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP.Hedging:RP.Hedging.RelatedParty
    
            ^OtherTFN = RP.Hedging:RP.Hedging.RelatedParty
    
            ^TFN = RP
            */
            assertion = (report.RPHedgingRelatedPartyExists != false && report.RPHedgingRelatedPartyIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPHedgingRelatedPartyOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.Insurance
    
            ^OtherTFN = RP:RP.Insurance
    
            ^TFN = RP
            */
            assertion = (report.RPInsuranceExists != false && report.RPInsuranceIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPInsuranceOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.Investment
    
            ^OtherTFN = RP:RP.Investment
    
            ^TFN = RP
            */
            assertion = (report.RPInvestmentExists != false && report.RPInvestmentIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPInvestmentOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP.Investment:RP.Investment.RelatedParty
    
            ^OtherTFN = RP.Investment:RP.Investment.RelatedParty
    
            ^TFN = RP
            */
            assertion = (report.RPInvestmentRelatedPartyExists != false && report.RPInvestmentRelatedPartyIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPInvestmentRelatedPartyOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.Leasing
    
            ^OtherTFN = RP:RP.Leasing
    
            ^TFN = RP
            */
            assertion = (report.RPLeasingExists != false && report.RPLeasingIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPLeasingOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP.Leasing:RP.Leasing.RelatedParty
    
            ^OtherTFN = RP.Leasing:RP.Leasing.RelatedParty
    
            ^TFN = RP
            */
            assertion = (report.RPLeasingRelatedPartyExists != false && report.RPLeasingRelatedPartyIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPLeasingRelatedPartyOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.Lending
    
            ^OtherTFN = RP:RP.Lending
    
            ^TFN = RP
            */
            assertion = (report.RPLendingExists != false && report.RPLendingIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPLendingOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP.Lending:RP.Lending.RelatedParty
    
            ^OtherTFN = RP.Lending:RP.Lending.RelatedParty
    
            ^TFN = RP
            */
            assertion = (report.RPLendingRelatedPartyExists != false && report.RPLendingRelatedPartyIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPLendingRelatedPartyOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.LicenceFees
    
            ^OtherTFN = RP:RP.LicenceFees
    
            ^TFN = RP
            */
            assertion = (report.RPLicenceFeesExists != false && report.RPLicenceFeesIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPLicenceFeesOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.Logistics
    
            ^OtherTFN = RP:RP.Logistics
    
            ^TFN = RP
            */
            assertion = (report.RPLogisticsExists != false && report.RPLogisticsIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPLogisticsOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.ManagementAndAdmin
    
            ^OtherTFN = RP:RP.ManagementAndAdmin
    
            ^TFN = RP
            */
            assertion = (report.RPManagementAndAdminExists != false && report.RPManagementAndAdminIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPManagementAndAdminOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.Other
    
            ^OtherTFN = RP:RP.Other
    
            ^TFN = RP
            */
            assertion = (report.RPOtherExists != false && report.RPOtherIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOtherOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP.Other:RP.Other.RelatedParty
    
            ^OtherTFN = RP.Other:RP.Other.RelatedParty
    
            ^TFN = RP
            */
            assertion = (report.RPOtherRelatedPartyExists != false && report.RPOtherRelatedPartyIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOtherRelatedPartyOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.OtherFinancialDealings
    
            ^OtherTFN = RP:RP.OtherFinancialDealings
    
            ^TFN = RP
            */
            assertion = (report.RPOtherFinancialDealingsExists != false && report.RPOtherFinancialDealingsIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOtherFinancialDealingsOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP.OtherFinancialDealings:RP.OtherFinancialDealings.InterestBearing
    
            ^OtherTFN = RP.OtherFinancialDealings:RP.OtherFinancialDealings.InterestBearing
    
            ^TFN = RP
            */
            assertion = (report.RPOtherFinancialDealingsInterestBearingExists != false && report.RPOtherFinancialDealingsInterestBearingIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOtherFinancialDealingsInterestBearingOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP.OtherFinancialDealings:RP.OtherFinancialDealings.InterestFree
    
            ^OtherTFN = RP.OtherFinancialDealings:RP.OtherFinancialDealings.InterestFree
    
            ^TFN = RP
            */
            assertion = (report.RPOtherFinancialDealingsInterestFreeExists != false && report.RPOtherFinancialDealingsInterestFreeIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOtherFinancialDealingsInterestFreeOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.OtherGuarantees
    
            ^OtherTFN = RP:RP.OtherGuarantees
    
            ^TFN = RP
            */
            assertion = (report.RPOtherGuaranteesExists != false && report.RPOtherGuaranteesIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOtherGuaranteesOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.OtherInsurance
    
            ^OtherTFN = RP:RP.OtherInsurance
    
            ^TFN = RP
            */
            assertion = (report.RPOtherInsuranceExists != false && report.RPOtherInsuranceIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOtherInsuranceOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.OtherInterest
    
            ^OtherTFN = RP:RP.OtherInterest
    
            ^TFN = RP
            */
            assertion = (report.RPOtherInterestExists != false && report.RPOtherInterestIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOtherInterestOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.OtherNotReportedAssignmentOfIntangibleNonRevenue
    
            ^OtherTFN = RP:RP.OtherNotReportedAssignmentOfIntangibleNonRevenue
    
            ^TFN = RP
            */
            assertion = (report.RPOtherNotReportedAssignmentOfIntangibleNonRevenueExists != false && report.RPOtherNotReportedAssignmentOfIntangibleNonRevenueIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOtherNotReportedAssignmentOfIntangibleNonRevenueOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.OtherNotReportedAssignmentOfLoansOrDebtsNonRevenue
    
            ^OtherTFN = RP:RP.OtherNotReportedAssignmentOfLoansOrDebtsNonRevenue
    
            ^TFN = RP
            */
            assertion = (report.RPOtherNotReportedAssignmentOfLoansOrDebtsNonRevenueExists != false && report.RPOtherNotReportedAssignmentOfLoansOrDebtsNonRevenueIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOtherNotReportedAssignmentOfLoansOrDebtsNonRevenueOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.OtherNotReportedAssignmentOfSharesOrEquityInterestsNonRevenue
    
            ^OtherTFN = RP:RP.OtherNotReportedAssignmentOfSharesOrEquityInterestsNonRevenue
    
            ^TFN = RP
            */
            assertion = (report.RPOtherNotReportedAssignmentOfSharesOrEquityInterestsNonRevenueExists != false && report.RPOtherNotReportedAssignmentOfSharesOrEquityInterestsNonRevenueIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOtherNotReportedAssignmentOfSharesOrEquityInterestsNonRevenueOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.OtherNotReportedIntangibleNonRevenue
    
            ^OtherTFN = RP:RP.OtherNotReportedIntangibleNonRevenue
    
            ^TFN = RP
            */
            assertion = (report.RPOtherNotReportedIntangibleNonRevenueExists != false && report.RPOtherNotReportedIntangibleNonRevenueIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOtherNotReportedIntangibleNonRevenueOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.OtherNotReportedRevenue
    
            ^OtherTFN = RP:RP.OtherNotReportedRevenue
    
            ^TFN = RP
            */
            assertion = (report.RPOtherNotReportedRevenueExists != false && report.RPOtherNotReportedRevenueIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOtherNotReportedRevenueOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.OtherNotReportedTangibleNonRevenue
    
            ^OtherTFN = RP:RP.OtherNotReportedTangibleNonRevenue
    
            ^TFN = RP
            */
            assertion = (report.RPOtherNotReportedTangibleNonRevenueExists != false && report.RPOtherNotReportedTangibleNonRevenueIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOtherNotReportedTangibleNonRevenueOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.OtherReinsurance
    
            ^OtherTFN = RP:RP.OtherReinsurance
    
            ^TFN = RP
            */
            assertion = (report.RPOtherReinsuranceExists != false && report.RPOtherReinsuranceIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOtherReinsuranceOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.OtherServices
    
            ^OtherTFN = RP:RP.OtherServices
    
            ^TFN = RP
            */
            assertion = (report.RPOtherServicesExists != false && report.RPOtherServicesIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOtherServicesOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.Quarterly
    
            ^OtherTFN = RP:RP.Quarterly
    
            ^TFN = RP
            */
            assertion = (report.RPQuarterlyExists != false && report.RPQuarterlyIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPQuarterlyOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.RechargeAmounts
    
            ^OtherTFN = RP:RP.RechargeAmounts
    
            ^TFN = RP
            */
            assertion = (report.RPRechargeAmountsExists != false && report.RPRechargeAmountsIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPRechargeAmountsOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.Reinsurance
    
            ^OtherTFN = RP:RP.Reinsurance
    
            ^TFN = RP
            */
            assertion = (report.RPReinsuranceExists != false && report.RPReinsuranceIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPReinsuranceOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.RentLease
    
            ^OtherTFN = RP:RP.RentLease
    
            ^TFN = RP
            */
            assertion = (report.RPRentLeaseExists != false && report.RPRentLeaseIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPRentLeaseOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.ResearchAndDevelopment
    
            ^OtherTFN = RP:RP.ResearchAndDevelopment
    
            ^TFN = RP
            */
            assertion = (report.RPResearchAndDevelopmentExists != false && report.RPResearchAndDevelopmentIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPResearchAndDevelopmentOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.RevenueNonMonetaryPayment
    
            ^OtherTFN = RP:RP.RevenueNonMonetaryPayment
    
            ^TFN = RP
            */
            assertion = (report.RPRevenueNonMonetaryPaymentExists != false && report.RPRevenueNonMonetaryPaymentIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPRevenueNonMonetaryPaymentOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.RevenueNoPayment
    
            ^OtherTFN = RP:RP.RevenueNoPayment
    
            ^TFN = RP
            */
            assertion = (report.RPRevenueNoPaymentExists != false && report.RPRevenueNoPaymentIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPRevenueNoPaymentOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.Royalties
    
            ^OtherTFN = RP:RP.Royalties
    
            ^TFN = RP
            */
            assertion = (report.RPRoyaltiesExists != false && report.RPRoyaltiesIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPRoyaltiesOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.s128F
    
            ^OtherTFN = RP:RP.s128F
    
            ^TFN = RP
            */
            assertion = (report.RPs128FExists != false && report.RPs128FIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPs128FOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.s128FA
    
            ^OtherTFN = RP:RP.s128FA
    
            ^TFN = RP
            */
            assertion = (report.RPs128FAExists != false && report.RPs128FAIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPs128FAOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.SalesAndMarketing
    
            ^OtherTFN = RP:RP.SalesAndMarketing
    
            ^TFN = RP
            */
            assertion = (report.RPSalesAndMarketingExists != false && report.RPSalesAndMarketingIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPSalesAndMarketingOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.Securitisation
    
            ^OtherTFN = RP:RP.Securitisation
    
            ^TFN = RP
            */
            assertion = (report.RPSecuritisationExists != false && report.RPSecuritisationIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPSecuritisationOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.SoftwareAndITServices
    
            ^OtherTFN = RP:RP.SoftwareAndITServices
    
            ^TFN = RP
            */
            assertion = (report.RPSoftwareAndITServicesExists != false && report.RPSoftwareAndITServicesIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPSoftwareAndITServicesOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.TangibleRevenue
    
            ^OtherTFN = RP:RP.TangibleRevenue
    
            ^TFN = RP
            */
            assertion = (report.RPTangibleRevenueExists != false && report.RPTangibleRevenueIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPTangibleRevenueOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.Technical
    
            ^OtherTFN = RP:RP.Technical
    
            ^TFN = RP
            */
            assertion = (report.RPTechnicalExists != false && report.RPTechnicalIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPTechnicalOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.TotalNet
    
            ^OtherTFN = RP:RP.TotalNet
    
            ^TFN = RP
            */
            assertion = (report.RPTotalNetExists != false && report.RPTotalNetIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPTotalNetOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP.TotalNet:RP.TotalNet.RelatedParty
    
            ^OtherTFN = RP.TotalNet:RP.TotalNet.RelatedParty
    
            ^TFN = RP
            */
            assertion = (report.RPTotalNetRelatedPartyExists != false && report.RPTotalNetRelatedPartyIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPTotalNetRelatedPartyOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.Trading
    
            ^OtherTFN = RP:RP.Trading
    
            ^TFN = RP
            */
            assertion = (report.RPTradingExists != false && report.RPTradingIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPTradingOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP.Trading:RP.Trading.RelatedParty
    
            ^OtherTFN = RP.Trading:RP.Trading.RelatedParty
    
            ^TFN = RP
            */
            assertion = (report.RPTradingRelatedPartyExists != false && report.RPTradingRelatedPartyIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPTradingRelatedPartyOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.001023

            /*  VR.ATO.GEN.001023
            TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
            Legacy Rule Format:
            IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^OtherTFN <> ^TFN
    
            Data Elements:
    
            ^Context = RP:RP.TreasuryRelated
    
            ^OtherTFN = RP:RP.TreasuryRelated
    
            ^TFN = RP
            */
            assertion = (report.RPTreasuryRelatedExists != false && report.RPTreasuryRelatedIdentifierTFN != report.RPIdentifierTFN);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Unexpected TFN mismatch with Reporting Party",
                    LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPTreasuryRelatedOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.001023

            #region VR.ATO.GEN.428040

            /*  VR.ATO.GEN.428040
            ABN is invalid
    
            Legacy Rule Format:
            IF (pyid.xx.xx:IdentifiersAustralianBusinessNumberIdentifer <> NULLORBLANK) and (ABNALGORITHM(pyid.xx.xx:IdentifiersAustralianBusinessNumber.Identifer) = FALSE)
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^IDS222 <> BLANK) and (FailsABNAlgorithm(^IDS222))
    
            Data Elements:
    
            RP:^IDS222 = tns:Identifiers.AustralianBusinessNumber.Identifier
            */
            assertion = (string.IsNullOrWhiteSpace(report.IDS222) != true && FailsABNAlgorithm(report.IDS222));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000477",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"ABN is invalid",
                    Location = "/xbrli:xbrl/tns:Identifiers.AustralianBusinessNumber.Identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.428040" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS222", Value = report.IDS222 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.428040

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP
    
            ^Context = RP
            */
            assertion = (report.RPExists != false && report.RPIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.Advisory
    
            ^Context = RP:RP.Advisory
            */
            assertion = (report.RPAdvisoryExists != false && report.RPAdvisoryIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPAdvisoryOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP.Advisory:RP.Advisory.RelatedParty
    
            ^Context = RP.Advisory:RP.Advisory.RelatedParty
            */
            assertion = (report.RPAdvisoryRelatedPartyExists != false && report.RPAdvisoryRelatedPartyIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPAdvisoryRelatedPartyOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.AssetManagement
    
            ^Context = RP:RP.AssetManagement
            */
            assertion = (report.RPAssetManagementExists != false && report.RPAssetManagementIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPAssetManagementOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.Borrowing
    
            ^Context = RP:RP.Borrowing
            */
            assertion = (report.RPBorrowingExists != false && report.RPBorrowingIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPBorrowingOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP.Borrowing:RP.Borrowing.RelatedParty
    
            ^Context = RP.Borrowing:RP.Borrowing.RelatedParty
            */
            assertion = (report.RPBorrowingRelatedPartyExists != false && report.RPBorrowingRelatedPartyIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPBorrowingRelatedPartyOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.BranchOperations
    
            ^Context = RP:RP.BranchOperations
            */
            assertion = (report.RPBranchOperationsExists != false && report.RPBranchOperationsIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPBranchOperationsOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP.BranchOperations:RP.BranchOperations.InterestBearing
    
            ^Context = RP.BranchOperations:RP.BranchOperations.InterestBearing
            */
            assertion = (report.RPBranchOperationsInterestBearingExists != false && report.RPBranchOperationsInterestBearingIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPBranchOperationsInterestBearingOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP.BranchOperations:RP.BranchOperations.InterestFree
    
            ^Context = RP.BranchOperations:RP.BranchOperations.InterestFree
            */
            assertion = (report.RPBranchOperationsInterestFreeExists != false && report.RPBranchOperationsInterestFreeIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPBranchOperationsInterestFreeOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.CapitalNonMonetaryPayment
    
            ^Context = RP:RP.CapitalNonMonetaryPayment
            */
            assertion = (report.RPCapitalNonMonetaryPaymentExists != false && report.RPCapitalNonMonetaryPaymentIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPCapitalNonMonetaryPaymentOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.CapitalNoPayment
    
            ^Context = RP:RP.CapitalNoPayment
            */
            assertion = (report.RPCapitalNoPaymentExists != false && report.RPCapitalNoPaymentIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPCapitalNoPaymentOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.CFCLC
    
            ^Context = RP:RP.CFCLC
            */
            assertion = (report.RPCFCLCExists != false && report.RPCFCLCIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPCFCLCOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.CFCSP
    
            ^Context = RP:RP.CFCSP
            */
            assertion = (report.RPCFCSPExists != false && report.RPCFCSPIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPCFCSPOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.CFCUC
    
            ^Context = RP:RP.CFCUC
            */
            assertion = (report.RPCFCUCExists != false && report.RPCFCUCIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPCFCUCOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.DebtFactoring
    
            ^Context = RP:RP.DebtFactoring
            */
            assertion = (report.RPDebtFactoringExists != false && report.RPDebtFactoringIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPDebtFactoringOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.Derivatives
    
            ^Context = RP:RP.Derivatives
            */
            assertion = (report.RPDerivativesExists != false && report.RPDerivativesIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPDerivativesOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.Division770
    
            ^Context = RP:RP.Division770
            */
            assertion = (report.RPDivision770Exists != false && report.RPDivision770IdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPDivision770OccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.DTA
    
            ^Context = RP:RP.DTA
            */
            assertion = (report.RPDTAExists != false && report.RPDTAIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPDTAOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.EligibleContract
    
            ^Context = RP:RP.EligibleContract
            */
            assertion = (report.RPEligibleContractExists != false && report.RPEligibleContractIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPEligibleContractOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP.EligibleContract:RP.EligibleContract.RelatedParty
    
            ^Context = RP.EligibleContract:RP.EligibleContract.RelatedParty
            */
            assertion = (report.RPEligibleContractRelatedPartyExists != false && report.RPEligibleContractRelatedPartyIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPEligibleContractRelatedPartyOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.GeneralDeduction
    
            ^Context = RP:RP.GeneralDeduction
            */
            assertion = (report.RPGeneralDeductionExists != false && report.RPGeneralDeductionIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPGeneralDeductionOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.GuaranteeType
    
            ^Context = RP:RP.GuaranteeType
            */
            assertion = (report.RPGuaranteeTypeExists != false && report.RPGuaranteeTypeIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPGuaranteeTypeOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP.GuaranteeType:RP.GuaranteeType.RelatedParty
    
            ^Context = RP.GuaranteeType:RP.GuaranteeType.RelatedParty
            */
            assertion = (report.RPGuaranteeTypeRelatedPartyExists != false && report.RPGuaranteeTypeRelatedPartyIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPGuaranteeTypeRelatedPartyOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.Hedging
    
            ^Context = RP:RP.Hedging
            */
            assertion = (report.RPHedgingExists != false && report.RPHedgingIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPHedgingOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP.Hedging:RP.Hedging.RelatedParty
    
            ^Context = RP.Hedging:RP.Hedging.RelatedParty
            */
            assertion = (report.RPHedgingRelatedPartyExists != false && report.RPHedgingRelatedPartyIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPHedgingRelatedPartyOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.Insurance
    
            ^Context = RP:RP.Insurance
            */
            assertion = (report.RPInsuranceExists != false && report.RPInsuranceIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPInsuranceOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.Investment
    
            ^Context = RP:RP.Investment
            */
            assertion = (report.RPInvestmentExists != false && report.RPInvestmentIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPInvestmentOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP.Investment:RP.Investment.RelatedParty
    
            ^Context = RP.Investment:RP.Investment.RelatedParty
            */
            assertion = (report.RPInvestmentRelatedPartyExists != false && report.RPInvestmentRelatedPartyIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPInvestmentRelatedPartyOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.Leasing
    
            ^Context = RP:RP.Leasing
            */
            assertion = (report.RPLeasingExists != false && report.RPLeasingIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPLeasingOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP.Leasing:RP.Leasing.RelatedParty
    
            ^Context = RP.Leasing:RP.Leasing.RelatedParty
            */
            assertion = (report.RPLeasingRelatedPartyExists != false && report.RPLeasingRelatedPartyIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPLeasingRelatedPartyOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.Lending
    
            ^Context = RP:RP.Lending
            */
            assertion = (report.RPLendingExists != false && report.RPLendingIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPLendingOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP.Lending:RP.Lending.RelatedParty
    
            ^Context = RP.Lending:RP.Lending.RelatedParty
            */
            assertion = (report.RPLendingRelatedPartyExists != false && report.RPLendingRelatedPartyIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPLendingRelatedPartyOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.LicenceFees
    
            ^Context = RP:RP.LicenceFees
            */
            assertion = (report.RPLicenceFeesExists != false && report.RPLicenceFeesIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPLicenceFeesOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.Logistics
    
            ^Context = RP:RP.Logistics
            */
            assertion = (report.RPLogisticsExists != false && report.RPLogisticsIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPLogisticsOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.ManagementAndAdmin
    
            ^Context = RP:RP.ManagementAndAdmin
            */
            assertion = (report.RPManagementAndAdminExists != false && report.RPManagementAndAdminIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPManagementAndAdminOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.Other
    
            ^Context = RP:RP.Other
            */
            assertion = (report.RPOtherExists != false && report.RPOtherIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOtherOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP.Other:RP.Other.RelatedParty
    
            ^Context = RP.Other:RP.Other.RelatedParty
            */
            assertion = (report.RPOtherRelatedPartyExists != false && report.RPOtherRelatedPartyIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOtherRelatedPartyOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.OtherFinancialDealings
    
            ^Context = RP:RP.OtherFinancialDealings
            */
            assertion = (report.RPOtherFinancialDealingsExists != false && report.RPOtherFinancialDealingsIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOtherFinancialDealingsOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP.OtherFinancialDealings:RP.OtherFinancialDealings.InterestBearing
    
            ^Context = RP.OtherFinancialDealings:RP.OtherFinancialDealings.InterestBearing
            */
            assertion = (report.RPOtherFinancialDealingsInterestBearingExists != false && report.RPOtherFinancialDealingsInterestBearingIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOtherFinancialDealingsInterestBearingOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP.OtherFinancialDealings:RP.OtherFinancialDealings.InterestFree
    
            ^Context = RP.OtherFinancialDealings:RP.OtherFinancialDealings.InterestFree
            */
            assertion = (report.RPOtherFinancialDealingsInterestFreeExists != false && report.RPOtherFinancialDealingsInterestFreeIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOtherFinancialDealingsInterestFreeOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.OtherGuarantees
    
            ^Context = RP:RP.OtherGuarantees
            */
            assertion = (report.RPOtherGuaranteesExists != false && report.RPOtherGuaranteesIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOtherGuaranteesOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.OtherInsurance
    
            ^Context = RP:RP.OtherInsurance
            */
            assertion = (report.RPOtherInsuranceExists != false && report.RPOtherInsuranceIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOtherInsuranceOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.OtherInterest
    
            ^Context = RP:RP.OtherInterest
            */
            assertion = (report.RPOtherInterestExists != false && report.RPOtherInterestIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOtherInterestOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.OtherNotReportedAssignmentOfIntangibleNonRevenue
    
            ^Context = RP:RP.OtherNotReportedAssignmentOfIntangibleNonRevenue
            */
            assertion = (report.RPOtherNotReportedAssignmentOfIntangibleNonRevenueExists != false && report.RPOtherNotReportedAssignmentOfIntangibleNonRevenueIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOtherNotReportedAssignmentOfIntangibleNonRevenueOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.OtherNotReportedAssignmentOfLoansOrDebtsNonRevenue
    
            ^Context = RP:RP.OtherNotReportedAssignmentOfLoansOrDebtsNonRevenue
            */
            assertion = (report.RPOtherNotReportedAssignmentOfLoansOrDebtsNonRevenueExists != false && report.RPOtherNotReportedAssignmentOfLoansOrDebtsNonRevenueIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOtherNotReportedAssignmentOfLoansOrDebtsNonRevenueOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.OtherNotReportedAssignmentOfSharesOrEquityInterestsNonRevenue
    
            ^Context = RP:RP.OtherNotReportedAssignmentOfSharesOrEquityInterestsNonRevenue
            */
            assertion = (report.RPOtherNotReportedAssignmentOfSharesOrEquityInterestsNonRevenueExists != false && report.RPOtherNotReportedAssignmentOfSharesOrEquityInterestsNonRevenueIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOtherNotReportedAssignmentOfSharesOrEquityInterestsNonRevenueOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.OtherNotReportedIntangibleNonRevenue
    
            ^Context = RP:RP.OtherNotReportedIntangibleNonRevenue
            */
            assertion = (report.RPOtherNotReportedIntangibleNonRevenueExists != false && report.RPOtherNotReportedIntangibleNonRevenueIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOtherNotReportedIntangibleNonRevenueOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.OtherNotReportedRevenue
    
            ^Context = RP:RP.OtherNotReportedRevenue
            */
            assertion = (report.RPOtherNotReportedRevenueExists != false && report.RPOtherNotReportedRevenueIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOtherNotReportedRevenueOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.OtherNotReportedTangibleNonRevenue
    
            ^Context = RP:RP.OtherNotReportedTangibleNonRevenue
            */
            assertion = (report.RPOtherNotReportedTangibleNonRevenueExists != false && report.RPOtherNotReportedTangibleNonRevenueIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOtherNotReportedTangibleNonRevenueOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.OtherReinsurance
    
            ^Context = RP:RP.OtherReinsurance
            */
            assertion = (report.RPOtherReinsuranceExists != false && report.RPOtherReinsuranceIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOtherReinsuranceOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.OtherServices
    
            ^Context = RP:RP.OtherServices
            */
            assertion = (report.RPOtherServicesExists != false && report.RPOtherServicesIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOtherServicesOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.Quarterly
    
            ^Context = RP:RP.Quarterly
            */
            assertion = (report.RPQuarterlyExists != false && report.RPQuarterlyIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPQuarterlyOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.RechargeAmounts
    
            ^Context = RP:RP.RechargeAmounts
            */
            assertion = (report.RPRechargeAmountsExists != false && report.RPRechargeAmountsIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPRechargeAmountsOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.Reinsurance
    
            ^Context = RP:RP.Reinsurance
            */
            assertion = (report.RPReinsuranceExists != false && report.RPReinsuranceIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPReinsuranceOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.RentLease
    
            ^Context = RP:RP.RentLease
            */
            assertion = (report.RPRentLeaseExists != false && report.RPRentLeaseIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPRentLeaseOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.ResearchAndDevelopment
    
            ^Context = RP:RP.ResearchAndDevelopment
            */
            assertion = (report.RPResearchAndDevelopmentExists != false && report.RPResearchAndDevelopmentIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPResearchAndDevelopmentOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.RevenueNonMonetaryPayment
    
            ^Context = RP:RP.RevenueNonMonetaryPayment
            */
            assertion = (report.RPRevenueNonMonetaryPaymentExists != false && report.RPRevenueNonMonetaryPaymentIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPRevenueNonMonetaryPaymentOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.RevenueNoPayment
    
            ^Context = RP:RP.RevenueNoPayment
            */
            assertion = (report.RPRevenueNoPaymentExists != false && report.RPRevenueNoPaymentIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPRevenueNoPaymentOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.Royalties
    
            ^Context = RP:RP.Royalties
            */
            assertion = (report.RPRoyaltiesExists != false && report.RPRoyaltiesIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPRoyaltiesOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.s128F
    
            ^Context = RP:RP.s128F
            */
            assertion = (report.RPs128FExists != false && report.RPs128FIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPs128FOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.s128FA
    
            ^Context = RP:RP.s128FA
            */
            assertion = (report.RPs128FAExists != false && report.RPs128FAIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPs128FAOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.SalesAndMarketing
    
            ^Context = RP:RP.SalesAndMarketing
            */
            assertion = (report.RPSalesAndMarketingExists != false && report.RPSalesAndMarketingIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPSalesAndMarketingOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.Securitisation
    
            ^Context = RP:RP.Securitisation
            */
            assertion = (report.RPSecuritisationExists != false && report.RPSecuritisationIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPSecuritisationOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.SoftwareAndITServices
    
            ^Context = RP:RP.SoftwareAndITServices
            */
            assertion = (report.RPSoftwareAndITServicesExists != false && report.RPSoftwareAndITServicesIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPSoftwareAndITServicesOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.TangibleRevenue
    
            ^Context = RP:RP.TangibleRevenue
            */
            assertion = (report.RPTangibleRevenueExists != false && report.RPTangibleRevenueIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPTangibleRevenueOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.Technical
    
            ^Context = RP:RP.Technical
            */
            assertion = (report.RPTechnicalExists != false && report.RPTechnicalIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPTechnicalOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.TotalNet
    
            ^Context = RP:RP.TotalNet
            */
            assertion = (report.RPTotalNetExists != false && report.RPTotalNetIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPTotalNetOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP.TotalNet:RP.TotalNet.RelatedParty
    
            ^Context = RP.TotalNet:RP.TotalNet.RelatedParty
            */
            assertion = (report.RPTotalNetRelatedPartyExists != false && report.RPTotalNetRelatedPartyIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPTotalNetRelatedPartyOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.Trading
    
            ^Context = RP:RP.Trading
            */
            assertion = (report.RPTradingExists != false && report.RPTradingIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPTradingOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP.Trading:RP.Trading.RelatedParty
    
            ^Context = RP.Trading:RP.Trading.RelatedParty
            */
            assertion = (report.RPTradingRelatedPartyExists != false && report.RPTradingRelatedPartyIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPTradingRelatedPartyOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.GEN.438029

            /*  VR.ATO.GEN.438029
            Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
    
            Data Elements:
    
            ^IdentifierScheme = RP:RP.TreasuryRelated
    
            ^Context = RP:RP.TreasuryRelated
            */
            assertion = (report.RPTreasuryRelatedExists != false && report.RPTreasuryRelatedIdentifierScheme != @"http://www.ato.gov.au/tfn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPTreasuryRelatedOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438029

            #region VR.ATO.IDS.440001

            /*  VR.ATO.IDS.440001
            If there is a 'No' response to 'Is the total of your international related party dealings over $2 million?' then no information should be entered for International related party dealings into Section A Questions 3 to 16 of the schedule.
    
            Legacy Rule Format:
            IF [IDS1] = FALSE AND ([IDS2] <> NULL OR [IDS9] <> NULL OR [IDS16] <> NULL OR [IDS21] <> NULL OR [IDS30] <> NULL OR [IDS35] <> NULL OR [IDS81] <> NULL OR [IDS88] <> NULL OR [IDS97] <> NULL OR [IDS123] <> NULL OR [IDS129] <> NULL OR [IDS138] <> NULL OR [IDS147] <> NULL OR [IDS150] <> NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS1] = IDS:RP:rvctc4.02.10:InternationalDealings.RelatedPartiesTransactionsExcessAggregateValue.Indicator
            [IDS2] = IDS:RP:rvctc4.02.05:InternationalDealings.RelatedPartiesTransactions.Indicator
            [IDS9] = IDS:RP:rvctc4.02.05:InternationalDealings.SpecifiedCountriesTransactions.Indicator
            [IDS16] = IDS:RP:rvctc4.02.05:InternationalDealings.TransactionsTangiblePropertyRevenue.Indicator
            [IDS21] = IDS:RP:rvctc4.02.05:InternationalDealings.TransactionsRoyaltiesLicenceFees.Indicator
            [IDS30] = IDS:RP:rvctc4.02.05:InternationalDealings.TransactionsRentLeasing.Indicator
            [IDS35] = IDS:RP:rvctc4.02.05:InternationalDealings.TransactionsServiceArrangements.Indicator
            [IDS81] = IDS:RP:rvctc4.02.05:InternationalDealings.DerivativeTransactions.Indicator
            [IDS88] = IDS:RP:rvctc4.02.05:InternationalDealings.DebtFactoringSecuritisation.Indicator
            [IDS97] = IDS:RP:rvctc4.02.05:InternationalDealings.OtherFinancialDealings.Indicator
            [IDS123] = IDS:RP:rvctc4.02.05:InternationalDealings.OtherRevenue.Indicator
            [IDS129] = IDS:RP:bafot.02.11:Miscellaneous.CapitalNature.Indicator
            [IDS138] = IDS:RP:bafot.02.11:Miscellaneous.ReceivedOrProvidedServicesPropertyProcessesRightsOrObligationsForNonMonetaryConsideration.Indicator
            [IDS147] = IDS:RP:rvctc4.02.05:InternationalDealings.ShareBasedEmployeeRemuneration.Indicator
            [IDS150] = IDS:RP:rvctc4.02.05:InternationalDealings.CostContributionArrangements.Indicator

            Technical Business Rule Format:
            ^IDS1 = FALSE AND (^IDS2 <> NULL OR ^IDS9 <> NULL OR ^IDS16 <> NULL OR ^IDS21 <> NULL OR ^IDS30 <> NULL OR ^IDS35 <> NULL OR ^IDS81 <> NULL OR ^IDS88 <> NULL OR ^IDS97 <> NULL OR ^IDS123 <> NULL OR ^IDS129 <> NULL OR ^IDS138 <> NULL OR ^IDS147 <> NULL OR ^IDS150 <> NULL)
    
            Data Elements:
    
            RP:^IDS1 = tns:InternationalDealings.RelatedPartiesTransactionsExcessAggregateValue.Indicator
    
            RP:^IDS2 = tns:InternationalDealings.RelatedPartiesTransactions.Indicator
    
            RP:^IDS9 = tns:InternationalDealings.SpecifiedCountriesTransactions.Indicator
    
            RP:^IDS16 = tns:InternationalDealings.TransactionsTangiblePropertyRevenue.Indicator
    
            RP:^IDS21 = tns:InternationalDealings.TransactionsRoyaltiesLicenceFees.Indicator
    
            RP:^IDS30 = tns:InternationalDealings.TransactionsRentLeasing.Indicator
    
            RP:^IDS35 = tns:InternationalDealings.TransactionsServiceArrangements.Indicator
    
            RP:^IDS81 = tns:InternationalDealings.DerivativeTransactions.Indicator
    
            RP:^IDS88 = tns:InternationalDealings.DebtFactoringSecuritisation.Indicator
    
            RP:^IDS97 = tns:InternationalDealings.OtherFinancialDealings.Indicator
    
            RP:^IDS123 = tns:InternationalDealings.OtherRevenue.Indicator
    
            RP:^IDS129 = tns:Miscellaneous.CapitalNature.Indicator
    
            RP:^IDS138 = tns:Miscellaneous.ReceivedOrProvidedServicesPropertyProcessesRightsOrObligationsForNonMonetaryConsideration.Indicator
    
            RP:^IDS147 = tns:InternationalDealings.ShareBasedEmployeeRemuneration.Indicator
    
            RP:^IDS150 = tns:InternationalDealings.CostContributionArrangements.Indicator
            */
            assertion = (report.IDS1 == false && (report.IDS2 != null || report.IDS9 != null || report.IDS16 != null || report.IDS21 != null || report.IDS30 != null || report.IDS35 != null || report.IDS81 != null || report.IDS88 != null || report.IDS97 != null || report.IDS123 != null || report.IDS129 != null || report.IDS138 != null || report.IDS147 != null || report.IDS150 != null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440001",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"International related party dealings information is not required",
                    LongDescription = @"If there is a 'False' response to 'Is the total of your international related party dealings over $2 million?' then no information should be entered for International related party dealings",
                    Location = "/xbrli:xbrl/tns:InternationalDealings.RelatedPartiesTransactionsExcessAggregateValue.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440001" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS1", Value = GetValueOrEmpty(report.IDS1) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS2", Value = GetValueOrEmpty(report.IDS2) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS9", Value = GetValueOrEmpty(report.IDS9) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS16", Value = GetValueOrEmpty(report.IDS16) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS21", Value = GetValueOrEmpty(report.IDS21) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS30", Value = GetValueOrEmpty(report.IDS30) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS35", Value = GetValueOrEmpty(report.IDS35) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS81", Value = GetValueOrEmpty(report.IDS81) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS88", Value = GetValueOrEmpty(report.IDS88) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS97", Value = GetValueOrEmpty(report.IDS97) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS123", Value = GetValueOrEmpty(report.IDS123) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS129", Value = GetValueOrEmpty(report.IDS129) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS138", Value = GetValueOrEmpty(report.IDS138) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS147", Value = GetValueOrEmpty(report.IDS147) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS150", Value = GetValueOrEmpty(report.IDS150) });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440001

            #region VR.ATO.IDS.440002

            /*  VR.ATO.IDS.440002
            If there is a 'Yes' response to 'Is the total of your international related party dealings over $2 million?' then all International related party dealings questions in Section A of the schedule must be completed.
    
            Legacy Rule Format:
            IF [IDS1] = TRUE AND ([IDS2] = NULL OR [IDS9] = NULL OR [IDS16] = NULL OR [IDS21] = NULL OR [IDS30] = NULL OR [IDS35] = NULL OR [IDS81] = NULL OR [IDS88] = NULL OR [IDS97] = NULL OR [IDS123] = NULL OR [IDS129] = NULL OR [IDS138] = NULL OR [IDS147] = NULL OR [IDS150] = NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS1] = IDS:RP:rvctc4.02.10:InternationalDealings.RelatedPartiesTransactionsExcessAggregateValue.Indicator
            [IDS2] = IDS:RP:rvctc4.02.05:InternationalDealings.RelatedPartiesTransactions.Indicator
            [IDS9] = IDS:RP:rvctc4.02.05:InternationalDealings.SpecifiedCountriesTransactions.Indicator
            [IDS16] = IDS:RP:rvctc4.02.05:InternationalDealings.TransactionsTangiblePropertyRevenue.Indicator
            [IDS21] = IDS:RP:rvctc4.02.05:InternationalDealings.TransactionsRoyaltiesLicenceFees.Indicator
            [IDS30] = IDS:RP:rvctc4.02.05:InternationalDealings.TransactionsRentLeasing.Indicator
            [IDS35] = IDS:RP:rvctc4.02.05:InternationalDealings.TransactionsServiceArrangements.Indicator
            [IDS81] = IDS:RP:rvctc4.02.05:InternationalDealings.DerivativeTransactions.Indicator
            [IDS88] = IDS:RP:rvctc4.02.05:InternationalDealings.DebtFactoringSecuritisation.Indicator
            [IDS97] = IDS:RP:rvctc4.02.05:InternationalDealings.OtherFinancialDealings.Indicator
            [IDS123] = IDS:RP:rvctc4.02.05:InternationalDealings.OtherRevenue.Indicator
            [IDS129] = IDS:RP:bafot.02.11:Miscellaneous.CapitalNature.Indicator
            [IDS138] = IDS:RP:bafot.02.11:Miscellaneous.ReceivedOrProvidedServicesPropertyProcessesRightsOrObligationsForNonMonetaryConsideration.Indicator
            [IDS147] = IDS:RP:rvctc4.02.05:InternationalDealings.ShareBasedEmployeeRemuneration.Indicator
            [IDS150] = IDS:RP:rvctc4.02.05:InternationalDealings.CostContributionArrangements.Indicator

            Technical Business Rule Format:
            ^IDS1 = TRUE AND (^IDS2 = NULL OR ^IDS9 = NULL OR ^IDS16 = NULL OR ^IDS21 = NULL OR ^IDS30 = NULL OR ^IDS35 = NULL OR ^IDS81 = NULL OR ^IDS88 = NULL OR ^IDS97 = NULL OR ^IDS123 = NULL OR ^IDS129 = NULL OR ^IDS138 = NULL OR ^IDS147 = NULL OR ^IDS150 = NULL)
    
            Data Elements:
    
            RP:^IDS1 = tns:InternationalDealings.RelatedPartiesTransactionsExcessAggregateValue.Indicator
    
            RP:^IDS2 = tns:InternationalDealings.RelatedPartiesTransactions.Indicator
    
            RP:^IDS9 = tns:InternationalDealings.SpecifiedCountriesTransactions.Indicator
    
            RP:^IDS16 = tns:InternationalDealings.TransactionsTangiblePropertyRevenue.Indicator
    
            RP:^IDS21 = tns:InternationalDealings.TransactionsRoyaltiesLicenceFees.Indicator
    
            RP:^IDS30 = tns:InternationalDealings.TransactionsRentLeasing.Indicator
    
            RP:^IDS35 = tns:InternationalDealings.TransactionsServiceArrangements.Indicator
    
            RP:^IDS81 = tns:InternationalDealings.DerivativeTransactions.Indicator
    
            RP:^IDS88 = tns:InternationalDealings.DebtFactoringSecuritisation.Indicator
    
            RP:^IDS97 = tns:InternationalDealings.OtherFinancialDealings.Indicator
    
            RP:^IDS123 = tns:InternationalDealings.OtherRevenue.Indicator
    
            RP:^IDS129 = tns:Miscellaneous.CapitalNature.Indicator
    
            RP:^IDS138 = tns:Miscellaneous.ReceivedOrProvidedServicesPropertyProcessesRightsOrObligationsForNonMonetaryConsideration.Indicator
    
            RP:^IDS147 = tns:InternationalDealings.ShareBasedEmployeeRemuneration.Indicator
    
            RP:^IDS150 = tns:InternationalDealings.CostContributionArrangements.Indicator
            */
            assertion = (report.IDS1 == true && (report.IDS2 == null || report.IDS9 == null || report.IDS16 == null || report.IDS21 == null || report.IDS30 == null || report.IDS35 == null || report.IDS81 == null || report.IDS88 == null || report.IDS97 == null || report.IDS123 == null || report.IDS129 == null || report.IDS138 == null || report.IDS147 == null || report.IDS150 == null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440002",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"International related party dealings information is required",
                    LongDescription = @"If there is a 'True' response to 'Is the total of your international related party dealings over $2 million?' then all International related party dealings questions must be completed",
                    Location = "/xbrli:xbrl/tns:InternationalDealings.RelatedPartiesTransactionsExcessAggregateValue.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440002" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS1", Value = GetValueOrEmpty(report.IDS1) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS2", Value = GetValueOrEmpty(report.IDS2) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS9", Value = GetValueOrEmpty(report.IDS9) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS16", Value = GetValueOrEmpty(report.IDS16) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS21", Value = GetValueOrEmpty(report.IDS21) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS30", Value = GetValueOrEmpty(report.IDS30) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS35", Value = GetValueOrEmpty(report.IDS35) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS81", Value = GetValueOrEmpty(report.IDS81) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS88", Value = GetValueOrEmpty(report.IDS88) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS97", Value = GetValueOrEmpty(report.IDS97) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS123", Value = GetValueOrEmpty(report.IDS123) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS129", Value = GetValueOrEmpty(report.IDS129) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS138", Value = GetValueOrEmpty(report.IDS138) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS147", Value = GetValueOrEmpty(report.IDS147) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS150", Value = GetValueOrEmpty(report.IDS150) });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440002

            #region VR.ATO.IDS.440006

            /*  VR.ATO.IDS.440006
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF (bafpr1.xx.xx:Expense.Total.Amount <> NULL) AND (bafpr1.xx.xx:Expense.Total.Amount <> MONETARY(U,11,0)) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS72, 'U', 11, 0)
    
            Data Elements:
    
            RP.AssetManagement:^IDS72 = tns:Expense.Total.Amount
            */
            assertion = NotMonetary(report.IDS72, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Expense.Total.Amount[@contextRef='" + report.RPAssetManagementId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440006" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS72", Value = report.IDS72.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440006

            #region VR.ATO.IDS.440006

            /*  VR.ATO.IDS.440006
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF (bafpr1.xx.xx:Expense.Total.Amount <> NULL) AND (bafpr1.xx.xx:Expense.Total.Amount <> MONETARY(U,11,0)) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS82, 'U', 11, 0)
    
            Data Elements:
    
            RP.Derivatives:^IDS82 = tns:Expense.Total.Amount
            */
            assertion = NotMonetary(report.IDS82, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Expense.Total.Amount[@contextRef='" + report.RPDerivativesId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440006" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS82", Value = report.IDS82.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440006

            #region VR.ATO.IDS.440006

            /*  VR.ATO.IDS.440006
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF (bafpr1.xx.xx:Expense.Total.Amount <> NULL) AND (bafpr1.xx.xx:Expense.Total.Amount <> MONETARY(U,11,0)) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS106, 'U', 11, 0)
    
            Data Elements:
    
            RP.OtherGuarantees:^IDS106 = tns:Expense.Total.Amount
            */
            assertion = NotMonetary(report.IDS106, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Expense.Total.Amount[@contextRef='" + report.RPOtherGuaranteesId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440006" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS106", Value = report.IDS106.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440006

            #region VR.ATO.IDS.440006

            /*  VR.ATO.IDS.440006
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF (bafpr1.xx.xx:Expense.Total.Amount <> NULL) AND (bafpr1.xx.xx:Expense.Total.Amount <> MONETARY(U,11,0)) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS44, 'U', 11, 0)
    
            Data Elements:
    
            RP.Insurance:^IDS44 = tns:Expense.Total.Amount
            */
            assertion = NotMonetary(report.IDS44, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Expense.Total.Amount[@contextRef='" + report.RPInsuranceId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440006" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS44", Value = report.IDS44.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440006

            #region VR.ATO.IDS.440006

            /*  VR.ATO.IDS.440006
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF (bafpr1.xx.xx:Expense.Total.Amount <> NULL) AND (bafpr1.xx.xx:Expense.Total.Amount <> MONETARY(U,11,0)) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS110, 'U', 11, 0)
    
            Data Elements:
    
            RP.OtherInsurance:^IDS110 = tns:Expense.Total.Amount
            */
            assertion = NotMonetary(report.IDS110, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Expense.Total.Amount[@contextRef='" + report.RPOtherInsuranceId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440006" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS110", Value = report.IDS110.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440006

            #region VR.ATO.IDS.440006

            /*  VR.ATO.IDS.440006
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF (bafpr1.xx.xx:Expense.Total.Amount <> NULL) AND (bafpr1.xx.xx:Expense.Total.Amount <> MONETARY(U,11,0)) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS102, 'U', 11, 0)
    
            Data Elements:
    
            RP.OtherInterest:^IDS102 = tns:Expense.Total.Amount
            */
            assertion = NotMonetary(report.IDS102, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Expense.Total.Amount[@contextRef='" + report.RPOtherInterestId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440006" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS102", Value = report.IDS102.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440006

            #region VR.ATO.IDS.440006

            /*  VR.ATO.IDS.440006
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF (bafpr1.xx.xx:Expense.Total.Amount <> NULL) AND (bafpr1.xx.xx:Expense.Total.Amount <> MONETARY(U,11,0)) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS68, 'U', 11, 0)
    
            Data Elements:
    
            RP.Logistics:^IDS68 = tns:Expense.Total.Amount
            */
            assertion = NotMonetary(report.IDS68, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Expense.Total.Amount[@contextRef='" + report.RPLogisticsId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440006" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS68", Value = report.IDS68.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440006

            #region VR.ATO.IDS.440006

            /*  VR.ATO.IDS.440006
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF (bafpr1.xx.xx:Expense.Total.Amount <> NULL) AND (bafpr1.xx.xx:Expense.Total.Amount <> MONETARY(U,11,0)) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS40, 'U', 11, 0)
    
            Data Elements:
    
            RP.ManagementAndAdmin:^IDS40 = tns:Expense.Total.Amount
            */
            assertion = NotMonetary(report.IDS40, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Expense.Total.Amount[@contextRef='" + report.RPManagementAndAdminId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440006" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS40", Value = report.IDS40.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440006

            #region VR.ATO.IDS.440006

            /*  VR.ATO.IDS.440006
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF (bafpr1.xx.xx:Expense.Total.Amount <> NULL) AND (bafpr1.xx.xx:Expense.Total.Amount <> MONETARY(U,11,0)) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS124, 'U', 11, 0)
    
            Data Elements:
    
            RP.OtherNotReportedRevenue:^IDS124 = tns:Expense.Total.Amount
            */
            assertion = NotMonetary(report.IDS124, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Expense.Total.Amount[@contextRef='" + report.RPOtherNotReportedRevenueId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440006" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS124", Value = report.IDS124.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440006

            #region VR.ATO.IDS.440006

            /*  VR.ATO.IDS.440006
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF (bafpr1.xx.xx:Expense.Total.Amount <> NULL) AND (bafpr1.xx.xx:Expense.Total.Amount <> MONETARY(U,11,0)) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS118, 'U', 11, 0)
    
            Data Elements:
    
            RP.OtherFinancialDealings:^IDS118 = tns:Expense.Total.Amount
            */
            assertion = NotMonetary(report.IDS118, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Expense.Total.Amount[@contextRef='" + report.RPOtherFinancialDealingsId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440006" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS118", Value = report.IDS118.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440006

            #region VR.ATO.IDS.440006

            /*  VR.ATO.IDS.440006
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF (bafpr1.xx.xx:Expense.Total.Amount <> NULL) AND (bafpr1.xx.xx:Expense.Total.Amount <> MONETARY(U,11,0)) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS76, 'U', 11, 0)
    
            Data Elements:
    
            RP.OtherServices:^IDS76 = tns:Expense.Total.Amount
            */
            assertion = NotMonetary(report.IDS76, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Expense.Total.Amount[@contextRef='" + report.RPOtherServicesId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440006" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS76", Value = report.IDS76.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440006

            #region VR.ATO.IDS.440006

            /*  VR.ATO.IDS.440006
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF (bafpr1.xx.xx:Expense.Total.Amount <> NULL) AND (bafpr1.xx.xx:Expense.Total.Amount <> MONETARY(U,11,0)) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS48, 'U', 11, 0)
    
            Data Elements:
    
            RP.Reinsurance:^IDS48 = tns:Expense.Total.Amount
            */
            assertion = NotMonetary(report.IDS48, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Expense.Total.Amount[@contextRef='" + report.RPReinsuranceId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440006" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS48", Value = report.IDS48.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440006

            #region VR.ATO.IDS.440006

            /*  VR.ATO.IDS.440006
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF (bafpr1.xx.xx:Expense.Total.Amount <> NULL) AND (bafpr1.xx.xx:Expense.Total.Amount <> MONETARY(U,11,0)) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS114, 'U', 11, 0)
    
            Data Elements:
    
            RP.OtherReinsurance:^IDS114 = tns:Expense.Total.Amount
            */
            assertion = NotMonetary(report.IDS114, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Expense.Total.Amount[@contextRef='" + report.RPOtherReinsuranceId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440006" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS114", Value = report.IDS114.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440006

            #region VR.ATO.IDS.440006

            /*  VR.ATO.IDS.440006
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF (bafpr1.xx.xx:Expense.Total.Amount <> NULL) AND (bafpr1.xx.xx:Expense.Total.Amount <> MONETARY(U,11,0)) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS31, 'U', 11, 0)
    
            Data Elements:
    
            RP.RentLease:^IDS31 = tns:Expense.Total.Amount
            */
            assertion = NotMonetary(report.IDS31, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Expense.Total.Amount[@contextRef='" + report.RPRentLeaseId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440006" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS31", Value = report.IDS31.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440006

            #region VR.ATO.IDS.440006

            /*  VR.ATO.IDS.440006
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF (bafpr1.xx.xx:Expense.Total.Amount <> NULL) AND (bafpr1.xx.xx:Expense.Total.Amount <> MONETARY(U,11,0)) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS52, 'U', 11, 0)
    
            Data Elements:
    
            RP.ResearchAndDevelopment:^IDS52 = tns:Expense.Total.Amount
            */
            assertion = NotMonetary(report.IDS52, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Expense.Total.Amount[@contextRef='" + report.RPResearchAndDevelopmentId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440006" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS52", Value = report.IDS52.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440006

            #region VR.ATO.IDS.440006

            /*  VR.ATO.IDS.440006
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF (bafpr1.xx.xx:Expense.Total.Amount <> NULL) AND (bafpr1.xx.xx:Expense.Total.Amount <> MONETARY(U,11,0)) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS56, 'U', 11, 0)
    
            Data Elements:
    
            RP.SalesAndMarketing:^IDS56 = tns:Expense.Total.Amount
            */
            assertion = NotMonetary(report.IDS56, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Expense.Total.Amount[@contextRef='" + report.RPSalesAndMarketingId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440006" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS56", Value = report.IDS56.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440006

            #region VR.ATO.IDS.440006

            /*  VR.ATO.IDS.440006
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF (bafpr1.xx.xx:Expense.Total.Amount <> NULL) AND (bafpr1.xx.xx:Expense.Total.Amount <> MONETARY(U,11,0)) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS60, 'U', 11, 0)
    
            Data Elements:
    
            RP.SoftwareAndITServices:^IDS60 = tns:Expense.Total.Amount
            */
            assertion = NotMonetary(report.IDS60, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Expense.Total.Amount[@contextRef='" + report.RPSoftwareAndITServicesId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440006" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS60", Value = report.IDS60.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440006

            #region VR.ATO.IDS.440006

            /*  VR.ATO.IDS.440006
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF (bafpr1.xx.xx:Expense.Total.Amount <> NULL) AND (bafpr1.xx.xx:Expense.Total.Amount <> MONETARY(U,11,0)) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS17, 'U', 11, 0)
    
            Data Elements:
    
            RP.TangibleRevenue:^IDS17 = tns:Expense.Total.Amount
            */
            assertion = NotMonetary(report.IDS17, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Expense.Total.Amount[@contextRef='" + report.RPTangibleRevenueId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440006" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS17", Value = report.IDS17.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440006

            #region VR.ATO.IDS.440006

            /*  VR.ATO.IDS.440006
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF (bafpr1.xx.xx:Expense.Total.Amount <> NULL) AND (bafpr1.xx.xx:Expense.Total.Amount <> MONETARY(U,11,0)) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS64, 'U', 11, 0)
    
            Data Elements:
    
            RP.Technical:^IDS64 = tns:Expense.Total.Amount
            */
            assertion = NotMonetary(report.IDS64, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Expense.Total.Amount[@contextRef='" + report.RPTechnicalId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440006" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS64", Value = report.IDS64.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440006

            #region VR.ATO.IDS.440006

            /*  VR.ATO.IDS.440006
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF (bafpr1.xx.xx:Expense.Total.Amount <> NULL) AND (bafpr1.xx.xx:Expense.Total.Amount <> MONETARY(U,11,0)) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS36, 'U', 11, 0)
    
            Data Elements:
    
            RP.TreasuryRelated:^IDS36 = tns:Expense.Total.Amount
            */
            assertion = NotMonetary(report.IDS36, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Expense.Total.Amount[@contextRef='" + report.RPTreasuryRelatedId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440006" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS36", Value = report.IDS36.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440006

            #region VR.ATO.IDS.440007

            /*  VR.ATO.IDS.440007
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF (bafpr1.xx.xx:Revenue.Total.Amount <> NULL) AND (bafpr1.xx.xx:Revenue.Total.Amount <> MONETARY(U,11,0)) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS73, 'U', 11, 0)
    
            Data Elements:
    
            RP.AssetManagement:^IDS73 = tns:Revenue.Total.Amount
            */
            assertion = NotMonetary(report.IDS73, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Revenue.Total.Amount[@contextRef='" + report.RPAssetManagementId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440007" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS73", Value = report.IDS73.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440007

            #region VR.ATO.IDS.440007

            /*  VR.ATO.IDS.440007
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF (bafpr1.xx.xx:Revenue.Total.Amount <> NULL) AND (bafpr1.xx.xx:Revenue.Total.Amount <> MONETARY(U,11,0)) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS83, 'U', 11, 0)
    
            Data Elements:
    
            RP.Derivatives:^IDS83 = tns:Revenue.Total.Amount
            */
            assertion = NotMonetary(report.IDS83, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Revenue.Total.Amount[@contextRef='" + report.RPDerivativesId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440007" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS83", Value = report.IDS83.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440007

            #region VR.ATO.IDS.440007

            /*  VR.ATO.IDS.440007
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF (bafpr1.xx.xx:Revenue.Total.Amount <> NULL) AND (bafpr1.xx.xx:Revenue.Total.Amount <> MONETARY(U,11,0)) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS107, 'U', 11, 0)
    
            Data Elements:
    
            RP.OtherGuarantees:^IDS107 = tns:Revenue.Total.Amount
            */
            assertion = NotMonetary(report.IDS107, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Revenue.Total.Amount[@contextRef='" + report.RPOtherGuaranteesId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440007" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS107", Value = report.IDS107.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440007

            #region VR.ATO.IDS.440007

            /*  VR.ATO.IDS.440007
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF (bafpr1.xx.xx:Revenue.Total.Amount <> NULL) AND (bafpr1.xx.xx:Revenue.Total.Amount <> MONETARY(U,11,0)) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS45, 'U', 11, 0)
    
            Data Elements:
    
            RP.Insurance:^IDS45 = tns:Revenue.Total.Amount
            */
            assertion = NotMonetary(report.IDS45, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Revenue.Total.Amount[@contextRef='" + report.RPInsuranceId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440007" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS45", Value = report.IDS45.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440007

            #region VR.ATO.IDS.440007

            /*  VR.ATO.IDS.440007
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF (bafpr1.xx.xx:Revenue.Total.Amount <> NULL) AND (bafpr1.xx.xx:Revenue.Total.Amount <> MONETARY(U,11,0)) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS111, 'U', 11, 0)
    
            Data Elements:
    
            RP.OtherInsurance:^IDS111 = tns:Revenue.Total.Amount
            */
            assertion = NotMonetary(report.IDS111, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Revenue.Total.Amount[@contextRef='" + report.RPOtherInsuranceId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440007" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS111", Value = report.IDS111.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440007

            #region VR.ATO.IDS.440007

            /*  VR.ATO.IDS.440007
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF (bafpr1.xx.xx:Revenue.Total.Amount <> NULL) AND (bafpr1.xx.xx:Revenue.Total.Amount <> MONETARY(U,11,0)) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS103, 'U', 11, 0)
    
            Data Elements:
    
            RP.OtherInterest:^IDS103 = tns:Revenue.Total.Amount
            */
            assertion = NotMonetary(report.IDS103, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Revenue.Total.Amount[@contextRef='" + report.RPOtherInterestId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440007" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS103", Value = report.IDS103.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440007

            #region VR.ATO.IDS.440007

            /*  VR.ATO.IDS.440007
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF (bafpr1.xx.xx:Revenue.Total.Amount <> NULL) AND (bafpr1.xx.xx:Revenue.Total.Amount <> MONETARY(U,11,0)) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS69, 'U', 11, 0)
    
            Data Elements:
    
            RP.Logistics:^IDS69 = tns:Revenue.Total.Amount
            */
            assertion = NotMonetary(report.IDS69, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Revenue.Total.Amount[@contextRef='" + report.RPLogisticsId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440007" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS69", Value = report.IDS69.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440007

            #region VR.ATO.IDS.440007

            /*  VR.ATO.IDS.440007
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF (bafpr1.xx.xx:Revenue.Total.Amount <> NULL) AND (bafpr1.xx.xx:Revenue.Total.Amount <> MONETARY(U,11,0)) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS41, 'U', 11, 0)
    
            Data Elements:
    
            RP.ManagementAndAdmin:^IDS41 = tns:Revenue.Total.Amount
            */
            assertion = NotMonetary(report.IDS41, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Revenue.Total.Amount[@contextRef='" + report.RPManagementAndAdminId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440007" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS41", Value = report.IDS41.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440007

            #region VR.ATO.IDS.440007

            /*  VR.ATO.IDS.440007
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF (bafpr1.xx.xx:Revenue.Total.Amount <> NULL) AND (bafpr1.xx.xx:Revenue.Total.Amount <> MONETARY(U,11,0)) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS125, 'U', 11, 0)
    
            Data Elements:
    
            RP.OtherNotReportedRevenue:^IDS125 = tns:Revenue.Total.Amount
            */
            assertion = NotMonetary(report.IDS125, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Revenue.Total.Amount[@contextRef='" + report.RPOtherNotReportedRevenueId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440007" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS125", Value = report.IDS125.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440007

            #region VR.ATO.IDS.440007

            /*  VR.ATO.IDS.440007
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF (bafpr1.xx.xx:Revenue.Total.Amount <> NULL) AND (bafpr1.xx.xx:Revenue.Total.Amount <> MONETARY(U,11,0)) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS119, 'U', 11, 0)
    
            Data Elements:
    
            RP.OtherFinancialDealings:^IDS119 = tns:Revenue.Total.Amount
            */
            assertion = NotMonetary(report.IDS119, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Revenue.Total.Amount[@contextRef='" + report.RPOtherFinancialDealingsId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440007" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS119", Value = report.IDS119.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440007

            #region VR.ATO.IDS.440007

            /*  VR.ATO.IDS.440007
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF (bafpr1.xx.xx:Revenue.Total.Amount <> NULL) AND (bafpr1.xx.xx:Revenue.Total.Amount <> MONETARY(U,11,0)) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS77, 'U', 11, 0)
    
            Data Elements:
    
            RP.OtherServices:^IDS77 = tns:Revenue.Total.Amount
            */
            assertion = NotMonetary(report.IDS77, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Revenue.Total.Amount[@contextRef='" + report.RPOtherServicesId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440007" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS77", Value = report.IDS77.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440007

            #region VR.ATO.IDS.440007

            /*  VR.ATO.IDS.440007
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF (bafpr1.xx.xx:Revenue.Total.Amount <> NULL) AND (bafpr1.xx.xx:Revenue.Total.Amount <> MONETARY(U,11,0)) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS49, 'U', 11, 0)
    
            Data Elements:
    
            RP.Reinsurance:^IDS49 = tns:Revenue.Total.Amount
            */
            assertion = NotMonetary(report.IDS49, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Revenue.Total.Amount[@contextRef='" + report.RPReinsuranceId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440007" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS49", Value = report.IDS49.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440007

            #region VR.ATO.IDS.440007

            /*  VR.ATO.IDS.440007
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF (bafpr1.xx.xx:Revenue.Total.Amount <> NULL) AND (bafpr1.xx.xx:Revenue.Total.Amount <> MONETARY(U,11,0)) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS115, 'U', 11, 0)
    
            Data Elements:
    
            RP.OtherReinsurance:^IDS115 = tns:Revenue.Total.Amount
            */
            assertion = NotMonetary(report.IDS115, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Revenue.Total.Amount[@contextRef='" + report.RPOtherReinsuranceId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440007" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS115", Value = report.IDS115.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440007

            #region VR.ATO.IDS.440007

            /*  VR.ATO.IDS.440007
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF (bafpr1.xx.xx:Revenue.Total.Amount <> NULL) AND (bafpr1.xx.xx:Revenue.Total.Amount <> MONETARY(U,11,0)) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS32, 'U', 11, 0)
    
            Data Elements:
    
            RP.RentLease:^IDS32 = tns:Revenue.Total.Amount
            */
            assertion = NotMonetary(report.IDS32, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Revenue.Total.Amount[@contextRef='" + report.RPRentLeaseId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440007" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS32", Value = report.IDS32.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440007

            #region VR.ATO.IDS.440007

            /*  VR.ATO.IDS.440007
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF (bafpr1.xx.xx:Revenue.Total.Amount <> NULL) AND (bafpr1.xx.xx:Revenue.Total.Amount <> MONETARY(U,11,0)) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS53, 'U', 11, 0)
    
            Data Elements:
    
            RP.ResearchAndDevelopment:^IDS53 = tns:Revenue.Total.Amount
            */
            assertion = NotMonetary(report.IDS53, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Revenue.Total.Amount[@contextRef='" + report.RPResearchAndDevelopmentId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440007" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS53", Value = report.IDS53.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440007

            #region VR.ATO.IDS.440007

            /*  VR.ATO.IDS.440007
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF (bafpr1.xx.xx:Revenue.Total.Amount <> NULL) AND (bafpr1.xx.xx:Revenue.Total.Amount <> MONETARY(U,11,0)) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS57, 'U', 11, 0)
    
            Data Elements:
    
            RP.SalesAndMarketing:^IDS57 = tns:Revenue.Total.Amount
            */
            assertion = NotMonetary(report.IDS57, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Revenue.Total.Amount[@contextRef='" + report.RPSalesAndMarketingId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440007" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS57", Value = report.IDS57.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440007

            #region VR.ATO.IDS.440007

            /*  VR.ATO.IDS.440007
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF (bafpr1.xx.xx:Revenue.Total.Amount <> NULL) AND (bafpr1.xx.xx:Revenue.Total.Amount <> MONETARY(U,11,0)) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS61, 'U', 11, 0)
    
            Data Elements:
    
            RP.SoftwareAndITServices:^IDS61 = tns:Revenue.Total.Amount
            */
            assertion = NotMonetary(report.IDS61, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Revenue.Total.Amount[@contextRef='" + report.RPSoftwareAndITServicesId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440007" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS61", Value = report.IDS61.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440007

            #region VR.ATO.IDS.440007

            /*  VR.ATO.IDS.440007
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF (bafpr1.xx.xx:Revenue.Total.Amount <> NULL) AND (bafpr1.xx.xx:Revenue.Total.Amount <> MONETARY(U,11,0)) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS18, 'U', 11, 0)
    
            Data Elements:
    
            RP.TangibleRevenue:^IDS18 = tns:Revenue.Total.Amount
            */
            assertion = NotMonetary(report.IDS18, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Revenue.Total.Amount[@contextRef='" + report.RPTangibleRevenueId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440007" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS18", Value = report.IDS18.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440007

            #region VR.ATO.IDS.440007

            /*  VR.ATO.IDS.440007
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF (bafpr1.xx.xx:Revenue.Total.Amount <> NULL) AND (bafpr1.xx.xx:Revenue.Total.Amount <> MONETARY(U,11,0)) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS65, 'U', 11, 0)
    
            Data Elements:
    
            RP.Technical:^IDS65 = tns:Revenue.Total.Amount
            */
            assertion = NotMonetary(report.IDS65, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Revenue.Total.Amount[@contextRef='" + report.RPTechnicalId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440007" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS65", Value = report.IDS65.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440007

            #region VR.ATO.IDS.440007

            /*  VR.ATO.IDS.440007
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF (bafpr1.xx.xx:Revenue.Total.Amount <> NULL) AND (bafpr1.xx.xx:Revenue.Total.Amount <> MONETARY(U,11,0)) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS37, 'U', 11, 0)
    
            Data Elements:
    
            RP.TreasuryRelated:^IDS37 = tns:Revenue.Total.Amount
            */
            assertion = NotMonetary(report.IDS37, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Revenue.Total.Amount[@contextRef='" + report.RPTreasuryRelatedId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440007" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS37", Value = report.IDS37.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440007

            #region VR.ATO.IDS.440012

            /*  VR.ATO.IDS.440012
            If International related party dealings information has been completed for Tangible property of a revenue nature then the response to 'Did you have any international related party dealings involving tangible property of a revenue nature, including trading stock and raw materials?' must be 'True'.
    
            Legacy Rule Format:
            IF ([IDS16] <> TRUE) AND ([IDS17] <> NULL OR [IDS18] <> NULL OR [IDS19] <> NULL OR [IDS20] <> NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS16] = IDS:RP:rvctc4.02.05:InternationalDealings.TransactionsTangiblePropertyRevenue.Indicator
            [IDS17] = IDS:RP.TangibleRevenue:bafpr1.02.16:Expense.Total.Amount
            [IDS18] = IDS:RP.TangibleRevenue:bafpr1.02.26:Revenue.Total.Amount
            [IDS19] = IDS:RP.TangibleRevenue:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS20] = IDS:RP.TangibleRevenue:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code

            Technical Business Rule Format:
            (^IDS16 <> TRUE) AND (^IDS17 <> NULL OR ^IDS18 <> NULL OR ^IDS19 <> NULL OR ^IDS20 <> NULL)
    
            Data Elements:
    
            RP:^IDS16 = tns:InternationalDealings.TransactionsTangiblePropertyRevenue.Indicator
    
            RP.TangibleRevenue:^IDS17 = tns:Expense.Total.Amount
    
            RP.TangibleRevenue:^IDS18 = tns:Revenue.Total.Amount
    
            RP.TangibleRevenue:^IDS19 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.TangibleRevenue:^IDS20 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            */
            assertion = (report.IDS16 != true && (report.IDS17 != null || report.IDS18 != null || report.IDS19 != null || report.IDS20 != null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440012",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"International related party dealings question incorrect",
                    LongDescription = @"If International related party dealings information has been completed for Tangible property of a revenue nature then the response to 'Did you have any international related party dealings involving tangible property of a revenue nature, including trading stock and raw materials?' must be 'True'",
                    Location = "/xbrli:xbrl/tns:InternationalDealings.TransactionsTangiblePropertyRevenue.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440012" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS16", Value = GetValueOrEmpty(report.IDS16) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS17", Value = report.IDS17.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS18", Value = report.IDS18.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS19", Value = report.IDS19 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS20", Value = report.IDS20 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440012

            #region VR.ATO.IDS.440013

            /*  VR.ATO.IDS.440013
            If there is a 'Yes' response to 'Did you have any international related party dealings involving tangible property of a revenue nature, including trading stock and raw materials?' then expenditure amount or revenue amount, main pricing methodology code and percentage of dealings with documentation code must be completed.
    
            Legacy Rule Format:
            IF [IDS16] = TRUE AND (([IDS17] = NULL AND [IDS18] = NULL) OR [IDS19] = NULL OR [IDS20] = NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS16] = IDS:RP:rvctc4.02.05:InternationalDealings.TransactionsTangiblePropertyRevenue.Indicator
            [IDS17] = IDS:RP.TangibleRevenue:bafpr1.02.16:Expense.Total.Amount
            [IDS18] = IDS:RP.TangibleRevenue:bafpr1.02.26:Revenue.Total.Amount
            [IDS19] = IDS:RP.TangibleRevenue:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS20] = IDS:RP.TangibleRevenue:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code

            Technical Business Rule Format:
            ^IDS16 = TRUE AND ((^IDS17 = NULL AND ^IDS18 = NULL) OR ^IDS19 = NULL OR ^IDS20 = NULL)
    
            Data Elements:
    
            RP:^IDS16 = tns:InternationalDealings.TransactionsTangiblePropertyRevenue.Indicator
    
            RP.TangibleRevenue:^IDS17 = tns:Expense.Total.Amount
    
            RP.TangibleRevenue:^IDS18 = tns:Revenue.Total.Amount
    
            RP.TangibleRevenue:^IDS19 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.TangibleRevenue:^IDS20 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            */
            assertion = (report.IDS16 == true && (report.IDS17 == null && report.IDS18 == null || report.IDS19 == null || report.IDS20 == null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440013",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Tangible property of a revenue nature information incomplete",
                    LongDescription = @"If there is a 'True' response to 'Did you have any international related party dealings involving tangible property of a revenue nature, including trading stock and raw materials?' then expenditure or revenue, main pricing methodology code and percentage of dealings with documentation code must be completed",
                    Location = "/xbrli:xbrl/tns:InternationalDealings.TransactionsTangiblePropertyRevenue.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440013" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS16", Value = GetValueOrEmpty(report.IDS16) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS17", Value = report.IDS17.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS18", Value = report.IDS18.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS19", Value = report.IDS19 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS20", Value = report.IDS20 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440013

            #region VR.ATO.IDS.440014

            /*  VR.ATO.IDS.440014
            If International related party dealings information has been completed for royalties or licence fees then the response to 'Did you have international related party dealings involving royalties or licence fees?' must be 'True'.
    
            Legacy Rule Format:
            IF [IDS21] <> TRUE AND ([IDS22] <> NULL OR [IDS23] <> NULL OR [IDS24] <> NULL OR [IDS25] <> NULL OR [IDS26] <> NULL OR [IDS27] <> NULL OR [IDS28] <> NULL OR [IDS29] <> NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS21] = IDS:RP:rvctc4.02.05:InternationalDealings.TransactionsRoyaltiesLicenceFees.Indicator
            [IDS22] = IDS:RP.Royalties:bafpr1.02.12:Expense.DeductionsTotal.Amount
            [IDS23] = IDS:RP.Royalties:bafpr1.02.12:Income.IncludedInAssessableTotal.Amount
            [IDS24] = IDS:RP.Royalties:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS25] = IDS:RP.Royalties:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            [IDS26] = IDS:RP.LicenceFees:bafpr1.02.12:Expense.DeductionsTotal.Amount
            [IDS27] = IDS:RP.LicenceFees:bafpr1.02.12:Income.IncludedInAssessableTotal.Amount
            [IDS28] = IDS:RP.LicenceFees:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS29] = IDS:RP.LicenceFees:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code

            Technical Business Rule Format:
            ^IDS21 <> TRUE AND (^IDS22 <> NULL OR ^IDS23 <> NULL OR ^IDS24 <> NULL OR ^IDS25 <> NULL OR ^IDS26 <> NULL OR ^IDS27 <> NULL OR ^IDS28 <> NULL OR ^IDS29 <> NULL)
    
            Data Elements:
    
            RP:^IDS21 = tns:InternationalDealings.TransactionsRoyaltiesLicenceFees.Indicator
    
            RP.Royalties:^IDS22 = tns:Expense.DeductionsTotal.Amount
    
            RP.Royalties:^IDS23 = tns:Income.IncludedInAssessableTotal.Amount
    
            RP.Royalties:^IDS24 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.Royalties:^IDS25 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
    
            RP.LicenceFees:^IDS26 = tns:Expense.DeductionsTotal.Amount
    
            RP.LicenceFees:^IDS27 = tns:Income.IncludedInAssessableTotal.Amount
    
            RP.LicenceFees:^IDS28 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.LicenceFees:^IDS29 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            */
            assertion = (report.IDS21 != true && (report.IDS22 != null || report.IDS23 != null || report.IDS24 != null || report.IDS25 != null || report.IDS26 != null || report.IDS27 != null || report.IDS28 != null || report.IDS29 != null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440014",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"International related party dealings question incorrect",
                    LongDescription = @"If International related party dealings information has been completed for royalties or licence fees then the response to 'Did you have international related party dealings involving royalties or licence fees?' must be 'True'",
                    Location = "/xbrli:xbrl/tns:InternationalDealings.TransactionsRoyaltiesLicenceFees.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440014" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS21", Value = GetValueOrEmpty(report.IDS21) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS22", Value = report.IDS22.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS23", Value = report.IDS23.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS24", Value = report.IDS24 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS25", Value = report.IDS25 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS26", Value = report.IDS26.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS27", Value = report.IDS27.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS28", Value = report.IDS28 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS29", Value = report.IDS29 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440014

            #region VR.ATO.IDS.440015

            /*  VR.ATO.IDS.440015
            If an amount of expenditure or revenue is present, both the main pricing methodology and the code for the percentage of the total dollar value of related party international dealings for which you have documentation must be completed.
    
            Legacy Rule Format:
            IF [IDS21] = TRUE AND [IDS22] = NULL AND [IDS23] = NULL AND [IDS24] = NULL AND [IDS25] = NULL AND [IDS26] = NULL AND [IDS27] = NULL AND [IDS28] = NULL AND [IDS29] = NULL
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS21] = IDS:RP:rvctc4.02.05:InternationalDealings.TransactionsRoyaltiesLicenceFees.Indicator
            [IDS22] = IDS:RP.Royalties:bafpr1.02.12:Expense.DeductionsTotal.Amount
            [IDS23] = IDS:RP.Royalties:bafpr1.02.12:Income.IncludedInAssessableTotal.Amount
            [IDS24] = IDS:RP.Royalties:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS25] = IDS:RP.Royalties:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            [IDS26] = IDS:RP.LicenceFees:bafpr1.02.12:Expense.DeductionsTotal.Amount
            [IDS27] = IDS:RP.LicenceFees:bafpr1.02.12:Income.IncludedInAssessableTotal.Amount
            [IDS28] = IDS:RP.LicenceFees:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS29] = IDS:RP.LicenceFees:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code

            Technical Business Rule Format:
            ^IDS21 = TRUE AND ^IDS22 = NULL AND ^IDS23 = NULL AND ^IDS24 = NULL AND ^IDS25 = NULL AND ^IDS26 = NULL AND ^IDS27 = NULL AND ^IDS28 = NULL AND ^IDS29 = NULL
    
            Data Elements:
    
            RP:^IDS21 = tns:InternationalDealings.TransactionsRoyaltiesLicenceFees.Indicator
    
            RP.Royalties:^IDS22 = tns:Expense.DeductionsTotal.Amount
    
            RP.Royalties:^IDS23 = tns:Income.IncludedInAssessableTotal.Amount
    
            RP.Royalties:^IDS24 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.Royalties:^IDS25 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
    
            RP.LicenceFees:^IDS26 = tns:Expense.DeductionsTotal.Amount
    
            RP.LicenceFees:^IDS27 = tns:Income.IncludedInAssessableTotal.Amount
    
            RP.LicenceFees:^IDS28 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.LicenceFees:^IDS29 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            */
            assertion = (report.IDS21 == true && report.IDS22 == null && report.IDS23 == null && report.IDS24 == null && report.IDS25 == null && report.IDS26 == null && report.IDS27 == null && report.IDS28 == null && report.IDS29 == null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440015",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"International related party dealings information required",
                    LongDescription = @"If there is a 'True' response to 'Did you have international related party dealings involving royalties or licence fees?' then royalties or licence fee information must be completed",
                    Location = "/xbrli:xbrl/tns:InternationalDealings.TransactionsRoyaltiesLicenceFees.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440015" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS21", Value = GetValueOrEmpty(report.IDS21) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS22", Value = report.IDS22.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS23", Value = report.IDS23.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS24", Value = report.IDS24 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS25", Value = report.IDS25 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS26", Value = report.IDS26.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS27", Value = report.IDS27.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS28", Value = report.IDS28 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS29", Value = report.IDS29 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440015

            #region VR.ATO.IDS.440016

            /*  VR.ATO.IDS.440016
            If an amount of expenditure or revenue is present, both the main pricing methodology and the code for the percentage of the total dollar value of related party international dealings for which you have documentation must be completed.
    
            Legacy Rule Format:
            IF ([IDS22] <> NULL OR [IDS23] <> NULL OR [IDS24] <> NULL OR [IDS25] <> NULL) AND (([IDS22] = NULL AND [IDS23] = NULL) OR [IDS24] = NULL OR [IDS25] = NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS22] = IDS:RP.Royalties:bafpr1.02.12:Expense.DeductionsTotal.Amount
            [IDS23] = IDS:RP.Royalties:bafpr1.02.12:Income.IncludedInAssessableTotal.Amount
            [IDS24] = IDS:RP.Royalties:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS25] = IDS:RP.Royalties:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code

            Technical Business Rule Format:
            (^IDS22 <> NULL OR ^IDS23 <> NULL OR ^IDS24 <> NULL OR ^IDS25 <> NULL) AND ((^IDS22 = NULL AND ^IDS23 = NULL) OR ^IDS24 = NULL OR ^IDS25 = NULL)
    
            Data Elements:
    
            RP.Royalties:^IDS22 = tns:Expense.DeductionsTotal.Amount
    
            RP.Royalties:^IDS23 = tns:Income.IncludedInAssessableTotal.Amount
    
            RP.Royalties:^IDS24 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.Royalties:^IDS25 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            */
            assertion = ((report.IDS22 != null || report.IDS23 != null || report.IDS24 != null || report.IDS25 != null) && (report.IDS22 == null && report.IDS23 == null || report.IDS24 == null || report.IDS25 == null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440016",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Royalties information incomplete",
                    LongDescription = @"If royalties information has been completed then deductions or income, main pricing methodology code and percentage of dealings with documentation code must be completed",
                    Location = "/xbrli:xbrl/tns:Expense.DeductionsTotal.Amount[@contextRef='" + report.RPRoyaltiesId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440016" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS22", Value = report.IDS22.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS23", Value = report.IDS23.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS24", Value = report.IDS24 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS25", Value = report.IDS25 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440016

            #region VR.ATO.IDS.440017

            /*  VR.ATO.IDS.440017
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF (bafpr1.xx.xx:Expense.DeductionsTotal.Amount <> NULL) AND (bafpr1.xx.xx:Expense.DeductionsTotal.Amount <> MONETARY(U,11,0)) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS26, 'U', 11, 0)
    
            Data Elements:
    
            RP.LicenceFees:^IDS26 = tns:Expense.DeductionsTotal.Amount
            */
            assertion = NotMonetary(report.IDS26, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Expense.DeductionsTotal.Amount[@contextRef='" + report.RPLicenceFeesId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440017" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS26", Value = report.IDS26.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440017

            #region VR.ATO.IDS.440017

            /*  VR.ATO.IDS.440017
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF (bafpr1.xx.xx:Expense.DeductionsTotal.Amount <> NULL) AND (bafpr1.xx.xx:Expense.DeductionsTotal.Amount <> MONETARY(U,11,0)) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS148, 'U', 11, 0)
    
            Data Elements:
    
            RP.RechargeAmounts:^IDS148 = tns:Expense.DeductionsTotal.Amount
            */
            assertion = NotMonetary(report.IDS148, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Expense.DeductionsTotal.Amount[@contextRef='" + report.RPRechargeAmountsId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440017" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS148", Value = report.IDS148.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440017

            #region VR.ATO.IDS.440017

            /*  VR.ATO.IDS.440017
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF (bafpr1.xx.xx:Expense.DeductionsTotal.Amount <> NULL) AND (bafpr1.xx.xx:Expense.DeductionsTotal.Amount <> MONETARY(U,11,0)) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS22, 'U', 11, 0)
    
            Data Elements:
    
            RP.Royalties:^IDS22 = tns:Expense.DeductionsTotal.Amount
            */
            assertion = NotMonetary(report.IDS22, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Expense.DeductionsTotal.Amount[@contextRef='" + report.RPRoyaltiesId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440017" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS22", Value = report.IDS22.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440017

            #region VR.ATO.IDS.440018

            /*  VR.ATO.IDS.440018
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF (bafpr1.xx.xx:Income.IncludedInAssessableTotal.Amount <> NULL) AND (bafpr1.xx.xx:Income.IncludedInAssessableTotal.Amount <> MONETARY(U,11,0)) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS27, 'U', 11, 0)
    
            Data Elements:
    
            RP.LicenceFees:^IDS27 = tns:Income.IncludedInAssessableTotal.Amount
            */
            assertion = NotMonetary(report.IDS27, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Income.IncludedInAssessableTotal.Amount[@contextRef='" + report.RPLicenceFeesId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440018" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS27", Value = report.IDS27.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440018

            #region VR.ATO.IDS.440018

            /*  VR.ATO.IDS.440018
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF (bafpr1.xx.xx:Income.IncludedInAssessableTotal.Amount <> NULL) AND (bafpr1.xx.xx:Income.IncludedInAssessableTotal.Amount <> MONETARY(U,11,0)) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS149, 'U', 11, 0)
    
            Data Elements:
    
            RP.RechargeAmounts:^IDS149 = tns:Income.IncludedInAssessableTotal.Amount
            */
            assertion = NotMonetary(report.IDS149, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Income.IncludedInAssessableTotal.Amount[@contextRef='" + report.RPRechargeAmountsId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440018" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS149", Value = report.IDS149.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440018

            #region VR.ATO.IDS.440018

            /*  VR.ATO.IDS.440018
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF (bafpr1.xx.xx:Income.IncludedInAssessableTotal.Amount <> NULL) AND (bafpr1.xx.xx:Income.IncludedInAssessableTotal.Amount <> MONETARY(U,11,0)) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS23, 'U', 11, 0)
    
            Data Elements:
    
            RP.Royalties:^IDS23 = tns:Income.IncludedInAssessableTotal.Amount
            */
            assertion = NotMonetary(report.IDS23, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Income.IncludedInAssessableTotal.Amount[@contextRef='" + report.RPRoyaltiesId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440018" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS23", Value = report.IDS23.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440018

            #region VR.ATO.IDS.440019

            /*  VR.ATO.IDS.440019
            If an amount of expenditure or revenue is present, both the main pricing methodology and the code for the percentage of the total dollar value of related party international dealings for which you have documentation must be completed.
    
            Legacy Rule Format:
            IF ([IDS26] <> NULL OR [IDS27] <> NULL OR [IDS28] <> NULL OR [IDS29] <> NULL) AND (([IDS26] = NULL AND [IDS27] = NULL) OR [IDS28] = NULL OR [IDS29] = NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS26] = IDS:RP.LicenceFees:bafpr1.02.12:Expense.DeductionsTotal.Amount
            [IDS27] = IDS:RP.LicenceFees:bafpr1.02.12:Income.IncludedInAssessableTotal.Amount
            [IDS28] = IDS:RP.LicenceFees:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS29] = IDS:RP.LicenceFees:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code

            Technical Business Rule Format:
            (^IDS26 <> NULL OR ^IDS27 <> NULL OR ^IDS28 <> NULL OR ^IDS29 <> NULL) AND ((^IDS26 = NULL AND ^IDS27 = NULL) OR ^IDS28 = NULL OR ^IDS29 = NULL)
    
            Data Elements:
    
            RP.LicenceFees:^IDS26 = tns:Expense.DeductionsTotal.Amount
    
            RP.LicenceFees:^IDS27 = tns:Income.IncludedInAssessableTotal.Amount
    
            RP.LicenceFees:^IDS28 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.LicenceFees:^IDS29 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            */
            assertion = ((report.IDS26 != null || report.IDS27 != null || report.IDS28 != null || report.IDS29 != null) && (report.IDS26 == null && report.IDS27 == null || report.IDS28 == null || report.IDS29 == null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440019",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Licence fees information incomplete",
                    LongDescription = @"If licence fees information has been completed then deductions or income, main pricing methodology code and percentage of dealings with documentation code must be completed",
                    Location = "/xbrli:xbrl/tns:Expense.DeductionsTotal.Amount[@contextRef='" + report.RPLicenceFeesId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440019" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS26", Value = report.IDS26.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS27", Value = report.IDS27.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS28", Value = report.IDS28 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS29", Value = report.IDS29 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440019

            #region VR.ATO.IDS.440020

            /*  VR.ATO.IDS.440020
            If International related party dealings information has been completed for rent or leasing then the response to 'Did you have any international related party dealings involving rent or leasing?' must be 'True'.
    
            Legacy Rule Format:
            IF [IDS30] <> TRUE AND ([IDS31] <> NULL OR [IDS32] <> NULL OR [IDS33] <> NULL OR [IDS34] <> NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS30] = IDS:RP:rvctc4.02.05:InternationalDealings.TransactionsRentLeasing.Indicator
            [IDS31] = IDS:RP.RentLease:bafpr1.02.16:Expense.Total.Amount
            [IDS32] = IDS:RP.RentLease:bafpr1.02.26:Revenue.Total.Amount
            [IDS33] = IDS:RP.RentLease:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS34] = IDS:RP.RentLease:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code

            Technical Business Rule Format:
            ^IDS30 <> TRUE AND (^IDS31 <> NULL OR ^IDS32 <> NULL OR ^IDS33 <> NULL OR ^IDS34 <> NULL)
    
            Data Elements:
    
            RP:^IDS30 = tns:InternationalDealings.TransactionsRentLeasing.Indicator
    
            RP.RentLease:^IDS31 = tns:Expense.Total.Amount
    
            RP.RentLease:^IDS32 = tns:Revenue.Total.Amount
    
            RP.RentLease:^IDS33 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.RentLease:^IDS34 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            */
            assertion = (report.IDS30 != true && (report.IDS31 != null || report.IDS32 != null || report.IDS33 != null || report.IDS34 != null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440020",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"International related party dealings question incorrect",
                    LongDescription = @"If International related party dealings information has been completed for rent or leasing then the response to 'Did you have any international related party dealings involving rent or leasing?' must be 'True'",
                    Location = "/xbrli:xbrl/tns:InternationalDealings.TransactionsRentLeasing.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440020" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS30", Value = GetValueOrEmpty(report.IDS30) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS31", Value = report.IDS31.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS32", Value = report.IDS32.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS33", Value = report.IDS33 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS34", Value = report.IDS34 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440020

            #region VR.ATO.IDS.440021

            /*  VR.ATO.IDS.440021
            If an amount of expenditure or revenue is present, both the main pricing methodology and the code for the percentage of the total dollar value of related party international dealings for which you have documentation must be completed.
    
            Legacy Rule Format:
            IF [IDS30] = TRUE AND (([IDS31] <> NULL OR [IDS32] <> NULL) AND ([IDS33] = NULL OR [IDS34] = NULL))
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS30] = IDS:RP:rvctc4.02.05:InternationalDealings.TransactionsRentLeasing.Indicator
            [IDS31] = IDS:RP.RentLease:bafpr1.02.16:Expense.Total.Amount
            [IDS32] = IDS:RP.RentLease:bafpr1.02.26:Revenue.Total.Amount
            [IDS33] = IDS:RP.RentLease:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS34] = IDS:RP.RentLease:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code

            Technical Business Rule Format:
            ^IDS30 = TRUE AND ((^IDS31 <> NULL OR ^IDS32 <> NULL) AND (^IDS33 = NULL OR ^IDS34 = NULL))
    
            Data Elements:
    
            RP:^IDS30 = tns:InternationalDealings.TransactionsRentLeasing.Indicator
    
            RP.RentLease:^IDS31 = tns:Expense.Total.Amount
    
            RP.RentLease:^IDS32 = tns:Revenue.Total.Amount
    
            RP.RentLease:^IDS33 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.RentLease:^IDS34 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            */
            assertion = (report.IDS30 == true && ((report.IDS31 != null || report.IDS32 != null) && (report.IDS33 == null || report.IDS34 == null)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440021",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Rent or leasing information incomplete",
                    LongDescription = @"If there is a 'True' response to 'Did you have any international related party dealings involving rent or leasing?' then expenditure or revenue, main pricing methodology code and percentage of dealings with documentation code must be completed",
                    Location = "/xbrli:xbrl/tns:InternationalDealings.TransactionsRentLeasing.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440021" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS30", Value = GetValueOrEmpty(report.IDS30) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS31", Value = report.IDS31.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS32", Value = report.IDS32.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS33", Value = report.IDS33 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS34", Value = report.IDS34 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440021

            #region VR.ATO.IDS.440022

            /*  VR.ATO.IDS.440022
            If International related party dealings information has been completed for any service arrangements then the response to 'Did you have any service arrangements with international related parties?' must be 'True'.
    
            Legacy Rule Format:
            IF [IDS35] <> TRUE AND ([IDS36] <> NULL OR [IDS37] <> NULL OR [IDS38] <> NULL OR [IDS39] <> NULL OR [IDS40] <> NULL OR [IDS41] <> NULL OR [IDS42] <> NULL OR 
            [IDS43] <> NULL OR [IDS44] <> NULL OR [IDS45] <> NULL OR [IDS46] <> NULL OR [IDS47] <> NULL OR [IDS48] <> NULL OR [IDS49] <> NULL OR [IDS50] <> NULL OR 
            [IDS51] <> NULL OR [IDS52] <> NULL OR [IDS53] <> NULL OR [IDS54] <> NULL OR [IDS55] <> NULL OR [IDS56] <> NULL OR [IDS57] <> NULL OR [IDS58] <> NULL OR 
            [IDS59] <> NULL OR [IDS60] <> NULL OR [IDS61] <> NULL OR [IDS62] <> NULL OR [IDS63] <> NULL OR [IDS64] <> NULL OR [IDS65] <> NULL OR [IDS66] <> NULL OR 
            [IDS67] <> NULL OR [IDS68] <> NULL OR [IDS69] <> NULL OR [IDS70] <> NULL OR [IDS71] <> NULL OR [IDS72] <> NULL OR [IDS73] <> NULL OR [IDS74] <> NULL OR 
            [IDS75] <> NULL OR [IDS76] <> NULL OR [IDS77] <> NULL OR [IDS78] <> NULL OR [IDS79] <> NULL OR [IDS80] <> NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS35] = IDS:RP:rvctc4.02.05:InternationalDealings.TransactionsServiceArrangements.Indicator
            [IDS36] = IDS:RP.TreasuryRelated:bafpr1.02.16:Expense.Total.Amount
            [IDS37] = IDS:RP.TreasuryRelated:bafpr1.02.26:Revenue.Total.Amount
            [IDS38] = IDS:RP.TreasuryRelated:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS39] = IDS:RP.TreasuryRelated:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            [IDS40] = IDS:RP.ManagementAndAdmin:bafpr1.02.16:Expense.Total.Amount
            [IDS41] = IDS:RP.ManagementAndAdmin:bafpr1.02.26:Revenue.Total.Amount
            [IDS42] = IDS:RP.ManagementAndAdmin:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS43] = IDS:RP.ManagementAndAdmin:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            [IDS44] = IDS:RP.Insurance:bafpr1.02.16:Expense.Total.Amount
            [IDS45] = IDS:RP.Insurance:bafpr1.02.26:Revenue.Total.Amount
            [IDS46] = IDS:RP.Insurance:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS47] = IDS:RP.Insurance:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            [IDS48] = IDS:RP.Reinsurance:bafpr1.02.16:Expense.Total.Amount
            [IDS49] = IDS:RP.Reinsurance:bafpr1.02.26:Revenue.Total.Amount
            [IDS50] = IDS:RP.Reinsurance:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS51] = IDS:RP.Reinsurance:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            [IDS52] = IDS:RP.ResearchAndDevelopment:bafpr1.02.16:Expense.Total.Amount
            [IDS53] = IDS:RP.ResearchAndDevelopment:bafpr1.02.26:Revenue.Total.Amount
            [IDS54] = IDS:RP.ResearchAndDevelopment:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS55] = IDS:RP.ResearchAndDevelopment:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            [IDS56] = IDS:RP.SalesAndMarketing:bafpr1.02.16:Expense.Total.Amount
            [IDS57] = IDS:RP.SalesAndMarketing:bafpr1.02.26:Revenue.Total.Amount
            [IDS58] = IDS:RP.SalesAndMarketing:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS59] = IDS:RP.SalesAndMarketing:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            [IDS60] = IDS:RP.SoftwareAndITServices:bafpr1.02.16:Expense.Total.Amount
            [IDS61] = IDS:RP.SoftwareAndITServices:bafpr1.02.26:Revenue.Total.Amount
            [IDS62] = IDS:RP.SoftwareAndITServices:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS63] = IDS:RP.SoftwareAndITServices:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            [IDS64] = IDS:RP.Technical:bafpr1.02.16:Expense.Total.Amount
            [IDS65] = IDS:RP.Technical:bafpr1.02.26:Revenue.Total.Amount
            [IDS66] = IDS:RP.Technical:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS67] = IDS:RP.Technical:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            [IDS68] = IDS:RP.Logistics:bafpr1.02.16:Expense.Total.Amount
            [IDS69] = IDS:RP.Logistics:bafpr1.02.26:Revenue.Total.Amount
            [IDS70] = IDS:RP.Logistics:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS71] = IDS:RP.Logistics:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            [IDS72] = IDS:RP.AssetManagement:bafpr1.02.16:Expense.Total.Amount
            [IDS73] = IDS:RP.AssetManagement:bafpr1.02.26:Revenue.Total.Amount
            [IDS74] = IDS:RP.AssetManagement:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS75] = IDS:RP.AssetManagement:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            [IDS76] = IDS:RP.OtherServices:bafpr1.02.16:Expense.Total.Amount
            [IDS77] = IDS:RP.OtherServices:bafpr1.02.26:Revenue.Total.Amount
            [IDS78] = IDS:RP.OtherServices:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS79] = IDS:RP.OtherServices:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            [IDS80] = IDS:RP.OtherServices:rvctc4.02.05:InternationalDealings.Description.Text

            Technical Business Rule Format:
            ^IDS35 <> TRUE AND (^IDS36 <> NULL OR ^IDS37 <> NULL OR ^IDS38 <> NULL OR ^IDS39 <> NULL OR ^IDS40 <> NULL OR ^IDS41 <> NULL OR ^IDS42 <> NULL OR ^IDS43 <> NULL OR ^IDS44 <> NULL OR ^IDS45 <> NULL OR ^IDS46 <> NULL OR ^IDS47 <> NULL OR ^IDS48 <> NULL OR ^IDS49 <> NULL OR ^IDS50 <> NULL OR ^IDS51 <> NULL OR ^IDS52 <> NULL OR ^IDS53 <> NULL OR ^IDS54 <> NULL OR ^IDS55 <> NULL OR ^IDS56 <> NULL OR ^IDS57 <> NULL OR ^IDS58 <> NULL OR ^IDS59 <> NULL OR ^IDS60 <> NULL OR ^IDS61 <> NULL OR ^IDS62 <> NULL OR ^IDS63 <> NULL OR ^IDS64 <> NULL OR ^IDS65 <> NULL OR ^IDS66 <> NULL OR ^IDS67 <> NULL OR ^IDS68 <> NULL OR ^IDS69 <> NULL OR ^IDS70 <> NULL OR ^IDS71 <> NULL OR ^IDS72 <> NULL OR ^IDS73 <> NULL OR ^IDS74 <> NULL OR ^IDS75 <> NULL OR ^IDS76 <> NULL OR ^IDS77 <> NULL OR ^IDS78 <> NULL OR ^IDS79 <> NULL OR ^IDS80 <> NULL)
    
            Data Elements:
    
            RP:^IDS35 = tns:InternationalDealings.TransactionsServiceArrangements.Indicator
    
            RP.TreasuryRelated:^IDS36 = tns:Expense.Total.Amount
    
            RP.TreasuryRelated:^IDS37 = tns:Revenue.Total.Amount
    
            RP.TreasuryRelated:^IDS38 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.TreasuryRelated:^IDS39 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
    
            RP.ManagementAndAdmin:^IDS40 = tns:Expense.Total.Amount
    
            RP.ManagementAndAdmin:^IDS41 = tns:Revenue.Total.Amount
    
            RP.ManagementAndAdmin:^IDS42 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.ManagementAndAdmin:^IDS43 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
    
            RP.Insurance:^IDS44 = tns:Expense.Total.Amount
    
            RP.Insurance:^IDS45 = tns:Revenue.Total.Amount
    
            RP.Insurance:^IDS46 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.Insurance:^IDS47 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
    
            RP.Reinsurance:^IDS48 = tns:Expense.Total.Amount
    
            RP.Reinsurance:^IDS49 = tns:Revenue.Total.Amount
    
            RP.Reinsurance:^IDS50 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.Reinsurance:^IDS51 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
    
            RP.ResearchAndDevelopment:^IDS52 = tns:Expense.Total.Amount
    
            RP.ResearchAndDevelopment:^IDS53 = tns:Revenue.Total.Amount
    
            RP.ResearchAndDevelopment:^IDS54 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.ResearchAndDevelopment:^IDS55 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
    
            RP.SalesAndMarketing:^IDS56 = tns:Expense.Total.Amount
    
            RP.SalesAndMarketing:^IDS57 = tns:Revenue.Total.Amount
    
            RP.SalesAndMarketing:^IDS58 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.SalesAndMarketing:^IDS59 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
    
            RP.SoftwareAndITServices:^IDS60 = tns:Expense.Total.Amount
    
            RP.SoftwareAndITServices:^IDS61 = tns:Revenue.Total.Amount
    
            RP.SoftwareAndITServices:^IDS62 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.SoftwareAndITServices:^IDS63 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
    
            RP.Technical:^IDS64 = tns:Expense.Total.Amount
    
            RP.Technical:^IDS65 = tns:Revenue.Total.Amount
    
            RP.Technical:^IDS66 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.Technical:^IDS67 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
    
            RP.Logistics:^IDS68 = tns:Expense.Total.Amount
    
            RP.Logistics:^IDS69 = tns:Revenue.Total.Amount
    
            RP.Logistics:^IDS70 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.Logistics:^IDS71 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
    
            RP.AssetManagement:^IDS72 = tns:Expense.Total.Amount
    
            RP.AssetManagement:^IDS73 = tns:Revenue.Total.Amount
    
            RP.AssetManagement:^IDS74 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.AssetManagement:^IDS75 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
    
            RP.OtherServices:^IDS76 = tns:Expense.Total.Amount
    
            RP.OtherServices:^IDS77 = tns:Revenue.Total.Amount
    
            RP.OtherServices:^IDS78 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.OtherServices:^IDS79 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
    
            RP.OtherServices:^IDS80 = tns:InternationalDealings.Description.Text
            */
            assertion = (report.IDS35 != true && (report.IDS36 != null || report.IDS37 != null || report.IDS38 != null || report.IDS39 != null || report.IDS40 != null || report.IDS41 != null || report.IDS42 != null || report.IDS43 != null || report.IDS44 != null || report.IDS45 != null || report.IDS46 != null || report.IDS47 != null || report.IDS48 != null || report.IDS49 != null || report.IDS50 != null || report.IDS51 != null || report.IDS52 != null || report.IDS53 != null || report.IDS54 != null || report.IDS55 != null || report.IDS56 != null || report.IDS57 != null || report.IDS58 != null || report.IDS59 != null || report.IDS60 != null || report.IDS61 != null || report.IDS62 != null || report.IDS63 != null || report.IDS64 != null || report.IDS65 != null || report.IDS66 != null || report.IDS67 != null || report.IDS68 != null || report.IDS69 != null || report.IDS70 != null || report.IDS71 != null || report.IDS72 != null || report.IDS73 != null || report.IDS74 != null || report.IDS75 != null || report.IDS76 != null || report.IDS77 != null || report.IDS78 != null || report.IDS79 != null || report.IDS80 != null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440022",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"International related party dealings question incorrect",
                    LongDescription = @"If International related party dealings information has been completed for any service arrangements then the response to 'Did you have any service arrangements with international related parties?' must be 'True'",
                    Location = "/xbrli:xbrl/tns:InternationalDealings.TransactionsServiceArrangements.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440022" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS35", Value = GetValueOrEmpty(report.IDS35) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS36", Value = report.IDS36.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS37", Value = report.IDS37.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS38", Value = report.IDS38 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS39", Value = report.IDS39 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS40", Value = report.IDS40.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS41", Value = report.IDS41.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS42", Value = report.IDS42 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS43", Value = report.IDS43 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS44", Value = report.IDS44.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS45", Value = report.IDS45.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS46", Value = report.IDS46 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS47", Value = report.IDS47 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS48", Value = report.IDS48.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS49", Value = report.IDS49.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS50", Value = report.IDS50 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS51", Value = report.IDS51 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS52", Value = report.IDS52.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS53", Value = report.IDS53.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS54", Value = report.IDS54 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS55", Value = report.IDS55 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS56", Value = report.IDS56.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS57", Value = report.IDS57.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS58", Value = report.IDS58 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS59", Value = report.IDS59 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS60", Value = report.IDS60.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS61", Value = report.IDS61.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS62", Value = report.IDS62 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS63", Value = report.IDS63 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS64", Value = report.IDS64.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS65", Value = report.IDS65.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS66", Value = report.IDS66 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS67", Value = report.IDS67 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS68", Value = report.IDS68.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS69", Value = report.IDS69.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS70", Value = report.IDS70 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS71", Value = report.IDS71 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS72", Value = report.IDS72.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS73", Value = report.IDS73.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS74", Value = report.IDS74 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS75", Value = report.IDS75 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS76", Value = report.IDS76.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS77", Value = report.IDS77.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS78", Value = report.IDS78 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS79", Value = report.IDS79 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS80", Value = report.IDS80 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440022

            #region VR.ATO.IDS.440023

            /*  VR.ATO.IDS.440023
            If there is a 'True' response to 'Did you have any service arrangements with international related parties?' then service arrangements information must be completed
    
            Legacy Rule Format:
            IF [IDS35] = TRUE AND [IDS36] = NULL AND [IDS37] = NULL AND [IDS38] = NULL AND [IDS39] = NULL AND [IDS40] = NULL AND [IDS41] = NULL AND [IDS42] = NULL AND [IDS43] = NULL AND [IDS44] = NULL AND [IDS45] = NULL AND [IDS46] = NULL AND [IDS47] = NULL AND [IDS48] = NULL AND [IDS49] = NULL AND [IDS50] = NULL AND [IDS51] = NULL AND 
            [IDS52] = NULL AND [IDS53] = NULL AND [IDS54] = NULL AND [IDS55] = NULL AND [IDS56] = NULL AND [IDS57] = NULL AND [IDS58] = NULL AND [IDS59] = NULL AND 
            [IDS60] = NULL AND [IDS61] = NULL AND [IDS62] = NULL AND [IDS63] = NULL AND [IDS64] = NULL AND [IDS65] = NULL AND [IDS66] = NULL AND [IDS67] = NULL AND 
            [IDS68] = NULL AND [IDS69] = NULL AND [IDS70] = NULL AND [IDS71] = NULL AND [IDS72] = NULL AND [IDS73] = NULL AND [IDS74] = NULL AND [IDS75] = NULL AND 
            [IDS76] = NULL AND [IDS77] = NULL AND [IDS78] = NULL AND [IDS79] = NULL AND [IDS80] = NULL
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS35] = IDS:RP:rvctc4.02.05:InternationalDealings.TransactionsServiceArrangements.Indicator
            [IDS36] = IDS:RP.TreasuryRelated:bafpr1.02.16:Expense.Total.Amount
            [IDS37] = IDS:RP.TreasuryRelated:bafpr1.02.26:Revenue.Total.Amount
            [IDS38] = IDS:RP.TreasuryRelated:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS39] = IDS:RP.TreasuryRelated:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            [IDS40] = IDS:RP.ManagementAndAdmin:bafpr1.02.16:Expense.Total.Amount
            [IDS41] = IDS:RP.ManagementAndAdmin:bafpr1.02.26:Revenue.Total.Amount
            [IDS42] = IDS:RP.ManagementAndAdmin:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS43] = IDS:RP.ManagementAndAdmin:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            [IDS44] = IDS:RP.Insurance:bafpr1.02.16:Expense.Total.Amount
            [IDS45] = IDS:RP.Insurance:bafpr1.02.26:Revenue.Total.Amount
            [IDS46] = IDS:RP.Insurance:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS47] = IDS:RP.Insurance:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            [IDS48] = IDS:RP.Reinsurance:bafpr1.02.16:Expense.Total.Amount
            [IDS49] = IDS:RP.Reinsurance:bafpr1.02.26:Revenue.Total.Amount
            [IDS50] = IDS:RP.Reinsurance:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS51] = IDS:RP.Reinsurance:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            [IDS52] = IDS:RP.ResearchAndDevelopment:bafpr1.02.16:Expense.Total.Amount
            [IDS53] = IDS:RP.ResearchAndDevelopment:bafpr1.02.26:Revenue.Total.Amount
            [IDS54] = IDS:RP.ResearchAndDevelopment:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS55] = IDS:RP.ResearchAndDevelopment:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            [IDS56] = IDS:RP.SalesAndMarketing:bafpr1.02.16:Expense.Total.Amount
            [IDS57] = IDS:RP.SalesAndMarketing:bafpr1.02.26:Revenue.Total.Amount
            [IDS58] = IDS:RP.SalesAndMarketing:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS59] = IDS:RP.SalesAndMarketing:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            [IDS60] = IDS:RP.SoftwareAndITServices:bafpr1.02.16:Expense.Total.Amount
            [IDS61] = IDS:RP.SoftwareAndITServices:bafpr1.02.26:Revenue.Total.Amount
            [IDS62] = IDS:RP.SoftwareAndITServices:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS63] = IDS:RP.SoftwareAndITServices:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            [IDS64] = IDS:RP.Technical:bafpr1.02.16:Expense.Total.Amount
            [IDS65] = IDS:RP.Technical:bafpr1.02.26:Revenue.Total.Amount
            [IDS66] = IDS:RP.Technical:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS67] = IDS:RP.Technical:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            [IDS68] = IDS:RP.Logistics:bafpr1.02.16:Expense.Total.Amount
            [IDS69] = IDS:RP.Logistics:bafpr1.02.26:Revenue.Total.Amount
            [IDS70] = IDS:RP.Logistics:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS71] = IDS:RP.Logistics:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            [IDS72] = IDS:RP.AssetManagement:bafpr1.02.16:Expense.Total.Amount
            [IDS73] = IDS:RP.AssetManagement:bafpr1.02.26:Revenue.Total.Amount
            [IDS74] = IDS:RP.AssetManagement:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS75] = IDS:RP.AssetManagement:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            [IDS76] = IDS:RP.OtherServices:bafpr1.02.16:Expense.Total.Amount
            [IDS77] = IDS:RP.OtherServices:bafpr1.02.26:Revenue.Total.Amount
            [IDS78] = IDS:RP.OtherServices:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS79] = IDS:RP.OtherServices:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            [IDS80] = IDS:RP.OtherServices:rvctc4.02.05:InternationalDealings.Description.Text

            Technical Business Rule Format:
            ^IDS35 = TRUE AND ^IDS36 = NULL AND ^IDS37 = NULL AND ^IDS38 = NULL AND ^IDS39 = NULL AND ^IDS40 = NULL AND ^IDS41 = NULL AND ^IDS42 = NULL AND ^IDS43 = NULL AND ^IDS44 = NULL AND ^IDS45 = NULL AND ^IDS46 = NULL AND ^IDS47 = NULL AND ^IDS48 = NULL AND ^IDS49 = NULL AND ^IDS50 = NULL AND ^IDS51 = NULL AND ^IDS52 = NULL AND ^IDS53 = NULL AND ^IDS54 = NULL AND ^IDS55 = NULL AND ^IDS56 = NULL AND ^IDS57 = NULL AND ^IDS58 = NULL AND ^IDS59 = NULL AND ^IDS60 = NULL AND ^IDS61 = NULL AND ^IDS62 = NULL AND ^IDS63 = NULL AND ^IDS64 = NULL AND ^IDS65 = NULL AND ^IDS66 = NULL AND ^IDS67 = NULL AND ^IDS68 = NULL AND ^IDS69 = NULL AND ^IDS70 = NULL AND ^IDS71 = NULL AND ^IDS72 = NULL AND ^IDS73 = NULL AND ^IDS74 = NULL AND ^IDS75 = NULL AND ^IDS76 = NULL AND ^IDS77 = NULL AND ^IDS78 = NULL AND ^IDS79 = NULL AND ^IDS80 = NULL
    
            Data Elements:
    
            RP:^IDS35 = tns:InternationalDealings.TransactionsServiceArrangements.Indicator
    
            RP.TreasuryRelated:^IDS36 = tns:Expense.Total.Amount
    
            RP.TreasuryRelated:^IDS37 = tns:Revenue.Total.Amount
    
            RP.TreasuryRelated:^IDS38 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.TreasuryRelated:^IDS39 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
    
            RP.ManagementAndAdmin:^IDS40 = tns:Expense.Total.Amount
    
            RP.ManagementAndAdmin:^IDS41 = tns:Revenue.Total.Amount
    
            RP.ManagementAndAdmin:^IDS42 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.ManagementAndAdmin:^IDS43 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
    
            RP.Insurance:^IDS44 = tns:Expense.Total.Amount
    
            RP.Insurance:^IDS45 = tns:Revenue.Total.Amount
    
            RP.Insurance:^IDS46 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.Insurance:^IDS47 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
    
            RP.Reinsurance:^IDS48 = tns:Expense.Total.Amount
    
            RP.Reinsurance:^IDS49 = tns:Revenue.Total.Amount
    
            RP.Reinsurance:^IDS50 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.Reinsurance:^IDS51 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
    
            RP.ResearchAndDevelopment:^IDS52 = tns:Expense.Total.Amount
    
            RP.ResearchAndDevelopment:^IDS53 = tns:Revenue.Total.Amount
    
            RP.ResearchAndDevelopment:^IDS54 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.ResearchAndDevelopment:^IDS55 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
    
            RP.SalesAndMarketing:^IDS56 = tns:Expense.Total.Amount
    
            RP.SalesAndMarketing:^IDS57 = tns:Revenue.Total.Amount
    
            RP.SalesAndMarketing:^IDS58 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.SalesAndMarketing:^IDS59 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
    
            RP.SoftwareAndITServices:^IDS60 = tns:Expense.Total.Amount
    
            RP.SoftwareAndITServices:^IDS61 = tns:Revenue.Total.Amount
    
            RP.SoftwareAndITServices:^IDS62 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.SoftwareAndITServices:^IDS63 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
    
            RP.Technical:^IDS64 = tns:Expense.Total.Amount
    
            RP.Technical:^IDS65 = tns:Revenue.Total.Amount
    
            RP.Technical:^IDS66 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.Technical:^IDS67 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
    
            RP.Logistics:^IDS68 = tns:Expense.Total.Amount
    
            RP.Logistics:^IDS69 = tns:Revenue.Total.Amount
    
            RP.Logistics:^IDS70 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.Logistics:^IDS71 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
    
            RP.AssetManagement:^IDS72 = tns:Expense.Total.Amount
    
            RP.AssetManagement:^IDS73 = tns:Revenue.Total.Amount
    
            RP.AssetManagement:^IDS74 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.AssetManagement:^IDS75 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
    
            RP.OtherServices:^IDS76 = tns:Expense.Total.Amount
    
            RP.OtherServices:^IDS77 = tns:Revenue.Total.Amount
    
            RP.OtherServices:^IDS78 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.OtherServices:^IDS79 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
    
            RP.OtherServices:^IDS80 = tns:InternationalDealings.Description.Text
            */
            assertion = (report.IDS35 == true && report.IDS36 == null && report.IDS37 == null && report.IDS38 == null && report.IDS39 == null && report.IDS40 == null && report.IDS41 == null && report.IDS42 == null && report.IDS43 == null && report.IDS44 == null && report.IDS45 == null && report.IDS46 == null && report.IDS47 == null && report.IDS48 == null && report.IDS49 == null && report.IDS50 == null && report.IDS51 == null && report.IDS52 == null && report.IDS53 == null && report.IDS54 == null && report.IDS55 == null && report.IDS56 == null && report.IDS57 == null && report.IDS58 == null && report.IDS59 == null && report.IDS60 == null && report.IDS61 == null && report.IDS62 == null && report.IDS63 == null && report.IDS64 == null && report.IDS65 == null && report.IDS66 == null && report.IDS67 == null && report.IDS68 == null && report.IDS69 == null && report.IDS70 == null && report.IDS71 == null && report.IDS72 == null && report.IDS73 == null && report.IDS74 == null && report.IDS75 == null && report.IDS76 == null && report.IDS77 == null && report.IDS78 == null && report.IDS79 == null && report.IDS80 == null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440023",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"International related party dealings information required",
                    LongDescription = @"If there is a 'True' response to 'Did you have any service arrangements with international related parties?' then service arrangements information must be completed",
                    Location = "/xbrli:xbrl/tns:InternationalDealings.TransactionsServiceArrangements.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440023" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS35", Value = GetValueOrEmpty(report.IDS35) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS36", Value = report.IDS36.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS37", Value = report.IDS37.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS38", Value = report.IDS38 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS39", Value = report.IDS39 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS40", Value = report.IDS40.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS41", Value = report.IDS41.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS42", Value = report.IDS42 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS43", Value = report.IDS43 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS44", Value = report.IDS44.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS45", Value = report.IDS45.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS46", Value = report.IDS46 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS47", Value = report.IDS47 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS48", Value = report.IDS48.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS49", Value = report.IDS49.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS50", Value = report.IDS50 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS51", Value = report.IDS51 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS52", Value = report.IDS52.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS53", Value = report.IDS53.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS54", Value = report.IDS54 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS55", Value = report.IDS55 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS56", Value = report.IDS56.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS57", Value = report.IDS57.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS58", Value = report.IDS58 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS59", Value = report.IDS59 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS60", Value = report.IDS60.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS61", Value = report.IDS61.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS62", Value = report.IDS62 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS63", Value = report.IDS63 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS64", Value = report.IDS64.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS65", Value = report.IDS65.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS66", Value = report.IDS66 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS67", Value = report.IDS67 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS68", Value = report.IDS68.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS69", Value = report.IDS69.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS70", Value = report.IDS70 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS71", Value = report.IDS71 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS72", Value = report.IDS72.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS73", Value = report.IDS73.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS74", Value = report.IDS74 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS75", Value = report.IDS75 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS76", Value = report.IDS76.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS77", Value = report.IDS77.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS78", Value = report.IDS78 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS79", Value = report.IDS79 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS80", Value = report.IDS80 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440023

            #region VR.ATO.IDS.440024

            /*  VR.ATO.IDS.440024
            If an amount of expenditure or revenue is present, both the main pricing methodology and the code for the percentage of the total dollar value of related party international dealings for which you have documentation must be completed.
    
            Legacy Rule Format:
            IF ([IDS36] <> NULL OR [IDS37] <> NULL OR [IDS38] <> NULL OR [IDS39] <> NULL) AND (([IDS36] = NULL AND [IDS37] = NULL) OR [IDS38] = NULL OR [IDS39] = NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS36] = IDS:RP.TreasuryRelated:bafpr1.02.16:Expense.Total.Amount
            [IDS37] = IDS:RP.TreasuryRelated:bafpr1.02.26:Revenue.Total.Amount
            [IDS38] = IDS:RP.TreasuryRelated:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS39] = IDS:RP.TreasuryRelated:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code

            Technical Business Rule Format:
            (^IDS36 <> NULL OR ^IDS37 <> NULL OR ^IDS38 <> NULL OR ^IDS39 <> NULL) AND ((^IDS36 = NULL AND ^IDS37 = NULL) OR ^IDS38 = NULL OR ^IDS39 = NULL)
    
            Data Elements:
    
            RP.TreasuryRelated:^IDS36 = tns:Expense.Total.Amount
    
            RP.TreasuryRelated:^IDS37 = tns:Revenue.Total.Amount
    
            RP.TreasuryRelated:^IDS38 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.TreasuryRelated:^IDS39 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            */
            assertion = ((report.IDS36 != null || report.IDS37 != null || report.IDS38 != null || report.IDS39 != null) && (report.IDS36 == null && report.IDS37 == null || report.IDS38 == null || report.IDS39 == null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440024",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Treasury related services information incomplete",
                    LongDescription = @"If service arrangements information has been completed for treasury related services then expenditure or revenue, main pricing methodology code and percentage of dealings with documentation code must be completed",
                    Location = "/xbrli:xbrl/tns:Expense.Total.Amount[@contextRef='" + report.RPTreasuryRelatedId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440024" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS36", Value = report.IDS36.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS37", Value = report.IDS37.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS38", Value = report.IDS38 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS39", Value = report.IDS39 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440024

            #region VR.ATO.IDS.440025

            /*  VR.ATO.IDS.440025
            If an amount of expenditure or revenue is present, both the main pricing methodology and the code for the percentage of the total dollar value of related party international dealings for which you have documentation must be completed.
    
            Legacy Rule Format:
            IF ([IDS40] <> NULL OR [IDS41] <> NULL OR [IDS42] <> NULL OR [IDS43] <> NULL) AND (([IDS40] = NULL AND [IDS41] = NULL) OR [IDS42] = NULL OR [IDS43] = NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS40] = IDS:RP.ManagementAndAdmin:bafpr1.02.16:Expense.Total.Amount
            [IDS41] = IDS:RP.ManagementAndAdmin:bafpr1.02.26:Revenue.Total.Amount
            [IDS42] = IDS:RP.ManagementAndAdmin:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS43] = IDS:RP.ManagementAndAdmin:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code

            Technical Business Rule Format:
            (^IDS40 <> NULL OR ^IDS41 <> NULL OR ^IDS42 <> NULL OR ^IDS43 <> NULL) AND ((^IDS40 = NULL AND ^IDS41 = NULL) OR ^IDS42 = NULL OR ^IDS43 = NULL)
    
            Data Elements:
    
            RP.ManagementAndAdmin:^IDS40 = tns:Expense.Total.Amount
    
            RP.ManagementAndAdmin:^IDS41 = tns:Revenue.Total.Amount
    
            RP.ManagementAndAdmin:^IDS42 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.ManagementAndAdmin:^IDS43 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            */
            assertion = ((report.IDS40 != null || report.IDS41 != null || report.IDS42 != null || report.IDS43 != null) && (report.IDS40 == null && report.IDS41 == null || report.IDS42 == null || report.IDS43 == null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440025",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Management and administration services information incomplete",
                    LongDescription = @"If service arrangements information has been completed for management and administration services then expenditure or revenue, main pricing methodology code and percentage of dealings with documentation code must be completed",
                    Location = "/xbrli:xbrl/tns:Expense.Total.Amount[@contextRef='" + report.RPManagementAndAdminId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440025" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS40", Value = report.IDS40.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS41", Value = report.IDS41.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS42", Value = report.IDS42 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS43", Value = report.IDS43 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440025

            #region VR.ATO.IDS.440026

            /*  VR.ATO.IDS.440026
            If an amount of Expenditure or revenue is present, both the main pricing methodology and the code for the percentage of the total dollar value of related party international dealings for which you have documentation must be completed.
    
            Legacy Rule Format:
            IF ([IDS44] <> NULL OR [IDS45] <> NULL OR [IDS46] <> NULL OR [IDS47] <> NULL) AND (([IDS44] = NULL AND [IDS45] = NULL) OR [IDS46] = NULL OR [IDS47] = NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS44] = IDS:RP.Insurance:bafpr1.02.16:Expense.Total.Amount
            [IDS45] = IDS:RP.Insurance:bafpr1.02.26:Revenue.Total.Amount
            [IDS46] = IDS:RP.Insurance:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS47] = IDS:RP.Insurance:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code

            Technical Business Rule Format:
            (^IDS44 <> NULL OR ^IDS45 <> NULL OR ^IDS46 <> NULL OR ^IDS47 <> NULL) AND ((^IDS44 = NULL AND ^IDS45 = NULL) OR ^IDS46 = NULL OR ^IDS47 = NULL)
    
            Data Elements:
    
            RP.Insurance:^IDS44 = tns:Expense.Total.Amount
    
            RP.Insurance:^IDS45 = tns:Revenue.Total.Amount
    
            RP.Insurance:^IDS46 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.Insurance:^IDS47 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            */
            assertion = ((report.IDS44 != null || report.IDS45 != null || report.IDS46 != null || report.IDS47 != null) && (report.IDS44 == null && report.IDS45 == null || report.IDS46 == null || report.IDS47 == null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440026",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Insurance information incomplete",
                    LongDescription = @"If service arrangements information has been completed for insurance then expenditure or revenue, main pricing methodology code and percentage of dealings with documentation code must be completed",
                    Location = "/xbrli:xbrl/tns:Expense.Total.Amount[@contextRef='" + report.RPInsuranceId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440026" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS44", Value = report.IDS44.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS45", Value = report.IDS45.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS46", Value = report.IDS46 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS47", Value = report.IDS47 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440026

            #region VR.ATO.IDS.440027

            /*  VR.ATO.IDS.440027
            If an amount of expenditure or revenue is present, both the main pricing methodology and the code for the percentage of the total dollar value of related party international dealings for which you have documentation must be completed.
    
            Legacy Rule Format:
            IF ([IDS48] <> NULL OR [IDS49] <> NULL OR [IDS50] <> NULL OR [IDS51] <> NULL) AND (([IDS48] = NULL AND [IDS49] = NULL) OR [IDS50] = NULL OR [IDS51] = NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS48] = IDS:RP.Reinsurance:bafpr1.02.16:Expense.Total.Amount
            [IDS49] = IDS:RP.Reinsurance:bafpr1.02.26:Revenue.Total.Amount
            [IDS50] = IDS:RP.Reinsurance:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS51] = IDS:RP.Reinsurance:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code

            Technical Business Rule Format:
            (^IDS48 <> NULL OR ^IDS49 <> NULL OR ^IDS50 <> NULL OR ^IDS51 <> NULL) AND ((^IDS48 = NULL AND ^IDS49 = NULL) OR ^IDS50 = NULL OR ^IDS51 = NULL)
    
            Data Elements:
    
            RP.Reinsurance:^IDS48 = tns:Expense.Total.Amount
    
            RP.Reinsurance:^IDS49 = tns:Revenue.Total.Amount
    
            RP.Reinsurance:^IDS50 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.Reinsurance:^IDS51 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            */
            assertion = ((report.IDS48 != null || report.IDS49 != null || report.IDS50 != null || report.IDS51 != null) && (report.IDS48 == null && report.IDS49 == null || report.IDS50 == null || report.IDS51 == null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440027",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Reinsurance information incomplete",
                    LongDescription = @"If service arrangements information has been completed for reinsurance then expenditure or revenue, main pricing methodology code and percentage of dealings with documentation code must be completed",
                    Location = "/xbrli:xbrl/tns:Expense.Total.Amount[@contextRef='" + report.RPReinsuranceId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440027" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS48", Value = report.IDS48.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS49", Value = report.IDS49.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS50", Value = report.IDS50 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS51", Value = report.IDS51 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440027

            #region VR.ATO.IDS.440028

            /*  VR.ATO.IDS.440028
            If an amount of expenditure or revenue is present, both the main pricing methodology and the code for the percentage of the total dollar value of related party international dealings for which you have documentation must be completed.
    
            Legacy Rule Format:
            IF ([IDS52] <> NULL OR [IDS53] <> NULL OR [IDS54] <> NULL OR [IDS55] <> NULL) AND (([IDS52] = NULL AND [IDS53] = NULL) OR [IDS54] = NULL OR [IDS55] = NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS52] = IDS:RP.ResearchAndDevelopment:bafpr1.02.16:Expense.Total.Amount
            [IDS53] = IDS:RP.ResearchAndDevelopment:bafpr1.02.26:Revenue.Total.Amount
            [IDS54] = IDS:RP.ResearchAndDevelopment:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS55] = IDS:RP.ResearchAndDevelopment:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code

            Technical Business Rule Format:
            (^IDS52 <> NULL OR ^IDS53 <> NULL OR ^IDS54 <> NULL OR ^IDS55 <> NULL) AND ((^IDS52 = NULL AND ^IDS53 = NULL) OR ^IDS54 = NULL OR ^IDS55 = NULL)
    
            Data Elements:
    
            RP.ResearchAndDevelopment:^IDS52 = tns:Expense.Total.Amount
    
            RP.ResearchAndDevelopment:^IDS53 = tns:Revenue.Total.Amount
    
            RP.ResearchAndDevelopment:^IDS54 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.ResearchAndDevelopment:^IDS55 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            */
            assertion = ((report.IDS52 != null || report.IDS53 != null || report.IDS54 != null || report.IDS55 != null) && (report.IDS52 == null && report.IDS53 == null || report.IDS54 == null || report.IDS55 == null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440028",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Research and development information incomplete",
                    LongDescription = @"If service arrangements information has been completed for research and development then expenditure or revenue, main pricing methodology code and percentage of dealings with documentation code must be completed",
                    Location = "/xbrli:xbrl/tns:Expense.Total.Amount[@contextRef='" + report.RPResearchAndDevelopmentId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440028" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS52", Value = report.IDS52.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS53", Value = report.IDS53.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS54", Value = report.IDS54 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS55", Value = report.IDS55 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440028

            #region VR.ATO.IDS.440029

            /*  VR.ATO.IDS.440029
            If an amount of expenditure or revenue is present, both the main pricing methodology and the code for the percentage of the total dollar value of related party international dealings for which you have documentation must be completed.
    
            Legacy Rule Format:
            IF ([IDS56] <> NULL OR [IDS57] <> NULL OR [IDS58] <> NULL OR [IDS59] <> NULL) AND (([IDS56] = NULL AND [IDS57] = NULL) OR [IDS58] = NULL OR [IDS59] = NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS56] = IDS:RP.SalesAndMarketing:bafpr1.02.16:Expense.Total.Amount
            [IDS57] = IDS:RP.SalesAndMarketing:bafpr1.02.26:Revenue.Total.Amount
            [IDS58] = IDS:RP.SalesAndMarketing:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS59] = IDS:RP.SalesAndMarketing:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code

            Technical Business Rule Format:
            (^IDS56 <> NULL OR ^IDS57 <> NULL OR ^IDS58 <> NULL OR ^IDS59 <> NULL) AND ((^IDS56 = NULL AND ^IDS57 = NULL) OR ^IDS58 = NULL OR ^IDS59 = NULL)
    
            Data Elements:
    
            RP.SalesAndMarketing:^IDS56 = tns:Expense.Total.Amount
    
            RP.SalesAndMarketing:^IDS57 = tns:Revenue.Total.Amount
    
            RP.SalesAndMarketing:^IDS58 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.SalesAndMarketing:^IDS59 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            */
            assertion = ((report.IDS56 != null || report.IDS57 != null || report.IDS58 != null || report.IDS59 != null) && (report.IDS56 == null && report.IDS57 == null || report.IDS58 == null || report.IDS59 == null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440029",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Sales and marketing services information incomplete",
                    LongDescription = @"If service arrangements information has been completed for sales and marketing services then expenditure or revenue, main pricing methodology code and percentage of dealings with documentation code must be completed",
                    Location = "/xbrli:xbrl/tns:Expense.Total.Amount[@contextRef='" + report.RPSalesAndMarketingId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440029" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS56", Value = report.IDS56.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS57", Value = report.IDS57.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS58", Value = report.IDS58 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS59", Value = report.IDS59 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440029

            #region VR.ATO.IDS.440030

            /*  VR.ATO.IDS.440030
            If an amount of expenditure or revenue is present, both the main pricing methodology and the code for the percentage of the total dollar value of related party international dealings for which you have documentation must be completed.
    
            Legacy Rule Format:
            IF ([IDS60] <> NULL OR [IDS61] <> NULL OR [IDS62] <> NULL OR [IDS63] <> NULL) AND (([IDS60] = NULL AND [IDS61] = NULL) OR [IDS62] = NULL OR [IDS63] = NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS60] = IDS:RP.SoftwareAndITServices:bafpr1.02.16:Expense.Total.Amount
            [IDS61] = IDS:RP.SoftwareAndITServices:bafpr1.02.26:Revenue.Total.Amount
            [IDS62] = IDS:RP.SoftwareAndITServices:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS63] = IDS:RP.SoftwareAndITServices:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code

            Technical Business Rule Format:
            (^IDS60 <> NULL OR ^IDS61 <> NULL OR ^IDS62 <> NULL OR ^IDS63 <> NULL) AND ((^IDS60 = NULL AND ^IDS61 = NULL) OR ^IDS62 = NULL OR ^IDS63 = NULL)
    
            Data Elements:
    
            RP.SoftwareAndITServices:^IDS60 = tns:Expense.Total.Amount
    
            RP.SoftwareAndITServices:^IDS61 = tns:Revenue.Total.Amount
    
            RP.SoftwareAndITServices:^IDS62 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.SoftwareAndITServices:^IDS63 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            */
            assertion = ((report.IDS60 != null || report.IDS61 != null || report.IDS62 != null || report.IDS63 != null) && (report.IDS60 == null && report.IDS61 == null || report.IDS62 == null || report.IDS63 == null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440030",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Software and information technology services information incomplete",
                    LongDescription = @"If service arrangements information has been completed for software and information technology services then expenditure or revenue, main pricing methodology code and percentage of dealings with documentation code must be completed",
                    Location = "/xbrli:xbrl/tns:Expense.Total.Amount[@contextRef='" + report.RPSoftwareAndITServicesId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440030" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS60", Value = report.IDS60.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS61", Value = report.IDS61.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS62", Value = report.IDS62 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS63", Value = report.IDS63 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440030

            #region VR.ATO.IDS.440031

            /*  VR.ATO.IDS.440031
            If an amount of expenditure or revenue is present, both the main pricing methodology and the code for the percentage of the total dollar value of related party international dealings for which you have documentation must be completed.
    
            Legacy Rule Format:
            IF ([IDS64] <> NULL OR [IDS65] <> NULL OR [IDS66] <> NULL OR [IDS67] <> NULL) AND (([IDS64] = NULL AND [IDS65] = NULL) OR [IDS66] = NULL OR [IDS67] = NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS64] = IDS:RP.Technical:bafpr1.02.16:Expense.Total.Amount
            [IDS65] = IDS:RP.Technical:bafpr1.02.26:Revenue.Total.Amount
            [IDS66] = IDS:RP.Technical:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS67] = IDS:RP.Technical:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code

            Technical Business Rule Format:
            (^IDS64 <> NULL OR ^IDS65 <> NULL OR ^IDS66 <> NULL OR ^IDS67 <> NULL) AND ((^IDS64 = NULL AND ^IDS65 = NULL) OR ^IDS66 = NULL OR ^IDS67 = NULL)
    
            Data Elements:
    
            RP.Technical:^IDS64 = tns:Expense.Total.Amount
    
            RP.Technical:^IDS65 = tns:Revenue.Total.Amount
    
            RP.Technical:^IDS66 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.Technical:^IDS67 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            */
            assertion = ((report.IDS64 != null || report.IDS65 != null || report.IDS66 != null || report.IDS67 != null) && (report.IDS64 == null && report.IDS65 == null || report.IDS66 == null || report.IDS67 == null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440031",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Technical services information incomplete",
                    LongDescription = @"If service arrangements information has been completed for technical services then expenditure or revenue, main pricing methodology code and percentage of dealings with documentation code must be completed",
                    Location = "/xbrli:xbrl/tns:Expense.Total.Amount[@contextRef='" + report.RPTechnicalId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440031" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS64", Value = report.IDS64.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS65", Value = report.IDS65.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS66", Value = report.IDS66 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS67", Value = report.IDS67 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440031

            #region VR.ATO.IDS.440032

            /*  VR.ATO.IDS.440032
            If an amount of expenditure or revenue is present, both the main pricing methodology and the code for the percentage of the total dollar value of related party international dealings for which you have documentation must be completed.
    
            Legacy Rule Format:
            IF ([IDS68] <> NULL OR [IDS69] <> NULL OR [IDS70] <> NULL OR [IDS71] <> NULL) AND (([IDS68] = NULL AND [IDS69] = NULL) OR [IDS70] = NULL OR [IDS71] = NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS68] = IDS:RP.Logistics:bafpr1.02.16:Expense.Total.Amount
            [IDS69] = IDS:RP.Logistics:bafpr1.02.26:Revenue.Total.Amount
            [IDS70] = IDS:RP.Logistics:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS71] = IDS:RP.Logistics:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code

            Technical Business Rule Format:
            (^IDS68 <> NULL OR ^IDS69 <> NULL OR ^IDS70 <> NULL OR ^IDS71 <> NULL) AND ((^IDS68 = NULL AND ^IDS69 = NULL) OR ^IDS70 = NULL OR ^IDS71 = NULL)
    
            Data Elements:
    
            RP.Logistics:^IDS68 = tns:Expense.Total.Amount
    
            RP.Logistics:^IDS69 = tns:Revenue.Total.Amount
    
            RP.Logistics:^IDS70 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.Logistics:^IDS71 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            */
            assertion = ((report.IDS68 != null || report.IDS69 != null || report.IDS70 != null || report.IDS71 != null) && (report.IDS68 == null && report.IDS69 == null || report.IDS70 == null || report.IDS71 == null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440032",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Logistics information incomplete",
                    LongDescription = @"If service arrangements information has been completed for logistics then expenditure or revenue, main pricing methodology code and percentage of dealings with documentation code must be completed",
                    Location = "/xbrli:xbrl/tns:Expense.Total.Amount[@contextRef='" + report.RPLogisticsId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440032" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS68", Value = report.IDS68.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS69", Value = report.IDS69.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS70", Value = report.IDS70 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS71", Value = report.IDS71 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440032

            #region VR.ATO.IDS.440033

            /*  VR.ATO.IDS.440033
            If an amount of expenditure or revenue is present, both the main pricing methodology and the code for the percentage of the total dollar value of related party international dealings for which you have documentation must be completed.
    
            Legacy Rule Format:
            IF ([IDS72] <> NULL OR [IDS73] <> NULL OR [IDS74] <> NULL OR [IDS75] <> NULL) AND (([IDS72] = NULL AND [IDS73] = NULL) OR [IDS74] = NULL OR [IDS75] = NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS72] = IDS:RP.AssetManagement:bafpr1.02.16:Expense.Total.Amount
            [IDS73] = IDS:RP.AssetManagement:bafpr1.02.26:Revenue.Total.Amount
            [IDS74] = IDS:RP.AssetManagement:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS75] = IDS:RP.AssetManagement:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code

            Technical Business Rule Format:
            (^IDS72 <> NULL OR ^IDS73 <> NULL OR ^IDS74 <> NULL OR ^IDS75 <> NULL) AND ((^IDS72 = NULL AND ^IDS73 = NULL) OR ^IDS74 = NULL OR ^IDS75 = NULL)
    
            Data Elements:
    
            RP.AssetManagement:^IDS72 = tns:Expense.Total.Amount
    
            RP.AssetManagement:^IDS73 = tns:Revenue.Total.Amount
    
            RP.AssetManagement:^IDS74 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.AssetManagement:^IDS75 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            */
            assertion = ((report.IDS72 != null || report.IDS73 != null || report.IDS74 != null || report.IDS75 != null) && (report.IDS72 == null && report.IDS73 == null || report.IDS74 == null || report.IDS75 == null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440033",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Asset management information incomplete",
                    LongDescription = @"If service arrangements information has been completed for asset management then expenditure or revenue, main pricing methodology code and percentage of dealings with documentation code must be completed",
                    Location = "/xbrli:xbrl/tns:Expense.Total.Amount[@contextRef='" + report.RPAssetManagementId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440033" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS72", Value = report.IDS72.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS73", Value = report.IDS73.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS74", Value = report.IDS74 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS75", Value = report.IDS75 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440033

            #region VR.ATO.IDS.440034

            /*  VR.ATO.IDS.440034
            If an amount of expenditure or revenue is present, both the main pricing methodology and the code for the percentage of the total dollar value of related party international dealings for which you have documentation must be completed.
    
            Legacy Rule Format:
            IF ([IDS76] <> NULL OR [IDS77] <> NULL OR [IDS78] <> NULL OR [IDS79] <> NULL OR [IDS80] <> NULL) AND (([IDS76] = NULL AND [IDS77] = NULL) OR [IDS78] = NULL OR [IDS79] = NULL OR [IDS80] = NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS76] = IDS:RP.OtherServices:bafpr1.02.16:Expense.Total.Amount
            [IDS77] = IDS:RP.OtherServices:bafpr1.02.26:Revenue.Total.Amount
            [IDS78] = IDS:RP.OtherServices:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS79] = IDS:RP.OtherServices:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            [IDS80] = IDS:RP.OtherServices:rvctc4.02.05:InternationalDealings.Description.Text

            Technical Business Rule Format:
            (^IDS76 <> NULL OR ^IDS77 <> NULL OR ^IDS78 <> NULL OR ^IDS79 <> NULL OR ^IDS80 <> NULL) AND ((^IDS76 = NULL AND ^IDS77 = NULL) OR ^IDS78 = NULL OR ^IDS79 = NULL OR ^IDS80 = NULL)
    
            Data Elements:
    
            RP.OtherServices:^IDS76 = tns:Expense.Total.Amount
    
            RP.OtherServices:^IDS77 = tns:Revenue.Total.Amount
    
            RP.OtherServices:^IDS78 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.OtherServices:^IDS79 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
    
            RP.OtherServices:^IDS80 = tns:InternationalDealings.Description.Text
            */
            assertion = ((report.IDS76 != null || report.IDS77 != null || report.IDS78 != null || report.IDS79 != null || report.IDS80 != null) && (report.IDS76 == null && report.IDS77 == null || report.IDS78 == null || report.IDS79 == null || report.IDS80 == null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440034",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Other services information incomplete",
                    LongDescription = @"If service arrangements information has been completed for asset management then expenditure or revenue, main pricing methodology code and percentage of dealings with documentation code must be completed",
                    Location = "/xbrli:xbrl/tns:Expense.Total.Amount[@contextRef='" + report.RPOtherServicesId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440034" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS76", Value = report.IDS76.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS77", Value = report.IDS77.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS78", Value = report.IDS78 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS79", Value = report.IDS79 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS80", Value = report.IDS80 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440034

            #region VR.ATO.IDS.440035

            /*  VR.ATO.IDS.440035
            If International related party dealings information has been completed for derivative transactions then the response to 'Did you have any derivative transactions with international related parties?' must be 'True'.
    
            Legacy Rule Format:
            IF ([IDS81] <> TRUE) AND ([IDS82] <> NULL OR [IDS83] <> NULL OR [IDS84] <> NULL OR [IDS85] <> NULL OR [IDS332] <> NULL OR [IDS87] <> NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS81] = IDS:RP:rvctc4.02.05:InternationalDealings.DerivativeTransactions.Indicator
            [IDS82] = IDS:RP.Derivatives:bafpr1.02.16:Expense.Total.Amount
            [IDS83] = IDS:RP.Derivatives:bafpr1.02.26:Revenue.Total.Amount
            [IDS84] = IDS:RP.Derivatives:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS85] = IDS:RP.Derivatives:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            [IDS87] = IDS:RP:rvctc4.02.05:InternationalDealings.DerivativesTradingGlobal.Indicator
            [IDS332] = IDS:RP.Derivatives:rvctc4.02.13:InternationalDealings.RelatedPartyTransactionType.Code

            Technical Business Rule Format:
            (^IDS81 <> TRUE) AND (^IDS82 <> NULL OR ^IDS83 <> NULL OR ^IDS84 <> NULL OR ^IDS85 <> NULL OR ^IDS332 <> NULL OR ^IDS87 <> NULL)
    
            Data Elements:
    
            RP:^IDS81 = tns:InternationalDealings.DerivativeTransactions.Indicator
    
            RP.Derivatives:^IDS82 = tns:Expense.Total.Amount
    
            RP.Derivatives:^IDS83 = tns:Revenue.Total.Amount
    
            RP.Derivatives:^IDS84 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.Derivatives:^IDS85 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
    
            RP:^IDS87 = tns:InternationalDealings.DerivativesTradingGlobal.Indicator
    
            RP.Derivatives:^IDS332 = tns:InternationalDealings.RelatedPartyTransactionType.Code
            */
            assertion = (report.IDS81 != true && (report.IDS82 != null || report.IDS83 != null || report.IDS84 != null || report.IDS85 != null || report.IDS332 != null || report.IDS87 != null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440035",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"International related party dealings question incorrect",
                    LongDescription = @"If International related party dealings information has been completed for derivative transactions then the response to 'Did you have any derivative transactions with international related parties?' must be 'True'",
                    Location = "/xbrli:xbrl/tns:InternationalDealings.DerivativeTransactions.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440035" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS81", Value = GetValueOrEmpty(report.IDS81) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS82", Value = report.IDS82.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS83", Value = report.IDS83.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS84", Value = report.IDS84 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS85", Value = report.IDS85 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS87", Value = GetValueOrEmpty(report.IDS87) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS332", Value = report.IDS332 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440035

            #region VR.ATO.IDS.440036

            /*  VR.ATO.IDS.440036
            If an amount of expenditure or revenue is present, both the main pricing methodology and the code for the percentage of the total dollar value of related party international dealings for which you have documentation must be completed.
    
            Legacy Rule Format:
            IF ([IDS81] = TRUE) AND (([IDS82] = NULL AND [IDS83] = NULL) OR [IDS84] = NULL OR [IDS85] = NULL OR [IDS332] = NULL OR [IDS87] = NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS81] = IDS:RP:rvctc4.02.05:InternationalDealings.DerivativeTransactions.Indicator
            [IDS82] = IDS:RP.Derivatives:bafpr1.02.16:Expense.Total.Amount
            [IDS83] = IDS:RP.Derivatives:bafpr1.02.26:Revenue.Total.Amount
            [IDS84] = IDS:RP.Derivatives:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS85] = IDS:RP.Derivatives:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            [IDS87] = IDS:RP:rvctc4.02.05:InternationalDealings.DerivativesTradingGlobal.Indicator
            [IDS332] = IDS:RP.Derivatives:rvctc4.02.13:InternationalDealings.RelatedPartyTransactionType.Code

            Technical Business Rule Format:
            (^IDS81 = TRUE) AND ((^IDS82 = NULL AND ^IDS83 = NULL) OR ^IDS84 = NULL OR ^IDS85 = NULL OR ^IDS332 = NULL OR ^IDS87 = NULL)
    
            Data Elements:
    
            RP:^IDS81 = tns:InternationalDealings.DerivativeTransactions.Indicator
    
            RP.Derivatives:^IDS82 = tns:Expense.Total.Amount
    
            RP.Derivatives:^IDS83 = tns:Revenue.Total.Amount
    
            RP.Derivatives:^IDS84 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.Derivatives:^IDS85 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
    
            RP:^IDS87 = tns:InternationalDealings.DerivativesTradingGlobal.Indicator
    
            RP.Derivatives:^IDS332 = tns:InternationalDealings.RelatedPartyTransactionType.Code
            */
            assertion = (report.IDS81 == true && (report.IDS82 == null && report.IDS83 == null || report.IDS84 == null || report.IDS85 == null || report.IDS332Collection == null || report.IDS87 == null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440036",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Derivative transactions information incomplete",
                    LongDescription = @"If there is a 'True' response to 'Did you have any derivative transactions with international related parties?' then expenditure or revenue, main pricing methodology code, percentage of dealings with documentation code and principal derivative type code must be completed, and a response must be entered at 'Did you engage in the trading of derivatives globally through a trading structure in which you shared global profits from these activities with international related parties?'",
                    Location = "/xbrli:xbrl/tns:InternationalDealings.DerivativeTransactions.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440036" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS81", Value = GetValueOrEmpty(report.IDS81) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS82", Value = report.IDS82.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS83", Value = report.IDS83.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS84", Value = report.IDS84 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS85", Value = report.IDS85 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS87", Value = GetValueOrEmpty(report.IDS87) });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440036

            #region VR.ATO.IDS.440037

            /*  VR.ATO.IDS.440037
            If International related party dealings information has been completed for debt factoring or securitisation then the response to 'Did you enter into any debt factoring or securitisation arrangements with international related parties?' must be 'True'.
    
            Legacy Rule Format:
            IF [IDS88] <> TRUE AND ([IDS89] <> NULL OR [IDS90] <> NULL OR [IDS91] <> NULL OR [IDS92] <> NULL OR [IDS93] <> NULL OR [IDS94] <> NULL OR [IDS95] <> NULL OR [IDS96] <> NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS88] = IDS:RP:rvctc4.02.05:InternationalDealings.DebtFactoringSecuritisation.Indicator
            [IDS89] = IDS:RP.DebtFactoring:bafpr1.02.12:Expense.BookValue.Amount
            [IDS90] = IDS:RP.DebtFactoring:bafpr1.02.12:Expense.Consideration.Amount
            [IDS91] = IDS:RP.DebtFactoring:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS92] = IDS:RP.DebtFactoring:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            [IDS93] = IDS:RP.Securitisation:bafpr1.02.12:Expense.BookValue.Amount
            [IDS94] = IDS:RP.Securitisation:bafpr1.02.12:Expense.Consideration.Amount
            [IDS95] = IDS:RP.Securitisation:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS96] = IDS:RP.Securitisation:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code

            Technical Business Rule Format:
            ^IDS88 <> TRUE AND (^IDS89 <> NULL OR ^IDS90 <> NULL OR ^IDS91 <> NULL OR ^IDS92 <> NULL OR ^IDS93 <> NULL OR ^IDS94 <> NULL OR ^IDS95 <> NULL OR ^IDS96 <> NULL)
    
            Data Elements:
    
            RP:^IDS88 = tns:InternationalDealings.DebtFactoringSecuritisation.Indicator
    
            RP.DebtFactoring:^IDS89 = tns:Expense.BookValue.Amount
    
            RP.DebtFactoring:^IDS90 = tns:Expense.Consideration.Amount
    
            RP.DebtFactoring:^IDS91 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.DebtFactoring:^IDS92 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
    
            RP.Securitisation:^IDS93 = tns:Expense.BookValue.Amount
    
            RP.Securitisation:^IDS94 = tns:Expense.Consideration.Amount
    
            RP.Securitisation:^IDS95 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.Securitisation:^IDS96 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            */
            assertion = (report.IDS88 != true && (report.IDS89 != null || report.IDS90 != null || report.IDS91 != null || report.IDS92 != null || report.IDS93 != null || report.IDS94 != null || report.IDS95 != null || report.IDS96 != null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440037",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"International related party dealings question incorrect",
                    LongDescription = @"If International related party dealings information has been completed for debt factoring or securitisation then the response to 'Did you enter into any debt factoring or securitisation arrangements with international related parties?' must be 'True'",
                    Location = "/xbrli:xbrl/tns:InternationalDealings.DebtFactoringSecuritisation.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440037" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS88", Value = GetValueOrEmpty(report.IDS88) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS89", Value = report.IDS89.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS90", Value = report.IDS90.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS91", Value = report.IDS91 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS92", Value = report.IDS92 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS93", Value = report.IDS93.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS94", Value = report.IDS94.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS95", Value = report.IDS95 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS96", Value = report.IDS96 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440037

            #region VR.ATO.IDS.440038

            /*  VR.ATO.IDS.440038
            If an amount of expenditure or revenue is present, both the main pricing methodology and the code for the percentage of the total dollar value of related party international dealings for which you have documentation must be completed.
    
            Legacy Rule Format:
            IF [IDS88] = TRUE AND [IDS89] = NULL AND [IDS90] = NULL AND [IDS91] = NULL AND [IDS92] = NULL AND [IDS93] = NULL AND [IDS94] = NULL AND [IDS95] = NULL AND [IDS96] = NULL
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS88] = IDS:RP:rvctc4.02.05:InternationalDealings.DebtFactoringSecuritisation.Indicator
            [IDS89] = IDS:RP.DebtFactoring:bafpr1.02.12:Expense.BookValue.Amount
            [IDS90] = IDS:RP.DebtFactoring:bafpr1.02.12:Expense.Consideration.Amount
            [IDS91] = IDS:RP.DebtFactoring:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS92] = IDS:RP.DebtFactoring:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            [IDS93] = IDS:RP.Securitisation:bafpr1.02.12:Expense.BookValue.Amount
            [IDS94] = IDS:RP.Securitisation:bafpr1.02.12:Expense.Consideration.Amount
            [IDS95] = IDS:RP.Securitisation:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS96] = IDS:RP.Securitisation:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code

            Technical Business Rule Format:
            ^IDS88 = TRUE AND ^IDS89 = NULL AND ^IDS90 = NULL AND ^IDS91 = NULL AND ^IDS92 = NULL AND ^IDS93 = NULL AND ^IDS94 = NULL AND ^IDS95 = NULL AND ^IDS96 = NULL
    
            Data Elements:
    
            RP:^IDS88 = tns:InternationalDealings.DebtFactoringSecuritisation.Indicator
    
            RP.DebtFactoring:^IDS89 = tns:Expense.BookValue.Amount
    
            RP.DebtFactoring:^IDS90 = tns:Expense.Consideration.Amount
    
            RP.DebtFactoring:^IDS91 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.DebtFactoring:^IDS92 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
    
            RP.Securitisation:^IDS93 = tns:Expense.BookValue.Amount
    
            RP.Securitisation:^IDS94 = tns:Expense.Consideration.Amount
    
            RP.Securitisation:^IDS95 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.Securitisation:^IDS96 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            */
            assertion = (report.IDS88 == true && report.IDS89 == null && report.IDS90 == null && report.IDS91 == null && report.IDS92 == null && report.IDS93 == null && report.IDS94 == null && report.IDS95 == null && report.IDS96 == null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440038",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"International related party dealings information required",
                    LongDescription = @"If there is a 'True' response to 'Did you enter into any debt factoring or securitisation arrangements with international related parties?' then debt factoring or securitisation information must be completed",
                    Location = "/xbrli:xbrl/tns:InternationalDealings.DebtFactoringSecuritisation.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440038" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS88", Value = GetValueOrEmpty(report.IDS88) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS89", Value = report.IDS89.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS90", Value = report.IDS90.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS91", Value = report.IDS91 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS92", Value = report.IDS92 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS93", Value = report.IDS93.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS94", Value = report.IDS94.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS95", Value = report.IDS95 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS96", Value = report.IDS96 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440038

            #region VR.ATO.IDS.440039

            /*  VR.ATO.IDS.440039
            If an amount of expenditure or revenue is present, both the main pricing methodology and the code for the percentage of the total dollar value of related party international dealings for which you have documentation must be completed.
    
            Legacy Rule Format:
            IF ([IDS89] <> NULL OR [IDS90] <> NULL OR [IDS91] <> NULL OR [IDS92] <> NULL) AND (([IDS89] = NULL AND [IDS90] = NULL) OR [IDS91] = NULL OR [IDS92] = NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS89] = IDS:RP.DebtFactoring:bafpr1.02.12:Expense.BookValue.Amount
            [IDS90] = IDS:RP.DebtFactoring:bafpr1.02.12:Expense.Consideration.Amount
            [IDS91] = IDS:RP.DebtFactoring:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS92] = IDS:RP.DebtFactoring:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code

            Technical Business Rule Format:
            (^IDS89 <> NULL OR ^IDS90 <> NULL OR ^IDS91 <> NULL OR ^IDS92 <> NULL) AND ((^IDS89 = NULL AND ^IDS90 = NULL) OR ^IDS91 = NULL OR ^IDS92 = NULL)
    
            Data Elements:
    
            RP.DebtFactoring:^IDS89 = tns:Expense.BookValue.Amount
    
            RP.DebtFactoring:^IDS90 = tns:Expense.Consideration.Amount
    
            RP.DebtFactoring:^IDS91 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.DebtFactoring:^IDS92 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            */
            assertion = ((report.IDS89 != null || report.IDS90 != null || report.IDS91 != null || report.IDS92 != null) && (report.IDS89 == null && report.IDS90 == null || report.IDS91 == null || report.IDS92 == null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440039",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Debt factoring information incomplete",
                    LongDescription = @"If debt factoring information has been completed then book value or consideration, main pricing methodology code and percentage of dealings with documentation code must be completed",
                    Location = "/xbrli:xbrl/tns:Expense.BookValue.Amount[@contextRef='" + report.RPDebtFactoringId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440039" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS89", Value = report.IDS89.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS90", Value = report.IDS90.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS91", Value = report.IDS91 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS92", Value = report.IDS92 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440039

            #region VR.ATO.IDS.440040

            /*  VR.ATO.IDS.440040
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF bafpr1.xx.xx:Expense.BookValue.Amount <> NULL AND bafpr1.xx.xx:Expense.BookValue.Amount <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS89, 'U', 11, 0)
    
            Data Elements:
    
            RP.DebtFactoring:^IDS89 = tns:Expense.BookValue.Amount
            */
            assertion = NotMonetary(report.IDS89, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Expense.BookValue.Amount[@contextRef='" + report.RPDebtFactoringId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440040" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS89", Value = report.IDS89.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440040

            #region VR.ATO.IDS.440040

            /*  VR.ATO.IDS.440040
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF bafpr1.xx.xx:Expense.BookValue.Amount <> NULL AND bafpr1.xx.xx:Expense.BookValue.Amount <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS93, 'U', 11, 0)
    
            Data Elements:
    
            RP.Securitisation:^IDS93 = tns:Expense.BookValue.Amount
            */
            assertion = NotMonetary(report.IDS93, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Expense.BookValue.Amount[@contextRef='" + report.RPSecuritisationId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440040" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS93", Value = report.IDS93.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440040

            #region VR.ATO.IDS.440041

            /*  VR.ATO.IDS.440041
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF bafpr1.xx.xx:Expense.Consideration.Amount <> NULL AND bafpr1.xx.xx:Expense.Consideration.Amount <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS90, 'U', 11, 0)
    
            Data Elements:
    
            RP.DebtFactoring:^IDS90 = tns:Expense.Consideration.Amount
            */
            assertion = NotMonetary(report.IDS90, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Expense.Consideration.Amount[@contextRef='" + report.RPDebtFactoringId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440041" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS90", Value = report.IDS90.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440041

            #region VR.ATO.IDS.440041

            /*  VR.ATO.IDS.440041
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF bafpr1.xx.xx:Expense.Consideration.Amount <> NULL AND bafpr1.xx.xx:Expense.Consideration.Amount <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS94, 'U', 11, 0)
    
            Data Elements:
    
            RP.Securitisation:^IDS94 = tns:Expense.Consideration.Amount
            */
            assertion = NotMonetary(report.IDS94, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Expense.Consideration.Amount[@contextRef='" + report.RPSecuritisationId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440041" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS94", Value = report.IDS94.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440041

            #region VR.ATO.IDS.440042

            /*  VR.ATO.IDS.440042
            If the securitisation information has been completed then book value or consideration amount and main pricing methodology code and percentage of dealings with documentation code must be completed.
    
            Legacy Rule Format:
            IF ([IDS93] <> NULL OR [IDS94] <> NULL OR [IDS95] <> NULL OR [IDS96] <> NULL) AND (([IDS93] = NULL AND [IDS94] = NULL) OR [IDS95] = NULL OR [IDS96] = NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS93] = IDS:RP.Securitisation:bafpr1.02.12:Expense.BookValue.Amount
            [IDS94] = IDS:RP.Securitisation:bafpr1.02.12:Expense.Consideration.Amount
            [IDS95] = IDS:RP.Securitisation:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS96] = IDS:RP.Securitisation:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code

            Technical Business Rule Format:
            (^IDS93 <> NULL OR ^IDS94 <> NULL OR ^IDS95 <> NULL OR ^IDS96 <> NULL) AND ((^IDS93 = NULL AND ^IDS94 = NULL) OR ^IDS95 = NULL OR ^IDS96 = NULL)
    
            Data Elements:
    
            RP.Securitisation:^IDS93 = tns:Expense.BookValue.Amount
    
            RP.Securitisation:^IDS94 = tns:Expense.Consideration.Amount
    
            RP.Securitisation:^IDS95 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.Securitisation:^IDS96 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            */
            assertion = ((report.IDS93 != null || report.IDS94 != null || report.IDS95 != null || report.IDS96 != null) && (report.IDS93 == null && report.IDS94 == null || report.IDS95 == null || report.IDS96 == null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440042",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Securitisation information incomplete",
                    LongDescription = @"If securitisation information has been completed then book value or consideration, main pricing methodology code and percentage of dealings with documentation code must be completed",
                    Location = "/xbrli:xbrl/tns:Expense.BookValue.Amount[@contextRef='" + report.RPSecuritisationId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440042" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS93", Value = report.IDS93.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS94", Value = report.IDS94.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS95", Value = report.IDS95 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS96", Value = report.IDS96 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440042

            #region VR.ATO.IDS.440047

            /*  VR.ATO.IDS.440047
            If dealings of a financial nature information has been completed for interest bearing loans, either amounts borrowed or amounts loaned, then an expenditure or revenue amount must be completed for interest.
    
            Legacy Rule Format:
            IF ([IDS98] > 0 OR [IDS100] > 0) AND ([IDS102] = NULL AND [IDS103] = NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS98] = IDS:RP.OtherFinancialDealings.InterestBearing:bafpo1.02.11:Liabilities.BorrowedAverageBalance.Amount
            [IDS100] = IDS:RP.OtherFinancialDealings.InterestBearing:bafpo1.02.11:Assets.LoanedAverageBalance.Amount
            [IDS102] = IDS:RP.OtherInterest:bafpr1.02.16:Expense.Total.Amount
            [IDS103] = IDS:RP.OtherInterest:bafpr1.02.26:Revenue.Total.Amount

            Technical Business Rule Format:
            (^IDS98 > 0 OR ^IDS100 > 0) AND (^IDS102 = NULL AND ^IDS103 = NULL)
    
            Data Elements:
    
            RP.OtherFinancialDealings.InterestBearing:^IDS98 = tns:Liabilities.BorrowedAverageBalance.Amount
    
            RP.OtherFinancialDealings.InterestBearing:^IDS100 = tns:Assets.LoanedAverageBalance.Amount
    
            RP.OtherInterest:^IDS102 = tns:Expense.Total.Amount
    
            RP.OtherInterest:^IDS103 = tns:Revenue.Total.Amount
            */
            assertion = ((report.IDS98.GetValueOrDefault() > 0 || report.IDS100.GetValueOrDefault() > 0) && (report.IDS102 == null && report.IDS103 == null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440047",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Interest bearing loans information incomplete",
                    LongDescription = @"If dealings of a financial nature information has been completed for interest bearing loans, either amounts borrowed or amounts loaned, then an expenditure or revenue amount must be completed for interest",
                    Location = "/xbrli:xbrl/tns:Liabilities.BorrowedAverageBalance.Amount[@contextRef='" + report.RPOtherFinancialDealingsInterestBearingId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440047" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS98", Value = report.IDS98.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS100", Value = report.IDS100.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS102", Value = report.IDS102.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS103", Value = report.IDS103.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440047

            #region VR.ATO.IDS.440048

            /*  VR.ATO.IDS.440048
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF bafpo1.xx.xx:Liabilities.BorrowedAverageBalance.Amount <> NULL AND bafpo1.xx.xx:Liabilities.BorrowedAverageBalance.Amount <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS99, 'U', 11, 0)
    
            Data Elements:
    
            RP.OtherFinancialDealings.InterestFree:^IDS99 = tns:Liabilities.BorrowedAverageBalance.Amount
            */
            assertion = NotMonetary(report.IDS99, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Liabilities.BorrowedAverageBalance.Amount[@contextRef='" + report.RPOtherFinancialDealingsInterestFreeId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440048" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS99", Value = report.IDS99.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440048

            #region VR.ATO.IDS.440048

            /*  VR.ATO.IDS.440048
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF bafpo1.xx.xx:Liabilities.BorrowedAverageBalance.Amount <> NULL AND bafpo1.xx.xx:Liabilities.BorrowedAverageBalance.Amount <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS161, 'U', 11, 0)
    
            Data Elements:
    
            RP.BranchOperations.InterestBearing:^IDS161 = tns:Liabilities.BorrowedAverageBalance.Amount
            */
            assertion = NotMonetary(report.IDS161, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Liabilities.BorrowedAverageBalance.Amount[@contextRef='" + report.RPBranchOperationsInterestBearingId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440048" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS161", Value = report.IDS161.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440048

            #region VR.ATO.IDS.440048

            /*  VR.ATO.IDS.440048
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF bafpo1.xx.xx:Liabilities.BorrowedAverageBalance.Amount <> NULL AND bafpo1.xx.xx:Liabilities.BorrowedAverageBalance.Amount <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS165, 'U', 11, 0)
    
            Data Elements:
    
            RP.BranchOperations.InterestFree:^IDS165 = tns:Liabilities.BorrowedAverageBalance.Amount
            */
            assertion = NotMonetary(report.IDS165, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Liabilities.BorrowedAverageBalance.Amount[@contextRef='" + report.RPBranchOperationsInterestFreeId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440048" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS165", Value = report.IDS165.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440048

            #region VR.ATO.IDS.440048

            /*  VR.ATO.IDS.440048
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF bafpo1.xx.xx:Liabilities.BorrowedAverageBalance.Amount <> NULL AND bafpo1.xx.xx:Liabilities.BorrowedAverageBalance.Amount <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS98, 'U', 11, 0)
    
            Data Elements:
    
            RP.OtherFinancialDealings.InterestBearing:^IDS98 = tns:Liabilities.BorrowedAverageBalance.Amount
            */
            assertion = NotMonetary(report.IDS98, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Liabilities.BorrowedAverageBalance.Amount[@contextRef='" + report.RPOtherFinancialDealingsInterestBearingId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440048" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS98", Value = report.IDS98.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440048

            #region VR.ATO.IDS.440050

            /*  VR.ATO.IDS.440050
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF bafpo1.xx.xx:Assets.LoanedAverageBalance.Amount <> NULL AND bafpo1.xx.xx:Assets.LoanedAverageBalance.Amount <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS101, 'U', 11, 0)
    
            Data Elements:
    
            RP.OtherFinancialDealings.InterestFree:^IDS101 = tns:Assets.LoanedAverageBalance.Amount
            */
            assertion = NotMonetary(report.IDS101, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Assets.LoanedAverageBalance.Amount[@contextRef='" + report.RPOtherFinancialDealingsInterestFreeId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440050" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS101", Value = report.IDS101.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440050

            #region VR.ATO.IDS.440050

            /*  VR.ATO.IDS.440050
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF bafpo1.xx.xx:Assets.LoanedAverageBalance.Amount <> NULL AND bafpo1.xx.xx:Assets.LoanedAverageBalance.Amount <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS162, 'U', 11, 0)
    
            Data Elements:
    
            RP.BranchOperations.InterestBearing:^IDS162 = tns:Assets.LoanedAverageBalance.Amount
            */
            assertion = NotMonetary(report.IDS162, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Assets.LoanedAverageBalance.Amount[@contextRef='" + report.RPBranchOperationsInterestBearingId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440050" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS162", Value = report.IDS162.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440050

            #region VR.ATO.IDS.440050

            /*  VR.ATO.IDS.440050
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF bafpo1.xx.xx:Assets.LoanedAverageBalance.Amount <> NULL AND bafpo1.xx.xx:Assets.LoanedAverageBalance.Amount <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS166, 'U', 11, 0)
    
            Data Elements:
    
            RP.BranchOperations.InterestFree:^IDS166 = tns:Assets.LoanedAverageBalance.Amount
            */
            assertion = NotMonetary(report.IDS166, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Assets.LoanedAverageBalance.Amount[@contextRef='" + report.RPBranchOperationsInterestFreeId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440050" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS166", Value = report.IDS166.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440050

            #region VR.ATO.IDS.440050

            /*  VR.ATO.IDS.440050
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF bafpo1.xx.xx:Assets.LoanedAverageBalance.Amount <> NULL AND bafpo1.xx.xx:Assets.LoanedAverageBalance.Amount <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS100, 'U', 11, 0)
    
            Data Elements:
    
            RP.OtherFinancialDealings.InterestBearing:^IDS100 = tns:Assets.LoanedAverageBalance.Amount
            */
            assertion = NotMonetary(report.IDS100, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Assets.LoanedAverageBalance.Amount[@contextRef='" + report.RPOtherFinancialDealingsInterestBearingId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440050" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS100", Value = report.IDS100.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440050

            #region VR.ATO.IDS.440051
            /* VR.ATO.IDS.440051
             
            Field value supplied exceeds maximum field length

            Legacy Rule Format:
            IF ([IDS80] <> NULLORBLANK) AND (LENGTH([IDS80]) > 200)
             RETURN VALIDATION MESSAGE
            ENDIF             

             [IDS80] = rvctc4.02.05:InternationalDealings.Description.Text

            Technical Business Rule Format:
            (^IDS80 <> NULLORBLANK) AND (LENGTH(^IDS80) > 200)

            RP.OtherServices:^IDS80 = tns:InternationalDealings.Description.Text
             */
            
            assertion = ((report.IDS80 != null) && report.IDS80.Length > 200);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field value supplied exceeds maximum field length",
                    Location = "/xbrli:xbrl/tns:InternationalDealings.Description.Text[@contextRef='" + report.RPOtherServicesId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440051" } },
                };

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS80", Value = report.IDS80 });

                response.Add(processMessage);

            }

            #endregion // VR.ATO.IDS.440051

            #region VR.ATO.IDS.440051
            /* VR.ATO.IDS.440051
             
            Field value supplied exceeds maximum field length

            Legacy Rule Format:
            IF ([IDS122] <> NULLORBLANK) AND (LENGTH([IDS122]) > 200)
             RETURN VALIDATION MESSAGE
            ENDIF             

             [IDS122] = rvctc4.02.05:InternationalDealings.Description.Text

            Technical Business Rule Format:
            (^IDS122 <> NULLORBLANK) AND (LENGTH(^IDS122) > 200)

            RP.OtherFinancialDealings:^IDS122 = tns:InternationalDealings.Description.Text
             */
            assertion = ((report.IDS122 != null) && report.IDS122.Length > 200);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field value supplied exceeds maximum field length",
                    Location = "/xbrli:xbrl/tns:InternationalDealings.Description.Text[@contextRef='" + report.RPOtherFinancialDealingsId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440051" } },
                };

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS122", Value = report.IDS122 });

                response.Add(processMessage);

            }

            #endregion // VR.ATO.IDS.440051

            #region VR.ATO.IDS.440051
            /* VR.ATO.IDS.440051
             
            Field value supplied exceeds maximum field length

            Legacy Rule Format:
            IF ([IDS128] <> NULLORBLANK) AND (LENGTH([IDS128]) > 200)
             RETURN VALIDATION MESSAGE
            ENDIF             

             [IDS128] = rvctc4.02.05:InternationalDealings.Description.Text

            Technical Business Rule Format:
            (^IDS128 <> NULLORBLANK) AND (LENGTH(^IDS128) > 200)

            RP.OtherNotReportedRevenue:^IDS128 = tns:InternationalDealings.Description.Text
             */
            assertion = ((report.IDS128 != null) && report.IDS128.Length > 200);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field value supplied exceeds maximum field length",
                    Location = "/xbrli:xbrl/tns:InternationalDealings.Description.Text[@contextRef='" + report.RPOtherNotReportedRevenueId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440051" } },
                };

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS128", Value = report.IDS128 });

                response.Add(processMessage);

            }

            #endregion // VR.ATO.IDS.440051

            #region VR.ATO.IDS.440051
            /* VR.ATO.IDS.440051
             
            Field value supplied exceeds maximum field length

            Legacy Rule Format:
            IF ([IDS157] <> NULLORBLANK) AND (LENGTH([IDS157]) > 200)
             RETURN VALIDATION MESSAGE
            ENDIF             

             [IDS157] = rvctc4.02.05:InternationalDealings.Description.Text

            Technical Business Rule Format:
            (^IDS157 <> NULLORBLANK) AND (LENGTH(^IDS157) > 200)

            RP.RestructuringEvent:^IDS157 = tns:InternationalDealings.Description.Text
             */
            assertion = report.RPRestructuringEventContextCollection != null && report.RPRestructuringEventContextCollection.Any( c => c.IDS157 != null && c.IDS157.Length > 200 );
            if (assertion)
            {
                IEnumerable<IDS2017.RPRestructuringEventContext> faultContexts = report.RPRestructuringEventContextCollection.Where(c => c.IDS157 != null && c.IDS157.Length > 200);
                foreach(IDS2017.RPRestructuringEventContext context in faultContexts)
                {
                    processMessage = new ProcessMessageDocument()
                    {
                        Code = "CMN.ATO.GEN.001011",
                        Severity = ProcessMessageSeverity.Error,
                        Description = @"Field value supplied exceeds maximum field length",
                        Location = "/xbrli:xbrl/xbrli:context[@id='" + context.Id+"']/xbrli:entity/xbrli:segment/xbrldi:typedMember[@dimension='tns:RestructuringEventDimension']/tns:RestructuringEventContainer",
                        Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440051" } },
                    };

                    processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "IDS157", Value = context.IDS157 });

                    response.Add(processMessage);
                }
            }

            #endregion // VR.ATO.IDS.440051

            #region VR.ATO.IDS.440052

            /*  VR.ATO.IDS.440052
            If an amount of expenditure or revenue is present, both the main pricing methodology and the code for the percentage of the total dollar value of related party international dealings for which you have documentation must be completed.
    
            Legacy Rule Format:
            IF ([IDS102] <> NULL OR [IDS103] <> NULL OR [IDS104] <> NULL OR [IDS105] <> NULL) AND (([IDS102] = NULL AND [IDS103] = NULL) OR [IDS104] = NULL OR [IDS105] = NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS102] = IDS:RP.OtherInterest:bafpr1.02.16:Expense.Total.Amount
            [IDS103] = IDS:RP.OtherInterest:bafpr1.02.26:Revenue.Total.Amount
            [IDS104] = IDS:RP.OtherInterest:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS105] = IDS:RP.OtherInterest:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code

            Technical Business Rule Format:
            (^IDS102 <> NULL OR ^IDS103 <> NULL OR ^IDS104 <> NULL OR ^IDS105 <> NULL) AND ((^IDS102 = NULL AND ^IDS103 = NULL) OR ^IDS104 = NULL OR ^IDS105 = NULL)
    
            Data Elements:
    
            RP.OtherInterest:^IDS102 = tns:Expense.Total.Amount
    
            RP.OtherInterest:^IDS103 = tns:Revenue.Total.Amount
    
            RP.OtherInterest:^IDS104 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.OtherInterest:^IDS105 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            */
            assertion = ((report.IDS102 != null || report.IDS103 != null || report.IDS104 != null || report.IDS105 != null) && (report.IDS102 == null && report.IDS103 == null || report.IDS104 == null || report.IDS105 == null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440052",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Interest information incomplete",
                    LongDescription = @"If dealings of a financial nature information has been completed for interest then expenditure or revenue, main pricing methodology code and percentage of dealings with documentation code must be completed",
                    Location = "/xbrli:xbrl/tns:Expense.Total.Amount[@contextRef='" + report.RPOtherInterestId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440052" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS102", Value = report.IDS102.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS103", Value = report.IDS103.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS104", Value = report.IDS104 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS105", Value = report.IDS105 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440052

            #region VR.ATO.IDS.440053

            /*  VR.ATO.IDS.440053
            If an amount of expenditure or revenue is present, both the main pricing methodology and the code for the percentage of the total dollar value of related party international dealings for which you have documentation must be completed.
    
            Legacy Rule Format:
            IF ([IDS106] <> NULL OR [IDS107] <> NULL OR [IDS108] <> NULL OR [IDS109] <> NULL) AND (([IDS106] = NULL AND [IDS107] = NULL) OR [IDS108] = NULL OR [IDS109] = NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS106] = IDS:RP.OtherGuarantees:bafpr1.02.16:Expense.Total.Amount
            [IDS107] = IDS:RP.OtherGuarantees:bafpr1.02.26:Revenue.Total.Amount
            [IDS108] = IDS:RP.OtherGuarantees:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS109] = IDS:RP.OtherGuarantees:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code

            Technical Business Rule Format:
            (^IDS106 <> NULL OR ^IDS107 <> NULL OR ^IDS108 <> NULL OR ^IDS109 <> NULL) AND ((^IDS106 = NULL AND ^IDS107 = NULL) OR ^IDS108 = NULL OR ^IDS109 = NULL)
    
            Data Elements:
    
            RP.OtherGuarantees:^IDS106 = tns:Expense.Total.Amount
    
            RP.OtherGuarantees:^IDS107 = tns:Revenue.Total.Amount
    
            RP.OtherGuarantees:^IDS108 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.OtherGuarantees:^IDS109 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            */
            assertion = ((report.IDS106 != null || report.IDS107 != null || report.IDS108 != null || report.IDS109 != null) && (report.IDS106 == null && report.IDS107 == null || report.IDS108 == null || report.IDS109 == null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440053",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Guarantees information incomplete",
                    LongDescription = @"If dealings of a financial nature information has been completed for guarantees then expenditure or revenue, main pricing methodology code and percentage of dealings with documentation code must be completed",
                    Location = "/xbrli:xbrl/tns:Expense.Total.Amount[@contextRef='" + report.RPOtherGuaranteesId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440053" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS106", Value = report.IDS106.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS107", Value = report.IDS107.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS108", Value = report.IDS108 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS109", Value = report.IDS109 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440053

            #region VR.ATO.IDS.440054

            /*  VR.ATO.IDS.440054
            If an amount of expenditure or revenue is present, both the main pricing methodology and the code for the percentage of the total dollar value of related party international dealings for which you have documentation must be completed.
    
            Legacy Rule Format:
            IF ([IDS110] <> NULL OR [IDS111] <> NULL OR [IDS112] <> NULL OR [IDS113] <> NULL) AND (([IDS110] = NULL AND [IDS111] = NULL) OR [IDS112] = NULL OR [IDS113] = NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS110] = IDS:RP.OtherInsurance:bafpr1.02.16:Expense.Total.Amount
            [IDS111] = IDS:RP.OtherInsurance:bafpr1.02.26:Revenue.Total.Amount
            [IDS112] = IDS:RP.OtherInsurance:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS113] = IDS:RP.OtherInsurance:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code

            Technical Business Rule Format:
            (^IDS110 <> NULL OR ^IDS111 <> NULL OR ^IDS112 <> NULL OR ^IDS113 <> NULL) AND ((^IDS110 = NULL AND ^IDS111 = NULL) OR ^IDS112 = NULL OR ^IDS113 = NULL)
    
            Data Elements:
    
            RP.OtherInsurance:^IDS110 = tns:Expense.Total.Amount
    
            RP.OtherInsurance:^IDS111 = tns:Revenue.Total.Amount
    
            RP.OtherInsurance:^IDS112 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.OtherInsurance:^IDS113 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            */
            assertion = ((report.IDS110 != null || report.IDS111 != null || report.IDS112 != null || report.IDS113 != null) && (report.IDS110 == null && report.IDS111 == null || report.IDS112 == null || report.IDS113 == null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440054",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Insurance information incomplete",
                    LongDescription = @"If dealings of a financial nature information has been completed for insurance then expenditure or revenue, main pricing methodology code and percentage of dealings with documentation code must be completed",
                    Location = "/xbrli:xbrl/tns:Expense.Total.Amount[@contextRef='" + report.RPOtherInsuranceId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440054" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS110", Value = report.IDS110.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS111", Value = report.IDS111.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS112", Value = report.IDS112 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS113", Value = report.IDS113 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440054

            #region VR.ATO.IDS.440055

            /*  VR.ATO.IDS.440055
            If an amount of expenditure or revenue is present, both the main pricing methodology and the code for the percentage of the total dollar value of related party international dealings for which you have documentation must be completed.
    
            Legacy Rule Format:
            IF ([IDS114] <> NULL OR [IDS115] <> NULL OR [IDS116] <> NULL OR [IDS117] <> NULL) AND (([IDS114] = NULL AND [IDS115] = NULL) OR [IDS116] = NULL OR [IDS117] = NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS114] = IDS:RP.OtherReinsurance:bafpr1.02.16:Expense.Total.Amount
            [IDS115] = IDS:RP.OtherReinsurance:bafpr1.02.26:Revenue.Total.Amount
            [IDS116] = IDS:RP.OtherReinsurance:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS117] = IDS:RP.OtherReinsurance:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code

            Technical Business Rule Format:
            (^IDS114 <> NULL OR ^IDS115 <> NULL OR ^IDS116 <> NULL OR ^IDS117 <> NULL) AND ((^IDS114 = NULL AND ^IDS115 = NULL) OR ^IDS116 = NULL OR ^IDS117 = NULL)
    
            Data Elements:
    
            RP.OtherReinsurance:^IDS114 = tns:Expense.Total.Amount
    
            RP.OtherReinsurance:^IDS115 = tns:Revenue.Total.Amount
    
            RP.OtherReinsurance:^IDS116 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.OtherReinsurance:^IDS117 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            */
            assertion = ((report.IDS114 != null || report.IDS115 != null || report.IDS116 != null || report.IDS117 != null) && (report.IDS114 == null && report.IDS115 == null || report.IDS116 == null || report.IDS117 == null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440055",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Reinsurance information incomplete",
                    LongDescription = @"If dealings of a financial nature information has been completed for reinsurance then expenditure or revenue, main pricing methodology code and percentage of dealings with documentation code must be completed",
                    Location = "/xbrli:xbrl/tns:Expense.Total.Amount[@contextRef='" + report.RPOtherReinsuranceId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440055" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS114", Value = report.IDS114.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS115", Value = report.IDS115.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS116", Value = report.IDS116 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS117", Value = report.IDS117 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440055

            #region VR.ATO.IDS.440056

            /*  VR.ATO.IDS.440056
            If an amount of expenditure or revenue is present, both the main pricing methodology and the code for the percentage of the total dollar value of related party international dealings for which you have documentation must be completed.
    
            Legacy Rule Format:
            IF ([IDS118] <> NULL OR [IDS119] <> NULL OR [IDS120] <> NULL OR [IDS121] <> NULL OR [IDS122] <> NULL) AND (([IDS118] = NULL AND [IDS119] = NULL) OR [IDS120] = NULL OR [IDS121] = NULL OR [IDS122] = NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS118] = IDS:RP.OtherFinancialDealings:bafpr1.02.16:Expense.Total.Amount
            [IDS119] = IDS:RP.OtherFinancialDealings:bafpr1.02.26:Revenue.Total.Amount
            [IDS120] = IDS:RP.OtherFinancialDealings:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS121] = IDS:RP.OtherFinancialDealings:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            [IDS122] = IDS:RP.OtherFinancialDealings:rvctc4.02.05:InternationalDealings.Description.Text

            Technical Business Rule Format:
            (^IDS118 <> NULL OR ^IDS119 <> NULL OR ^IDS120 <> NULL OR ^IDS121 <> NULL OR ^IDS122 <> NULL) AND ((^IDS118 = NULL AND ^IDS119 = NULL) OR ^IDS120 = NULL OR ^IDS121 = NULL OR ^IDS122 = NULL)
    
            Data Elements:
    
            RP.OtherFinancialDealings:^IDS118 = tns:Expense.Total.Amount
    
            RP.OtherFinancialDealings:^IDS119 = tns:Revenue.Total.Amount
    
            RP.OtherFinancialDealings:^IDS120 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.OtherFinancialDealings:^IDS121 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
    
            RP.OtherFinancialDealings:^IDS122 = tns:InternationalDealings.Description.Text
            */
            assertion = ((report.IDS118 != null || report.IDS119 != null || report.IDS120 != null || report.IDS121 != null || report.IDS122 != null) && (report.IDS118 == null && report.IDS119 == null || report.IDS120 == null || report.IDS121 == null || report.IDS122 == null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440056",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Other financial dealings information incomplete",
                    LongDescription = @"If dealings of a financial nature information has been completed for other financial dealings then expenditure or revenue, main pricing methodology code, percentage of dealings with documentation code and description must be completed",
                    Location = "/xbrli:xbrl/tns:Expense.Total.Amount[@contextRef='" + report.RPOtherFinancialDealingsId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440056" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS118", Value = report.IDS118.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS119", Value = report.IDS119.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS120", Value = report.IDS120 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS121", Value = report.IDS121 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS122", Value = report.IDS122 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440056

            #region VR.ATO.IDS.440057

            /*  VR.ATO.IDS.440057
            If International related party dealings information has been completed for other dealings of a revenue nature then the response to 'Did you have any other international related party dealings of a revenue nature?' must be 'True'.
    
            Legacy Rule Format:
            IF ([IDS123] <> TRUE) AND ([IDS124] <> NULL OR [IDS125] <> NULL OR [IDS126] <> NULL OR [IDS127] <> NULL OR [IDS128] <> NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS123] = IDS:RP:rvctc4.02.05:InternationalDealings.OtherRevenue.Indicator
            [IDS124] = IDS:RP.OtherNotReportedRevenue:bafpr1.02.16:Expense.Total.Amount
            [IDS125] = IDS:RP.OtherNotReportedRevenue:bafpr1.02.26:Revenue.Total.Amount
            [IDS126] = IDS:RP.OtherNotReportedRevenue:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS127] = IDS:RP.OtherNotReportedRevenue:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            [IDS128] = IDS:RP.OtherNotReportedRevenue:rvctc4.02.05:InternationalDealings.Description.Text

            Technical Business Rule Format:
            (^IDS123 <> TRUE) AND (^IDS124 <> NULL OR ^IDS125 <> NULL OR ^IDS126 <> NULL OR ^IDS127 <> NULL OR ^IDS128 <> NULL)
    
            Data Elements:
    
            RP:^IDS123 = tns:InternationalDealings.OtherRevenue.Indicator
    
            RP.OtherNotReportedRevenue:^IDS124 = tns:Expense.Total.Amount
    
            RP.OtherNotReportedRevenue:^IDS125 = tns:Revenue.Total.Amount
    
            RP.OtherNotReportedRevenue:^IDS126 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.OtherNotReportedRevenue:^IDS127 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
    
            RP.OtherNotReportedRevenue:^IDS128 = tns:InternationalDealings.Description.Text
            */
            assertion = (report.IDS123 != true && (report.IDS124 != null || report.IDS125 != null || report.IDS126 != null || report.IDS127 != null || report.IDS128 != null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440057",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"International related party dealings question incorrect",
                    LongDescription = @"If International related party dealings information has been completed for other dealings of a revenue nature then the response to 'Did you have any other international related party dealings of a revenue nature?' must be 'True'",
                    Location = "/xbrli:xbrl/tns:InternationalDealings.OtherRevenue.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440057" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS123", Value = GetValueOrEmpty(report.IDS123) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS124", Value = report.IDS124.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS125", Value = report.IDS125.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS126", Value = report.IDS126 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS127", Value = report.IDS127 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS128", Value = report.IDS128 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440057

            #region VR.ATO.IDS.440058

            /*  VR.ATO.IDS.440058
            If an amount of expenditure or revenue is present, both the main pricing methodology and the code for the percentage of the total dollar value of related party international dealings for which you have documentation must be completed
    
            Legacy Rule Format:
            IF ([IDS123] = TRUE) AND (([IDS124] = NULL AND [IDS125] = NULL) OR [IDS126] = NULL OR [IDS127] = NULL OR [IDS128] = NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS123] = IDS:RP:rvctc4.02.05:InternationalDealings.OtherRevenue.Indicator
            [IDS124] = IDS:RP.OtherNotReportedRevenue:bafpr1.02.16:Expense.Total.Amount
            [IDS125] = IDS:RP.OtherNotReportedRevenue:bafpr1.02.26:Revenue.Total.Amount
            [IDS126] = IDS:RP.OtherNotReportedRevenue:bafot.02.11:Miscellaneous.ArmsLengthPricingMethod.Code
            [IDS127] = IDS:RP.OtherNotReportedRevenue:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            [IDS128] = IDS:RP.OtherNotReportedRevenue:rvctc4.02.05:InternationalDealings.Description.Text

            Technical Business Rule Format:
            (^IDS123 = TRUE) AND ((^IDS124 = NULL AND ^IDS125 = NULL) OR ^IDS126 = NULL OR ^IDS127 = NULL OR ^IDS128 = NULL)
    
            Data Elements:
    
            RP:^IDS123 = tns:InternationalDealings.OtherRevenue.Indicator
    
            RP.OtherNotReportedRevenue:^IDS124 = tns:Expense.Total.Amount
    
            RP.OtherNotReportedRevenue:^IDS125 = tns:Revenue.Total.Amount
    
            RP.OtherNotReportedRevenue:^IDS126 = tns:Miscellaneous.ArmsLengthPricingMethod.Code
    
            RP.OtherNotReportedRevenue:^IDS127 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
    
            RP.OtherNotReportedRevenue:^IDS128 = tns:InternationalDealings.Description.Text
            */
            assertion = (report.IDS123 == true && (report.IDS124 == null && report.IDS125 == null || report.IDS126 == null || report.IDS127 == null || report.IDS128 == null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440058",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Other dealings of a revenue nature information incomplete",
                    LongDescription = @"If there is a 'True' response to 'Did you have any other international related party dealings of a revenue nature?' then expenditure or revenue, main pricing methodology code, percentage of dealings with documentation code and description must be completed",
                    Location = "/xbrli:xbrl/tns:InternationalDealings.OtherRevenue.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440058" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS123", Value = GetValueOrEmpty(report.IDS123) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS124", Value = report.IDS124.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS125", Value = report.IDS125.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS126", Value = report.IDS126 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS127", Value = report.IDS127 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS128", Value = report.IDS128 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440058

            #region VR.ATO.IDS.440059

            /*  VR.ATO.IDS.440059
            If International related party dealings information has been completed for tangible or intangible property then the response to 'Did you dispose of or acquire any tangible/intangible property of a non-revenue (capital) nature to or from international related parties?' must be 'True'.
    
            Legacy Rule Format:
            IF [IDS129] <> TRUE AND ([IDS130] <> NULL OR [IDS131] <> NULL OR [IDS132] <> NULL OR [IDS133] <> NULL OR [IDS134] <> NULL OR [IDS135] <> NULL OR [IDS136] <> NULL OR [IDS137] <> NULL OR [IDS340] <> NULL OR [IDS341] <> NULL OR [IDS342] <> NULL OR [IDS343] <> NULL OR [IDS344] <> NULL OR [IDS345] <> NULL OR [IDS346] <> NULL OR [IDS347] <> NULL OR [IDS348] <> NULL OR [IDS349] <> NULL OR [IDS350] <> NULL OR [IDS351] <> NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS129] = IDS:RP:bafot.02.11:Miscellaneous.CapitalNature.Indicator
            [IDS130] = IDS:RP.OtherNotReportedTangibleNonRevenue:bafpo1.02.11:Assets.ConsiderationPaid.Amount
            [IDS131] = IDS:RP.OtherNotReportedTangibleNonRevenue:bafpo1.02.11:Assets.ConsiderationReceived.Amount
            [IDS132] = IDS:RP.OtherNotReportedTangibleNonRevenue:bafot.02.11:Miscellaneous.AcquisitionsAndDisposalsPricingMethod.Code
            [IDS133] = IDS:RP.OtherNotReportedTangibleNonRevenue:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            [IDS134] = IDS:RP.OtherNotReportedIntangibleNonRevenue:bafpo1.02.11:Assets.ConsiderationPaid.Amount
            [IDS135] = IDS:RP.OtherNotReportedIntangibleNonRevenue:bafpo1.02.11:Assets.ConsiderationReceived.Amount
            [IDS136] = IDS:RP.OtherNotReportedIntangibleNonRevenue:bafot.02.11:Miscellaneous.AcquisitionsAndDisposalsPricingMethod.Code
            [IDS137] = IDS:RP.OtherNotReportedIntangibleNonRevenue:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            [IDS340] = IDS:RP.OtherNotReportedAssignmentOfIntangibleNonRevenue:bafpo1.02.11:Assets.ConsiderationPaid.Amount
            [IDS341] = IDS:RP.OtherNotReportedAssignmentOfIntangibleNonRevenue:bafpo1.02.11:Assets.ConsiderationReceived.Amount
            [IDS342] = IDS:RP.OtherNotReportedAssignmentOfIntangibleNonRevenue:bafot.02.11:Miscellaneous.AcquisitionsAndDisposalsPricingMethod.Code
            [IDS343] = IDS:RP.OtherNotReportedAssignmentOfIntangibleNonRevenue:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            [IDS344] = IDS:RP.OtherNotReportedAssignmentOfSharesOrEquityInterestsNonRevenue:bafpo1.02.11:Assets.ConsiderationPaid.Amount
            [IDS345] = IDS:RP.OtherNotReportedAssignmentOfSharesOrEquityInterestsNonRevenue:bafpo1.02.11:Assets.ConsiderationReceived.Amount
            [IDS346] = IDS:RP.OtherNotReportedAssignmentOfSharesOrEquityInterestsNonRevenue:bafot.02.11:Miscellaneous.AcquisitionsAndDisposalsPricingMethod.Code
            [IDS347] = IDS:RP.OtherNotReportedAssignmentOfSharesOrEquityInterestsNonRevenue:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            [IDS348] = IDS:RP.OtherNotReportedAssignmentOfLoansOrDebtsNonRevenue:bafpo1.02.11:Assets.ConsiderationPaid.Amount
            [IDS349] = IDS:RP.OtherNotReportedAssignmentOfLoansOrDebtsNonRevenue:bafpo1.02.11:Assets.ConsiderationReceived.Amount
            [IDS350] = IDS:RP.OtherNotReportedAssignmentOfLoansOrDebtsNonRevenue:bafot.02.11:Miscellaneous.AcquisitionsAndDisposalsPricingMethod.Code
            [IDS351] = IDS:RP.OtherNotReportedAssignmentOfLoansOrDebtsNonRevenue:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code

            Technical Business Rule Format:
            ^IDS129 <> TRUE AND (^IDS130 <> NULL OR ^IDS131 <> NULL OR ^IDS132 <> NULL OR ^IDS133 <> NULL OR ^IDS134 <> NULL OR ^IDS135 <> NULL OR ^IDS136 <> NULL OR ^IDS137 <> NULL OR ^IDS340 <> NULL OR ^IDS341 <> NULL OR ^IDS342 <> NULL OR ^IDS343 <> NULL OR ^IDS344 <> NULL OR ^IDS345 <> NULL OR ^IDS346 <> NULL OR ^IDS347 <> NULL OR ^IDS348 <> NULL OR ^IDS349 <> NULL OR ^IDS350 <> NULL OR ^IDS351 <> NULL)
    
            Data Elements:
    
            RP:^IDS129 = tns:Miscellaneous.CapitalNature.Indicator
    
            RP.OtherNotReportedTangibleNonRevenue:^IDS130 = tns:Assets.ConsiderationPaid.Amount
    
            RP.OtherNotReportedTangibleNonRevenue:^IDS131 = tns:Assets.ConsiderationReceived.Amount
    
            RP.OtherNotReportedTangibleNonRevenue:^IDS132 = tns:Miscellaneous.AcquisitionsAndDisposalsPricingMethod.Code
    
            RP.OtherNotReportedTangibleNonRevenue:^IDS133 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
    
            RP.OtherNotReportedIntangibleNonRevenue:^IDS134 = tns:Assets.ConsiderationPaid.Amount
    
            RP.OtherNotReportedIntangibleNonRevenue:^IDS135 = tns:Assets.ConsiderationReceived.Amount
    
            RP.OtherNotReportedIntangibleNonRevenue:^IDS136 = tns:Miscellaneous.AcquisitionsAndDisposalsPricingMethod.Code
    
            RP.OtherNotReportedIntangibleNonRevenue:^IDS137 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
    
            RP.OtherNotReportedAssignmentOfIntangibleNonRevenue:^IDS340 = tns:Assets.ConsiderationPaid.Amount
    
            RP.OtherNotReportedAssignmentOfIntangibleNonRevenue:^IDS341 = tns:Assets.ConsiderationReceived.Amount
    
            RP.OtherNotReportedAssignmentOfIntangibleNonRevenue:^IDS342 = tns:Miscellaneous.AcquisitionsAndDisposalsPricingMethod.Code
    
            RP.OtherNotReportedAssignmentOfIntangibleNonRevenue:^IDS343 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
    
            RP.OtherNotReportedAssignmentOfSharesOrEquityInterestsNonRevenue:^IDS344 = tns:Assets.ConsiderationPaid.Amount
    
            RP.OtherNotReportedAssignmentOfSharesOrEquityInterestsNonRevenue:^IDS345 = tns:Assets.ConsiderationReceived.Amount
    
            RP.OtherNotReportedAssignmentOfSharesOrEquityInterestsNonRevenue:^IDS346 = tns:Miscellaneous.AcquisitionsAndDisposalsPricingMethod.Code
    
            RP.OtherNotReportedAssignmentOfSharesOrEquityInterestsNonRevenue:^IDS347 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
    
            RP.OtherNotReportedAssignmentOfLoansOrDebtsNonRevenue:^IDS348 = tns:Assets.ConsiderationPaid.Amount
    
            RP.OtherNotReportedAssignmentOfLoansOrDebtsNonRevenue:^IDS349 = tns:Assets.ConsiderationReceived.Amount
    
            RP.OtherNotReportedAssignmentOfLoansOrDebtsNonRevenue:^IDS350 = tns:Miscellaneous.AcquisitionsAndDisposalsPricingMethod.Code
    
            RP.OtherNotReportedAssignmentOfLoansOrDebtsNonRevenue:^IDS351 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            */
            assertion = (report.IDS129 != true && (report.IDS130 != null || report.IDS131 != null || report.IDS132 != null || report.IDS133 != null || report.IDS134 != null || report.IDS135 != null || report.IDS136 != null || report.IDS137 != null || report.IDS340 != null || report.IDS341 != null || report.IDS342 != null || report.IDS343 != null || report.IDS344 != null || report.IDS345 != null || report.IDS346 != null || report.IDS347 != null || report.IDS348 != null || report.IDS349 != null || report.IDS350 != null || report.IDS351 != null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440457",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"International related party dealings question incorrect",
                    LongDescription = @"If International related party dealings information has been completed for tangible, assignment of intellectual property, assignment of shares or other equity interests, assignment of loans or debts or intangible property then the response to 'Did you dispose of or acquire any tangible/intangible property of a non-revenue (capital) nature to or from international related parties?' must be 'True'",
                    Location = "/xbrli:xbrl/tns:Miscellaneous.CapitalNature.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440059" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS129", Value = GetValueOrEmpty(report.IDS129) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS130", Value = report.IDS130.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS131", Value = report.IDS131.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS132", Value = report.IDS132 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS133", Value = report.IDS133 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS134", Value = report.IDS134.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS135", Value = report.IDS135.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS136", Value = report.IDS136 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS137", Value = report.IDS137 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS340", Value = report.IDS340.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS341", Value = report.IDS341.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS342", Value = report.IDS342 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS343", Value = report.IDS343 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS344", Value = report.IDS344.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS345", Value = report.IDS345.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS346", Value = report.IDS346 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS347", Value = report.IDS347 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS348", Value = report.IDS348.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS349", Value = report.IDS349.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS350", Value = report.IDS350 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS351", Value = report.IDS351 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440059

            #region VR.ATO.IDS.440060

            /*  VR.ATO.IDS.440060
            If an amount of expenditure or revenue is present, both the main pricing methodology and the code for the percentage of the total dollar value of related party international dealings for which you have documentation must be completed
    
            Legacy Rule Format:
            IF [IDS129] = TRUE AND [IDS130] = NULL AND [IDS131] = NULL AND [IDS132] = NULL AND [IDS133] = NULL AND [IDS134] = NULL AND [IDS135] = NULL AND [IDS136] = NULL AND [IDS137] = NULL AND [IDS340] = NULL AND [IDS341] = NULL AND [IDS342] = NULL AND [IDS343] = NULL AND [IDS344] = NULL AND [IDS345] = NULL AND [IDS346] = NULL AND [IDS347] = NULL AND [IDS348] = NULL AND [IDS349] = NULL AND [IDS350] = NULL AND [IDS351] = NULL
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS129] = IDS:RP:bafot.02.11:Miscellaneous.CapitalNature.Indicator
            [IDS130] = IDS:RP.OtherNotReportedTangibleNonRevenue:bafpo1.02.11:Assets.ConsiderationPaid.Amount
            [IDS131] = IDS:RP.OtherNotReportedTangibleNonRevenue:bafpo1.02.11:Assets.ConsiderationReceived.Amount
            [IDS132] = IDS:RP.OtherNotReportedTangibleNonRevenue:bafot.02.11:Miscellaneous.AcquisitionsAndDisposalsPricingMethod.Code
            [IDS133] = IDS:RP.OtherNotReportedTangibleNonRevenue:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            [IDS134] = IDS:RP.OtherNotReportedIntangibleNonRevenue:bafpo1.02.11:Assets.ConsiderationPaid.Amount
            [IDS135] = IDS:RP.OtherNotReportedIntangibleNonRevenue:bafpo1.02.11:Assets.ConsiderationReceived.Amount
            [IDS136] = IDS:RP.OtherNotReportedIntangibleNonRevenue:bafot.02.11:Miscellaneous.AcquisitionsAndDisposalsPricingMethod.Code
            [IDS137] = IDS:RP.OtherNotReportedIntangibleNonRevenue:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            [IDS340] = IDS:RP.OtherNotReportedAssignmentOfIntangibleNonRevenue:bafpo1.02.11:Assets.ConsiderationPaid.Amount
            [IDS341] = IDS:RP.OtherNotReportedAssignmentOfIntangibleNonRevenue:bafpo1.02.11:Assets.ConsiderationReceived.Amount
            [IDS342] = IDS:RP.OtherNotReportedAssignmentOfIntangibleNonRevenue:bafot.02.11:Miscellaneous.AcquisitionsAndDisposalsPricingMethod.Code
            [IDS343] = IDS:RP.OtherNotReportedAssignmentOfIntangibleNonRevenue:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            [IDS344] = IDS:RP.OtherNotReportedAssignmentOfSharesOrEquityInterestsNonRevenue:bafpo1.02.11:Assets.ConsiderationPaid.Amount
            [IDS345] = IDS:RP.OtherNotReportedAssignmentOfSharesOrEquityInterestsNonRevenue:bafpo1.02.11:Assets.ConsiderationReceived.Amount
            [IDS346] = IDS:RP.OtherNotReportedAssignmentOfSharesOrEquityInterestsNonRevenue:bafot.02.11:Miscellaneous.AcquisitionsAndDisposalsPricingMethod.Code
            [IDS347] = IDS:RP.OtherNotReportedAssignmentOfSharesOrEquityInterestsNonRevenue:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            [IDS348] = IDS:RP.OtherNotReportedAssignmentOfLoansOrDebtsNonRevenue:bafpo1.02.11:Assets.ConsiderationPaid.Amount
            [IDS349] = IDS:RP.OtherNotReportedAssignmentOfLoansOrDebtsNonRevenue:bafpo1.02.11:Assets.ConsiderationReceived.Amount
            [IDS350] = IDS:RP.OtherNotReportedAssignmentOfLoansOrDebtsNonRevenue:bafot.02.11:Miscellaneous.AcquisitionsAndDisposalsPricingMethod.Code
            [IDS351] = IDS:RP.OtherNotReportedAssignmentOfLoansOrDebtsNonRevenue:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code

            Technical Business Rule Format:
            ^IDS129 = TRUE AND ^IDS130 = NULL AND ^IDS131 = NULL AND ^IDS132 = NULL AND ^IDS133 = NULL AND ^IDS134 = NULL AND ^IDS135 = NULL AND ^IDS136 = NULL AND ^IDS137 = NULL AND ^IDS340 = NULL AND ^IDS341 = NULL AND ^IDS342 = NULL AND ^IDS343 = NULL AND ^IDS344 = NULL AND ^IDS345 = NULL AND ^IDS346 = NULL AND ^IDS347 = NULL AND ^IDS348 = NULL AND ^IDS349 = NULL AND ^IDS350 = NULL AND ^IDS351 = NULL
    
            Data Elements:
    
            RP:^IDS129 = tns:Miscellaneous.CapitalNature.Indicator
    
            RP.OtherNotReportedTangibleNonRevenue:^IDS130 = tns:Assets.ConsiderationPaid.Amount
    
            RP.OtherNotReportedTangibleNonRevenue:^IDS131 = tns:Assets.ConsiderationReceived.Amount
    
            RP.OtherNotReportedTangibleNonRevenue:^IDS132 = tns:Miscellaneous.AcquisitionsAndDisposalsPricingMethod.Code
    
            RP.OtherNotReportedTangibleNonRevenue:^IDS133 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
    
            RP.OtherNotReportedIntangibleNonRevenue:^IDS134 = tns:Assets.ConsiderationPaid.Amount
    
            RP.OtherNotReportedIntangibleNonRevenue:^IDS135 = tns:Assets.ConsiderationReceived.Amount
    
            RP.OtherNotReportedIntangibleNonRevenue:^IDS136 = tns:Miscellaneous.AcquisitionsAndDisposalsPricingMethod.Code
    
            RP.OtherNotReportedIntangibleNonRevenue:^IDS137 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
    
            RP.OtherNotReportedAssignmentOfIntangibleNonRevenue:^IDS340 = tns:Assets.ConsiderationPaid.Amount
    
            RP.OtherNotReportedAssignmentOfIntangibleNonRevenue:^IDS341 = tns:Assets.ConsiderationReceived.Amount
    
            RP.OtherNotReportedAssignmentOfIntangibleNonRevenue:^IDS342 = tns:Miscellaneous.AcquisitionsAndDisposalsPricingMethod.Code
    
            RP.OtherNotReportedAssignmentOfIntangibleNonRevenue:^IDS343 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
    
            RP.OtherNotReportedAssignmentOfSharesOrEquityInterestsNonRevenue:^IDS344 = tns:Assets.ConsiderationPaid.Amount
    
            RP.OtherNotReportedAssignmentOfSharesOrEquityInterestsNonRevenue:^IDS345 = tns:Assets.ConsiderationReceived.Amount
    
            RP.OtherNotReportedAssignmentOfSharesOrEquityInterestsNonRevenue:^IDS346 = tns:Miscellaneous.AcquisitionsAndDisposalsPricingMethod.Code
    
            RP.OtherNotReportedAssignmentOfSharesOrEquityInterestsNonRevenue:^IDS347 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
    
            RP.OtherNotReportedAssignmentOfLoansOrDebtsNonRevenue:^IDS348 = tns:Assets.ConsiderationPaid.Amount
    
            RP.OtherNotReportedAssignmentOfLoansOrDebtsNonRevenue:^IDS349 = tns:Assets.ConsiderationReceived.Amount
    
            RP.OtherNotReportedAssignmentOfLoansOrDebtsNonRevenue:^IDS350 = tns:Miscellaneous.AcquisitionsAndDisposalsPricingMethod.Code
    
            RP.OtherNotReportedAssignmentOfLoansOrDebtsNonRevenue:^IDS351 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            */
            assertion = (report.IDS129 == true && report.IDS130 == null && report.IDS131 == null && report.IDS132 == null && report.IDS133 == null && report.IDS134 == null && report.IDS135 == null && report.IDS136 == null && report.IDS137 == null && report.IDS340 == null && report.IDS341 == null && report.IDS342 == null && report.IDS343 == null && report.IDS344 == null && report.IDS345 == null && report.IDS346 == null && report.IDS347 == null && report.IDS348 == null && report.IDS349 == null && report.IDS350 == null && report.IDS351 == null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440458",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"International related party dealings information required",
                    LongDescription = @"If there is a 'True' response to 'Did you dispose of or acquire any tangible/intangible property of a non-revenue (capital) nature to or from international related parties?' then tangible assignment of intellectual property, assignment of shares or other equity interests, assignment of loans or debts or intangible property information must be completed",
                    Location = "/xbrli:xbrl/tns:Miscellaneous.CapitalNature.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440060" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS129", Value = GetValueOrEmpty(report.IDS129) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS130", Value = report.IDS130.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS131", Value = report.IDS131.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS132", Value = report.IDS132 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS133", Value = report.IDS133 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS134", Value = report.IDS134.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS135", Value = report.IDS135.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS136", Value = report.IDS136 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS137", Value = report.IDS137 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS340", Value = report.IDS340.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS341", Value = report.IDS341.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS342", Value = report.IDS342 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS343", Value = report.IDS343 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS344", Value = report.IDS344.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS345", Value = report.IDS345.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS346", Value = report.IDS346 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS347", Value = report.IDS347 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS348", Value = report.IDS348.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS349", Value = report.IDS349.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS350", Value = report.IDS350 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS351", Value = report.IDS351 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440060

            #region VR.ATO.IDS.440061

            /*  VR.ATO.IDS.440061
            If an amount of expenditure or revenue is present, both the main pricing methodology and the code for the percentage of the total dollar value of related party international dealings for which you have documentation must be completed.
    
            Legacy Rule Format:
            IF ([IDS130] <> NULL OR [IDS131] <> NULL OR [IDS132] <> NULL OR [IDS133] <> NULL) AND 
             (([IDS130] = NULL AND [IDS131] = NULL) OR [IDS132] = NULL OR [IDS133] = NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS130] = IDS:RP.OtherNotReportedTangibleNonRevenue:bafpo1.02.11:Assets.ConsiderationPaid.Amount
            [IDS131] = IDS:RP.OtherNotReportedTangibleNonRevenue:bafpo1.02.11:Assets.ConsiderationReceived.Amount
            [IDS132] = IDS:RP.OtherNotReportedTangibleNonRevenue:bafot.02.11:Miscellaneous.AcquisitionsAndDisposalsPricingMethod.Code
            [IDS133] = IDS:RP.OtherNotReportedTangibleNonRevenue:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code

            Technical Business Rule Format:
            (^IDS130 <> NULL OR ^IDS131 <> NULL OR ^IDS132 <> NULL OR ^IDS133 <> NULL) AND  ((^IDS130 = NULL AND ^IDS131 = NULL) OR ^IDS132 = NULL OR ^IDS133 = NULL)
    
            Data Elements:
    
            RP.OtherNotReportedTangibleNonRevenue:^IDS130 = tns:Assets.ConsiderationPaid.Amount
    
            RP.OtherNotReportedTangibleNonRevenue:^IDS131 = tns:Assets.ConsiderationReceived.Amount
    
            RP.OtherNotReportedTangibleNonRevenue:^IDS132 = tns:Miscellaneous.AcquisitionsAndDisposalsPricingMethod.Code
    
            RP.OtherNotReportedTangibleNonRevenue:^IDS133 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            */
            assertion = ((report.IDS130 != null || report.IDS131 != null || report.IDS132 != null || report.IDS133 != null) && (report.IDS130 == null && report.IDS131 == null || report.IDS132 == null || report.IDS133 == null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440061",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Tangible property information incomplete",
                    LongDescription = @"If tangible property information has been completed then consideration paid or consideration received, main capital asset pricing methodology code and percentage of dealings with documentation code must be completed",
                    Location = "/xbrli:xbrl/tns:Assets.ConsiderationPaid.Amount[@contextRef='" + report.RPOtherNotReportedTangibleNonRevenueId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440061" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS130", Value = report.IDS130.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS131", Value = report.IDS131.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS132", Value = report.IDS132 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS133", Value = report.IDS133 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440061

            #region VR.ATO.IDS.440062

            /*  VR.ATO.IDS.440062
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS130] <> NULL AND [IDS130] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS130] = IDS:RP.OtherNotReportedTangibleNonRevenue:bafpo1.02.11:Assets.ConsiderationPaid.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS130, 'U', 11, 0)
    
            Data Elements:
    
            RP.OtherNotReportedTangibleNonRevenue:^IDS130 = tns:Assets.ConsiderationPaid.Amount
            */
            assertion = NotMonetary(report.IDS130, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Assets.ConsiderationPaid.Amount[@contextRef='" + report.RPOtherNotReportedTangibleNonRevenueId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440062" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS130", Value = report.IDS130.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440062

            #region VR.ATO.IDS.440063

            /*  VR.ATO.IDS.440063
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS131] <> NULL AND [IDS131] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS131] = IDS:RP.OtherNotReportedTangibleNonRevenue:bafpo1.02.11:Assets.ConsiderationReceived.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS131, 'U', 11, 0)
    
            Data Elements:
    
            RP.OtherNotReportedTangibleNonRevenue:^IDS131 = tns:Assets.ConsiderationReceived.Amount
            */
            assertion = NotMonetary(report.IDS131, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Assets.ConsiderationReceived.Amount[@contextRef='" + report.RPOtherNotReportedTangibleNonRevenueId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440063" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS131", Value = report.IDS131.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440063

            #region VR.ATO.IDS.440064

            /*  VR.ATO.IDS.440064
            If an amount of expenditure or revenue is present, both the main pricing methodology and the code for the percentage of the total dollar value of related party international dealings for which you have documentation must be completed.
    
            Legacy Rule Format:
            IF ([IDS134] <> NULL OR [IDS135] <> NULL OR [IDS136] <> NULL OR [IDS137] <> NULL) AND (([IDS134] = NULL AND [IDS135] = NULL) OR [IDS136] = NULL OR [IDS137] = NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS134] = IDS:RP.OtherNotReportedIntangibleNonRevenue:bafpo1.02.11:Assets.ConsiderationPaid.Amount
            [IDS135] = IDS:RP.OtherNotReportedIntangibleNonRevenue:bafpo1.02.11:Assets.ConsiderationReceived.Amount
            [IDS136] = IDS:RP.OtherNotReportedIntangibleNonRevenue:bafot.02.11:Miscellaneous.AcquisitionsAndDisposalsPricingMethod.Code
            [IDS137] = IDS:RP.OtherNotReportedIntangibleNonRevenue:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code

            Technical Business Rule Format:
            (^IDS134 <> NULL OR ^IDS135 <> NULL OR ^IDS136 <> NULL OR ^IDS137 <> NULL) AND ((^IDS134 = NULL AND ^IDS135 = NULL) OR ^IDS136 = NULL OR ^IDS137 = NULL)
    
            Data Elements:
    
            RP.OtherNotReportedIntangibleNonRevenue:^IDS134 = tns:Assets.ConsiderationPaid.Amount
    
            RP.OtherNotReportedIntangibleNonRevenue:^IDS135 = tns:Assets.ConsiderationReceived.Amount
    
            RP.OtherNotReportedIntangibleNonRevenue:^IDS136 = tns:Miscellaneous.AcquisitionsAndDisposalsPricingMethod.Code
    
            RP.OtherNotReportedIntangibleNonRevenue:^IDS137 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            */
            assertion = ((report.IDS134 != null || report.IDS135 != null || report.IDS136 != null || report.IDS137 != null) && (report.IDS134 == null && report.IDS135 == null || report.IDS136 == null || report.IDS137 == null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440443",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Other intangible property information incomplete",
                    Location = "/xbrli:xbrl/tns:Assets.ConsiderationPaid.Amount[@contextRef='" + report.RPOtherNotReportedIntangibleNonRevenueId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440064" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS134", Value = report.IDS134.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS135", Value = report.IDS135.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS136", Value = report.IDS136 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS137", Value = report.IDS137 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440064


            #region VR.ATO.IDS.440065
            /* VR.ATO.IDS.440065
             
            Field value supplied exceeds maximum field length

            Legacy Rule Format:
            IF ([IDS171] <> NULLORBLANK) AND (LENGTH([IDS171]) > 200)
             RETURN VALIDATION MESSAGE
            ENDIF             

             [IDS171] = bafpr1.02.00:Income.Other.Description

            Technical Business Rule Format:
            (^IDS171 <> NULLORBLANK) AND (LENGTH(^IDS171) > 200)

            RP.BranchOperations:^IDS171 = tns:Income.Other.Description
             */
            assertion = report.RPBranchOperationsInternallyRecordedDealingsContextCollection != null && report.RPBranchOperationsInternallyRecordedDealingsContextCollection.Any(c => c.IDS171 != null && c.IDS171.Length > 200);
            if (assertion)
            {
                IEnumerable<IDS2017.RPBranchOperationsInternallyRecordedDealingsContext> faultContexts = report.RPBranchOperationsInternallyRecordedDealingsContextCollection.Where(c => c.IDS171 != null && c.IDS171.Length > 200);
                foreach (IDS2017.RPBranchOperationsInternallyRecordedDealingsContext context in faultContexts)
                {
                    processMessage = new ProcessMessageDocument()
                    {
                        Code = "CMN.ATO.GEN.001011",
                        Severity = ProcessMessageSeverity.Error,
                        Description = @"Field value supplied exceeds maximum field length",
                        Location = "/xbrli:xbrl/xbrli:context[@id='"+ context.Id +"']/xbrli:entity/xbrli:segment/xbrldi:typedMember[@dimension='tns:InternallyRecordedDealingsDimension']/tns:InternallyRecordedDealingsContainer",
                        Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440065" } },
                    };

                    processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "IDS171", Value = context.IDS171 });

                    response.Add(processMessage);
                }
            }

            #endregion // VR.ATO.IDS.440065



            #region VR.ATO.IDS.440067

            /*  VR.ATO.IDS.440067
            If International related party dealings information has been completed for No payment or non-monetary payment then the response to 'Did you provide any of the following for no payment or a non-monetary payment, or receive any of the following for a non-monetary payment to/from an international related party?' must be 'Yes'.
    
            Legacy Rule Format:
            IF [IDS138] <> TRUE AND ([IDS139] <> NULL OR [IDS140] <> NULL OR [IDS141] <> NULL OR [IDS142] <> NULL OR [IDS143] <> NULL OR [IDS144] <> NULL OR [IDS145] <> NULL OR [IDS146] <> NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS138] = IDS:RP:bafot.02.11:Miscellaneous.ReceivedOrProvidedServicesPropertyProcessesRightsOrObligationsForNonMonetaryConsideration.Indicator
            [IDS139] = IDS:RP.CapitalNoPayment:pyde.02.08:OrganisationDetails.InternationalRelatedPartyCountry.Code
            [IDS140] = IDS:RP.CapitalNoPayment:bafot.02.11:Miscellaneous.NatureOfItem.Code
            [IDS141] = IDS:RP.RevenueNoPayment:pyde.02.08:OrganisationDetails.InternationalRelatedPartyCountry.Code
            [IDS142] = IDS:RP.RevenueNoPayment:bafot.02.11:Miscellaneous.NatureOfItem.Code
            [IDS143] = IDS:RP.CapitalNonMonetaryPayment:pyde.02.08:OrganisationDetails.InternationalRelatedPartyCountry.Code
            [IDS144] = IDS:RP.CapitalNonMonetaryPayment:bafot.02.11:Miscellaneous.NatureOfItem.Code
            [IDS145] = IDS:RP.RevenueNonMonetaryPayment:pyde.02.08:OrganisationDetails.InternationalRelatedPartyCountry.Code
            [IDS146] = IDS:RP.RevenueNonMonetaryPayment:bafot.02.11:Miscellaneous.NatureOfItem.Code

            Technical Business Rule Format:
            ^IDS138 <> TRUE AND (^IDS139 <> NULL OR ^IDS140 <> NULL OR ^IDS141 <> NULL OR ^IDS142 <> NULL OR ^IDS143 <> NULL OR ^IDS144 <> NULL OR ^IDS145 <> NULL OR ^IDS146 <> NULL)
    
            Data Elements:
    
            RP:^IDS138 = tns:Miscellaneous.ReceivedOrProvidedServicesPropertyProcessesRightsOrObligationsForNonMonetaryConsideration.Indicator
    
            RP.CapitalNoPayment:^IDS139 = tns:OrganisationDetails.InternationalRelatedPartyCountry.Code
    
            RP.CapitalNoPayment:^IDS140 = tns:Miscellaneous.NatureOfItem.Code
    
            RP.RevenueNoPayment:^IDS141 = tns:OrganisationDetails.InternationalRelatedPartyCountry.Code
    
            RP.RevenueNoPayment:^IDS142 = tns:Miscellaneous.NatureOfItem.Code
    
            RP.CapitalNonMonetaryPayment:^IDS143 = tns:OrganisationDetails.InternationalRelatedPartyCountry.Code
    
            RP.CapitalNonMonetaryPayment:^IDS144 = tns:Miscellaneous.NatureOfItem.Code
    
            RP.RevenueNonMonetaryPayment:^IDS145 = tns:OrganisationDetails.InternationalRelatedPartyCountry.Code
    
            RP.RevenueNonMonetaryPayment:^IDS146 = tns:Miscellaneous.NatureOfItem.Code
            */
            assertion = (report.IDS138 != true && (report.IDS139 != null || report.IDS140 != null || report.IDS141 != null || report.IDS142 != null || report.IDS143 != null || report.IDS144 != null || report.IDS145 != null || report.IDS146 != null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440067",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"International related party dealings question incorrect",
                    LongDescription = @"If International related party dealings information has been completed for No payment or non-monetary payment then the response to 'Did you provide any of the following for no payment or a non-monetary payment, or receive any of the following for a non-monetary payment to/from an international related party?' must be 'True'",
                    Location = "/xbrli:xbrl/tns:Miscellaneous.ReceivedOrProvidedServicesPropertyProcessesRightsOrObligationsForNonMonetaryConsideration.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440067" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS138", Value = GetValueOrEmpty(report.IDS138) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS139", Value = report.IDS139 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS140", Value = report.IDS140 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS141", Value = report.IDS141 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS142", Value = report.IDS142 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS143", Value = report.IDS143 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS144", Value = report.IDS144 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS145", Value = report.IDS145 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS146", Value = report.IDS146 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440067

            #region VR.ATO.IDS.440068

            /*  VR.ATO.IDS.440068
            If there is a 'Yes' response to 'Did you provide any of the following for no payment or a non-monetary payment, or receive any of the following for a non-monetary payment to/from an international related party?' then No payment or non-monetary payment information must be completed.
    
            Legacy Rule Format:
            IF [IDS138] = TRUE AND ([IDS139] = NULL AND [IDS140] = NULL AND [IDS141] = NULL AND [IDS142] = NULL AND [IDS143] = NULL AND [IDS144] = NULL AND [IDS145] = NULL AND [IDS146] = NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS138] = IDS:RP:bafot.02.11:Miscellaneous.ReceivedOrProvidedServicesPropertyProcessesRightsOrObligationsForNonMonetaryConsideration.Indicator
            [IDS139] = IDS:RP.CapitalNoPayment:pyde.02.08:OrganisationDetails.InternationalRelatedPartyCountry.Code
            [IDS140] = IDS:RP.CapitalNoPayment:bafot.02.11:Miscellaneous.NatureOfItem.Code
            [IDS141] = IDS:RP.RevenueNoPayment:pyde.02.08:OrganisationDetails.InternationalRelatedPartyCountry.Code
            [IDS142] = IDS:RP.RevenueNoPayment:bafot.02.11:Miscellaneous.NatureOfItem.Code
            [IDS143] = IDS:RP.CapitalNonMonetaryPayment:pyde.02.08:OrganisationDetails.InternationalRelatedPartyCountry.Code
            [IDS144] = IDS:RP.CapitalNonMonetaryPayment:bafot.02.11:Miscellaneous.NatureOfItem.Code
            [IDS145] = IDS:RP.RevenueNonMonetaryPayment:pyde.02.08:OrganisationDetails.InternationalRelatedPartyCountry.Code
            [IDS146] = IDS:RP.RevenueNonMonetaryPayment:bafot.02.11:Miscellaneous.NatureOfItem.Code

            Technical Business Rule Format:
            ^IDS138 = TRUE AND (^IDS139 = NULL AND ^IDS140 = NULL AND ^IDS141 = NULL AND ^IDS142 = NULL AND ^IDS143 = NULL AND ^IDS144 = NULL AND ^IDS145 = NULL AND ^IDS146 = NULL)
    
            Data Elements:
    
            RP:^IDS138 = tns:Miscellaneous.ReceivedOrProvidedServicesPropertyProcessesRightsOrObligationsForNonMonetaryConsideration.Indicator
    
            RP.CapitalNoPayment:^IDS139 = tns:OrganisationDetails.InternationalRelatedPartyCountry.Code
    
            RP.CapitalNoPayment:^IDS140 = tns:Miscellaneous.NatureOfItem.Code
    
            RP.RevenueNoPayment:^IDS141 = tns:OrganisationDetails.InternationalRelatedPartyCountry.Code
    
            RP.RevenueNoPayment:^IDS142 = tns:Miscellaneous.NatureOfItem.Code
    
            RP.CapitalNonMonetaryPayment:^IDS143 = tns:OrganisationDetails.InternationalRelatedPartyCountry.Code
    
            RP.CapitalNonMonetaryPayment:^IDS144 = tns:Miscellaneous.NatureOfItem.Code
    
            RP.RevenueNonMonetaryPayment:^IDS145 = tns:OrganisationDetails.InternationalRelatedPartyCountry.Code
    
            RP.RevenueNonMonetaryPayment:^IDS146 = tns:Miscellaneous.NatureOfItem.Code
            */
            assertion = (report.IDS138 == true && (report.IDS139 == null && report.IDS140 == null && report.IDS141 == null && report.IDS142 == null && report.IDS143 == null && report.IDS144 == null && report.IDS145 == null && report.IDS146 == null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440068",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"International related party dealings information required",
                    LongDescription = @"If there is a 'True' response to 'Did you provide any of the following for no payment or a non-monetary payment, or receive any of the following for a non-monetary payment to/from an international related party?' then No payment or non-monetary payment information must be completed",
                    Location = "/xbrli:xbrl/tns:Miscellaneous.ReceivedOrProvidedServicesPropertyProcessesRightsOrObligationsForNonMonetaryConsideration.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440068" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS138", Value = GetValueOrEmpty(report.IDS138) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS139", Value = report.IDS139 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS140", Value = report.IDS140 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS141", Value = report.IDS141 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS142", Value = report.IDS142 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS143", Value = report.IDS143 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS144", Value = report.IDS144 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS145", Value = report.IDS145 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS146", Value = report.IDS146 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440068

            #region VR.ATO.IDS.440069

            /*  VR.ATO.IDS.440069
            If capital No payment information has been completed then both foreign country code and nature of item code must be completed.
    
            Legacy Rule Format:
            IF ([IDS139] <> NULL AND [IDS140] = NULL) OR ([IDS140] <> NULL AND [IDS139] = NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS139] = IDS:RP.CapitalNoPayment:pyde.02.08:OrganisationDetails.InternationalRelatedPartyCountry.Code
            [IDS140] = IDS:RP.CapitalNoPayment:bafot.02.11:Miscellaneous.NatureOfItem.Code

            Technical Business Rule Format:
            (^IDS139 <> NULL AND ^IDS140 = NULL) OR (^IDS140 <> NULL AND ^IDS139 = NULL)
    
            Data Elements:
    
            RP.CapitalNoPayment:^IDS139 = tns:OrganisationDetails.InternationalRelatedPartyCountry.Code
    
            RP.CapitalNoPayment:^IDS140 = tns:Miscellaneous.NatureOfItem.Code
            */
            assertion = (report.IDS139 != null && report.IDS140 == null || report.IDS140 != null && report.IDS139 == null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440069",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Foreign country and nature of item information incomplete",
                    LongDescription = @"If capital No payment information has been completed then both foreign country code and nature of item code must be completed",
                    Location = "/xbrli:xbrl/tns:OrganisationDetails.InternationalRelatedPartyCountry.Code[@contextRef='" + report.RPCapitalNoPaymentId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440069" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS139", Value = report.IDS139 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS140", Value = report.IDS140 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440069

            #region VR.ATO.IDS.440070

            /*  VR.ATO.IDS.440070
            If revenue No payment information has been completed then both foreign country code and nature of item code must be completed.
    
            Legacy Rule Format:
            IF ([IDS141] <> NULL AND [IDS142] = NULL) OR ([IDS142] <> NULL AND [IDS141] = NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS141] = IDS:RP.RevenueNoPayment:pyde.02.08:OrganisationDetails.InternationalRelatedPartyCountry.Code
            [IDS142] = IDS:RP.RevenueNoPayment:bafot.02.11:Miscellaneous.NatureOfItem.Code

            Technical Business Rule Format:
            (^IDS141 <> NULL AND ^IDS142 = NULL) OR (^IDS142 <> NULL AND ^IDS141 = NULL)
    
            Data Elements:
    
            RP.RevenueNoPayment:^IDS141 = tns:OrganisationDetails.InternationalRelatedPartyCountry.Code
    
            RP.RevenueNoPayment:^IDS142 = tns:Miscellaneous.NatureOfItem.Code
            */
            assertion = (report.IDS141 != null && report.IDS142 == null || report.IDS142 != null && report.IDS141 == null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440070",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Foreign country and nature of item information incomplete",
                    LongDescription = @"If revenue No payment information has been completed then both foreign country code and nature of item code must be completed",
                    Location = "/xbrli:xbrl/tns:OrganisationDetails.InternationalRelatedPartyCountry.Code[@contextRef='" + report.RPRevenueNoPaymentId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440070" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS141", Value = report.IDS141 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS142", Value = report.IDS142 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440070

            #region VR.ATO.IDS.440071

            /*  VR.ATO.IDS.440071
            If capital non-monetary payment information has been completed then both foreign country code and nature of item code must be completed.
    
            Legacy Rule Format:
            IF ([IDS143] <> NULL AND [IDS144] = NULL) OR ([IDS144] <> NULL AND [IDS143] = NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS143] = IDS:RP.CapitalNonMonetaryPayment:pyde.02.08:OrganisationDetails.InternationalRelatedPartyCountry.Code
            [IDS144] = IDS:RP.CapitalNonMonetaryPayment:bafot.02.11:Miscellaneous.NatureOfItem.Code

            Technical Business Rule Format:
            (^IDS143 <> NULL AND ^IDS144 = NULL) OR (^IDS144 <> NULL AND ^IDS143 = NULL)
    
            Data Elements:
    
            RP.CapitalNonMonetaryPayment:^IDS143 = tns:OrganisationDetails.InternationalRelatedPartyCountry.Code
    
            RP.CapitalNonMonetaryPayment:^IDS144 = tns:Miscellaneous.NatureOfItem.Code
            */
            assertion = (report.IDS143 != null && report.IDS144 == null || report.IDS144 != null && report.IDS143 == null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440071",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Foreign country and nature of item information incomplete",
                    LongDescription = @"If capital non-monetary payment information has been completed then both foreign country code and nature of item code must be completed",
                    Location = "/xbrli:xbrl/tns:OrganisationDetails.InternationalRelatedPartyCountry.Code[@contextRef='" + report.RPCapitalNonMonetaryPaymentId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440071" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS143", Value = report.IDS143 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS144", Value = report.IDS144 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440071

            #region VR.ATO.IDS.440072

            /*  VR.ATO.IDS.440072
            If revenue non-monetary payment information has been completed then both foreign country code and nature of item code must be completed.
    
            Legacy Rule Format:
            IF ([IDS145] <> NULL AND [IDS146] = NULL) OR ([IDS146] <> NULL AND [IDS145] = NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS145] = IDS:RP.RevenueNonMonetaryPayment:pyde.02.08:OrganisationDetails.InternationalRelatedPartyCountry.Code
            [IDS146] = IDS:RP.RevenueNonMonetaryPayment:bafot.02.11:Miscellaneous.NatureOfItem.Code

            Technical Business Rule Format:
            (^IDS145 <> NULL AND ^IDS146 = NULL) OR (^IDS146 <> NULL AND ^IDS145 = NULL)
    
            Data Elements:
    
            RP.RevenueNonMonetaryPayment:^IDS145 = tns:OrganisationDetails.InternationalRelatedPartyCountry.Code
    
            RP.RevenueNonMonetaryPayment:^IDS146 = tns:Miscellaneous.NatureOfItem.Code
            */
            assertion = (report.IDS145 != null && report.IDS146 == null || report.IDS146 != null && report.IDS145 == null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440072",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Foreign country and nature of item information incomplete",
                    LongDescription = @"If revenue non-monetary payment information has been completed then both foreign country code and nature of item code must be completed",
                    Location = "/xbrli:xbrl/tns:OrganisationDetails.InternationalRelatedPartyCountry.Code[@contextRef='" + report.RPRevenueNonMonetaryPaymentId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440072" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS145", Value = report.IDS145 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS146", Value = report.IDS146 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440072

            #region VR.ATO.IDS.440073

            /*  VR.ATO.IDS.440073
            If International related party dealings information has been completed for recharge amounts then the response to 'Did you provide or receive share-based employee remuneration to or from an international related party?' must be 'Yes'.
    
            Legacy Rule Format:
            IF ([IDS147] <> TRUE OR [IDS147] = NULL) AND ([IDS148] <> NULL OR [IDS149] <> NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS147] = IDS:RP:rvctc4.02.05:InternationalDealings.ShareBasedEmployeeRemuneration.Indicator
            [IDS148] = IDS:RP.RechargeAmounts:bafpr1.02.12:Expense.DeductionsTotal.Amount
            [IDS149] = IDS:RP.RechargeAmounts:bafpr1.02.12:Income.IncludedInAssessableTotal.Amount

            Technical Business Rule Format:
            (^IDS147 <> TRUE OR ^IDS147 = NULL) AND (^IDS148 <> NULL OR ^IDS149 <> NULL)
    
            Data Elements:
    
            RP:^IDS147 = tns:InternationalDealings.ShareBasedEmployeeRemuneration.Indicator
    
            RP.RechargeAmounts:^IDS148 = tns:Expense.DeductionsTotal.Amount
    
            RP.RechargeAmounts:^IDS149 = tns:Income.IncludedInAssessableTotal.Amount
            */
            assertion = ((report.IDS147 != true || report.IDS147 == null) && (report.IDS148 != null || report.IDS149 != null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440073",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"International related party dealings question incorrect",
                    LongDescription = @"If International related party dealings information has been completed for recharge amounts then the response to 'Did you provide or receive share-based employee remuneration to or from an international related party?' must be 'True'",
                    Location = "/xbrli:xbrl/tns:InternationalDealings.ShareBasedEmployeeRemuneration.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440073" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS147", Value = GetValueOrEmpty(report.IDS147) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS148", Value = report.IDS148.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS149", Value = report.IDS149.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440073

            #region VR.ATO.IDS.440074

            /*  VR.ATO.IDS.440074
            If there is a 'Yes' response to 'Did you provide or receive share-based employee remuneration to or from an international related party?' then recharge amounts information must be completed.
    
            Legacy Rule Format:
            IF [IDS147] = TRUE AND ([IDS148] = NULL AND [IDS149] = NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS147] = IDS:RP:rvctc4.02.05:InternationalDealings.ShareBasedEmployeeRemuneration.Indicator
            [IDS148] = IDS:RP.RechargeAmounts:bafpr1.02.12:Expense.DeductionsTotal.Amount
            [IDS149] = IDS:RP.RechargeAmounts:bafpr1.02.12:Income.IncludedInAssessableTotal.Amount

            Technical Business Rule Format:
            ^IDS147 = TRUE AND (^IDS148 = NULL AND ^IDS149 = NULL)
    
            Data Elements:
    
            RP:^IDS147 = tns:InternationalDealings.ShareBasedEmployeeRemuneration.Indicator
    
            RP.RechargeAmounts:^IDS148 = tns:Expense.DeductionsTotal.Amount
    
            RP.RechargeAmounts:^IDS149 = tns:Income.IncludedInAssessableTotal.Amount
            */
            assertion = (report.IDS147 == true && (report.IDS148 == null && report.IDS149 == null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440074",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"International related party dealings information required",
                    LongDescription = @"If there is a 'True' response to 'Did you provide or receive share-based employee remuneration to or from an international related party?' then recharge amounts information must be completed",
                    Location = "/xbrli:xbrl/tns:InternationalDealings.ShareBasedEmployeeRemuneration.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440074" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS147", Value = GetValueOrEmpty(report.IDS147) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS148", Value = report.IDS148.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS149", Value = report.IDS149.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440074

            #region VR.ATO.IDS.440082

            /*  VR.ATO.IDS.440082
            This field is Mandatory - must be completed
    
            Legacy Rule Format:
            IF [IDS160] = NULL
            RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS160] = IDS:RP:rvctc4.02.05:InternationalDealings.BranchOperations.Indicator

            Technical Business Rule Format:
            ^IDS160 = NULL
    
            Data Elements:
    
            RP:^IDS160 = tns:InternationalDealings.BranchOperations.Indicator
            */
            assertion = (report.IDS160 == null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001001",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Mandatory field not supplied",
                    Location = "/xbrli:xbrl/tns:InternationalDealings.BranchOperations.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440082" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS160", Value = GetValueOrEmpty(report.IDS160) });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440082

            #region VR.ATO.IDS.440083

            /*  VR.ATO.IDS.440083
            If internally recorded dealings with branch operations information has been completed for interest bearing loans, either amounts borrowed average balance or amounts borrowed interest, then both of these must be completed.
    
            Legacy Rule Format:
            IF ([IDS161] <> NULL AND [IDS163] = NULL) OR ([IDS163] <> NULL AND [IDS161] = NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS161] = IDS:RP.BranchOperations.InterestBearing:bafpo1.02.11:Liabilities.BorrowedAverageBalance.Amount
            [IDS163] = IDS:RP.BranchOperations.InterestBearing:bafpr1.02.12:Expense.InterestBorrowedTotal.Amount

            Technical Business Rule Format:
            (^IDS161 <> NULL AND ^IDS163 = NULL) OR (^IDS163 <> NULL AND ^IDS161 = NULL)
    
            Data Elements:
    
            RP.BranchOperations.InterestBearing:^IDS161 = tns:Liabilities.BorrowedAverageBalance.Amount
    
            RP.BranchOperations.InterestBearing:^IDS163 = tns:Expense.InterestBorrowedTotal.Amount
            */
            assertion = (report.IDS161 != null && report.IDS163 == null || report.IDS163 != null && report.IDS161 == null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440083",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Interest bearing loans Amounts borrowed information incomplete",
                    LongDescription = @"If internally recorded dealings with branch operations information has been completed for interest bearing loans, either amounts borrowed average balance or amounts borrowed interest, then both of these must be completed",
                    Location = "/xbrli:xbrl/tns:Liabilities.BorrowedAverageBalance.Amount[@contextRef='" + report.RPBranchOperationsInterestBearingId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440083" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS161", Value = report.IDS161.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS163", Value = report.IDS163.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440083

            #region VR.ATO.IDS.440086

            /*  VR.ATO.IDS.440086
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS163] <> NULL AND [IDS163] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS163] = IDS:RP.BranchOperations.InterestBearing:bafpr1.02.12:Expense.InterestBorrowedTotal.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS163, 'U', 11, 0)
    
            Data Elements:
    
            RP.BranchOperations.InterestBearing:^IDS163 = tns:Expense.InterestBorrowedTotal.Amount
            */
            assertion = NotMonetary(report.IDS163, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Expense.InterestBorrowedTotal.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440086" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS163", Value = report.IDS163.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440086

            #region VR.ATO.IDS.440087

            /*  VR.ATO.IDS.440087
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS164] <> NULL AND [IDS164] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS164] = IDS:RP.BranchOperations.InterestBearing:bafpr1.02.12:Income.InterestLoanedTotal.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS164, 'U', 11, 0)
    
            Data Elements:
    
            RP.BranchOperations.InterestBearing:^IDS164 = tns:Income.InterestLoanedTotal.Amount
            */
            assertion = NotMonetary(report.IDS164, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Income.InterestLoanedTotal.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440087" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS164", Value = report.IDS164.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440087

            #region VR.ATO.IDS.440090

            /*  VR.ATO.IDS.440090
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS167] <> NULL AND [IDS167] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS167] = IDS:RP.BranchOperations:bafpr1.02.12:Expense.TradingStockPurchaseCosts.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS167, 'U', 11, 0)
    
            Data Elements:
    
            RP.BranchOperations:^IDS167 = tns:Expense.TradingStockPurchaseCosts.Amount
            */
            assertion = NotMonetary(report.IDS167, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Expense.TradingStockPurchaseCosts.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440090" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS167", Value = report.IDS167.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440090

            #region VR.ATO.IDS.440091

            /*  VR.ATO.IDS.440091
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS168] <> NULL AND [IDS168] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS168] = IDS:RP.BranchOperations:bafpr1.02.12:Income.TradingStockSalesTotal.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS168, 'U', 11, 0)
    
            Data Elements:
    
            RP.BranchOperations:^IDS168 = tns:Income.TradingStockSalesTotal.Amount
            */
            assertion = NotMonetary(report.IDS168, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Income.TradingStockSalesTotal.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440091" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS168", Value = report.IDS168.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440091

            #region VR.ATO.IDS.440095

            /*  VR.ATO.IDS.440095
            If there is a 'No' response to 'Did you hold any financing arrangements during the income year?' then average quarterly balance of debt interests or equity interests information should not be completed.
    
            Legacy Rule Format:
            IF [IDS172] = FALSE AND ([IDS173] <> NULL OR [IDS174] <> NULL OR [IDS175] <> NULL OR [IDS176] <> NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS172] = IDS:RP:rvctc4.02.05:InternationalDealings.FinancialArrangements.Indicator
            [IDS173] = IDS:RP.Quarterly:bafpr2.02.12:Expense.Interest.DebtReceivedAverageBalance.Amount
            [IDS174] = IDS:RP.Quarterly:bafpr2.02.12:Income.Interest.DebtProvidedAverageBalance.Amount
            [IDS175] = IDS:RP.Quarterly:bafpr2.02.12:Expense.Interest.EquityReceivedAverageBalance.Amount
            [IDS176] = IDS:RP.Quarterly:bafpr2.02.12:Income.Interest.EquityProvidedAverageBalance.Amount

            Technical Business Rule Format:
            ^IDS172 = FALSE AND (^IDS173 <> NULL OR ^IDS174 <> NULL OR ^IDS175 <> NULL OR ^IDS176 <> NULL)
    
            Data Elements:
    
            RP:^IDS172 = tns:InternationalDealings.FinancialArrangements.Indicator
    
            RP.Quarterly:^IDS173 = tns:Expense.Interest.DebtReceivedAverageBalance.Amount
    
            RP.Quarterly:^IDS174 = tns:Income.Interest.DebtProvidedAverageBalance.Amount
    
            RP.Quarterly:^IDS175 = tns:Expense.Interest.EquityReceivedAverageBalance.Amount
    
            RP.Quarterly:^IDS176 = tns:Income.Interest.EquityProvidedAverageBalance.Amount
            */
            assertion = (report.IDS172 == false && (report.IDS173 != null || report.IDS174 != null || report.IDS175 != null || report.IDS176 != null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440095",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Financial arrangements information not required",
                    LongDescription = @"If there is a 'False' response to 'Did you hold any financing arrangements during the income year?' then average quarterly balance of debt interests or equity interests information should not be completed",
                    Location = "/xbrli:xbrl/tns:InternationalDealings.FinancialArrangements.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440095" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS172", Value = GetValueOrEmpty(report.IDS172) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS173", Value = report.IDS173.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS174", Value = report.IDS174.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS175", Value = report.IDS175.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS176", Value = report.IDS176.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440095

            #region VR.ATO.IDS.440096

            /*  VR.ATO.IDS.440096
            If there is a 'Yes' response to 'Did you hold any financing arrangements during the income year?' then average quarterly balance of debt interests or equity interests information must be completed.
    
            Legacy Rule Format:
            IF [IDS172] = TRUE AND [IDS173] = NULL AND [IDS174] = NULL AND [IDS175] = NULL AND [IDS176] = NULL
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS172] = IDS:RP:rvctc4.02.05:InternationalDealings.FinancialArrangements.Indicator
            [IDS173] = IDS:RP.Quarterly:bafpr2.02.12:Expense.Interest.DebtReceivedAverageBalance.Amount
            [IDS174] = IDS:RP.Quarterly:bafpr2.02.12:Income.Interest.DebtProvidedAverageBalance.Amount
            [IDS175] = IDS:RP.Quarterly:bafpr2.02.12:Expense.Interest.EquityReceivedAverageBalance.Amount
            [IDS176] = IDS:RP.Quarterly:bafpr2.02.12:Income.Interest.EquityProvidedAverageBalance.Amount

            Technical Business Rule Format:
            ^IDS172 = TRUE AND ^IDS173 = NULL AND ^IDS174 = NULL AND ^IDS175 = NULL AND ^IDS176 = NULL
    
            Data Elements:
    
            RP:^IDS172 = tns:InternationalDealings.FinancialArrangements.Indicator
    
            RP.Quarterly:^IDS173 = tns:Expense.Interest.DebtReceivedAverageBalance.Amount
    
            RP.Quarterly:^IDS174 = tns:Income.Interest.DebtProvidedAverageBalance.Amount
    
            RP.Quarterly:^IDS175 = tns:Expense.Interest.EquityReceivedAverageBalance.Amount
    
            RP.Quarterly:^IDS176 = tns:Income.Interest.EquityProvidedAverageBalance.Amount
            */
            assertion = (report.IDS172 == true && report.IDS173 == null && report.IDS174 == null && report.IDS175 == null && report.IDS176 == null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440096",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Financial arrangements information required",
                    LongDescription = @"If there is a 'True' response to 'Did you hold any financing arrangements during the income year?' then average quarterly balance of debt interests or equity interests information must be completed",
                    Location = "/xbrli:xbrl/tns:InternationalDealings.FinancialArrangements.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440096" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS172", Value = GetValueOrEmpty(report.IDS172) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS173", Value = report.IDS173.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS174", Value = report.IDS174.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS175", Value = report.IDS175.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS176", Value = report.IDS176.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440096

            #region VR.ATO.IDS.440097

            /*  VR.ATO.IDS.440097
            This field is Mandatory - must be completed
    
            Legacy Rule Format:
            IF [IDS172] = NULL
            RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS172] = IDS:RP:rvctc4.02.05:InternationalDealings.FinancialArrangements.Indicator

            Technical Business Rule Format:
            ^IDS172 = NULL
    
            Data Elements:
    
            RP:^IDS172 = tns:InternationalDealings.FinancialArrangements.Indicator
            */
            assertion = (report.IDS172 == null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001001",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Mandatory field not supplied",
                    Location = "/xbrli:xbrl/tns:InternationalDealings.FinancialArrangements.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440097" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS172", Value = GetValueOrEmpty(report.IDS172) });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440097

            #region VR.ATO.IDS.440098

            /*  VR.ATO.IDS.440098
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS173] <> NULL AND [IDS173] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS173] = IDS:RP.Quarterly:bafpr2.02.12:Expense.Interest.DebtReceivedAverageBalance.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS173, 'U', 11, 0)
    
            Data Elements:
    
            RP.Quarterly:^IDS173 = tns:Expense.Interest.DebtReceivedAverageBalance.Amount
            */
            assertion = NotMonetary(report.IDS173, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Expense.Interest.DebtReceivedAverageBalance.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440098" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS173", Value = report.IDS173.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440098

            #region VR.ATO.IDS.440099

            /*  VR.ATO.IDS.440099
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS174] <> NULL AND [IDS174] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS174] = IDS:RP.Quarterly:bafpr2.02.12:Income.Interest.DebtProvidedAverageBalance.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS174, 'U', 11, 0)
    
            Data Elements:
    
            RP.Quarterly:^IDS174 = tns:Income.Interest.DebtProvidedAverageBalance.Amount
            */
            assertion = NotMonetary(report.IDS174, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Income.Interest.DebtProvidedAverageBalance.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440099" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS174", Value = report.IDS174.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440099

            #region VR.ATO.IDS.440100

            /*  VR.ATO.IDS.440100
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS175] <> NULL AND [IDS175] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS175] = IDS:RP.Quarterly:bafpr2.02.12:Expense.Interest.EquityReceivedAverageBalance.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS175, 'U', 11, 0)
    
            Data Elements:
    
            RP.Quarterly:^IDS175 = tns:Expense.Interest.EquityReceivedAverageBalance.Amount
            */
            assertion = NotMonetary(report.IDS175, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Expense.Interest.EquityReceivedAverageBalance.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440100" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS175", Value = report.IDS175.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440100

            #region VR.ATO.IDS.440101

            /*  VR.ATO.IDS.440101
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS176] <> NULL AND [IDS176] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS176] = IDS:RP.Quarterly:bafpr2.02.12:Income.Interest.EquityProvidedAverageBalance.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS176, 'U', 11, 0)
    
            Data Elements:
    
            RP.Quarterly:^IDS176 = tns:Income.Interest.EquityProvidedAverageBalance.Amount
            */
            assertion = NotMonetary(report.IDS176, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Income.Interest.EquityProvidedAverageBalance.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440101" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS176", Value = report.IDS176.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440101

            #region VR.ATO.IDS.440102

            /*  VR.ATO.IDS.440102
            If there is a 'False' response to 'Are you subject to the Taxation of Financial Arrangements rules contained in Division 230 of the ITAA 1997?' then the tax timing method elections you have made should not be completed.
    
            Legacy Rule Format:
            IF [IDS177] = FALSE AND ([IDS178] <> NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS177] = IDS:RP:rvctc4.02.05:InternationalDealings.TaxationOfFinancialArrangementsRulesApplied.Indicator
            [IDS178] = IDS:RP:rvctc4.02.05:InternationalDealings.TaxTimingMethodElections.Code

            Technical Business Rule Format:
            ^IDS177 = FALSE AND (^IDS178 <> NULL)
    
            Data Elements:
    
            RP:^IDS177 = tns:InternationalDealings.TaxationOfFinancialArrangementsRulesApplied.Indicator
    
            RP:^IDS178 = tns:InternationalDealings.TaxTimingMethodElections.Code
            */
            assertion = (report.IDS177 == false && report.IDS178Collection != null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440102",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Financial arrangements information not required",
                    LongDescription = @"If there is a 'False' response to 'Are you subject to the Taxation of Financial Arrangements rules contained in Division 230 of the ITAA 1997?' then the tax timing method elections you have made should not be completed",
                    Location = "/xbrli:xbrl/tns:InternationalDealings.TaxationOfFinancialArrangementsRulesApplied.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440102" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS177", Value = GetValueOrEmpty(report.IDS177) });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440102

            #region VR.ATO.IDS.440103

            /*  VR.ATO.IDS.440103
            If there is a 'True' response to 'Are you subject to the Taxation of Financial Arrangements rules contained in Division 230 of the ITAA 1997?' then the tax timing method elections you have made must be completed.
    
            Legacy Rule Format:
            IF [IDS177] = TRUE AND [IDS178] = NULL
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS177] = IDS:RP:rvctc4.02.05:InternationalDealings.TaxationOfFinancialArrangementsRulesApplied.Indicator
            [IDS178] = IDS:RP:rvctc4.02.05:InternationalDealings.TaxTimingMethodElections.Code

            Technical Business Rule Format:
            ^IDS177 = TRUE AND ^IDS178 = NULL
    
            Data Elements:
    
            RP:^IDS177 = tns:InternationalDealings.TaxationOfFinancialArrangementsRulesApplied.Indicator
    
            RP:^IDS178 = tns:InternationalDealings.TaxTimingMethodElections.Code
            */
            assertion = (report.IDS177 == true && report.IDS178Collection == null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440103",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Financial arrangements information required",
                    LongDescription = @"If there is a 'True' response to 'Are you subject to the Taxation of Financial Arrangements rules contained in Division 230 of the ITAA 1997?' then the tax timing method elections you have made must be completed",
                    Location = "/xbrli:xbrl/tns:InternationalDealings.TaxationOfFinancialArrangementsRulesApplied.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440103" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS177", Value = GetValueOrEmpty(report.IDS177) });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440103

            #region VR.ATO.IDS.440104

            /*  VR.ATO.IDS.440104
            This field is Mandatory - must be completed
    
            Legacy Rule Format:
            IF [IDS177] = NULL
            RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS177] = IDS:RP:rvctc4.02.05:InternationalDealings.TaxationOfFinancialArrangementsRulesApplied.Indicator

            Technical Business Rule Format:
            ^IDS177 = NULL
    
            Data Elements:
    
            RP:^IDS177 = tns:InternationalDealings.TaxationOfFinancialArrangementsRulesApplied.Indicator
            */
            assertion = (report.IDS177 == null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001001",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Mandatory field not supplied",
                    Location = "/xbrli:xbrl/tns:InternationalDealings.TaxationOfFinancialArrangementsRulesApplied.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440104" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS177", Value = GetValueOrEmpty(report.IDS177) });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440104

            #region VR.ATO.IDS.440105

            /*  VR.ATO.IDS.440105
            If there is a 'No' response to 'Did you have any interests in controlled foreign companies (CFCs) or controlled foreign trusts (CFTs)?' then the number of CFCs and CFTs which you had an interest in and amounts included in assessable income under sections 456, 457 or 459A should not be completed, and a response at 'Did you have a CFC that was a resident of an unlisted country that provided a benefit (as defined in section 47A of the ITAA 1936), either directly or indirectly, to you or any of your related entities at any time during the income year?' should not be completed.
    
            Legacy Rule Format:
            IF [IDS184] = FALSE AND ([IDS185] <> NULL OR [IDS186] <> NULL OR [IDS187] <> NULL OR [IDS188] <> NULL OR [IDS189] <> NULL OR [IDS190] <> NULL OR [IDS191] <> NULL OR [IDS192] <> NULL OR [IDS193] <> NULL OR [IDS194] <> NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS184] = IDS:RP:bafot.02.11:Miscellaneous.InterestInControlledForeignCompaniesAndControlledForeignTrusts.Indicator
            [IDS185] = IDS:RP.CFCLC:bafot.02.29:Miscellaneous.ControlledForeignCompaniesTrustsInterest.Count
            [IDS186] = IDS:RP.CFCSP:bafot.02.29:Miscellaneous.ControlledForeignCompaniesTrustsInterest.Count
            [IDS187] = IDS:RP.CFCUC:bafot.02.29:Miscellaneous.ControlledForeignCompaniesTrustsInterest.Count
            [IDS188] = IDS:RP.CFCLC:bafpr1.02.12:Income.ControlledForeignCompaniesAttributableIncome.Amount
            [IDS189] = IDS:RP.CFCSP:bafpr1.02.12:Income.ControlledForeignCompaniesAttributableIncome.Amount
            [IDS190] = IDS:RP.CFCUC:bafpr1.02.12:Income.ControlledForeignCompaniesAttributableIncome.Amount
            [IDS191] = IDS:RP:bafpr1.02.12:Income.ControlledForeignCompaniesAttributableIncomeTotal.Amount
            [IDS192] = IDS:RP:bafpr1.02.12:Income.ControlledForeignCompaniesChangeOfResidenceIncome.Amount
            [IDS193] = IDS:RP:bafpr1.02.12:Income.ControlledForeignCompaniesAndControlledForeignTrustsInterposedAustralianEntitiesAttributableIncomeTotal.Amount
            [IDS194] = IDS:RP:rvctc4.02.05:InternationalDealings.ControlledForeignCompaniesResidentUnlistedCountryBenefitProvided.Indicator

            Technical Business Rule Format:
            ^IDS184 = FALSE AND (^IDS185 <> NULL OR ^IDS186 <> NULL OR ^IDS187 <> NULL OR ^IDS188 <> NULL OR ^IDS189 <> NULL OR ^IDS190 <> NULL OR ^IDS191 <> NULL OR ^IDS192 <> NULL OR ^IDS193 <> NULL OR ^IDS194 <> NULL)
    
            Data Elements:
    
            RP:^IDS184 = tns:Miscellaneous.InterestInControlledForeignCompaniesAndControlledForeignTrusts.Indicator
    
            RP.CFCLC:^IDS185 = tns:Miscellaneous.InterestInControlledForeignCompaniesAndControlledForeignTrusts.Count
    
            RP.CFCSP:^IDS186 = tns:Miscellaneous.InterestInControlledForeignCompaniesAndControlledForeignTrusts.Count
    
            RP.CFCUC:^IDS187 = tns:Miscellaneous.InterestInControlledForeignCompaniesAndControlledForeignTrusts.Count
    
            RP.CFCLC:^IDS188 = tns:Income.ControlledForeignCompaniesAttributableIncome.Amount
    
            RP.CFCSP:^IDS189 = tns:Income.ControlledForeignCompaniesAttributableIncome.Amount
    
            RP.CFCUC:^IDS190 = tns:Income.ControlledForeignCompaniesAttributableIncome.Amount
    
            RP:^IDS191 = tns:Income.ControlledForeignCompaniesAttributableIncomeTotal.Amount
    
            RP:^IDS192 = tns:Income.ControlledForeignCompaniesChangeOfResidenceIncome.Amount
    
            RP:^IDS193 = tns:Income.ControlledForeignCompaniesAndControlledForeignTrustsInterposedAustralianEntitiesAttributableIncomeTotal.Amount
    
            RP:^IDS194 = tns:InternationalDealings.ControlledForeignCompaniesResidentUnlistedCountryBenefitProvided.Indicator
            */
            assertion = (report.IDS184 == false && (report.IDS185 != null || report.IDS186 != null || report.IDS187 != null || report.IDS188 != null || report.IDS189 != null || report.IDS190 != null || report.IDS191 != null || report.IDS192 != null || report.IDS193 != null || report.IDS194 != null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440105",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Interests in foreign entities information not required",
                    LongDescription = @"If there is a 'False' response to 'Did you have any interests in controlled foreign companies (CFCs) or controlled foreign trusts (CFTs)?' then the number of CFCs and CFTs which you had an interest in and amounts included in assessable income under sections 456, 457 or 459A should not be completed, and a response at 'Did you have a CFC that was a resident of an unlisted country that provided a benefit (as defined in section 47A of the ITAA 1936), either directly or indirectly, to you or any of your related entities at any time during the income year?' should not be completed",
                    Location = "/xbrli:xbrl/tns:Miscellaneous.InterestInControlledForeignCompaniesAndControlledForeignTrusts.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440105" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS184", Value = GetValueOrEmpty(report.IDS184) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS185", Value = report.IDS185.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS186", Value = report.IDS186.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS187", Value = report.IDS187.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS188", Value = report.IDS188.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS189", Value = report.IDS189.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS190", Value = report.IDS190.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS191", Value = report.IDS191.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS192", Value = report.IDS192.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS193", Value = report.IDS193.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS194", Value = GetValueOrEmpty(report.IDS194) });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440105

            #region VR.ATO.IDS.440106

            /*  VR.ATO.IDS.440106
            If there is a 'Yes' response to 'Did you have any interests in controlled foreign companies (CFCs) or controlled foreign trusts (CFTs)?' then the number of CFCs and CFTs which you had an interest in and amounts included in assessable income under sections 456, 457 or 459A must be completed, and a response at 'Did you have a CFC that was a resident of an unlisted country that provided a benefit (as defined in section 47A of the ITAA 1936), either directly or indirectly, to you or any of your related entities at any time during the income year?' must be completed.
    
            Legacy Rule Format:
            IF [IDS184] = TRUE AND (([IDS185] = NULL AND [IDS186] = NULL AND [IDS187] = NULL) OR ([IDS188] = NULL AND [IDS189] = NULL AND [IDS190] = NULL AND [IDS191] = NULL AND [IDS192] = NULL AND [IDS193] = NULL) OR [IDS194] = NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS184] = IDS:RP:bafot.02.11:Miscellaneous.InterestInControlledForeignCompaniesAndControlledForeignTrusts.Indicator
            [IDS185] = IDS:RP.CFCLC:bafot.02.29:Miscellaneous.ControlledForeignCompaniesTrustsInterest.Count
            [IDS186] = IDS:RP.CFCSP:bafot.02.29:Miscellaneous.ControlledForeignCompaniesTrustsInterest.Count
            [IDS187] = IDS:RP.CFCUC:bafot.02.29:Miscellaneous.ControlledForeignCompaniesTrustsInterest.Count
            [IDS188] = IDS:RP.CFCLC:bafpr1.02.12:Income.ControlledForeignCompaniesAttributableIncome.Amount
            [IDS189] = IDS:RP.CFCSP:bafpr1.02.12:Income.ControlledForeignCompaniesAttributableIncome.Amount
            [IDS190] = IDS:RP.CFCUC:bafpr1.02.12:Income.ControlledForeignCompaniesAttributableIncome.Amount
            [IDS191] = IDS:RP:bafpr1.02.12:Income.ControlledForeignCompaniesAttributableIncomeTotal.Amount
            [IDS192] = IDS:RP:bafpr1.02.12:Income.ControlledForeignCompaniesChangeOfResidenceIncome.Amount
            [IDS193] = IDS:RP:bafpr1.02.12:Income.ControlledForeignCompaniesAndControlledForeignTrustsInterposedAustralianEntitiesAttributableIncomeTotal.Amount
            [IDS194] = IDS:RP:rvctc4.02.05:InternationalDealings.ControlledForeignCompaniesResidentUnlistedCountryBenefitProvided.Indicator

            Technical Business Rule Format:
            ^IDS184 = TRUE AND ((^IDS185 = NULL AND ^IDS186 = NULL AND ^IDS187 = NULL) OR (^IDS188 = NULL AND ^IDS189 = NULL AND ^IDS190 = NULL AND ^IDS191 = NULL AND ^IDS192 = NULL AND ^IDS193 = NULL) OR ^IDS194 = NULL)
    
            Data Elements:
    
            RP:^IDS184 = tns:Miscellaneous.InterestInControlledForeignCompaniesAndControlledForeignTrusts.Indicator
    
            RP.CFCLC:^IDS185 = tns:Miscellaneous.InterestInControlledForeignCompaniesAndControlledForeignTrusts.Count
    
            RP.CFCSP:^IDS186 = tns:Miscellaneous.InterestInControlledForeignCompaniesAndControlledForeignTrusts.Count
    
            RP.CFCUC:^IDS187 = tns:Miscellaneous.InterestInControlledForeignCompaniesAndControlledForeignTrusts.Count
    
            RP.CFCLC:^IDS188 = tns:Income.ControlledForeignCompaniesAttributableIncome.Amount
    
            RP.CFCSP:^IDS189 = tns:Income.ControlledForeignCompaniesAttributableIncome.Amount
    
            RP.CFCUC:^IDS190 = tns:Income.ControlledForeignCompaniesAttributableIncome.Amount
    
            RP:^IDS191 = tns:Income.ControlledForeignCompaniesAttributableIncomeTotal.Amount
    
            RP:^IDS192 = tns:Income.ControlledForeignCompaniesChangeOfResidenceIncome.Amount
    
            RP:^IDS193 = tns:Income.ControlledForeignCompaniesAndControlledForeignTrustsInterposedAustralianEntitiesAttributableIncomeTotal.Amount
    
            RP:^IDS194 = tns:InternationalDealings.ControlledForeignCompaniesResidentUnlistedCountryBenefitProvided.Indicator
            */
            assertion = (report.IDS184 == true && (report.IDS185 == null && report.IDS186 == null && report.IDS187 == null || report.IDS188 == null && report.IDS189 == null && report.IDS190 == null && report.IDS191 == null && report.IDS192 == null && report.IDS193 == null || report.IDS194 == null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440106",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Interests in foreign entities information required",
                    LongDescription = @"If there is a 'True' response to 'Did you have any interests in controlled foreign companies (CFCs) or controlled foreign trusts (CFTs)?' then the number of CFCs and CFTs which you had an interest in and amounts included in assessable income under sections 456, 457 or 459A must be completed, and a response at 'Did you have a CFC that was a resident of an unlisted country that provided a benefit (as defined in section 47A of the ITAA 1936), either directly or indirectly, to you or any of your related entities at any time during the income year?' must be completed",
                    Location = "/xbrli:xbrl/tns:Miscellaneous.InterestInControlledForeignCompaniesAndControlledForeignTrusts.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440106" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS184", Value = GetValueOrEmpty(report.IDS184) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS185", Value = report.IDS185.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS186", Value = report.IDS186.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS187", Value = report.IDS187.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS188", Value = report.IDS188.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS189", Value = report.IDS189.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS190", Value = report.IDS190.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS191", Value = report.IDS191.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS192", Value = report.IDS192.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS193", Value = report.IDS193.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS194", Value = GetValueOrEmpty(report.IDS194) });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440106

            #region VR.ATO.IDS.440107

            /*  VR.ATO.IDS.440107
            This field is Mandatory - must be completed
    
            Legacy Rule Format:
            IF [IDS184] = NULL
            RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS184] = IDS:RP:bafot.02.11:Miscellaneous.InterestInControlledForeignCompaniesAndControlledForeignTrusts.Indicator

            Technical Business Rule Format:
            ^IDS184 = NULL
    
            Data Elements:
    
            RP:^IDS184 = tns:Miscellaneous.InterestInControlledForeignCompaniesAndControlledForeignTrusts.Indicator
            */
            assertion = (report.IDS184 == null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001001",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Mandatory field not supplied",
                    Location = "/xbrli:xbrl/tns:Miscellaneous.InterestInControlledForeignCompaniesAndControlledForeignTrusts.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440107" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS184", Value = GetValueOrEmpty(report.IDS184) });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440107

            #region VR.ATO.IDS.440108

            /*  VR.ATO.IDS.440108
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF bafpr1.xx.xx:Income.ControlledForeignCompaniesAttributableIncome.Amount <> NULL AND bafpr1.xx.xx:Income.ControlledForeignCompaniesAttributableIncome.Amount <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS188, 'U', 11, 0)
    
            Data Elements:
    
            RP.CFCLC:^IDS188 = tns:Income.ControlledForeignCompaniesAttributableIncome.Amount
            */
            assertion = NotMonetary(report.IDS188, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Income.ControlledForeignCompaniesAttributableIncome.Amount[@contextRef='" + report.RPCFCLCId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440108" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS188", Value = report.IDS188.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440108

            #region VR.ATO.IDS.440108

            /*  VR.ATO.IDS.440108
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF bafpr1.xx.xx:Income.ControlledForeignCompaniesAttributableIncome.Amount <> NULL AND bafpr1.xx.xx:Income.ControlledForeignCompaniesAttributableIncome.Amount <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS190, 'U', 11, 0)
    
            Data Elements:
    
            RP.CFCUC:^IDS190 = tns:Income.ControlledForeignCompaniesAttributableIncome.Amount
            */
            assertion = NotMonetary(report.IDS190, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Income.ControlledForeignCompaniesAttributableIncome.Amount[@contextRef='" + report.RPCFCUCId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440108" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS190", Value = report.IDS190.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440108

            #region VR.ATO.IDS.440108

            /*  VR.ATO.IDS.440108
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF bafpr1.xx.xx:Income.ControlledForeignCompaniesAttributableIncome.Amount <> NULL AND bafpr1.xx.xx:Income.ControlledForeignCompaniesAttributableIncome.Amount <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS189, 'U', 11, 0)
    
            Data Elements:
    
            RP.CFCSP:^IDS189 = tns:Income.ControlledForeignCompaniesAttributableIncome.Amount
            */
            assertion = NotMonetary(report.IDS189, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Income.ControlledForeignCompaniesAttributableIncome.Amount[@contextRef='" + report.RPCFCSPId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440108" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS189", Value = report.IDS189.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440108

            #region VR.ATO.IDS.440111

            /*  VR.ATO.IDS.440111
            In question 'Specify the amounts included in your assessable income under the following sections of the ITAA1936' of the IDS the total of Section 456 CFCs attributable income must equal the amounts at Listed countries, Specified countries and Other unlisted countries.
    
            Legacy Rule Format:
            IF [IDS191] <> ([IDS188] + [IDS189] + [IDS190])
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS188] = IDS:RP.CFCLC:bafpr1.02.12:Income.ControlledForeignCompaniesAttributableIncome.Amount
            [IDS189] = IDS:RP.CFCSP:bafpr1.02.12:Income.ControlledForeignCompaniesAttributableIncome.Amount
            [IDS190] = IDS:RP.CFCUC:bafpr1.02.12:Income.ControlledForeignCompaniesAttributableIncome.Amount
            [IDS191] = IDS:RP:bafpr1.02.12:Income.ControlledForeignCompaniesAttributableIncomeTotal.Amount

            Technical Business Rule Format:
            ^IDS191 <> (^IDS188 + ^IDS189 + ^IDS190)
    
            Data Elements:
    
            RP:^IDS191 = tns:Income.ControlledForeignCompaniesAttributableIncomeTotal.Amount
    
            RP.CFCLC:^IDS188 = tns:Income.ControlledForeignCompaniesAttributableIncome.Amount
    
            RP.CFCSP:^IDS189 = tns:Income.ControlledForeignCompaniesAttributableIncome.Amount
    
            RP.CFCUC:^IDS190 = tns:Income.ControlledForeignCompaniesAttributableIncome.Amount
            */
            assertion = (report.IDS191.GetValueOrDefault() != report.IDS188.GetValueOrDefault() + report.IDS189.GetValueOrDefault() + report.IDS190.GetValueOrDefault());
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440111",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Total of Section 456 CFCs attributable income incorrect",
                    LongDescription = @"Section 456 CFCs attributable income Total must equal the sum of listed countries, specified countries and other unlisted countries",
                    Location = "/xbrli:xbrl/tns:Income.ControlledForeignCompaniesAttributableIncomeTotal.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440111" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS191", Value = report.IDS191.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS188", Value = report.IDS188.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS189", Value = report.IDS189.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS190", Value = report.IDS190.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440111

            #region VR.ATO.IDS.440112

            /*  VR.ATO.IDS.440112
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS191] <> NULL AND [IDS191] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS191] = IDS:RP:bafpr1.02.12:Income.ControlledForeignCompaniesAttributableIncomeTotal.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS191, 'U', 11, 0)
    
            Data Elements:
    
            RP:^IDS191 = tns:Income.ControlledForeignCompaniesAttributableIncomeTotal.Amount
            */
            assertion = NotMonetary(report.IDS191, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Income.ControlledForeignCompaniesAttributableIncomeTotal.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440112" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS191", Value = report.IDS191.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440112

            #region VR.ATO.IDS.440113

            /*  VR.ATO.IDS.440113
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS192] <> NULL AND [IDS192] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS192] = IDS:RP:bafpr1.02.12:Income.ControlledForeignCompaniesChangeOfResidenceIncome.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS192, 'U', 11, 0)
    
            Data Elements:
    
            RP:^IDS192 = tns:Income.ControlledForeignCompaniesChangeOfResidenceIncome.Amount
            */
            assertion = NotMonetary(report.IDS192, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Income.ControlledForeignCompaniesChangeOfResidenceIncome.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440113" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS192", Value = report.IDS192.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440113

            #region VR.ATO.IDS.440114

            /*  VR.ATO.IDS.440114
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS193] <> NULL AND [IDS193] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS193] = IDS:RP:bafpr1.02.12:Income.ControlledForeignCompaniesAndControlledForeignTrustsInterposedAustralianEntitiesAttributableIncomeTotal.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS193, 'U', 11, 0)
    
            Data Elements:
    
            RP:^IDS193 = tns:Income.ControlledForeignCompaniesAndControlledForeignTrustsInterposedAustralianEntitiesAttributableIncomeTotal.Amount
            */
            assertion = NotMonetary(report.IDS193, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Income.ControlledForeignCompaniesAndControlledForeignTrustsInterposedAustralianEntitiesAttributableIncomeTotal.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440114" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS193", Value = report.IDS193.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440114

            #region VR.ATO.IDS.440115

            /*  VR.ATO.IDS.440115
            If there is a 'False' response to 'Do you have foreign branch operations or any direct or indirect interests in foreign companies or foreign trusts?' then the non-assessable foreign income derived under sections 23AH, 23AI, or subdivision 768-A should not be completed, responses at 'Did you have any debt deductions in earning non-assessable non-exempt foreign income?' and 'Did you have any capital gains tax (CGT) events in relation to your interest in a foreign company?' should not be completed.
    
            Legacy Rule Format:
            IF [IDS195] = FALSE AND ([IDS196] <> NULL OR [IDS197] <> NULL OR [IDS198] <> NULL OR [IDS199] <> NULL OR [IDS200] <> NULL OR [IDS201] <> NULL OR [IDS202] <> NULL OR [IDS206] <> NULL OR [IDS208] <> NULL OR [IDS320] <> NULL OR [IDS321] <> NULL OR [IDS322] <> NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            
            [IDS195] = IDS:RP:bafpr1.02.12:Income.ForeignBranchOperationsInterestsInForeignCompaniesOrForeignTrusts.Indicator
            [IDS196] = IDS:RP.CFCLC:bafpr1.02.12:Income.ForeignBranchProfitsOfAustralianCompaniesNonAssessableNonExemptIncome.Amount
            [IDS197] = IDS:RP.CFCSP:bafpr1.02.12:Income.ForeignBranchProfitsOfAustralianCompaniesNonAssessableNonExemptIncome.Amount
            [IDS198] = IDS:RP.CFCUC:bafpr1.02.12:Income.ForeignBranchProfitsOfAustralianCompaniesNonAssessableNonExemptIncome.Amount
            [IDS199] = IDS:RP:bafpr1.02.12:Expense.NonDeductibleExemptIncome.Amount
            [IDS200] = IDS:RP.CFCLC:bafpr1.02.12:Income.PaidOutOfAttributedControlledForeignCompanyIncomeNonAssessableNonExemptIncome.Amount
            [IDS201] = IDS:RP.CFCSP:bafpr1.02.12:Income.PaidOutOfAttributedControlledForeignCompanyIncomeNonAssessableNonExemptIncome.Amount
            [IDS202] = IDS:RP.CFCUC:bafpr1.02.12:Income.PaidOutOfAttributedControlledForeignCompanyIncomeNonAssessableNonExemptIncome.Amount
            [IDS206] = IDS:RP:rvctc2.02.09:IncomeTax.Deduction.DebtEarningNonAssessableNonExemptForeignIncome.Indicator
            [IDS208] = IDS:RP:rvctc3.02.00:CapitalGainsTax.Event.Indicator
            [IDS320] = IDS:RP.CFCLC:bafpr1.02.22:Income.NonPortfolioDividendFromForeignCompanyNonAssessableNonExemptIncome.Amount
            [IDS321] = IDS:RP.CFCSP:bafpr1.02.22:Income.NonPortfolioDividendFromForeignCompanyNonAssessableNonExemptIncome.Amount
            [IDS322] = IDS:RP.CFCUC:bafpr1.02.22:Income.NonPortfolioDividendFromForeignCompanyNonAssessableNonExemptIncome.Amount

            Technical Business Rule Format:
            ^IDS195 = FALSE AND (^IDS196 <> NULL OR ^IDS197 <> NULL OR ^IDS198 <> NULL OR ^IDS199 <> NULL OR ^IDS200 <> NULL OR ^IDS201 <> NULL OR ^IDS202 <> NULL OR ^IDS206 <> NULL OR ^IDS208 <> NULL OR ^IDS320 <> NULL OR ^IDS321 <> NULL OR ^IDS322 <> NULL)
    
            Data Elements:
    
            RP:^IDS195 = tns:Income.ForeignBranchOperationsInterestsInForeignCompaniesOrForeignTrusts.Indicator
    
            RP.CFCLC:^IDS196 = tns:Income.ForeignBranchProfitsOfAustralianCompaniesNonAssessableNonExemptIncome.Amount
    
            RP.CFCSP:^IDS197 = tns:Income.ForeignBranchProfitsOfAustralianCompaniesNonAssessableNonExemptIncome.Amount
    
            RP.CFCUC:^IDS198 = tns:Income.ForeignBranchProfitsOfAustralianCompaniesNonAssessableNonExemptIncome.Amount
    
            RP:^IDS199 = tns:Expense.NonDeductibleExemptIncome.Amount
    
            RP.CFCLC:^IDS200 = tns:Income.PaidOutOfAttributedControlledForeignCompanyIncomeNonAssessableNonExemptIncome.Amount
    
            RP.CFCSP:^IDS201 = tns:Income.PaidOutOfAttributedControlledForeignCompanyIncomeNonAssessableNonExemptIncome.Amount
    
            RP.CFCUC:^IDS202 = tns:Income.PaidOutOfAttributedControlledForeignCompanyIncomeNonAssessableNonExemptIncome.Amount
    
            RP:^IDS206 = tns:IncomeTax.Deduction.DebtEarningNonAssessableNonExemptForeignIncome.Indicator
    
            RP:^IDS208 = tns:CapitalGainsTax.Event.Indicator
    
            RP.CFCLC:^IDS320 = tns:Income.NonPortfolioDividendFromForeignCompanyNonAssessableNonExemptIncome.Amount
    
            RP.CFCSP:^IDS321 = tns:Income.NonPortfolioDividendFromForeignCompanyNonAssessableNonExemptIncome.Amount
    
            RP.CFCUC:^IDS322 = tns:Income.NonPortfolioDividendFromForeignCompanyNonAssessableNonExemptIncome.Amount
            */
            assertion = (report.IDS195 == false && (report.IDS196 != null || report.IDS197 != null || report.IDS198 != null || report.IDS199 != null || report.IDS200 != null || report.IDS201 != null || report.IDS202 != null || report.IDS206 != null || report.IDS208 != null || report.IDS320 != null || report.IDS321 != null || report.IDS322 != null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440302",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Interests in foreign entities information not required",
                    LongDescription = @"If there is a 'False' response to 'Do you have foreign branch operations or any direct or indirect interests in foreign companies or foreign trusts?' then the non-assessable foreign income derived under sections 23AH, 23AI or 23AJ should not be completed, responses at 'Did you have any debt deductions in earning non-assessable non-exempt foreign income?' and 'Did you have any capital gains tax (CGT) events in relation to your interest in a foreign company?' should not be completed.",
                    Location = "/xbrli:xbrl/tns:Income.ForeignBranchOperationsInterestsInForeignCompaniesOrForeignTrusts.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440115" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS195", Value = GetValueOrEmpty(report.IDS195) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS196", Value = report.IDS196.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS197", Value = report.IDS197.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS198", Value = report.IDS198.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS199", Value = report.IDS199.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS200", Value = report.IDS200.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS201", Value = report.IDS201.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS202", Value = report.IDS202.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS206", Value = GetValueOrEmpty(report.IDS206) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS208", Value = GetValueOrEmpty(report.IDS208) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS320", Value = report.IDS320.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS321", Value = report.IDS321.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS322", Value = report.IDS322.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440115

            #region VR.ATO.IDS.440116

            /*  VR.ATO.IDS.440116
            If there is a 'True' response to 'Do you have foreign branch operations or any direct or indirect interests in foreign companies or foreign trusts?' then the non-assessable foreign income derived under sections 23AH, 23AI, or subdivision 768-A must be completed and responses at 'Did you have any debt deductions in earning non-assessable non-exempt foreign income?' and 'Did you have any capital gains tax (CGT) events in relation to your interest in a foreign company?' must be completed.
    
            Legacy Rule Format:
            IF [IDS195] = TRUE AND (([IDS196] = NULL AND [IDS197] = NULL AND [IDS198] = NULL AND [IDS199] = NULL AND [IDS200] = NULL AND [IDS201] = NULL AND [IDS202] = NULL AND [IDS320] = NULL AND [IDS321] = NULL AND [IDS322] = NULL) OR [IDS206] = NULL OR [IDS208] = NULL)
              RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS195] = IDS:RP:bafpr1.02.12:Income.ForeignBranchOperationsInterestsInForeignCompaniesOrForeignTrusts.Indicator
            [IDS196] = IDS:RP.CFCLC:bafpr1.02.12:Income.ForeignBranchProfitsOfAustralianCompaniesNonAssessableNonExemptIncome.Amount
            [IDS197] = IDS:RP.CFCSP:bafpr1.02.12:Income.ForeignBranchProfitsOfAustralianCompaniesNonAssessableNonExemptIncome.Amount
            [IDS198] = IDS:RP.CFCUC:bafpr1.02.12:Income.ForeignBranchProfitsOfAustralianCompaniesNonAssessableNonExemptIncome.Amount
            [IDS199] = IDS:RP:bafpr1.02.12:Expense.NonDeductibleExemptIncome.Amount
            [IDS200] = IDS:RP.CFCLC:bafpr1.02.12:Income.PaidOutOfAttributedControlledForeignCompanyIncomeNonAssessableNonExemptIncome.Amount
            [IDS201] = IDS:RP.CFCSP:bafpr1.02.12:Income.PaidOutOfAttributedControlledForeignCompanyIncomeNonAssessableNonExemptIncome.Amount
            [IDS202] = IDS:RP.CFCUC:bafpr1.02.12:Income.PaidOutOfAttributedControlledForeignCompanyIncomeNonAssessableNonExemptIncome.Amount
            [IDS206] = IDS:RP:rvctc2.02.09:IncomeTax.Deduction.DebtEarningNonAssessableNonExemptForeignIncome.Indicator
            [IDS208] = IDS:RP:rvctc3.02.00:CapitalGainsTax.Event.Indicator
            [IDS320] = IDS:RP.CFCLC:bafpr1.02.22:Income.NonPortfolioDividendFromForeignCompanyNonAssessableNonExemptIncome.Amount
            [IDS321] = IDS:RP.CFCSP:bafpr1.02.22:Income.NonPortfolioDividendFromForeignCompanyNonAssessableNonExemptIncome.Amount
            [IDS322] = IDS:RP.CFCUC:bafpr1.02.22:Income.NonPortfolioDividendFromForeignCompanyNonAssessableNonExemptIncome.Amount

            Technical Business Rule Format:
            ^IDS195 = TRUE AND ((^IDS196 = NULL AND ^IDS197 = NULL AND ^IDS198 = NULL AND ^IDS199 = NULL AND ^IDS200 = NULL AND ^IDS201 = NULL AND ^IDS202 = NULL AND ^IDS320 = NULL AND ^IDS321 = NULL AND ^IDS322 = NULL) OR ^IDS206 = NULL OR ^IDS208 = NULL)
    
            Data Elements:
    
            RP:^IDS195 = tns:Income.ForeignBranchOperationsInterestsInForeignCompaniesOrForeignTrusts.Indicator
    
            RP.CFCLC:^IDS196 = tns:Income.ForeignBranchProfitsOfAustralianCompaniesNonAssessableNonExemptIncome.Amount
    
            RP.CFCSP:^IDS197 = tns:Income.ForeignBranchProfitsOfAustralianCompaniesNonAssessableNonExemptIncome.Amount
    
            RP.CFCUC:^IDS198 = tns:Income.ForeignBranchProfitsOfAustralianCompaniesNonAssessableNonExemptIncome.Amount
    
            RP:^IDS199 = tns:Expense.NonDeductibleExemptIncome.Amount
    
            RP.CFCLC:^IDS200 = tns:Income.PaidOutOfAttributedControlledForeignCompanyIncomeNonAssessableNonExemptIncome.Amount
    
            RP.CFCSP:^IDS201 = tns:Income.PaidOutOfAttributedControlledForeignCompanyIncomeNonAssessableNonExemptIncome.Amount
    
            RP.CFCUC:^IDS202 = tns:Income.PaidOutOfAttributedControlledForeignCompanyIncomeNonAssessableNonExemptIncome.Amount
    
            RP:^IDS206 = tns:IncomeTax.Deduction.DebtEarningNonAssessableNonExemptForeignIncome.Indicator
    
            RP:^IDS208 = tns:CapitalGainsTax.Event.Indicator
    
            RP.CFCLC:^IDS320 = tns:Income.NonPortfolioDividendFromForeignCompanyNonAssessableNonExemptIncome.Amount
    
            RP.CFCSP:^IDS321 = tns:Income.NonPortfolioDividendFromForeignCompanyNonAssessableNonExemptIncome.Amount
    
            RP.CFCUC:^IDS322 = tns:Income.NonPortfolioDividendFromForeignCompanyNonAssessableNonExemptIncome.Amount
            */
            assertion = (report.IDS195 == true && (report.IDS196 == null && report.IDS197 == null && report.IDS198 == null && report.IDS199 == null && report.IDS200 == null && report.IDS201 == null && report.IDS202 == null && report.IDS320 == null && report.IDS321 == null && report.IDS322 == null || report.IDS206 == null || report.IDS208 == null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440116",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Interests in foreign entities information required",
                    LongDescription = @"If there is a 'True' response to 'Do you have foreign branch operations or any direct or indirect interests in foreign companies or foreign trusts?' then the non-assessable foreign income derived under sections 23AH, 23AI or 23AJ must be completed and responses at 'Did you have any debt deductions in earning non-assessable non-exempt foreign income?' and 'Did you have any capital gains tax (CGT) events in relation to your interest in a foreign company?' must be completed.",
                    Location = "/xbrli:xbrl/tns:Income.ForeignBranchOperationsInterestsInForeignCompaniesOrForeignTrusts.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440116" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS195", Value = GetValueOrEmpty(report.IDS195) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS196", Value = report.IDS196.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS197", Value = report.IDS197.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS198", Value = report.IDS198.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS199", Value = report.IDS199.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS200", Value = report.IDS200.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS201", Value = report.IDS201.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS202", Value = report.IDS202.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS320", Value = report.IDS320.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS321", Value = report.IDS321.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS322", Value = report.IDS322.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS206", Value = GetValueOrEmpty(report.IDS206) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS208", Value = GetValueOrEmpty(report.IDS208) });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440116

            #region VR.ATO.IDS.440117

            /*  VR.ATO.IDS.440117
            This field is Mandatory - must be completed
    
            Legacy Rule Format:
            IF [IDS195] = NULL
            RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS195] = IDS:RP:bafpr1.02.12:Income.ForeignBranchOperationsInterestsInForeignCompaniesOrForeignTrusts.Indicator

            Technical Business Rule Format:
            ^IDS195 = NULL
    
            Data Elements:
    
            RP:^IDS195 = tns:Income.ForeignBranchOperationsInterestsInForeignCompaniesOrForeignTrusts.Indicator
            */
            assertion = (report.IDS195 == null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001001",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Mandatory field not supplied",
                    Location = "/xbrli:xbrl/tns:Income.ForeignBranchOperationsInterestsInForeignCompaniesOrForeignTrusts.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440117" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS195", Value = GetValueOrEmpty(report.IDS195) });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440117

            #region VR.ATO.IDS.440118

            /*  VR.ATO.IDS.440118
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF bafpr1.xx.xx:Income.ForeignBranchProfitsOfAustralianCompaniesNonAssessableNonExemptIncome.Amount <> NULL AND bafpr1.xx.xx:Income.ForeignBranchProfitsOfAustralianCompaniesNonAssessableNonExemptIncome.Amount <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS196, 'U', 11, 0)
    
            Data Elements:
    
            RP.CFCLC:^IDS196 = tns:Income.ForeignBranchProfitsOfAustralianCompaniesNonAssessableNonExemptIncome.Amount
            */
            assertion = NotMonetary(report.IDS196, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Income.ForeignBranchProfitsOfAustralianCompaniesNonAssessableNonExemptIncome.Amount[@contextRef='" + report.RPCFCLCId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440118" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS196", Value = report.IDS196.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440118

            #region VR.ATO.IDS.440118

            /*  VR.ATO.IDS.440118
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF bafpr1.xx.xx:Income.ForeignBranchProfitsOfAustralianCompaniesNonAssessableNonExemptIncome.Amount <> NULL AND bafpr1.xx.xx:Income.ForeignBranchProfitsOfAustralianCompaniesNonAssessableNonExemptIncome.Amount <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS198, 'U', 11, 0)
    
            Data Elements:
    
            RP.CFCUC:^IDS198 = tns:Income.ForeignBranchProfitsOfAustralianCompaniesNonAssessableNonExemptIncome.Amount
            */
            assertion = NotMonetary(report.IDS198, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Income.ForeignBranchProfitsOfAustralianCompaniesNonAssessableNonExemptIncome.Amount[@contextRef='" + report.RPCFCUCId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440118" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS198", Value = report.IDS198.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440118

            #region VR.ATO.IDS.440118

            /*  VR.ATO.IDS.440118
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF bafpr1.xx.xx:Income.ForeignBranchProfitsOfAustralianCompaniesNonAssessableNonExemptIncome.Amount <> NULL AND bafpr1.xx.xx:Income.ForeignBranchProfitsOfAustralianCompaniesNonAssessableNonExemptIncome.Amount <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS197, 'U', 11, 0)
    
            Data Elements:
    
            RP.CFCSP:^IDS197 = tns:Income.ForeignBranchProfitsOfAustralianCompaniesNonAssessableNonExemptIncome.Amount
            */
            assertion = NotMonetary(report.IDS197, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Income.ForeignBranchProfitsOfAustralianCompaniesNonAssessableNonExemptIncome.Amount[@contextRef='" + report.RPCFCSPId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440118" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS197", Value = report.IDS197.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440118

            #region VR.ATO.IDS.440121

            /*  VR.ATO.IDS.440121
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS199] <> NULL AND [IDS199] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS199] = IDS:RP:bafpr1.02.12:Expense.NonDeductibleExemptIncome.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS199, 'U', 11, 0)
    
            Data Elements:
    
            RP:^IDS199 = tns:Expense.NonDeductibleExemptIncome.Amount
            */
            assertion = NotMonetary(report.IDS199, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Expense.NonDeductibleExemptIncome.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440121" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS199", Value = report.IDS199.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440121

            #region VR.ATO.IDS.440122

            /*  VR.ATO.IDS.440122
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF bafpr1.xx.xx:Income.PaidOutOfAttributedControlledForeignCompanyIncomeNonAssessableNonExemptIncome.Amount <> NULL AND bafpr1.xx.xx:Income.PaidOutOfAttributedControlledForeignCompanyIncomeNonAssessableNonExemptIncome.Amount <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS200, 'U', 11, 0)
    
            Data Elements:
    
            RP.CFCLC:^IDS200 = tns:Income.PaidOutOfAttributedControlledForeignCompanyIncomeNonAssessableNonExemptIncome.Amount
            */
            assertion = NotMonetary(report.IDS200, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Income.PaidOutOfAttributedControlledForeignCompanyIncomeNonAssessableNonExemptIncome.Amount[@contextRef='" + report.RPCFCLCId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440122" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS200", Value = report.IDS200.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440122

            #region VR.ATO.IDS.440122

            /*  VR.ATO.IDS.440122
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF bafpr1.xx.xx:Income.PaidOutOfAttributedControlledForeignCompanyIncomeNonAssessableNonExemptIncome.Amount <> NULL AND bafpr1.xx.xx:Income.PaidOutOfAttributedControlledForeignCompanyIncomeNonAssessableNonExemptIncome.Amount <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS202, 'U', 11, 0)
    
            Data Elements:
    
            RP.CFCUC:^IDS202 = tns:Income.PaidOutOfAttributedControlledForeignCompanyIncomeNonAssessableNonExemptIncome.Amount
            */
            assertion = NotMonetary(report.IDS202, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Income.PaidOutOfAttributedControlledForeignCompanyIncomeNonAssessableNonExemptIncome.Amount[@contextRef='" + report.RPCFCUCId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440122" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS202", Value = report.IDS202.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440122

            #region VR.ATO.IDS.440122

            /*  VR.ATO.IDS.440122
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF bafpr1.xx.xx:Income.PaidOutOfAttributedControlledForeignCompanyIncomeNonAssessableNonExemptIncome.Amount <> NULL AND bafpr1.xx.xx:Income.PaidOutOfAttributedControlledForeignCompanyIncomeNonAssessableNonExemptIncome.Amount <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS201, 'U', 11, 0)
    
            Data Elements:
    
            RP.CFCSP:^IDS201 = tns:Income.PaidOutOfAttributedControlledForeignCompanyIncomeNonAssessableNonExemptIncome.Amount
            */
            assertion = NotMonetary(report.IDS201, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Income.PaidOutOfAttributedControlledForeignCompanyIncomeNonAssessableNonExemptIncome.Amount[@contextRef='" + report.RPCFCSPId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440122" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS201", Value = report.IDS201.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440122

            #region VR.ATO.IDS.440128

            /*  VR.ATO.IDS.440128
            If Interests in foreign entities information has been completed for debt deductions in earning non-assessable foreign income claimed under s25-90 then the response to 'Did you have any debt deductions in earning non-assessable foreign income (s25-90)?' must be 'Yes'.
    
            Legacy Rule Format:
            IF [IDS206] <> TRUE AND [IDS207] <> NULL
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS206] = IDS:RP:rvctc2.02.09:IncomeTax.Deduction.DebtEarningNonAssessableNonExemptForeignIncome.Indicator
            [IDS207] = IDS:RP:rvctc2.02.09:IncomeTax.Deduction.DebtEarningNonAssessableNonExemptForeignIncomeTotal.Amount

            Technical Business Rule Format:
            ^IDS206 <> TRUE AND ^IDS207 <> NULL
    
            Data Elements:
    
            RP:^IDS206 = tns:IncomeTax.Deduction.DebtEarningNonAssessableNonExemptForeignIncome.Indicator
    
            RP:^IDS207 = tns:IncomeTax.Deduction.DebtEarningNonAssessableNonExemptForeignIncomeTotal.Amount
            */
            assertion = (report.IDS206 != true && report.IDS207 != null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440303",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Interests in foreign entities information completed incorrectly",
                    LongDescription = @"If 'Debt deductions in earning non-assessable non-exempt foreign income claimed' is greater than zero, a 'true' response is required for 'Did you have any debt deductions in earning non-assessable non-exempt foreign income?'.",
                    Location = "/xbrli:xbrl/tns:IncomeTax.Deduction.DebtEarningNonAssessableNonExemptForeignIncome.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440128" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS206", Value = GetValueOrEmpty(report.IDS206) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS207", Value = report.IDS207.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440128

            #region VR.ATO.IDS.440129

            /*  VR.ATO.IDS.440129
            If there is a 'Yes' response to 'Did you have any debt deductions in earning non-assessable non-exempt foreign income (s25-90)?' then 'Debt deductions in earning non-assessable non-exempt foreign income claimed under s25-90' must be completed.
    
            Legacy Rule Format:
            IF [IDS206] = TRUE AND [IDS207] = NULL
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS206] = IDS:RP:rvctc2.02.09:IncomeTax.Deduction.DebtEarningNonAssessableNonExemptForeignIncome.Indicator
            [IDS207] = IDS:RP:rvctc2.02.09:IncomeTax.Deduction.DebtEarningNonAssessableNonExemptForeignIncomeTotal.Amount

            Technical Business Rule Format:
            ^IDS206 = TRUE AND ^IDS207 = NULL
    
            Data Elements:
    
            RP:^IDS206 = tns:IncomeTax.Deduction.DebtEarningNonAssessableNonExemptForeignIncome.Indicator
    
            RP:^IDS207 = tns:IncomeTax.Deduction.DebtEarningNonAssessableNonExemptForeignIncomeTotal.Amount
            */
            assertion = (report.IDS206 == true && report.IDS207 == null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440304",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Interests in foreign entities information required",
                    LongDescription = @"IIf there is a 'true' response to 'Did you have any debt deductions in earning non-assessable non-exempt foreign income?' then 'Debt deductions in earning non-assessable non-exempt foreign income claimed' must be completed.",
                    Location = "/xbrli:xbrl/tns:IncomeTax.Deduction.DebtEarningNonAssessableNonExemptForeignIncome.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440129" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS206", Value = GetValueOrEmpty(report.IDS206) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS207", Value = report.IDS207.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440129

            #region VR.ATO.IDS.440130

            /*  VR.ATO.IDS.440130
            If there is an amount at 'Debt deductions in earning non-assessable non-exempt foreign income claimed under s25-90 or 230-15(3)', it must be less than or equal to the amount at 'General information - Debt deductions'.
    
            Legacy Rule Format:
            IF [IDS220] = TRUE AND [IDS207] > 0 AND ([IDS207] > [IDS226])
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS207] = IDS:RP:rvctc2.02.09:IncomeTax.Deduction.DebtEarningNonAssessableNonExemptForeignIncomeTotal.Amount
            [IDS220] = IDS:RP:bafpo6.02.15:Liabilities.ThinCapitalisation.ProvisionsApplied.Indicator
            [IDS226] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.DeductionDebt.Amount

            Technical Business Rule Format:
            ^IDS220 = TRUE AND ^IDS207 > 0 AND (^IDS207 > ^IDS226)
    
            Data Elements:
    
            RP:^IDS207 = tns:IncomeTax.Deduction.DebtEarningNonAssessableNonExemptForeignIncomeTotal.Amount
    
            RP:^IDS220 = tns:Liabilities.ThinCapitalisation.ProvisionsApplied.Indicator
    
            RP:^IDS226 = tns:Liabilities.ThinCapitalisation.DeductionDebt.Amount
            */
            assertion = (report.IDS220 == true && report.IDS207.GetValueOrDefault() > 0 && report.IDS207.GetValueOrDefault() > report.IDS226.GetValueOrDefault());
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440305",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Debt deductions incorrect",
                    LongDescription = @"If 'Debt deductions in earning non-assessable non-exempt foreign income claimed' (Interests in foreign entities) is greater than zero, and there is 'True' response to 'Did the thin capitalisation rules apply to you?' then the value must also be less than or equal to 'General information - Debt deductions' (Thin capitalisation).",
                    Location = "/xbrli:xbrl/tns:IncomeTax.Deduction.DebtEarningNonAssessableNonExemptForeignIncomeTotal.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440130" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS220", Value = GetValueOrEmpty(report.IDS220) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS207", Value = report.IDS207.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS226", Value = report.IDS226.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440130

            #region VR.ATO.IDS.440132

            /*  VR.ATO.IDS.440132
            If Interests in foreign entities information has been completed for capital gain/loss amounts or capital gain/loss reductions then the response to 'Did you have any capital gains tax (CGT) events in relation to your interest in a foreign company?' must be 'Yes'.
    
            Legacy Rule Format:
            IF ([IDS208] <> TRUE) AND ([IDS209] <> NULL OR [IDS210] <> NULL OR [IDS211] <> NULL OR [IDS212] <> NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS208] = IDS:RP:rvctc3.02.00:CapitalGainsTax.Event.Indicator
            [IDS209] = IDS:RP:rvctc3.02.10:CapitalGainsTax.ActiveForeignBusinessCapitalGains.Amount
            [IDS210] = IDS:RP:rvctc1.02.10:IncomeTax.ActiveForeignBusinessCapitalGainsReduction.Amount
            [IDS211] = IDS:RP:rvctc3.02.10:CapitalGainsTax.ActiveForeignBusinessCapitalLosses.Amount
            [IDS212] = IDS:RP:rvctc1.02.10:IncomeTax.ActiveForeignBusinessCapitalLossesReduction.Amount

            Technical Business Rule Format:
            (^IDS208 <> TRUE) AND (^IDS209 <> NULL OR ^IDS210 <> NULL OR ^IDS211 <> NULL OR ^IDS212 <> NULL)
    
            Data Elements:
    
            RP:^IDS208 = tns:CapitalGainsTax.Event.Indicator
    
            RP:^IDS209 = tns:CapitalGainsTax.ActiveForeignBusinessCapitalGains.Amount
    
            RP:^IDS210 = tns:IncomeTax.ActiveForeignBusinessCapitalGainsReduction.Amount
    
            RP:^IDS211 = tns:CapitalGainsTax.ActiveForeignBusinessCapitalLosses.Amount
    
            RP:^IDS212 = tns:IncomeTax.ActiveForeignBusinessCapitalLossesReduction.Amount
            */
            assertion = (report.IDS208 != true && (report.IDS209 != null || report.IDS210 != null || report.IDS211 != null || report.IDS212 != null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440132",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Interests in foreign entities question incorrect",
                    LongDescription = @"If Interests in foreign entities information has been completed for capital gain/loss amounts or capital gain/loss reductions then the response to 'Did you have any capital gains tax (CGT) events in relation to your interest in a foreign company?' must be 'True'",
                    Location = "/xbrli:xbrl/tns:CapitalGainsTax.Event.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440132" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS208", Value = GetValueOrEmpty(report.IDS208) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS209", Value = report.IDS209.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS210", Value = report.IDS210.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS211", Value = report.IDS211.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS212", Value = report.IDS212.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440132

            #region VR.ATO.IDS.440133

            /*  VR.ATO.IDS.440133
            If there is a 'True' response to 'Did you have any capital gains tax (CGT) events in relation to your interest in a foreign company?' then capital gain/loss amounts or capital gain/loss reductions must be completed.
    
            Legacy Rule Format:
            IF [IDS208] = TRUE AND [IDS209] = NULL AND [IDS210] = NULL AND [IDS211] = NULL AND [IDS212] = NULL
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS208] = IDS:RP:rvctc3.02.00:CapitalGainsTax.Event.Indicator
            [IDS209] = IDS:RP:rvctc3.02.10:CapitalGainsTax.ActiveForeignBusinessCapitalGains.Amount
            [IDS210] = IDS:RP:rvctc1.02.10:IncomeTax.ActiveForeignBusinessCapitalGainsReduction.Amount
            [IDS211] = IDS:RP:rvctc3.02.10:CapitalGainsTax.ActiveForeignBusinessCapitalLosses.Amount
            [IDS212] = IDS:RP:rvctc1.02.10:IncomeTax.ActiveForeignBusinessCapitalLossesReduction.Amount

            Technical Business Rule Format:
            ^IDS208 = TRUE AND ^IDS209 = NULL AND ^IDS210 = NULL AND ^IDS211 = NULL AND ^IDS212 = NULL
    
            Data Elements:
    
            RP:^IDS208 = tns:CapitalGainsTax.Event.Indicator
    
            RP:^IDS209 = tns:CapitalGainsTax.ActiveForeignBusinessCapitalGains.Amount
    
            RP:^IDS210 = tns:IncomeTax.ActiveForeignBusinessCapitalGainsReduction.Amount
    
            RP:^IDS211 = tns:CapitalGainsTax.ActiveForeignBusinessCapitalLosses.Amount
    
            RP:^IDS212 = tns:IncomeTax.ActiveForeignBusinessCapitalLossesReduction.Amount
            */
            assertion = (report.IDS208 == true && report.IDS209 == null && report.IDS210 == null && report.IDS211 == null && report.IDS212 == null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440133",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Interests in foreign entities information required",
                    LongDescription = @"If there is a 'True' response to 'Did you have any capital gains tax (CGT) events in relation to your interest in a foreign company?' then capital gain/loss amounts or capital gain/loss reductions must be completed",
                    Location = "/xbrli:xbrl/tns:CapitalGainsTax.Event.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440133" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS208", Value = GetValueOrEmpty(report.IDS208) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS209", Value = report.IDS209.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS210", Value = report.IDS210.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS211", Value = report.IDS211.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS212", Value = report.IDS212.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440133

            #region VR.ATO.IDS.440134

            /*  VR.ATO.IDS.440134
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS209] <> NULL AND [IDS209] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS209] = IDS:RP:rvctc3.02.10:CapitalGainsTax.ActiveForeignBusinessCapitalGains.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS209, 'U', 11, 0)
    
            Data Elements:
    
            RP:^IDS209 = tns:CapitalGainsTax.ActiveForeignBusinessCapitalGains.Amount
            */
            assertion = NotMonetary(report.IDS209, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:CapitalGainsTax.ActiveForeignBusinessCapitalGains.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440134" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS209", Value = report.IDS209.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440134

            #region VR.ATO.IDS.440135

            /*  VR.ATO.IDS.440135
            If there is an amount at 'Did you have any capital gains tax (CGT) events in relation to your interest in a foreign company? - Capital gain reductions' it must be less than or equal to the amount at 'Did you have any capital gains tax (CGT) events in relation to your interest in a foreign company? - Capital gain amounts'.
    
            Legacy Rule Format:
            IF [IDS210] > 0 AND [IDS210] > [IDS209]
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS209] = IDS:RP:rvctc3.02.10:CapitalGainsTax.ActiveForeignBusinessCapitalGains.Amount
            [IDS210] = IDS:RP:rvctc1.02.10:IncomeTax.ActiveForeignBusinessCapitalGainsReduction.Amount

            Technical Business Rule Format:
            ^IDS210 > 0 AND ^IDS210 > ^IDS209
    
            Data Elements:
    
            RP:^IDS210 = tns:IncomeTax.ActiveForeignBusinessCapitalGainsReduction.Amount
    
            RP:^IDS209 = tns:CapitalGainsTax.ActiveForeignBusinessCapitalGains.Amount
            */
            assertion = (report.IDS210.GetValueOrDefault() > 0 && report.IDS210.GetValueOrDefault() > report.IDS209.GetValueOrDefault());
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440135",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Capital gains reductions must not be greater than the Capital gains amounts",
                    LongDescription = @"If interests in foreign entities information has been completed for capital gains tax events, then the capital gains reductions must not be greater than the capital gains amounts",
                    Location = "/xbrli:xbrl/tns:IncomeTax.ActiveForeignBusinessCapitalGainsReduction.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440135" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS210", Value = report.IDS210.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS209", Value = report.IDS209.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440135

            #region VR.ATO.IDS.440136

            /*  VR.ATO.IDS.440136
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS210] <> NULL AND [IDS210] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS210] = IDS:RP:rvctc1.02.10:IncomeTax.ActiveForeignBusinessCapitalGainsReduction.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS210, 'U', 11, 0)
    
            Data Elements:
    
            RP:^IDS210 = tns:IncomeTax.ActiveForeignBusinessCapitalGainsReduction.Amount
            */
            assertion = NotMonetary(report.IDS210, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:IncomeTax.ActiveForeignBusinessCapitalGainsReduction.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440136" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS210", Value = report.IDS210.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440136

            #region VR.ATO.IDS.440137

            /*  VR.ATO.IDS.440137
            If there is an amount at 'Did you have any capital gains tax (CGT) events in relation to your interest in a foreign company? - Capital loss reductions' it must be less than or equal to the amount at 'Did you have any capital gains tax (CGT) events in relation to your interest in a foreign company? - Capital loss amounts'.
    
            Legacy Rule Format:
            IF [IDS212] > 0 AND [IDS212] > [IDS211]
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS211] = IDS:RP:rvctc3.02.10:CapitalGainsTax.ActiveForeignBusinessCapitalLosses.Amount
            [IDS212] = IDS:RP:rvctc1.02.10:IncomeTax.ActiveForeignBusinessCapitalLossesReduction.Amount

            Technical Business Rule Format:
            ^IDS212 > 0 AND ^IDS212 > ^IDS211
    
            Data Elements:
    
            RP:^IDS211 = tns:CapitalGainsTax.ActiveForeignBusinessCapitalLosses.Amount
    
            RP:^IDS212 = tns:IncomeTax.ActiveForeignBusinessCapitalLossesReduction.Amount
            */
            assertion = (report.IDS212.GetValueOrDefault() > 0 && report.IDS212.GetValueOrDefault() > report.IDS211.GetValueOrDefault());
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440137",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Capital loss reductions must not be greater than the Capital loss amounts",
                    LongDescription = @"If interests in foreign entities information has been completed for capital gains tax events, then the capital loss reductions must not be greater than the capital loss amounts",
                    Location = "/xbrli:xbrl/tns:CapitalGainsTax.ActiveForeignBusinessCapitalLosses.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440137" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS212", Value = report.IDS212.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS211", Value = report.IDS211.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440137

            #region VR.ATO.IDS.440138

            /*  VR.ATO.IDS.440138
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS211] <> NULL AND [IDS211] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS211] = IDS:RP:rvctc3.02.10:CapitalGainsTax.ActiveForeignBusinessCapitalLosses.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS211, 'U', 11, 0)
    
            Data Elements:
    
            RP:^IDS211 = tns:CapitalGainsTax.ActiveForeignBusinessCapitalLosses.Amount
            */
            assertion = NotMonetary(report.IDS211, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:CapitalGainsTax.ActiveForeignBusinessCapitalLosses.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440138" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS211", Value = report.IDS211.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440138

            #region VR.ATO.IDS.440139

            /*  VR.ATO.IDS.440139
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS212] <> NULL AND [IDS212] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS212] = IDS:RP:rvctc1.02.10:IncomeTax.ActiveForeignBusinessCapitalLossesReduction.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS212, 'U', 11, 0)
    
            Data Elements:
    
            RP:^IDS212 = tns:IncomeTax.ActiveForeignBusinessCapitalLossesReduction.Amount
            */
            assertion = NotMonetary(report.IDS212, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:IncomeTax.ActiveForeignBusinessCapitalLossesReduction.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440139" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS212", Value = report.IDS212.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440139

            #region VR.ATO.IDS.440141

            /*  VR.ATO.IDS.440141
            If Interests in foreign entities information has been completed for FHLPs or FHCs then the response to 'Were you a partner in a foreign hybrid limited partnership (FHLP) or shareholder in a foreign hybrid company (FHC)?' must be 'Yes'.
    
            Legacy Rule Format:
            IF ([IDS217] <> TRUE) AND ([IDS218] <> NULL OR [IDS219] <> NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS217] = IDS:RP:bafot.02.11:Miscellaneous.ForeignHybridLimitedPartnershipOrForeignHybridCompanyShareholder.Indicator
            [IDS218] = IDS:RP:bafot.02.11:Miscellaneous.ForeignHybridLimitedPartnershipOrForeignHybridCompanyInterestIn.Count
            [IDS219] = IDS:RP:bafpo7.02.11:Assets.Investment.ForeignHybridLimitedPartnershipOrForeignHybridCompanyNetIncomeProfitTotal.Amount

            Technical Business Rule Format:
            (^IDS217 <> TRUE) AND (^IDS218 <> NULL OR ^IDS219 <> NULL)
    
            Data Elements:
    
            RP:^IDS217 = tns:Miscellaneous.ForeignHybridLimitedPartnershipOrForeignHybridCompanyShareholder.Indicator
    
            RP:^IDS218 = tns:Miscellaneous.ForeignHybridLimitedPartnershipOrForeignHybridCompanyInterestIn.Count
    
            RP:^IDS219 = tns:Assets.Investment.ForeignHybridLimitedPartnershipOrForeignHybridCompanyNetIncomeProfitTotal.Amount
            */
            assertion = (report.IDS217 != true && (report.IDS218 != null || report.IDS219 != null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440141",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Interests in foreign entities question incorrect",
                    LongDescription = @"If Interests in foreign entities information has been completed for FHLPs or FHCs then the response to 'Were you a partner in a foreign hybrid limited partnership (FHLP) or shareholder in a foreign hybrid company (FHC)?' must be 'True'",
                    Location = "/xbrli:xbrl/tns:Miscellaneous.ForeignHybridLimitedPartnershipOrForeignHybridCompanyShareholder.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440141" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS217", Value = GetValueOrEmpty(report.IDS217) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS218", Value = report.IDS218.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS219", Value = report.IDS219.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440141

            #region VR.ATO.IDS.440142

            /*  VR.ATO.IDS.440142
            If there is a 'Yes' response to 'Were you a partner in a foreign hybrid limited partnership (FHLP) or shareholder in a foreign hybrid company (FHC)?' then both the number of FHLPs or FHCs you had an interest in and the total amount of your share of net income/distribution of profit must be completed.
    
            Legacy Rule Format:
            IF [IDS217] = TRUE AND ([IDS218] = NULL OR [IDS219] = NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS217] = IDS:RP:bafot.02.11:Miscellaneous.ForeignHybridLimitedPartnershipOrForeignHybridCompanyShareholder.Indicator
            [IDS218] = IDS:RP:bafot.02.11:Miscellaneous.ForeignHybridLimitedPartnershipOrForeignHybridCompanyInterestIn.Count
            [IDS219] = IDS:RP:bafpo7.02.11:Assets.Investment.ForeignHybridLimitedPartnershipOrForeignHybridCompanyNetIncomeProfitTotal.Amount

            Technical Business Rule Format:
            ^IDS217 = TRUE AND (^IDS218 = NULL OR ^IDS219 = NULL)
    
            Data Elements:
    
            RP:^IDS217 = tns:Miscellaneous.ForeignHybridLimitedPartnershipOrForeignHybridCompanyShareholder.Indicator
    
            RP:^IDS218 = tns:Miscellaneous.ForeignHybridLimitedPartnershipOrForeignHybridCompanyInterestIn.Count
    
            RP:^IDS219 = tns:Assets.Investment.ForeignHybridLimitedPartnershipOrForeignHybridCompanyNetIncomeProfitTotal.Amount
            */
            assertion = (report.IDS217 == true && (report.IDS218 == null || report.IDS219 == null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440142",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"FHLP/FHC information incomplete",
                    LongDescription = @"If there is a 'True' response to 'Were you a partner in a foreign hybrid limited partnership (FHLP) or shareholder in a foreign hybrid company (FHC)?' then both the number of FHLPs or FHCs you had an interest in and the total amount of your share of net income/distribution of profit must be completed",
                    Location = "/xbrli:xbrl/tns:Miscellaneous.ForeignHybridLimitedPartnershipOrForeignHybridCompanyShareholder.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440142" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS217", Value = GetValueOrEmpty(report.IDS217) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS218", Value = report.IDS218.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS219", Value = report.IDS219.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440142

            #region VR.ATO.IDS.440143

            /*  VR.ATO.IDS.440143
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS219] <> NULL AND [IDS219] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS219] = IDS:RP:bafpo7.02.11:Assets.Investment.ForeignHybridLimitedPartnershipOrForeignHybridCompanyNetIncomeProfitTotal.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS219, 'U', 11, 0)
    
            Data Elements:
    
            RP:^IDS219 = tns:Assets.Investment.ForeignHybridLimitedPartnershipOrForeignHybridCompanyNetIncomeProfitTotal.Amount
            */
            assertion = NotMonetary(report.IDS219, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Assets.Investment.ForeignHybridLimitedPartnershipOrForeignHybridCompanyNetIncomeProfitTotal.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440143" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS219", Value = report.IDS219.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440143

            #region VR.ATO.IDS.440144

            /*  VR.ATO.IDS.440144
            If there is a 'False' response to 'Did the thin capitalisation rules affect you?' then no information should be entered into Section D - Thin capitalisation of the schedule.
    
            Legacy Rule Format:
            IF [IDS220] = FALSE AND ([IDS221] <> NULL OR [IDS223] <> NULL OR [IDS224] <> NULL OR [IDS225] <> NULL OR [IDS226] <> NULL OR [IDS227] <> NULL OR [IDS228] <> NULL OR [IDS229] <> NULL OR [IDS230] <> NULL OR [IDS241] <> NULL OR [IDS255] <> NULL OR [IDS257] <> NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS220] = IDS:RP:bafpo6.02.15:Liabilities.ThinCapitalisation.ProvisionsApplied.Indicator
            [IDS221] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.AustralianResidentCompanyElected.Indicator
            [IDS223] = IDS:RP:bafpo6.02.13:Liabilities.ThinCapitalisation.EntityType.Code
            [IDS224] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.GeneralToFinancialStatusChange.Indicator
            [IDS225] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.AveragingMethodAdopted.Code
            [IDS226] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.DeductionDebt.Amount
            [IDS227] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.RelatedNonResidentsDebtDeduction.Amount
            [IDS228] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.DeductionDebtDisallowed.Amount
            [IDS229] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.DebtAdjustedAverage.Amount
            [IDS230] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.AuthorisedDepositTakingInstitution.Indicator
            [IDS241] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.NonAuthorisedDepositTakingInstitution.Indicator
            [IDS255] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.ArmsLengthTests.Indicator
            [IDS257] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.GearingDebtCapitalTest.Indicator

            Technical Business Rule Format:
            ^IDS220 = FALSE AND (^IDS221 <> NULL OR ^IDS223 <> NULL OR ^IDS224 <> NULL OR ^IDS225 <> NULL OR ^IDS226 <> NULL OR ^IDS227 <> NULL OR ^IDS228 <> NULL OR ^IDS229 <> NULL OR ^IDS230 <> NULL OR ^IDS241 <> NULL OR ^IDS255 <> NULL OR ^IDS257 <> NULL)
    
            Data Elements:
    
            RP:^IDS220 = tns:Liabilities.ThinCapitalisation.ProvisionsApplied.Indicator
    
            RP:^IDS221 = tns:Liabilities.ThinCapitalisation.AustralianResidentCompanyElected.Indicator
    
            RP:^IDS223 = tns:Liabilities.ThinCapitalisation.EntityType.Code
    
            RP:^IDS224 = tns:Liabilities.ThinCapitalisation.GeneralToFinancialStatusChange.Indicator
    
            RP:^IDS225 = tns:Liabilities.ThinCapitalisation.AveragingMethodAdopted.Code
    
            RP:^IDS226 = tns:Liabilities.ThinCapitalisation.DeductionDebt.Amount
    
            RP:^IDS227 = tns:Liabilities.ThinCapitalisation.RelatedNonResidentsDebtDeduction.Amount
    
            RP:^IDS228 = tns:Liabilities.ThinCapitalisation.DeductionDebtDisallowed.Amount
    
            RP:^IDS229 = tns:Liabilities.ThinCapitalisation.DebtAdjustedAverage.Amount
    
            RP:^IDS230 = tns:Liabilities.ThinCapitalisation.AuthorisedDepositTakingInstitution.Indicator
    
            RP:^IDS241 = tns:Liabilities.ThinCapitalisation.NonAuthorisedDepositTakingInstitution.Indicator
    
            RP:^IDS255 = tns:Liabilities.ThinCapitalisation.ArmsLengthTests.Indicator
    
            RP:^IDS257 = tns:Liabilities.ThinCapitalisation.GearingDebtCapitalTest.Indicator
            */
            assertion = (report.IDS220 == false && (report.IDS221 != null || report.IDS223 != null || report.IDS224 != null || report.IDS225 != null || report.IDS226 != null || report.IDS227 != null || report.IDS228 != null || report.IDS229 != null || report.IDS230 != null || report.IDS241 != null || report.IDS255 != null || report.IDS257 != null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440144",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Thin capitalisation information not required",
                    LongDescription = @"If there is a 'False' response to 'Did the thin capitalisation rules affect you?' then thin capitalisation information should not be entered in the schedule.",
                    Location = "/xbrli:xbrl/tns:Liabilities.ThinCapitalisation.ProvisionsApplied.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440144" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS220", Value = GetValueOrEmpty(report.IDS220) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS221", Value = GetValueOrEmpty(report.IDS221) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS223", Value = report.IDS223 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS224", Value = GetValueOrEmpty(report.IDS224) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS225", Value = report.IDS225 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS226", Value = report.IDS226.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS227", Value = report.IDS227.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS228", Value = report.IDS228.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS229", Value = report.IDS229.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS230", Value = GetValueOrEmpty(report.IDS230) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS241", Value = GetValueOrEmpty(report.IDS241) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS255", Value = GetValueOrEmpty(report.IDS255) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS257", Value = GetValueOrEmpty(report.IDS257) });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440144

            #region VR.ATO.IDS.440145

            /*  VR.ATO.IDS.440145
            If there is a 'True' response to 'Did the thin capitalisation rules apply to you?' then a response must be entered for 'Has an Australian resident company elected under subdivision 820-FB of the ITAA 1997 to treat your qualifying Australian branch operations as part of a consolidated group, MEC group or a single company for thin capitalisation purposes?'.
    
            Legacy Rule Format:
            IF [IDS220] = TRUE AND [IDS221] = NULL
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS220] = IDS:RP:bafpo6.02.15:Liabilities.ThinCapitalisation.ProvisionsApplied.Indicator
            [IDS221] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.AustralianResidentCompanyElected.Indicator

            Technical Business Rule Format:
            ^IDS220 = TRUE AND ^IDS221 = NULL
    
            Data Elements:
    
            RP:^IDS220 = tns:Liabilities.ThinCapitalisation.ProvisionsApplied.Indicator
    
            RP:^IDS221 = tns:Liabilities.ThinCapitalisation.AustralianResidentCompanyElected.Indicator
            */
            assertion = (report.IDS220 == true && report.IDS221 == null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440145",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Thin capitalisation information required",
                    LongDescription = @"If there is a 'True' response to 'Did the thin capitalisation rules apply to you?' then a response must be entered for 'Has an Australian resident company elected under subdivision 820-FB of the ITAA 1997 to treat your qualifying Australian branch operations as part of a consolidated group, MEC group or a single company for thin capitalisation purposes?'.",
                    Location = "/xbrli:xbrl/tns:Liabilities.ThinCapitalisation.ProvisionsApplied.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440145" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS220", Value = GetValueOrEmpty(report.IDS220) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS221", Value = GetValueOrEmpty(report.IDS221) });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440145

            #region VR.ATO.IDS.440146

            /*  VR.ATO.IDS.440146
            This field is Mandatory - must be completed
    
            Legacy Rule Format:
            IF [IDS220] = NULL
            RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS220] = IDS:RP:bafpo6.02.15:Liabilities.ThinCapitalisation.ProvisionsApplied.Indicator

            Technical Business Rule Format:
            ^IDS220 = NULL
    
            Data Elements:
    
            RP:^IDS220 = tns:Liabilities.ThinCapitalisation.ProvisionsApplied.Indicator
            */
            assertion = (report.IDS220 == null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001001",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Mandatory field not supplied",
                    Location = "/xbrli:xbrl/tns:Liabilities.ThinCapitalisation.ProvisionsApplied.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440146" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS220", Value = GetValueOrEmpty(report.IDS220) });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440146

            #region VR.ATO.IDS.440147

            /*  VR.ATO.IDS.440147
            If there is a 'No' response to 'Has an Australian resident company elected under subdivision 820-FB of the ITAA 1997 to treat your qualifying Australian branch operations as part of a consolidated group, MEC group or a single company for thin capitalisation purposes?' then the Australian Business Number (ABN) should not be completed and all subsequent questions in Section D should be completed.
    
            Legacy Rule Format:
            IF [IDS221] = FALSE AND ([IDS222] <> NULL OR ([IDS223] = NULL OR [IDS224] = NULL OR [IDS225] = NULL OR [IDS230] = NULL OR [IDS241] = NULL OR [IDS255] = NULL OR [IDS257] = NULL) OR ([IDS226] = NULL OR [IDS227] = NULL OR [IDS228] = NULL OR [IDS229] = NULL))
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS221] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.AustralianResidentCompanyElected.Indicator
            [IDS222] = IDS:RP:pyid.02.00:Identifiers.AustralianBusinessNumber.Identifier
            [IDS223] = IDS:RP:bafpo6.02.13:Liabilities.ThinCapitalisation.EntityType.Code
            [IDS224] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.GeneralToFinancialStatusChange.Indicator
            [IDS225] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.AveragingMethodAdopted.Code
            [IDS226] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.DeductionDebt.Amount
            [IDS227] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.RelatedNonResidentsDebtDeduction.Amount
            [IDS228] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.DeductionDebtDisallowed.Amount
            [IDS229] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.DebtAdjustedAverage.Amount
            [IDS230] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.AuthorisedDepositTakingInstitution.Indicator
            [IDS241] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.NonAuthorisedDepositTakingInstitution.Indicator
            [IDS255] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.ArmsLengthTests.Indicator
            [IDS257] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.GearingDebtCapitalTest.Indicator

            Technical Business Rule Format:
            ^IDS221 = FALSE AND (^IDS222 <> NULL OR (^IDS223 = NULL OR ^IDS224 = NULL OR ^IDS225 = NULL OR ^IDS230 = NULL OR ^IDS241 = NULL OR ^IDS255 = NULL OR ^IDS257 = NULL) OR (^IDS226 = NULL OR ^IDS227 = NULL OR ^IDS228 = NULL OR ^IDS229 = NULL))
    
            Data Elements:
    
            RP:^IDS221 = tns:Liabilities.ThinCapitalisation.AustralianResidentCompanyElected.Indicator
    
            RP:^IDS222 = tns:Identifiers.AustralianBusinessNumber.Identifier
    
            RP:^IDS223 = tns:Liabilities.ThinCapitalisation.EntityType.Code
    
            RP:^IDS224 = tns:Liabilities.ThinCapitalisation.GeneralToFinancialStatusChange.Indicator
    
            RP:^IDS225 = tns:Liabilities.ThinCapitalisation.AveragingMethodAdopted.Code
    
            RP:^IDS226 = tns:Liabilities.ThinCapitalisation.DeductionDebt.Amount
    
            RP:^IDS227 = tns:Liabilities.ThinCapitalisation.RelatedNonResidentsDebtDeduction.Amount
    
            RP:^IDS228 = tns:Liabilities.ThinCapitalisation.DeductionDebtDisallowed.Amount
    
            RP:^IDS229 = tns:Liabilities.ThinCapitalisation.DebtAdjustedAverage.Amount
    
            RP:^IDS230 = tns:Liabilities.ThinCapitalisation.AuthorisedDepositTakingInstitution.Indicator
    
            RP:^IDS241 = tns:Liabilities.ThinCapitalisation.NonAuthorisedDepositTakingInstitution.Indicator
    
            RP:^IDS255 = tns:Liabilities.ThinCapitalisation.ArmsLengthTests.Indicator
    
            RP:^IDS257 = tns:Liabilities.ThinCapitalisation.GearingDebtCapitalTest.Indicator
            */
            assertion = (report.IDS221 == false && (report.IDS222 != null || (report.IDS223 == null || report.IDS224 == null || report.IDS225 == null || report.IDS230 == null || report.IDS241 == null || report.IDS255 == null || report.IDS257 == null) || (report.IDS226 == null || report.IDS227 == null || report.IDS228 == null || report.IDS229 == null)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440147",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Thin capitalisation information required",
                    LongDescription = @"If there is a 'False' response to 'Has an Australian resident company elected under subdivision 820-FB of the ITAA 1997 to treat your qualifying Australian branch operations as part of a consolidated group, MEC group or a single company for thin capitalisation purposes?' then the Australian Business Number (ABN) should not be completed and all subsequent Thin capitalisation questions should be completed",
                    Location = "/xbrli:xbrl/tns:Liabilities.ThinCapitalisation.AustralianResidentCompanyElected.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440147" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS221", Value = GetValueOrEmpty(report.IDS221) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS222", Value = report.IDS222 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS223", Value = report.IDS223 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS224", Value = GetValueOrEmpty(report.IDS224) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS225", Value = report.IDS225 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS230", Value = GetValueOrEmpty(report.IDS230) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS241", Value = GetValueOrEmpty(report.IDS241) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS255", Value = GetValueOrEmpty(report.IDS255) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS257", Value = GetValueOrEmpty(report.IDS257) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS226", Value = report.IDS226.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS227", Value = report.IDS227.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS228", Value = report.IDS228.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS229", Value = report.IDS229.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440147

            #region VR.ATO.IDS.440148

            /*  VR.ATO.IDS.440148
            If there is a 'Yes' response to 'Has an Australian resident company elected under subdivision 820-FB of the ITAA 1997 to treat your qualifying Australian branch operations as part of a consolidated group, MEC group or a single company for thin capitalisation purposes?' then the Australian Business Number (ABN) should be completed and all subsequent questions in Section D - Thin capitalisation should not be completed.
    
            Legacy Rule Format:
            IF [IDS221] = TRUE AND ([IDS222] = NULL OR ([IDS223] <> NULL OR [IDS224] <> NULL OR [IDS225] <> NULL OR [IDS226] <> NULL OR [IDS227] <> NULL OR [IDS228] <> NULL OR [IDS229] <> NULL OR [IDS230] <> NULL OR [IDS241] <> NULL OR [IDS255] <> NULL OR [IDS257] <> NULL))
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS221] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.AustralianResidentCompanyElected.Indicator
            [IDS222] = IDS:RP:pyid.02.00:Identifiers.AustralianBusinessNumber.Identifier
            [IDS223] = IDS:RP:bafpo6.02.13:Liabilities.ThinCapitalisation.EntityType.Code
            [IDS224] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.GeneralToFinancialStatusChange.Indicator
            [IDS225] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.AveragingMethodAdopted.Code
            [IDS226] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.DeductionDebt.Amount
            [IDS227] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.RelatedNonResidentsDebtDeduction.Amount
            [IDS228] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.DeductionDebtDisallowed.Amount
            [IDS229] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.DebtAdjustedAverage.Amount
            [IDS230] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.AuthorisedDepositTakingInstitution.Indicator
            [IDS241] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.NonAuthorisedDepositTakingInstitution.Indicator
            [IDS255] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.ArmsLengthTests.Indicator
            [IDS257] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.GearingDebtCapitalTest.Indicator

            Technical Business Rule Format:
            ^IDS221 = TRUE AND (^IDS222 = NULL OR (^IDS223 <> NULL OR ^IDS224 <> NULL OR ^IDS225 <> NULL OR ^IDS226 <> NULL OR ^IDS227 <> NULL OR ^IDS228 <> NULL OR ^IDS229 <> NULL OR ^IDS230 <> NULL OR ^IDS241 <> NULL OR ^IDS255 <> NULL OR ^IDS257 <> NULL))
    
            Data Elements:
    
            RP:^IDS221 = tns:Liabilities.ThinCapitalisation.AustralianResidentCompanyElected.Indicator
    
            RP:^IDS222 = tns:Identifiers.AustralianBusinessNumber.Identifier
    
            RP:^IDS223 = tns:Liabilities.ThinCapitalisation.EntityType.Code
    
            RP:^IDS224 = tns:Liabilities.ThinCapitalisation.GeneralToFinancialStatusChange.Indicator
    
            RP:^IDS225 = tns:Liabilities.ThinCapitalisation.AveragingMethodAdopted.Code
    
            RP:^IDS226 = tns:Liabilities.ThinCapitalisation.DeductionDebt.Amount
    
            RP:^IDS227 = tns:Liabilities.ThinCapitalisation.RelatedNonResidentsDebtDeduction.Amount
    
            RP:^IDS228 = tns:Liabilities.ThinCapitalisation.DeductionDebtDisallowed.Amount
    
            RP:^IDS229 = tns:Liabilities.ThinCapitalisation.DebtAdjustedAverage.Amount
    
            RP:^IDS230 = tns:Liabilities.ThinCapitalisation.AuthorisedDepositTakingInstitution.Indicator
    
            RP:^IDS241 = tns:Liabilities.ThinCapitalisation.NonAuthorisedDepositTakingInstitution.Indicator
    
            RP:^IDS255 = tns:Liabilities.ThinCapitalisation.ArmsLengthTests.Indicator
    
            RP:^IDS257 = tns:Liabilities.ThinCapitalisation.GearingDebtCapitalTest.Indicator
            */
            assertion = (report.IDS221 == true && (report.IDS222 == null || (report.IDS223 != null || report.IDS224 != null || report.IDS225 != null || report.IDS226 != null || report.IDS227 != null || report.IDS228 != null || report.IDS229 != null || report.IDS230 != null || report.IDS241 != null || report.IDS255 != null || report.IDS257 != null)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440148",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Thin capitalisation information not required",
                    LongDescription = @"If there is a 'True' response to 'Has an Australian resident company elected under subdivision 820-FB of the ITAA 1997 to treat your qualifying Australian branch operations as part of a consolidated group, MEC group or a single company for thin capitalisation purposes?' then the Australian Business Number (ABN) should be completed and all subsequent Thin capitalisation questions should not be completed",
                    Location = "/xbrli:xbrl/tns:Liabilities.ThinCapitalisation.AustralianResidentCompanyElected.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440148" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS221", Value = GetValueOrEmpty(report.IDS221) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS222", Value = report.IDS222 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS223", Value = report.IDS223 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS224", Value = GetValueOrEmpty(report.IDS224) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS225", Value = report.IDS225 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS226", Value = report.IDS226.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS227", Value = report.IDS227.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS228", Value = report.IDS228.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS229", Value = report.IDS229.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS230", Value = GetValueOrEmpty(report.IDS230) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS241", Value = GetValueOrEmpty(report.IDS241) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS255", Value = GetValueOrEmpty(report.IDS255) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS257", Value = GetValueOrEmpty(report.IDS257) });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440148

            #region VR.ATO.IDS.440149

            /*  VR.ATO.IDS.440149
            If the (Adjusted) average equity capital is greater than zero, the entity type at the end of the income year must be 7 or 8.
    
            Legacy Rule Format:
            IF ([IDS231] > 0) AND [IDS223] <> SET ("7","8")
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS223] = IDS:RP:bafpo6.02.13:Liabilities.ThinCapitalisation.EntityType.Code
            [IDS231] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.EquityCapitalAdjustedAverage.Amount

            Technical Business Rule Format:
            (^IDS231 > 0) AND NotInSet(^IDS223, '"7","8"')
    
            Data Elements:
    
            RP:^IDS223 = tns:Liabilities.ThinCapitalisation.EntityType.Code
    
            RP:^IDS231 = tns:Liabilities.ThinCapitalisation.EquityCapitalAdjustedAverage.Amount
            */
            assertion = (report.IDS231.GetValueOrDefault() > 0 && !(IsMatch(report.IDS223, @"^(7|8)$", RegexOptions.IgnoreCase)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440149",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity Type code must be 7 or 8",
                    LongDescription = @"If there are amounts greater than zero for '(Adjusted) average equity capital', then the entity type at the end of the income year must be 7 = Outward or 8 = Inward",
                    Location = "/xbrli:xbrl/tns:Liabilities.ThinCapitalisation.EntityType.Code",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440149" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS231", Value = report.IDS231.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS223", Value = report.IDS223 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440149

            #region VR.ATO.IDS.440150

            /*  VR.ATO.IDS.440150
            If there is an amount greater than zero at 'Outward investing ADI - Equity capital attributable to overseas permanent establishment(s)',  and/or  'Outward investing ADI - Average value of controlled foreign entity equity' and /or 'Outward investing ADI - Tier 1 prudential capital deductions', the code at 'What was your entity type at the end of the income year', must be 7.  Please insert the correct code or delete the amount(s) at outward investing ADI.
    
            Legacy Rule Format:
            IF ([IDS235] > 0 OR [IDS237] > 0 OR [IDS238] > 0) AND ([IDS223] <> "7")
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS223] = IDS:RP:bafpo6.02.13:Liabilities.ThinCapitalisation.EntityType.Code
            [IDS235] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.EquityCapitalAttributableToOverseasPermanentEstablishments.Amount
            [IDS237] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.ControlledForeignADIEntityEquityAverageValue.Amount
            [IDS238] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.Tier1PrudentialCapitalDeduction.Amount

            Technical Business Rule Format:
            (^IDS235 > 0 OR ^IDS237 > 0 OR ^IDS238 > 0) AND (^IDS223 <> '7')
    
            Data Elements:
    
            RP:^IDS223 = tns:Liabilities.ThinCapitalisation.EntityType.Code
    
            RP:^IDS235 = tns:Liabilities.ThinCapitalisation.EquityCapitalAttributableToOverseasPermanentEstablishments.Amount
    
            RP:^IDS237 = tns:Liabilities.ThinCapitalisation.ControlledForeignADIEntityEquityAverageValue.Amount
    
            RP:^IDS238 = tns:Liabilities.ThinCapitalisation.Tier1PrudentialCapitalDeduction.Amount
            */
            assertion = ((report.IDS235.GetValueOrDefault() > 0 || report.IDS237.GetValueOrDefault() > 0 || report.IDS238.GetValueOrDefault() > 0) && report.IDS223 != @"7");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440150",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Incorrect entity type code for an ADI entity, Entity Type code must be 7",
                    LongDescription = @"If there are amounts greater than zero for Outward investing ADI at 'Equity capital attributable to overseas permanent establishment(s)' or 'Average value of controlled foreign entity equity' or 'Tier 1 prudential capital deductions', then the entity type at the end of the income year must be 7 = Outward",
                    Location = "/xbrli:xbrl/tns:Liabilities.ThinCapitalisation.EntityType.Code",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440150" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS235", Value = report.IDS235.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS237", Value = report.IDS237.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS238", Value = report.IDS238.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS223", Value = report.IDS223 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440150

            #region VR.ATO.IDS.440151

            /*  VR.ATO.IDS.440151
            If amount(s) greater than zero are present at 'Inward investing ADI - Average of risk weighted assets attributable to Australian permanent establishment(s), and/or 'Inward investing ADI - Average value of dotation capital', then the code at 'What was your enitty type at the end of the income year' must be '8'. Please insert the correct code or delete the amount(s) at Inward investing ADI.
    
            Legacy Rule Format:
            IF ([IDS239] > 0 OR [IDS240] > 0) AND ([IDS223] <> "8")
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS223] = IDS:RP:bafpo6.02.13:Liabilities.ThinCapitalisation.EntityType.Code
            [IDS239] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.RiskWeightedAssetsAttributableToAustralianPermanentEstablishmentsAverage.Amount
            [IDS240] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.DotationCapitalAverageValue.Amount

            Technical Business Rule Format:
            (^IDS239 > 0 OR ^IDS240 > 0) AND (^IDS223 <> '8')
    
            Data Elements:
    
            RP:^IDS223 = tns:Liabilities.ThinCapitalisation.EntityType.Code
    
            RP:^IDS239 = tns:Capital.ThinCapitalisation.RiskWeightedAssetsAttributableToAustralianPermanentEstablishmentsAverage.Amount
    
            RP:^IDS240 = tns:Capital.ThinCapitalisation.DotationCapitalAverageValue.Amount
            */
            assertion = ((report.IDS239.GetValueOrDefault() > 0 || report.IDS240.GetValueOrDefault() > 0) && report.IDS223 != @"8");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440151",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity Type code must be 8",
                    LongDescription = @"If there are amounts greater than zero for Inward investing ADI at 'Average of risk weighted assets attributable to Australian permanent establishment(s)' or 'Average value of dotation capital', then the entity type at the end of the income year must be 8 = Inward",
                    Location = "/xbrli:xbrl/tns:Liabilities.ThinCapitalisation.EntityType.Code",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440151" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS239", Value = report.IDS239.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS240", Value = report.IDS240.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS223", Value = report.IDS223 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440151

            #region VR.ATO.IDS.440152

            /*  VR.ATO.IDS.440152
            If there are amounts greater than zero for All non-ADI entities at any of 'Average value of: assets, non-debt liabilities, associate entity debt, associate entity equity, associate entity excess amount' then the entity type at the end of the income year must be 1, 2, 3, 4, 5, 6, 9 or 10.
    
            Legacy Rule Format:
            IF ([IDS242] > 0 OR [IDS246] > 0 OR [IDS247] > 0 OR [IDS248] > 0 OR [IDS249] > 0) AND ([IDS223] <> SET("1","2","3","4","5","6","9","10"))
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS223] = IDS:RP:bafpo6.02.13:Liabilities.ThinCapitalisation.EntityType.Code
            [IDS242] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.AssetsValueAverage.Amount
            [IDS246] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.NonDebtLiabilitiesAverageValue.Amount
            [IDS247] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.AssociateEntityDebtAverageValue.Amount
            [IDS248] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.AssociateEntityEquityAverageValue.Amount
            [IDS249] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.AssociateEntityExcessAverageValue.Amount

            Technical Business Rule Format:
            (^IDS242 > 0 OR ^IDS246 > 0 OR ^IDS247 > 0 OR ^IDS248 > 0 OR ^IDS249 > 0) AND (NotInSet(^IDS223, '"1","2","3","4","5","6","9","10"'))
    
            Data Elements:
    
            RP:^IDS223 = tns:Liabilities.ThinCapitalisation.EntityType.Code
    
            RP:^IDS242 = tns:Capital.ThinCapitalisation.AssetsValueAverage.Amount
    
            RP:^IDS246 = tns:Liabilities.ThinCapitalisation.NonDebtLiabilitiesAverageValue.Amount
    
            RP:^IDS247 = tns:Liabilities.ThinCapitalisation.AssociateEntityDebtAverageValue.Amount
    
            RP:^IDS248 = tns:Capital.ThinCapitalisation.AssociateEntityEquityAverageValue.Amount
    
            RP:^IDS249 = tns:Liabilities.ThinCapitalisation.AssociateEntityExcessAverageValue.Amount
            */
            assertion = ((report.IDS242.GetValueOrDefault() > 0 || report.IDS246.GetValueOrDefault() > 0 || report.IDS247.GetValueOrDefault() > 0 || report.IDS248.GetValueOrDefault() > 0 || report.IDS249.GetValueOrDefault() > 0) && !(IsMatch(report.IDS223, @"^(1|2|3|4|5|6|9|10)$", RegexOptions.IgnoreCase)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440152",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity Type code must be must be 1, 2, 3, 4, 5, 6, 9 or 10",
                    LongDescription = @"If there are amounts greater than zero for All non-ADI entities at any of 'Average value of: assets, non-debt liabilities, associate entity debt, associate entity equity, associate entity excess amount' then the entity type at the end of the income year must be 1 = Outward investor (general), 2 = Outward investor (financial), 3 = Inward investment vehicle (general), 4 = Inward investment vehicle (financial), 5 = Inward investor (general) or 6 = Inward investor (financial), 9 = Outward investor (general) under subsection 820-85(2) and inward investment vehicle (general) under subsection 820-185(2), 10 = Outward investor (financial) under subsection 820-85(2) and inward investment vehicle (financial) under subsection 820-185(2)",
                    Location = "/xbrli:xbrl/tns:Liabilities.ThinCapitalisation.EntityType.Code",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440152" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS242", Value = report.IDS242.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS246", Value = report.IDS246.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS247", Value = report.IDS247.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS248", Value = report.IDS248.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS249", Value = report.IDS249.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS223", Value = report.IDS223 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440152

            #region VR.ATO.IDS.440153

            /*  VR.ATO.IDS.440153
            If the Average zero capital amount and/or Average on-lent amount are greater than zero, the entity type at the end of the income year must be 2, 4, 6 or 10.
    
            Legacy Rule Format:
            IF ([IDS251] > 0 OR [IDS252] > 0) AND ([IDS223] <> SET ("2","4","6","10"))
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS223] = IDS:RP:bafpo6.02.13:Liabilities.ThinCapitalisation.EntityType.Code
            [IDS251] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.ZeroCapitalAverage.Amount
            [IDS252] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.OnLentAverage.Amount

            Technical Business Rule Format:
            (^IDS251 > 0 OR ^IDS252 > 0) AND (NotInSet(^IDS223, '"2","4","6","10"'))
    
            Data Elements:
    
            RP:^IDS223 = tns:Liabilities.ThinCapitalisation.EntityType.Code
    
            RP:^IDS251 = tns:Capital.ThinCapitalisation.ZeroCapitalAverage.Amount
    
            RP:^IDS252 = tns:Liabilities.ThinCapitalisation.OnLentAverage.Amount
            */
            assertion = ((report.IDS251.GetValueOrDefault() > 0 || report.IDS252.GetValueOrDefault() > 0) && !(IsMatch(report.IDS223, @"^(2|4|6|10)$", RegexOptions.IgnoreCase)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440153",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity Type code must be 2, 4, 6 or 10.",
                    LongDescription = @"If there are amounts greater than zero for 'Average zero capital amount' or 'Average on-lent amount', then the entity type at the end of the income year must be 2 = Outward investor (financial), 4 = Inward investment vehicle (financial), 6 = Inward investor (financial) or 10 = Outward investor (financial) under subsection 820-85(2) and inward investment vehicle (financial) under subsection 820-185(2)",
                    Location = "/xbrli:xbrl/tns:Liabilities.ThinCapitalisation.EntityType.Code",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440153" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS251", Value = report.IDS251.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS252", Value = report.IDS252.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS223", Value = report.IDS223 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440153

            #region VR.ATO.IDS.440154

            /*  VR.ATO.IDS.440154
            If the Average value of controlled foreign entity equity  and/or Average value of controlled foreign entity debt  are greater than zero, the entity type at the end of the income year must be 1, 2, 9 or 10.
    
            Legacy Rule Format:
            IF ([IDS253] > 0 OR [IDS254] > 0) AND ([IDS223] <> SET ("1","2","9","10"))
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS223] = IDS:RP:bafpo6.02.13:Liabilities.ThinCapitalisation.EntityType.Code
            [IDS253] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.ControlledForeignNonAuthorisedDepositTakingInstitutionEntityEquityAverageValue.Amount
            [IDS254] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.ControlledForeignEntityDebtAverageValue.Amount

            Technical Business Rule Format:
            (^IDS253 > 0 OR ^IDS254 > 0) AND (NotInSet(^IDS223, '"1","2","9","10"'))
    
            Data Elements:
    
            RP:^IDS223 = tns:Liabilities.ThinCapitalisation.EntityType.Code
    
            RP:^IDS253 = tns:Capital.ThinCapitalisation.ControlledForeignNonAuthorisedDepositTakingInstitutionEntityEquityAverageValue.Amount
    
            RP:^IDS254 = tns:Capital.ThinCapitalisation.ControlledForeignEntityDebtAverageValue.Amount
            */
            assertion = ((report.IDS253.GetValueOrDefault() > 0 || report.IDS254.GetValueOrDefault() > 0) && !(IsMatch(report.IDS223, @"^(1|2|9|10)$", RegexOptions.IgnoreCase)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440154",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity Type code must be 1, 2, 9 or 10.",
                    LongDescription = @"If there are amounts greater than zero for 'Average value of controlled foreign entity equity' or 'Average value of controlled foreign entity debt', then the entity type at the end of the income year must be 1 = Outward investor (general), 2 = Outward investor (financial), 9 = Outward investor (general) under subsection 820-85(2) and inward investment vehicle (general) under subsection 820-185(2), 10 = Outward investor (financial) under subsection 820-85(2) and inward investment vehicle (financial) under subsection 820-185(2)",
                    Location = "/xbrli:xbrl/tns:Liabilities.ThinCapitalisation.EntityType.Code",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440154" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS253", Value = report.IDS253.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS254", Value = report.IDS254.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS223", Value = report.IDS223 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440154

            #region VR.ATO.IDS.440155

            /*  VR.ATO.IDS.440155
            If the Worldwide group capital ratio and/or Worldwide capital amount are greater than zero, the entity type at the end of the income year must be 7.
    
            Legacy Rule Format:
            IF ([IDS258] > 0 OR [IDS259] > 0) AND ([IDS223] <> "7")
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS223] = IDS:RP:bafpo6.02.13:Liabilities.ThinCapitalisation.EntityType.Code
            [IDS258] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.WorldwideGroupCapitalRatio.Fraction
            [IDS259] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.WorldwideCapital.Amount

            Technical Business Rule Format:
            (^IDS258 > 0 OR ^IDS259 > 0) AND (^IDS223 <> '7')
    
            Data Elements:
    
            RP:^IDS223 = tns:Liabilities.ThinCapitalisation.EntityType.Code
    
            RP:^IDS258 = tns:Capital.ThinCapitalisation.WorldwideGroupCapitalRatio.Fraction
    
            RP:^IDS259 = tns:Capital.ThinCapitalisation.WorldwideCapital.Amount
            */
            assertion = ((report.IDS258.GetValueOrDefault() > 0 || report.IDS259.GetValueOrDefault() > 0) && report.IDS223 != @"7");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440155",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity Type code must be 7",
                    LongDescription = @"If there are amounts greater than zero for 'Worldwide group capital ratio' or 'Worldwide capital amount', then the entity type at the end of the income year must be 7 = Outward",
                    Location = "/xbrli:xbrl/tns:Liabilities.ThinCapitalisation.EntityType.Code",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440155" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS258", Value = report.IDS258.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS259", Value = report.IDS259.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS223", Value = report.IDS223 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440155

            #region VR.ATO.IDS.440156

            /*  VR.ATO.IDS.440156
            If either 'Non-ADI Worldwide debt', or Non-ADI Worldwide equity' or 'Non-ADI Worldwide gearing debt amount' are greater than zero, the entity type at the end of the income year must be 1, 2, 3, 4, 5, 6, 9 or 10.
    
            Legacy Rule Format:
            IF ([IDS260] > 0 OR [IDS261] > 0 OR [IDS262] > 0) AND [IDS223] <> SET ("1","2","3","4","5","6","9","10")
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS223] = IDS:RP:bafpo6.02.13:Liabilities.ThinCapitalisation.EntityType.Code
            [IDS260] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.WorldwideDebtTotal.Amount
            [IDS261] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.WorldwideEquity.Amount
            [IDS262] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.WorldwideGearingDebt.Amount

            Technical Business Rule Format:
            (^IDS260 > 0 OR ^IDS261 > 0 OR ^IDS262 > 0) AND NotInSet(^IDS223, '"1","2","3","4","5","6","9","10"')
    
            Data Elements:
    
            RP:^IDS223 = tns:Liabilities.ThinCapitalisation.EntityType.Code
    
            RP:^IDS260 = tns:Capital.ThinCapitalisation.WorldwideDebtTotal.Amount
    
            RP:^IDS261 = tns:Liabilities.ThinCapitalisation.WorldwideEquity.Amount
    
            RP:^IDS262 = tns:Capital.ThinCapitalisation.WorldwideGearingDebt.Amount
            */
            assertion = ((report.IDS260.GetValueOrDefault() > 0 || report.IDS261.GetValueOrDefault() > 0 || report.IDS262.GetValueOrDefault() > 0) && !(IsMatch(report.IDS223, @"^(1|2|3|4|5|6|9|10)$", RegexOptions.IgnoreCase)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440156",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity Type code must be 1, 2, 3, 4, 5, 6, 9 or 10.",
                    LongDescription = @"If there are amounts greater than zero for 'Worldwide debt', 'Worldwide equity' or 'Worldwide gearing debt amount', then the entity type at the end of the income year must be 1 = Outward investor (general), 2 = Outward investor (financial), 3 = Inward investment vehicle (general), 4 = Inward investment vehicle (financial), 5 = Inward investor (general) or 6 = Inward investor (financial), 9 = Outward investor (general) under subsection 820-85(2) and inward investment vehicle (general) under subsection 820-185(2), 10 = Outward investor (financial) under subsection 820-85(2) and inward investment vehicle (financial) under subsection 820-185(2)",
                    Location = "/xbrli:xbrl/tns:Liabilities.ThinCapitalisation.EntityType.Code",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440156" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS260", Value = report.IDS260.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS261", Value = report.IDS261.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS262", Value = report.IDS262.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS223", Value = report.IDS223 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440156

            #region VR.ATO.IDS.440157

            /*  VR.ATO.IDS.440157
            If the entity type at the end of the income year is present, then an answer to "Have you changed your status from 'general' to 'financial' during the income year?" is required.
    
            Legacy Rule Format:
            IF [IDS223] <> NULL AND [IDS224] = NULL
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS223] = IDS:RP:bafpo6.02.13:Liabilities.ThinCapitalisation.EntityType.Code
            [IDS224] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.GeneralToFinancialStatusChange.Indicator

            Technical Business Rule Format:
            ^IDS223 <> NULL AND ^IDS224 = NULL
    
            Data Elements:
    
            RP:^IDS224 = tns:Liabilities.ThinCapitalisation.GeneralToFinancialStatusChange.Indicator
    
            RP:^IDS223 = tns:Liabilities.ThinCapitalisation.EntityType.Code
            */
            assertion = (report.IDS223 != null && report.IDS224 == null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440157",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity status is required",
                    LongDescription = @"If the entity type at the end of the income year is present, then an answer to ""Have you changed your status from 'general' to 'financial' during the income year?"" is required",
                    Location = "/xbrli:xbrl/tns:Liabilities.ThinCapitalisation.GeneralToFinancialStatusChange.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440157" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS223", Value = report.IDS223 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS224", Value = GetValueOrEmpty(report.IDS224) });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440157

            #region VR.ATO.IDS.440158

            /*  VR.ATO.IDS.440158
            If the entity type at the end of the income year is present, then the method used for calculating 'average values' is required.
    
            Legacy Rule Format:
            IF [IDS223] <> NULL AND [IDS225] = NULL
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS223] = IDS:RP:bafpo6.02.13:Liabilities.ThinCapitalisation.EntityType.Code
            [IDS225] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.AveragingMethodAdopted.Code

            Technical Business Rule Format:
            ^IDS223 <> NULL AND ^IDS225 = NULL
    
            Data Elements:
    
            RP:^IDS225 = tns:Liabilities.ThinCapitalisation.AveragingMethodAdopted.Code
    
            RP:^IDS223 = tns:Liabilities.ThinCapitalisation.EntityType.Code
            */
            assertion = (report.IDS223 != null && report.IDS225 == null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440158",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Average values method is required",
                    LongDescription = @"If the entity type at the end of the income year is present, then the method used for calculating 'average values' is required",
                    Location = "/xbrli:xbrl/tns:Liabilities.ThinCapitalisation.AveragingMethodAdopted.Code",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440158" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS223", Value = report.IDS223 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS225", Value = report.IDS225 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440158

            #region VR.ATO.IDS.440159

            /*  VR.ATO.IDS.440159
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS226] <> NULL AND [IDS226] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS226] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.DeductionDebt.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS226, 'U', 11, 0)
    
            Data Elements:
    
            RP:^IDS226 = tns:Liabilities.ThinCapitalisation.DeductionDebt.Amount
            */
            assertion = NotMonetary(report.IDS226, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Liabilities.ThinCapitalisation.DeductionDebt.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440159" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS226", Value = report.IDS226.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440159

            #region VR.ATO.IDS.440160

            /*  VR.ATO.IDS.440160
            If there is an amount at 'Debt deductions on debt from related non-residents' it must be less than or equal to the amount at General information - Debt deductions.
    
            Legacy Rule Format:
            IF ([IDS227] > 0) AND ([IDS227] > [IDS226])
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS226] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.DeductionDebt.Amount
            [IDS227] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.RelatedNonResidentsDebtDeduction.Amount

            Technical Business Rule Format:
            (^IDS227 > 0) AND (^IDS227 > ^IDS226)
    
            Data Elements:
    
            RP:^IDS227 = tns:Liabilities.ThinCapitalisation.RelatedNonResidentsDebtDeduction.Amount
    
            RP:^IDS226 = tns:Liabilities.ThinCapitalisation.DeductionDebt.Amount
            */
            assertion = (report.IDS227.GetValueOrDefault() > 0 && report.IDS227.GetValueOrDefault() > report.IDS226.GetValueOrDefault());
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440160",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Debt deductions incorrect",
                    LongDescription = @"If there is an amount at 'General information - Debt deductions on debt from related non-residents'  it must be less than or equal to the amount at 'General information - Debt deductions'",
                    Location = "/xbrli:xbrl/tns:Liabilities.ThinCapitalisation.RelatedNonResidentsDebtDeduction.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440160" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS227", Value = report.IDS227.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS226", Value = report.IDS226.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440160

            #region VR.ATO.IDS.440161

            /*  VR.ATO.IDS.440161
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS227] <> NULL AND [IDS227] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS227] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.RelatedNonResidentsDebtDeduction.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS227, 'U', 11, 0)
    
            Data Elements:
    
            RP:^IDS227 = tns:Liabilities.ThinCapitalisation.RelatedNonResidentsDebtDeduction.Amount
            */
            assertion = NotMonetary(report.IDS227, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Liabilities.ThinCapitalisation.RelatedNonResidentsDebtDeduction.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440161" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS227", Value = report.IDS227.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440161

            #region VR.ATO.IDS.440162

            /*  VR.ATO.IDS.440162
            If the entity type at the end of the income year is present, then the amount of debt deduction disallowed is required. If there is no debt deduction disallowed calculated, enter zero at General information - Amount of debt deduction disallowed.
    
            Legacy Rule Format:
            IF [IDS223] <> NULL AND [IDS228] = NULL
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS223] = IDS:RP:bafpo6.02.13:Liabilities.ThinCapitalisation.EntityType.Code
            [IDS228] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.DeductionDebtDisallowed.Amount

            Technical Business Rule Format:
            ^IDS223 <> NULL AND ^IDS228 = NULL
    
            Data Elements:
    
            RP:^IDS228 = tns:Liabilities.ThinCapitalisation.DeductionDebtDisallowed.Amount
    
            RP:^IDS223 = tns:Liabilities.ThinCapitalisation.EntityType.Code
            */
            assertion = (report.IDS223 != null && report.IDS228 == null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440162",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Amount of debt deduction disallowed is required",
                    LongDescription = @"If the entity type at the end of the income year is present, then the amount of debt deduction disallowed is required. If there is no debt deduction disallowed calculated, enter zero",
                    Location = "/xbrli:xbrl/tns:Liabilities.ThinCapitalisation.DeductionDebtDisallowed.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440162" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS223", Value = report.IDS223 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS228", Value = report.IDS228.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440162

            #region VR.ATO.IDS.440163

            /*  VR.ATO.IDS.440163
            If there is an amount greater than zero at General information - Amount of debt deduction disallowed, there must also be an amount greater than zero at All non-ADI entities - Excess debt amount and General information - Debt deductions.
    
            Legacy Rule Format:
            IF ([IDS223] = SET ("1","2","3","4","5","6")) AND ([IDS228] > 0) AND (([IDS226] = NULL OR [IDS226] = 0) OR ([IDS245] = NULL OR [IDS245] = 0))
              RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS223] = IDS:RP:bafpo6.02.13:Liabilities.ThinCapitalisation.EntityType.Code
            [IDS226] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.DeductionDebt.Amount
            [IDS228] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.DeductionDebtDisallowed.Amount
            [IDS245] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.ExcessDebt.Amount

            Technical Business Rule Format:
            (InSet(^IDS223, '"1","2","3","4","5","6"')) AND (^IDS228 > 0) AND ((^IDS226 = NULL OR ^IDS226 = 0) OR (^IDS245 = NULL OR ^IDS245 = 0))
    
            Data Elements:
    
            RP:^IDS228 = tns:Liabilities.ThinCapitalisation.DeductionDebtDisallowed.Amount
    
            RP:^IDS223 = tns:Liabilities.ThinCapitalisation.EntityType.Code
    
            RP:^IDS226 = tns:Liabilities.ThinCapitalisation.DeductionDebt.Amount
    
            RP:^IDS245 = tns:Liabilities.ThinCapitalisation.ExcessDebt.Amount
            */
            assertion = (IsMatch(report.IDS223, @"^(1|2|3|4|5|6)$") && report.IDS228.GetValueOrDefault() > 0 && (report.IDS226 == null || report.IDS226 == 0 || (report.IDS245 == null || report.IDS245 == 0)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440163",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Excess debt amount and debt deductions required",
                    LongDescription = @"If entity is a non-authorised deposit taking institution (non-ADI) and 'general information - Amount of debt greater deduction disallowed' is greater than zero then 'General information - Debt deductions' and 'All non-ADI entities - Excess debt amount' must be greater than zero",
                    Location = "/xbrli:xbrl/tns:Liabilities.ThinCapitalisation.DeductionDebtDisallowed.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440163" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS223", Value = report.IDS223 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS228", Value = report.IDS228.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS226", Value = report.IDS226.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS245", Value = report.IDS245.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440163

            #region VR.ATO.IDS.440164

            /*  VR.ATO.IDS.440164
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS228] <> NULL AND [IDS228] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS228] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.DeductionDebtDisallowed.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS228, 'U', 11, 0)
    
            Data Elements:
    
            RP:^IDS228 = tns:Liabilities.ThinCapitalisation.DeductionDebtDisallowed.Amount
            */
            assertion = NotMonetary(report.IDS228, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Liabilities.ThinCapitalisation.DeductionDebtDisallowed.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440164" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS228", Value = report.IDS228.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440164

            #region VR.ATO.IDS.440165

            /*  VR.ATO.IDS.440165
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS229] <> NULL AND [IDS229] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS229] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.DebtAdjustedAverage.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS229, 'U', 11, 0)
    
            Data Elements:
    
            RP:^IDS229 = tns:Liabilities.ThinCapitalisation.DebtAdjustedAverage.Amount
            */
            assertion = NotMonetary(report.IDS229, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Liabilities.ThinCapitalisation.DebtAdjustedAverage.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440165" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS229", Value = report.IDS229.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440165

            #region VR.ATO.IDS.440166

            /*  VR.ATO.IDS.440166
            If Thin capitalisation information has been completed for all ADI entities, outward investing ADI or inward investing ADI then the response to 'Were you an authorised deposit taking institution (ADI) for the income year?' must be 'Yes'.
    
            Legacy Rule Format:
            IF ([IDS230] <> TRUE) AND ([IDS231] <> NULL OR [IDS232] <> NULL OR [IDS233] <> NULL OR [IDS234] <> NULL OR [IDS235] <> NULL OR [IDS236] <> NULL OR [IDS237] <> NULL OR [IDS238] <> NULL OR [IDS239] <> NULL OR [IDS240] <> NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS230] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.AuthorisedDepositTakingInstitution.Indicator
            [IDS231] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.EquityCapitalAdjustedAverage.Amount
            [IDS232] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.SafeHarbour.Amount
            [IDS233] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.EquityShortfall.Amount
            [IDS234] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.RiskWeightedAssetsAverageValue.Amount
            [IDS235] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.EquityCapitalAttributableToOverseasPermanentEstablishments.Amount
            [IDS236] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.RiskWeightedAssetsOverseasPermanentEstablishmentsAverageValueTotal.Amount
            [IDS237] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.ControlledForeignADIEntityEquityAverageValue.Amount
            [IDS238] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.Tier1PrudentialCapitalDeduction.Amount
            [IDS239] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.RiskWeightedAssetsAttributableToAustralianPermanentEstablishmentsAverage.Amount
            [IDS240] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.DotationCapitalAverageValue.Amount

            Technical Business Rule Format:
            (^IDS230 <> TRUE) AND (^IDS231 <> NULL OR ^IDS232 <> NULL OR ^IDS233 <> NULL OR ^IDS234 <> NULL OR ^IDS235 <> NULL OR ^IDS236 <> NULL OR ^IDS237 <> NULL OR ^IDS238 <> NULL OR ^IDS239 <> NULL OR ^IDS240 <> NULL)
    
            Data Elements:
    
            RP:^IDS230 = tns:Liabilities.ThinCapitalisation.AuthorisedDepositTakingInstitution.Indicator
    
            RP:^IDS231 = tns:Liabilities.ThinCapitalisation.EquityCapitalAdjustedAverage.Amount
    
            RP:^IDS232 = tns:Capital.ThinCapitalisation.SafeHarbour.Amount
    
            RP:^IDS233 = tns:Capital.ThinCapitalisation.EquityShortfall.Amount
    
            RP:^IDS234 = tns:Liabilities.ThinCapitalisation.RiskWeightedAssetsAverageValue.Amount
    
            RP:^IDS235 = tns:Liabilities.ThinCapitalisation.EquityCapitalAttributableToOverseasPermanentEstablishments.Amount
    
            RP:^IDS236 = tns:Liabilities.ThinCapitalisation.RiskWeightedAssetsOverseasPermanentEstablishmentsAverageValueTotal.Amount
    
            RP:^IDS237 = tns:Liabilities.ThinCapitalisation.ControlledForeignADIEntityEquityAverageValue.Amount
    
            RP:^IDS238 = tns:Liabilities.ThinCapitalisation.Tier1PrudentialCapitalDeduction.Amount
    
            RP:^IDS239 = tns:Capital.ThinCapitalisation.RiskWeightedAssetsAttributableToAustralianPermanentEstablishmentsAverage.Amount
    
            RP:^IDS240 = tns:Capital.ThinCapitalisation.DotationCapitalAverageValue.Amount
            */
            assertion = (report.IDS230 != true && (report.IDS231 != null || report.IDS232 != null || report.IDS233 != null || report.IDS234 != null || report.IDS235 != null || report.IDS236 != null || report.IDS237 != null || report.IDS238 != null || report.IDS239 != null || report.IDS240 != null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440166",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Thin capitalisation question incorrect",
                    LongDescription = @"If Thin capitalisation information has been completed for all ADI entities, outward investing ADI or inward investing ADI then the response to 'Were you an authorised deposit taking institution (ADI) for the income year?' must be 'True'",
                    Location = "/xbrli:xbrl/tns:Liabilities.ThinCapitalisation.AuthorisedDepositTakingInstitution.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440166" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS230", Value = GetValueOrEmpty(report.IDS230) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS231", Value = report.IDS231.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS232", Value = report.IDS232.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS233", Value = report.IDS233.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS234", Value = report.IDS234.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS235", Value = report.IDS235.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS236", Value = report.IDS236.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS237", Value = report.IDS237.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS238", Value = report.IDS238.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS239", Value = report.IDS239.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS240", Value = report.IDS240.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440166

            #region VR.ATO.IDS.440167

            /*  VR.ATO.IDS.440167
            If there is a 'Yes' response to 'Were you an authorised deposit taking institution (ADI) for the income year?' then all applicable ADI entities, outward investing ADI or inward investing ADI information must be completed.
    
            Legacy Rule Format:
            IF [IDS230] = TRUE AND [IDS231] = NULL AND [IDS232] = NULL AND [IDS233] = NULL AND [IDS234] = NULL AND [IDS235] = NULL AND [IDS236] = NULL AND [IDS237] = NULL AND [IDS238] = NULL AND [IDS239] = NULL AND [IDS240] = NULL
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS230] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.AuthorisedDepositTakingInstitution.Indicator
            [IDS231] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.EquityCapitalAdjustedAverage.Amount
            [IDS232] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.SafeHarbour.Amount
            [IDS233] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.EquityShortfall.Amount
            [IDS234] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.RiskWeightedAssetsAverageValue.Amount
            [IDS235] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.EquityCapitalAttributableToOverseasPermanentEstablishments.Amount
            [IDS236] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.RiskWeightedAssetsOverseasPermanentEstablishmentsAverageValueTotal.Amount
            [IDS237] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.ControlledForeignADIEntityEquityAverageValue.Amount
            [IDS238] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.Tier1PrudentialCapitalDeduction.Amount
            [IDS239] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.RiskWeightedAssetsAttributableToAustralianPermanentEstablishmentsAverage.Amount
            [IDS240] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.DotationCapitalAverageValue.Amount

            Technical Business Rule Format:
            ^IDS230 = TRUE AND ^IDS231 = NULL AND ^IDS232 = NULL AND ^IDS233 = NULL AND ^IDS234 = NULL AND ^IDS235 = NULL AND ^IDS236 = NULL AND ^IDS237 = NULL AND ^IDS238 = NULL AND ^IDS239 = NULL AND ^IDS240 = NULL
    
            Data Elements:
    
            RP:^IDS230 = tns:Liabilities.ThinCapitalisation.AuthorisedDepositTakingInstitution.Indicator
    
            RP:^IDS231 = tns:Liabilities.ThinCapitalisation.EquityCapitalAdjustedAverage.Amount
    
            RP:^IDS232 = tns:Capital.ThinCapitalisation.SafeHarbour.Amount
    
            RP:^IDS233 = tns:Capital.ThinCapitalisation.EquityShortfall.Amount
    
            RP:^IDS234 = tns:Liabilities.ThinCapitalisation.RiskWeightedAssetsAverageValue.Amount
    
            RP:^IDS235 = tns:Liabilities.ThinCapitalisation.EquityCapitalAttributableToOverseasPermanentEstablishments.Amount
    
            RP:^IDS236 = tns:Liabilities.ThinCapitalisation.RiskWeightedAssetsOverseasPermanentEstablishmentsAverageValueTotal.Amount
    
            RP:^IDS237 = tns:Liabilities.ThinCapitalisation.ControlledForeignADIEntityEquityAverageValue.Amount
    
            RP:^IDS238 = tns:Liabilities.ThinCapitalisation.Tier1PrudentialCapitalDeduction.Amount
    
            RP:^IDS239 = tns:Capital.ThinCapitalisation.RiskWeightedAssetsAttributableToAustralianPermanentEstablishmentsAverage.Amount
    
            RP:^IDS240 = tns:Capital.ThinCapitalisation.DotationCapitalAverageValue.Amount
            */
            assertion = (report.IDS230 == true && report.IDS231 == null && report.IDS232 == null && report.IDS233 == null && report.IDS234 == null && report.IDS235 == null && report.IDS236 == null && report.IDS237 == null && report.IDS238 == null && report.IDS239 == null && report.IDS240 == null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440167",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Thin capitalisation information required",
                    LongDescription = @"If there is a 'True' response to 'Were you an authorised deposit taking institution (ADI) for the income year?' then all applicable ADI entities, outward investing ADI or inward investing ADI information must be completed",
                    Location = "/xbrli:xbrl/tns:Liabilities.ThinCapitalisation.AuthorisedDepositTakingInstitution.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440167" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS230", Value = GetValueOrEmpty(report.IDS230) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS231", Value = report.IDS231.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS232", Value = report.IDS232.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS233", Value = report.IDS233.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS234", Value = report.IDS234.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS235", Value = report.IDS235.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS236", Value = report.IDS236.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS237", Value = report.IDS237.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS238", Value = report.IDS238.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS239", Value = report.IDS239.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS240", Value = report.IDS240.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440167

            #region VR.ATO.IDS.440168

            /*  VR.ATO.IDS.440168
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS231] <> NULL AND [IDS231] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS231] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.EquityCapitalAdjustedAverage.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS231, 'U', 11, 0)
    
            Data Elements:
    
            RP:^IDS231 = tns:Liabilities.ThinCapitalisation.EquityCapitalAdjustedAverage.Amount
            */
            assertion = NotMonetary(report.IDS231, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Liabilities.ThinCapitalisation.EquityCapitalAdjustedAverage.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440168" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS231", Value = report.IDS231.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440168

            #region VR.ATO.IDS.440169

            /*  VR.ATO.IDS.440169
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS232] <> NULL AND [IDS232] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS232] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.SafeHarbour.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS232, 'U', 11, 0)
    
            Data Elements:
    
            RP:^IDS232 = tns:Capital.ThinCapitalisation.SafeHarbour.Amount
            */
            assertion = NotMonetary(report.IDS232, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Capital.ThinCapitalisation.SafeHarbour.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440169" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS232", Value = report.IDS232.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440169

            #region VR.ATO.IDS.440170

            /*  VR.ATO.IDS.440170
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS233] <> NULL AND [IDS233] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS233] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.EquityShortfall.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS233, 'U', 11, 0)
    
            Data Elements:
    
            RP:^IDS233 = tns:Capital.ThinCapitalisation.EquityShortfall.Amount
            */
            assertion = NotMonetary(report.IDS233, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Capital.ThinCapitalisation.EquityShortfall.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440170" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS233", Value = report.IDS233.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440170

            #region VR.ATO.IDS.440171

            /*  VR.ATO.IDS.440171
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS234] <> NULL AND [IDS234] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS234] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.RiskWeightedAssetsAverageValue.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS234, 'U', 11, 0)
    
            Data Elements:
    
            RP:^IDS234 = tns:Liabilities.ThinCapitalisation.RiskWeightedAssetsAverageValue.Amount
            */
            assertion = NotMonetary(report.IDS234, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Liabilities.ThinCapitalisation.RiskWeightedAssetsAverageValue.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440171" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS234", Value = report.IDS234.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440171

            #region VR.ATO.IDS.440172

            /*  VR.ATO.IDS.440172
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS235] <> NULL AND [IDS235] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS235] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.EquityCapitalAttributableToOverseasPermanentEstablishments.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS235, 'U', 11, 0)
    
            Data Elements:
    
            RP:^IDS235 = tns:Liabilities.ThinCapitalisation.EquityCapitalAttributableToOverseasPermanentEstablishments.Amount
            */
            assertion = NotMonetary(report.IDS235, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Liabilities.ThinCapitalisation.EquityCapitalAttributableToOverseasPermanentEstablishments.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440172" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS235", Value = report.IDS235.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440172

            #region VR.ATO.IDS.440173

            /*  VR.ATO.IDS.440173
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS236] <> NULL AND [IDS236] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS236] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.RiskWeightedAssetsOverseasPermanentEstablishmentsAverageValueTotal.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS236, 'U', 11, 0)
    
            Data Elements:
    
            RP:^IDS236 = tns:Liabilities.ThinCapitalisation.RiskWeightedAssetsOverseasPermanentEstablishmentsAverageValueTotal.Amount
            */
            assertion = NotMonetary(report.IDS236, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Liabilities.ThinCapitalisation.RiskWeightedAssetsOverseasPermanentEstablishmentsAverageValueTotal.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440173" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS236", Value = report.IDS236.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440173

            #region VR.ATO.IDS.440174

            /*  VR.ATO.IDS.440174
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS237] <> NULL AND [IDS237] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS237] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.ControlledForeignADIEntityEquityAverageValue.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS237, 'U', 11, 0)
    
            Data Elements:
    
            RP:^IDS237 = tns:Liabilities.ThinCapitalisation.ControlledForeignADIEntityEquityAverageValue.Amount
            */
            assertion = NotMonetary(report.IDS237, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Liabilities.ThinCapitalisation.ControlledForeignADIEntityEquityAverageValue.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440174" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS237", Value = report.IDS237.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440174

            #region VR.ATO.IDS.440175

            /*  VR.ATO.IDS.440175
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS238] <> NULL AND [IDS238] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS238] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.Tier1PrudentialCapitalDeduction.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS238, 'U', 11, 0)
    
            Data Elements:
    
            RP:^IDS238 = tns:Liabilities.ThinCapitalisation.Tier1PrudentialCapitalDeduction.Amount
            */
            assertion = NotMonetary(report.IDS238, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Liabilities.ThinCapitalisation.Tier1PrudentialCapitalDeduction.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440175" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS238", Value = report.IDS238.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440175

            #region VR.ATO.IDS.440176

            /*  VR.ATO.IDS.440176
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS239] <> NULL AND [IDS239] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS239] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.RiskWeightedAssetsAttributableToAustralianPermanentEstablishmentsAverage.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS239, 'U', 11, 0)
    
            Data Elements:
    
            RP:^IDS239 = tns:Capital.ThinCapitalisation.RiskWeightedAssetsAttributableToAustralianPermanentEstablishmentsAverage.Amount
            */
            assertion = NotMonetary(report.IDS239, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Capital.ThinCapitalisation.RiskWeightedAssetsAttributableToAustralianPermanentEstablishmentsAverage.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440176" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS239", Value = report.IDS239.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440176

            #region VR.ATO.IDS.440177

            /*  VR.ATO.IDS.440177
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS240] <> NULL AND [IDS240] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS240] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.DotationCapitalAverageValue.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS240, 'U', 11, 0)
    
            Data Elements:
    
            RP:^IDS240 = tns:Capital.ThinCapitalisation.DotationCapitalAverageValue.Amount
            */
            assertion = NotMonetary(report.IDS240, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Capital.ThinCapitalisation.DotationCapitalAverageValue.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440177" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS240", Value = report.IDS240.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440177

            #region VR.ATO.IDS.440178

            /*  VR.ATO.IDS.440178
            If Thin capitalisation information has been completed for all non-ADI entities, financial entity or outward investing entity then the response to 'Were you a non-authorised deposit taking institution (non-ADI) for the income year?' must be 'Yes'.
    
            Legacy Rule Format:
            IF [IDS241] <> TRUE AND ([IDS242] <> NULL OR [IDS243] <> NULL OR [IDS244] <> NULL OR [IDS245] <> NULL OR [IDS246] <> NULL OR [IDS247] <> NULL OR [IDS248] <> NULL OR [IDS249] <> NULL OR [IDS250] <> NULL OR [IDS251] <> NULL OR [IDS252] <> NULL OR [IDS253] <> NULL OR [IDS254] <> NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS241] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.NonAuthorisedDepositTakingInstitution.Indicator
            [IDS242] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.AssetsValueAverage.Amount
            [IDS243] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.AssetRevaluation.Amount
            [IDS244] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.DebtMaximumAllowable.Amount
            [IDS245] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.ExcessDebt.Amount
            [IDS246] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.NonDebtLiabilitiesAverageValue.Amount
            [IDS247] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.AssociateEntityDebtAverageValue.Amount
            [IDS248] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.AssociateEntityEquityAverageValue.Amount
            [IDS249] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.AssociateEntityExcessAverageValue.Amount
            [IDS250] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.ExcludedEquityInterestsAverage.Amount
            [IDS251] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.ZeroCapitalAverage.Amount
            [IDS252] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.OnLentAverage.Amount
            [IDS253] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.ControlledForeignNonAuthorisedDepositTakingInstitutionEntityEquityAverageValue.Amount
            [IDS254] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.ControlledForeignEntityDebtAverageValue.Amount

            Technical Business Rule Format:
            ^IDS241 <> TRUE AND (^IDS242 <> NULL OR ^IDS243 <> NULL OR ^IDS244 <> NULL OR ^IDS245 <> NULL OR ^IDS246 <> NULL OR ^IDS247 <> NULL OR ^IDS248 <> NULL OR ^IDS249 <> NULL OR ^IDS250 <> NULL OR ^IDS251 <> NULL OR ^IDS252 <> NULL OR ^IDS253 <> NULL OR ^IDS254 <> NULL)
    
            Data Elements:
    
            RP:^IDS241 = tns:Liabilities.ThinCapitalisation.NonAuthorisedDepositTakingInstitution.Indicator
    
            RP:^IDS242 = tns:Capital.ThinCapitalisation.AssetsValueAverage.Amount
    
            RP:^IDS243 = tns:Capital.ThinCapitalisation.AssetRevaluation.Amount
    
            RP:^IDS244 = tns:Liabilities.ThinCapitalisation.DebtMaximumAllowable.Amount
    
            RP:^IDS245 = tns:Liabilities.ThinCapitalisation.ExcessDebt.Amount
    
            RP:^IDS246 = tns:Liabilities.ThinCapitalisation.NonDebtLiabilitiesAverageValue.Amount
    
            RP:^IDS247 = tns:Liabilities.ThinCapitalisation.AssociateEntityDebtAverageValue.Amount
    
            RP:^IDS248 = tns:Capital.ThinCapitalisation.AssociateEntityEquityAverageValue.Amount
    
            RP:^IDS249 = tns:Liabilities.ThinCapitalisation.AssociateEntityExcessAverageValue.Amount
    
            RP:^IDS250 = tns:Capital.ThinCapitalisation.ExcludedEquityInterestsAverage.Amount
    
            RP:^IDS251 = tns:Capital.ThinCapitalisation.ZeroCapitalAverage.Amount
    
            RP:^IDS252 = tns:Liabilities.ThinCapitalisation.OnLentAverage.Amount
    
            RP:^IDS253 = tns:Capital.ThinCapitalisation.ControlledForeignNonAuthorisedDepositTakingInstitutionEntityEquityAverageValue.Amount
    
            RP:^IDS254 = tns:Capital.ThinCapitalisation.ControlledForeignEntityDebtAverageValue.Amount
            */
            assertion = (report.IDS241 != true && (report.IDS242 != null || report.IDS243 != null || report.IDS244 != null || report.IDS245 != null || report.IDS246 != null || report.IDS247 != null || report.IDS248 != null || report.IDS249 != null || report.IDS250 != null || report.IDS251 != null || report.IDS252 != null || report.IDS253 != null || report.IDS254 != null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440178",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Thin capitalisation question incorrect",
                    LongDescription = @"If Thin capitalisation information has been completed for all non-ADI entities, financial entity or outward investing entity then the response to 'Were you a non-authorised deposit taking institution (non-ADI) for the income year?' must be 'True'",
                    Location = "/xbrli:xbrl/tns:Liabilities.ThinCapitalisation.NonAuthorisedDepositTakingInstitution.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440178" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS241", Value = GetValueOrEmpty(report.IDS241) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS242", Value = report.IDS242.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS243", Value = report.IDS243.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS244", Value = report.IDS244.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS245", Value = report.IDS245.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS246", Value = report.IDS246.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS247", Value = report.IDS247.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS248", Value = report.IDS248.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS249", Value = report.IDS249.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS250", Value = report.IDS250.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS251", Value = report.IDS251.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS252", Value = report.IDS252.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS253", Value = report.IDS253.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS254", Value = report.IDS254.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440178

            #region VR.ATO.IDS.440179

            /*  VR.ATO.IDS.440179
            If there is a 'Yes' response to 'Were you a non-authorised deposit taking institution (non-ADI) for the income year?' then all applicable non-ADI entities, financial entity or outward investing entity information must be completed.
    
            Legacy Rule Format:
            IF [IDS241] = TRUE AND ([IDS242] = NULL AND [IDS243] = NULL AND [IDS244] = NULL AND [IDS245] = NULL AND [IDS246] = NULL AND [IDS247] = NULL AND [IDS248] = NULL AND [IDS249] = NULL AND [IDS250] = NULL AND [IDS251] = NULL AND [IDS252] = NULL AND [IDS253] = NULL AND [IDS254] = NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS241] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.NonAuthorisedDepositTakingInstitution.Indicator
            [IDS242] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.AssetsValueAverage.Amount
            [IDS243] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.AssetRevaluation.Amount
            [IDS244] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.DebtMaximumAllowable.Amount
            [IDS245] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.ExcessDebt.Amount
            [IDS246] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.NonDebtLiabilitiesAverageValue.Amount
            [IDS247] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.AssociateEntityDebtAverageValue.Amount
            [IDS248] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.AssociateEntityEquityAverageValue.Amount
            [IDS249] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.AssociateEntityExcessAverageValue.Amount
            [IDS250] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.ExcludedEquityInterestsAverage.Amount
            [IDS251] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.ZeroCapitalAverage.Amount
            [IDS252] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.OnLentAverage.Amount
            [IDS253] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.ControlledForeignNonAuthorisedDepositTakingInstitutionEntityEquityAverageValue.Amount
            [IDS254] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.ControlledForeignEntityDebtAverageValue.Amount

            Technical Business Rule Format:
            ^IDS241 = TRUE AND (^IDS242 = NULL AND ^IDS243 = NULL AND ^IDS244 = NULL AND ^IDS245 = NULL AND ^IDS246 = NULL AND ^IDS247 = NULL AND ^IDS248 = NULL AND ^IDS249 = NULL AND ^IDS250 = NULL AND ^IDS251 = NULL AND ^IDS252 = NULL AND ^IDS253 = NULL AND ^IDS254 = NULL)
    
            Data Elements:
    
            RP:^IDS241 = tns:Liabilities.ThinCapitalisation.NonAuthorisedDepositTakingInstitution.Indicator
    
            RP:^IDS242 = tns:Capital.ThinCapitalisation.AssetsValueAverage.Amount
    
            RP:^IDS243 = tns:Capital.ThinCapitalisation.AssetRevaluation.Amount
    
            RP:^IDS244 = tns:Liabilities.ThinCapitalisation.DebtMaximumAllowable.Amount
    
            RP:^IDS245 = tns:Liabilities.ThinCapitalisation.ExcessDebt.Amount
    
            RP:^IDS246 = tns:Liabilities.ThinCapitalisation.NonDebtLiabilitiesAverageValue.Amount
    
            RP:^IDS247 = tns:Liabilities.ThinCapitalisation.AssociateEntityDebtAverageValue.Amount
    
            RP:^IDS248 = tns:Capital.ThinCapitalisation.AssociateEntityEquityAverageValue.Amount
    
            RP:^IDS249 = tns:Liabilities.ThinCapitalisation.AssociateEntityExcessAverageValue.Amount
    
            RP:^IDS250 = tns:Capital.ThinCapitalisation.ExcludedEquityInterestsAverage.Amount
    
            RP:^IDS251 = tns:Capital.ThinCapitalisation.ZeroCapitalAverage.Amount
    
            RP:^IDS252 = tns:Liabilities.ThinCapitalisation.OnLentAverage.Amount
    
            RP:^IDS253 = tns:Capital.ThinCapitalisation.ControlledForeignNonAuthorisedDepositTakingInstitutionEntityEquityAverageValue.Amount
    
            RP:^IDS254 = tns:Capital.ThinCapitalisation.ControlledForeignEntityDebtAverageValue.Amount
            */
            assertion = (report.IDS241 == true && (report.IDS242 == null && report.IDS243 == null && report.IDS244 == null && report.IDS245 == null && report.IDS246 == null && report.IDS247 == null && report.IDS248 == null && report.IDS249 == null && report.IDS250 == null && report.IDS251 == null && report.IDS252 == null && report.IDS253 == null && report.IDS254 == null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440179",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Thin capitalisation information required",
                    LongDescription = @"If there is a 'True' response to 'Were you a non-authorised deposit taking institution (non-ADI) for the income year?' then all applicable non-ADI entities, financial entity or outward investing entity information must be completed",
                    Location = "/xbrli:xbrl/tns:Liabilities.ThinCapitalisation.NonAuthorisedDepositTakingInstitution.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440179" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS241", Value = GetValueOrEmpty(report.IDS241) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS242", Value = report.IDS242.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS243", Value = report.IDS243.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS244", Value = report.IDS244.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS245", Value = report.IDS245.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS246", Value = report.IDS246.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS247", Value = report.IDS247.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS248", Value = report.IDS248.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS249", Value = report.IDS249.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS250", Value = report.IDS250.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS251", Value = report.IDS251.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS252", Value = report.IDS252.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS253", Value = report.IDS253.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS254", Value = report.IDS254.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440179

            #region VR.ATO.IDS.440180

            /*  VR.ATO.IDS.440180
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS242] <> NULL AND [IDS242] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS242] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.AssetsValueAverage.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS242, 'U', 11, 0)
    
            Data Elements:
    
            RP:^IDS242 = tns:Capital.ThinCapitalisation.AssetsValueAverage.Amount
            */
            assertion = NotMonetary(report.IDS242, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Capital.ThinCapitalisation.AssetsValueAverage.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440180" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS242", Value = report.IDS242.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440180

            #region VR.ATO.IDS.440181

            /*  VR.ATO.IDS.440181
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS243] <> NULL AND [IDS243] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS243] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.AssetRevaluation.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS243, 'U', 11, 0)
    
            Data Elements:
    
            RP:^IDS243 = tns:Capital.ThinCapitalisation.AssetRevaluation.Amount
            */
            assertion = NotMonetary(report.IDS243, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Capital.ThinCapitalisation.AssetRevaluation.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440181" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS243", Value = report.IDS243.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440181

            #region VR.ATO.IDS.440182

            /*  VR.ATO.IDS.440182
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS244] <> NULL AND [IDS244] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS244] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.DebtMaximumAllowable.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS244, 'U', 11, 0)
    
            Data Elements:
    
            RP:^IDS244 = tns:Liabilities.ThinCapitalisation.DebtMaximumAllowable.Amount
            */
            assertion = NotMonetary(report.IDS244, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Liabilities.ThinCapitalisation.DebtMaximumAllowable.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440182" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS244", Value = report.IDS244.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440182

            #region VR.ATO.IDS.440183

            /*  VR.ATO.IDS.440183
            If Excess debt amount is greater than zero, there must be either an Amount of debt deduction disallowed and/or Debt Deductions present.
    
            Legacy Rule Format:
            IF [IDS245] > 0 AND ([IDS226] = NULL OR [IDS228] = NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS226] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.DeductionDebt.Amount
            [IDS228] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.DeductionDebtDisallowed.Amount
            [IDS245] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.ExcessDebt.Amount

            Technical Business Rule Format:
            ^IDS245 > 0 AND (^IDS226 = NULL OR ^IDS228 = NULL)
    
            Data Elements:
    
            RP:^IDS245 = tns:Liabilities.ThinCapitalisation.ExcessDebt.Amount
    
            RP:^IDS226 = tns:Liabilities.ThinCapitalisation.DeductionDebt.Amount
    
            RP:^IDS228 = tns:Liabilities.ThinCapitalisation.DeductionDebtDisallowed.Amount
            */
            assertion = (report.IDS245.GetValueOrDefault() > 0 && (report.IDS226 == null || report.IDS228 == null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440183",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Debt deductions and/or amount of debt deduction disallowed required",
                    LongDescription = @"If 'All non-ADI entities - excess debt amount' is greater than zero then 'General information - debt deductions' and/or 'General information - amount of debt deduction disallowed' must be supplied.",
                    Location = "/xbrli:xbrl/tns:Liabilities.ThinCapitalisation.ExcessDebt.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440183" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS245", Value = report.IDS245.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS226", Value = report.IDS226.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS228", Value = report.IDS228.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440183

            #region VR.ATO.IDS.440184

            /*  VR.ATO.IDS.440184
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS245] <> NULL AND [IDS245] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS245] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.ExcessDebt.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS245, 'U', 11, 0)
    
            Data Elements:
    
            RP:^IDS245 = tns:Liabilities.ThinCapitalisation.ExcessDebt.Amount
            */
            assertion = NotMonetary(report.IDS245, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Liabilities.ThinCapitalisation.ExcessDebt.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440184" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS245", Value = report.IDS245.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440184

            #region VR.ATO.IDS.440185

            /*  VR.ATO.IDS.440185
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS246] <> NULL AND [IDS246] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS246] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.NonDebtLiabilitiesAverageValue.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS246, 'U', 11, 0)
    
            Data Elements:
    
            RP:^IDS246 = tns:Liabilities.ThinCapitalisation.NonDebtLiabilitiesAverageValue.Amount
            */
            assertion = NotMonetary(report.IDS246, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Liabilities.ThinCapitalisation.NonDebtLiabilitiesAverageValue.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440185" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS246", Value = report.IDS246.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440185

            #region VR.ATO.IDS.440186

            /*  VR.ATO.IDS.440186
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS247] <> NULL AND [IDS247] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS247] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.AssociateEntityDebtAverageValue.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS247, 'U', 11, 0)
    
            Data Elements:
    
            RP:^IDS247 = tns:Liabilities.ThinCapitalisation.AssociateEntityDebtAverageValue.Amount
            */
            assertion = NotMonetary(report.IDS247, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Liabilities.ThinCapitalisation.AssociateEntityDebtAverageValue.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440186" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS247", Value = report.IDS247.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440186

            #region VR.ATO.IDS.440187

            /*  VR.ATO.IDS.440187
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS248] <> NULL AND [IDS248] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS248] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.AssociateEntityEquityAverageValue.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS248, 'U', 11, 0)
    
            Data Elements:
    
            RP:^IDS248 = tns:Capital.ThinCapitalisation.AssociateEntityEquityAverageValue.Amount
            */
            assertion = NotMonetary(report.IDS248, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Capital.ThinCapitalisation.AssociateEntityEquityAverageValue.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440187" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS248", Value = report.IDS248.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440187

            #region VR.ATO.IDS.440188

            /*  VR.ATO.IDS.440188
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS249] <> NULL AND [IDS249] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS249] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.AssociateEntityExcessAverageValue.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS249, 'U', 11, 0)
    
            Data Elements:
    
            RP:^IDS249 = tns:Liabilities.ThinCapitalisation.AssociateEntityExcessAverageValue.Amount
            */
            assertion = NotMonetary(report.IDS249, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Liabilities.ThinCapitalisation.AssociateEntityExcessAverageValue.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440188" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS249", Value = report.IDS249.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440188

            #region VR.ATO.IDS.440189

            /*  VR.ATO.IDS.440189
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS250] <> NULL AND [IDS250] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS250] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.ExcludedEquityInterestsAverage.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS250, 'U', 11, 0)
    
            Data Elements:
    
            RP:^IDS250 = tns:Capital.ThinCapitalisation.ExcludedEquityInterestsAverage.Amount
            */
            assertion = NotMonetary(report.IDS250, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Capital.ThinCapitalisation.ExcludedEquityInterestsAverage.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440189" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS250", Value = report.IDS250.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440189

            #region VR.ATO.IDS.440190

            /*  VR.ATO.IDS.440190
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS251] <> NULL AND [IDS251] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS251] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.ZeroCapitalAverage.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS251, 'U', 11, 0)
    
            Data Elements:
    
            RP:^IDS251 = tns:Capital.ThinCapitalisation.ZeroCapitalAverage.Amount
            */
            assertion = NotMonetary(report.IDS251, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Capital.ThinCapitalisation.ZeroCapitalAverage.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440190" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS251", Value = report.IDS251.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440190

            #region VR.ATO.IDS.440191

            /*  VR.ATO.IDS.440191
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS252] <> NULL AND [IDS252] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS252] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.OnLentAverage.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS252, 'U', 11, 0)
    
            Data Elements:
    
            RP:^IDS252 = tns:Liabilities.ThinCapitalisation.OnLentAverage.Amount
            */
            assertion = NotMonetary(report.IDS252, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Liabilities.ThinCapitalisation.OnLentAverage.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440191" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS252", Value = report.IDS252.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440191

            #region VR.ATO.IDS.440192

            /*  VR.ATO.IDS.440192
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS253] <> NULL AND [IDS253] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS253] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.ControlledForeignNonAuthorisedDepositTakingInstitutionEntityEquityAverageValue.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS253, 'U', 11, 0)
    
            Data Elements:
    
            RP:^IDS253 = tns:Capital.ThinCapitalisation.ControlledForeignNonAuthorisedDepositTakingInstitutionEntityEquityAverageValue.Amount
            */
            assertion = NotMonetary(report.IDS253, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Capital.ThinCapitalisation.ControlledForeignNonAuthorisedDepositTakingInstitutionEntityEquityAverageValue.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440192" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS253", Value = report.IDS253.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440192

            #region VR.ATO.IDS.440193

            /*  VR.ATO.IDS.440193
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS254] <> NULL AND [IDS254] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS254] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.ControlledForeignEntityDebtAverageValue.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS254, 'U', 11, 0)
    
            Data Elements:
    
            RP:^IDS254 = tns:Capital.ThinCapitalisation.ControlledForeignEntityDebtAverageValue.Amount
            */
            assertion = NotMonetary(report.IDS254, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Capital.ThinCapitalisation.ControlledForeignEntityDebtAverageValue.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440193" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS254", Value = report.IDS254.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440193

            #region VR.ATO.IDS.440194

            /*  VR.ATO.IDS.440194
            If Thin capitalisation information has been completed for arm's length debt (non-ADI) or capital (ADI) amount then the response to 'Did you rely on arm's length tests?' must be 'Yes'.
    
            Legacy Rule Format:
            IF [IDS255] <> TRUE AND [IDS256] <> NULL
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS255] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.ArmsLengthTests.Indicator
            [IDS256] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.ArmsLengthDebt.Amount

            Technical Business Rule Format:
            ^IDS255 <> TRUE AND ^IDS256 <> NULL
    
            Data Elements:
    
            RP:^IDS255 = tns:Liabilities.ThinCapitalisation.ArmsLengthTests.Indicator
    
            RP:^IDS256 = tns:Capital.ThinCapitalisation.ArmsLengthDebt.Amount
            */
            assertion = (report.IDS255 != true && report.IDS256 != null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440194",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Thin capitalisation question incorrect",
                    LongDescription = @"If Thin capitalisation information has been completed for arm's length debt (non-ADI) or capital (ADI) amount then the response to 'Did you rely on arm's length tests?' must be 'True'",
                    Location = "/xbrli:xbrl/tns:Liabilities.ThinCapitalisation.ArmsLengthTests.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440194" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS255", Value = GetValueOrEmpty(report.IDS255) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS256", Value = report.IDS256.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440194

            #region VR.ATO.IDS.440195

            /*  VR.ATO.IDS.440195
            If there is a 'Yes' response to 'Did you rely on arm's length tests?' then arm's length debt (non-ADI) or capital (ADI) amount must be completed.
    
            Legacy Rule Format:
            IF [IDS255] = TRUE AND [IDS256] = NULL
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS255] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.ArmsLengthTests.Indicator
            [IDS256] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.ArmsLengthDebt.Amount

            Technical Business Rule Format:
            ^IDS255 = TRUE AND ^IDS256 = NULL
    
            Data Elements:
    
            RP:^IDS255 = tns:Liabilities.ThinCapitalisation.ArmsLengthTests.Indicator
    
            RP:^IDS256 = tns:Capital.ThinCapitalisation.ArmsLengthDebt.Amount
            */
            assertion = (report.IDS255 == true && report.IDS256 == null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440195",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Thin capitalisation information required",
                    LongDescription = @"If there is a 'True' response to 'Did you rely on arm's length tests?' then arm's length debt (non-ADI) or capital (ADI) amount must be completed",
                    Location = "/xbrli:xbrl/tns:Liabilities.ThinCapitalisation.ArmsLengthTests.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440195" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS255", Value = GetValueOrEmpty(report.IDS255) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS256", Value = report.IDS256.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440195

            #region VR.ATO.IDS.440196

            /*  VR.ATO.IDS.440196
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS256] <> NULL AND [IDS256] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS256] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.ArmsLengthDebt.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS256, 'U', 11, 0)
    
            Data Elements:
    
            RP:^IDS256 = tns:Capital.ThinCapitalisation.ArmsLengthDebt.Amount
            */
            assertion = NotMonetary(report.IDS256, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Capital.ThinCapitalisation.ArmsLengthDebt.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440196" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS256", Value = report.IDS256.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440196

            #region VR.ATO.IDS.440197

            /*  VR.ATO.IDS.440197
            If Thin capitalisation information has been completed for worldwide gearing debt/capital tests then the response to 'Did you rely on worldwide gearing debt/capital tests?' must be 'Yes'.
    
            Legacy Rule Format:
            IF [IDS257] <> TRUE AND ([IDS258] <> NULL OR [IDS259] <> NULL OR [IDS260] <> NULL OR [IDS261] <> NULL OR [IDS262] <> NULL OR [IDS323] <> NULL OR [IDS324] <> NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS257] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.GearingDebtCapitalTest.Indicator
            [IDS258] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.WorldwideGroupCapitalRatio.Fraction
            [IDS259] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.WorldwideCapital.Amount
            [IDS260] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.WorldwideDebtTotal.Amount
            [IDS261] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.WorldwideEquity.Amount
            [IDS262] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.WorldwideGearingDebt.Amount
            [IDS323] = IDS:RP:bafpo6.02.13:Capital.ThinCapitalisation.StatementWorldwideAsset.Amount
            [IDS324] = IDS:RP:bafpo6.02.13:Capital.ThinCapitalisation.AverageAustralianAsset.Amount

            Technical Business Rule Format:
            ^IDS257 <> TRUE AND (^IDS258 <> NULL OR ^IDS259 <> NULL OR ^IDS260 <> NULL OR ^IDS261 <> NULL OR ^IDS262 <> NULL OR ^IDS323 <> NULL OR ^IDS324 <> NULL)
    
            Data Elements:
    
            RP:^IDS257 = tns:Liabilities.ThinCapitalisation.GearingDebtCapitalTest.Indicator
    
            RP:^IDS258 = tns:Capital.ThinCapitalisation.WorldwideGroupCapitalRatio.Fraction
    
            RP:^IDS259 = tns:Capital.ThinCapitalisation.WorldwideCapital.Amount
    
            RP:^IDS260 = tns:Capital.ThinCapitalisation.WorldwideDebtTotal.Amount
    
            RP:^IDS261 = tns:Liabilities.ThinCapitalisation.WorldwideEquity.Amount
    
            RP:^IDS262 = tns:Capital.ThinCapitalisation.WorldwideGearingDebt.Amount
    
            RP:^IDS323 = tns:Capital.ThinCapitalisation.StatementWorldwideAsset.Amount
    
            RP:^IDS324 = tns:Capital.ThinCapitalisation.AverageAustralianAsset.Amount
            */
            assertion = (report.IDS257 != true && (report.IDS258 != null || report.IDS259 != null || report.IDS260 != null || report.IDS261 != null || report.IDS262 != null || report.IDS323 != null || report.IDS324 != null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440197",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Thin capitalisation question incorrect",
                    LongDescription = @"If Thin capitalisation information has been completed for worldwide gearing debt/capital tests then the response to 'Did you rely on worldwide gearing debt/capital tests?' must be 'True'",
                    Location = "/xbrli:xbrl/tns:Liabilities.ThinCapitalisation.GearingDebtCapitalTest.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440197" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS257", Value = GetValueOrEmpty(report.IDS257) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS258", Value = report.IDS258.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS259", Value = report.IDS259.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS260", Value = report.IDS260.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS261", Value = report.IDS261.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS262", Value = report.IDS262.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS323", Value = report.IDS323.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS324", Value = report.IDS324.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440197

            #region VR.ATO.IDS.440198

            /*  VR.ATO.IDS.440198
            If there is a 'Yes' response to 'Did you rely on worldwide gearing debt/capital tests?' then all applicable worldwide gearing debt/capital test information must be completed.
    
            Legacy Rule Format:
            IF [IDS257] = TRUE AND [IDS258] = NULL AND [IDS259] = NULL AND [IDS260] = NULL AND [IDS261] = NULL AND [IDS262] = NULL AND [IDS323] = NULL AND [IDS324] = NULL
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS257] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.GearingDebtCapitalTest.Indicator
            [IDS258] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.WorldwideGroupCapitalRatio.Fraction
            [IDS259] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.WorldwideCapital.Amount
            [IDS260] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.WorldwideDebtTotal.Amount
            [IDS261] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.WorldwideEquity.Amount
            [IDS262] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.WorldwideGearingDebt.Amount
            [IDS323] = IDS:RP:bafpo6.02.13:Capital.ThinCapitalisation.StatementWorldwideAsset.Amount
            [IDS324] = IDS:RP:bafpo6.02.13:Capital.ThinCapitalisation.AverageAustralianAsset.Amount

            Technical Business Rule Format:
            ^IDS257 = TRUE AND ^IDS258 = NULL AND ^IDS259 = NULL AND ^IDS260 = NULL AND ^IDS261 = NULL AND ^IDS262 = NULL AND ^IDS323 = NULL AND ^IDS324 = NULL
    
            Data Elements:
    
            RP:^IDS257 = tns:Liabilities.ThinCapitalisation.GearingDebtCapitalTest.Indicator
    
            RP:^IDS258 = tns:Capital.ThinCapitalisation.WorldwideGroupCapitalRatio.Fraction
    
            RP:^IDS259 = tns:Capital.ThinCapitalisation.WorldwideCapital.Amount
    
            RP:^IDS260 = tns:Capital.ThinCapitalisation.WorldwideDebtTotal.Amount
    
            RP:^IDS261 = tns:Liabilities.ThinCapitalisation.WorldwideEquity.Amount
    
            RP:^IDS262 = tns:Capital.ThinCapitalisation.WorldwideGearingDebt.Amount
    
            RP:^IDS323 = tns:Capital.ThinCapitalisation.StatementWorldwideAsset.Amount
    
            RP:^IDS324 = tns:Capital.ThinCapitalisation.AverageAustralianAsset.Amount
            */
            assertion = (report.IDS257 == true && report.IDS258 == null && report.IDS259 == null && report.IDS260 == null && report.IDS261 == null && report.IDS262 == null && report.IDS323 == null && report.IDS324 == null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440198",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Thin capitalisation information required",
                    LongDescription = @"If there is a 'True' response to 'Did you rely on worldwide gearing debt/capital tests?' then all applicable worldwide gearing debt/capital test information must be completed",
                    Location = "/xbrli:xbrl/tns:Liabilities.ThinCapitalisation.GearingDebtCapitalTest.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440198" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS257", Value = GetValueOrEmpty(report.IDS257) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS258", Value = report.IDS258.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS259", Value = report.IDS259.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS260", Value = report.IDS260.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS261", Value = report.IDS261.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS262", Value = report.IDS262.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS323", Value = report.IDS323.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS324", Value = report.IDS324.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440198

            #region VR.ATO.IDS.440199

            /*  VR.ATO.IDS.440199
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS259] <> NULL AND [IDS259] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS259] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.WorldwideCapital.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS259, 'U', 11, 0)
    
            Data Elements:
    
            RP:^IDS259 = tns:Capital.ThinCapitalisation.WorldwideCapital.Amount
            */
            assertion = NotMonetary(report.IDS259, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Capital.ThinCapitalisation.WorldwideCapital.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440199" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS259", Value = report.IDS259.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440199

            #region VR.ATO.IDS.440200

            /*  VR.ATO.IDS.440200
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS260] <> NULL AND [IDS260] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS260] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.WorldwideDebtTotal.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS260, 'U', 11, 0)
    
            Data Elements:
    
            RP:^IDS260 = tns:Capital.ThinCapitalisation.WorldwideDebtTotal.Amount
            */
            assertion = NotMonetary(report.IDS260, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Capital.ThinCapitalisation.WorldwideDebtTotal.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440200" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS260", Value = report.IDS260.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440200

            #region VR.ATO.IDS.440201

            /*  VR.ATO.IDS.440201
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS261] <> NULL AND [IDS261] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS261] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.WorldwideEquity.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS261, 'U', 11, 0)
    
            Data Elements:
    
            RP:^IDS261 = tns:Liabilities.ThinCapitalisation.WorldwideEquity.Amount
            */
            assertion = NotMonetary(report.IDS261, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Liabilities.ThinCapitalisation.WorldwideEquity.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440201" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS261", Value = report.IDS261.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440201

            #region VR.ATO.IDS.440202

            /*  VR.ATO.IDS.440202
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS262] <> NULL AND [IDS262] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS262] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.WorldwideGearingDebt.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS262, 'U', 11, 0)
    
            Data Elements:
    
            RP:^IDS262 = tns:Capital.ThinCapitalisation.WorldwideGearingDebt.Amount
            */
            assertion = NotMonetary(report.IDS262, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Capital.ThinCapitalisation.WorldwideGearingDebt.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440202" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS262", Value = report.IDS262.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440202

            #region VR.ATO.IDS.440203

            /*  VR.ATO.IDS.440203
            If there is a 'No' response to 'Are you a foreign bank or other qualifying financial entity that has not elected out of Part IIIB of the ITAA 1936?' then amounts under sections 160ZZZ, 160ZZZA or 160ZZZJ should not be completed.
    
            Legacy Rule Format:
            IF [IDS263] = FALSE AND ([IDS264] <> NULL OR [IDS265] <> NULL OR [IDS266] <> NULL OR [IDS267] <> NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS263] = IDS:RP:bafot.02.11:FinancialServices.ForeignBankOrQualifyingFinancialEntity.Indicator
            [IDS264] = IDS:RP.Quarterly:bafot.02.11:FinancialServices.NotionalAverageBorrowings.Amount
            [IDS265] = IDS:RP:bafot.02.11:FinancialServices.NonOffshoreBankingUnitNotionalInterest.Amount
            [IDS266] = IDS:RP:bafot.02.11:FinancialServices.OffshoreBankingUnitNotionalInterest.Amount
            [IDS267] = IDS:RP:bafot.02.11:FinancialServices.NotionalInterestTaxWithholding.Amount

            Technical Business Rule Format:
            ^IDS263 = FALSE AND (^IDS264 <> NULL OR ^IDS265 <> NULL OR ^IDS266 <> NULL OR ^IDS267 <> NULL)
    
            Data Elements:
    
            RP:^IDS263 = tns:FinancialServices.ForeignBankOrQualifyingFinancialEntity.Indicator
    
            RP.Quarterly:^IDS264 = tns:FinancialServices.NotionalAverageBorrowings.Amount
    
            RP:^IDS265 = tns:FinancialServices.NonOffshoreBankingUnitNotionalInterest.Amount
    
            RP:^IDS266 = tns:FinancialServices.OffshoreBankingUnitNotionalInterest.Amount
    
            RP:^IDS267 = tns:FinancialServices.NotionalInterestTaxWithholding.Amount
            */
            assertion = (report.IDS263 == false && (report.IDS264 != null || report.IDS265 != null || report.IDS266 != null || report.IDS267 != null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440203",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Financial services entities information not required",
                    LongDescription = @"If there is a 'False' response to 'Are you a foreign bank or other qualifying financial entity that has not elected out of Part IIIB of the ITAA 1936?' then amounts under sections 160ZZZ, 160ZZZA or 160ZZZJ should not be completed",
                    Location = "/xbrli:xbrl/tns:FinancialServices.ForeignBankOrQualifyingFinancialEntity.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440203" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS263", Value = GetValueOrEmpty(report.IDS263) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS264", Value = report.IDS264.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS265", Value = report.IDS265.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS266", Value = report.IDS266.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS267", Value = report.IDS267.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440203

            #region VR.ATO.IDS.440204

            /*  VR.ATO.IDS.440204
            If there is a 'Yes' response to 'Are you a foreign bank or other qualifying financial entity that has not elected out of Part IIIB of the ITAA 1936?' then amounts under sections 160ZZZ, 160ZZZA or 160ZZZJ must be completed.
    
            Legacy Rule Format:
            IF [IDS263] = TRUE AND [IDS264] = NULL AND [IDS265] = NULL AND [IDS266] = NULL AND [IDS267] = NULL
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS263] = IDS:RP:bafot.02.11:FinancialServices.ForeignBankOrQualifyingFinancialEntity.Indicator
            [IDS264] = IDS:RP.Quarterly:bafot.02.11:FinancialServices.NotionalAverageBorrowings.Amount
            [IDS265] = IDS:RP:bafot.02.11:FinancialServices.NonOffshoreBankingUnitNotionalInterest.Amount
            [IDS266] = IDS:RP:bafot.02.11:FinancialServices.OffshoreBankingUnitNotionalInterest.Amount
            [IDS267] = IDS:RP:bafot.02.11:FinancialServices.NotionalInterestTaxWithholding.Amount

            Technical Business Rule Format:
            ^IDS263 = TRUE AND ^IDS264 = NULL AND ^IDS265 = NULL AND ^IDS266 = NULL AND ^IDS267 = NULL
    
            Data Elements:
    
            RP:^IDS263 = tns:FinancialServices.ForeignBankOrQualifyingFinancialEntity.Indicator
    
            RP.Quarterly:^IDS264 = tns:FinancialServices.NotionalAverageBorrowings.Amount
    
            RP:^IDS265 = tns:FinancialServices.NonOffshoreBankingUnitNotionalInterest.Amount
    
            RP:^IDS266 = tns:FinancialServices.OffshoreBankingUnitNotionalInterest.Amount
    
            RP:^IDS267 = tns:FinancialServices.NotionalInterestTaxWithholding.Amount
            */
            assertion = (report.IDS263 == true && report.IDS264 == null && report.IDS265 == null && report.IDS266 == null && report.IDS267 == null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440204",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Financial services entities information required",
                    LongDescription = @"If there is a 'True' response to 'Are you a foreign bank or other qualifying financial entity that has not elected out of Part IIIB of the ITAA 1936?' then amounts under sections 160ZZZ, 160ZZZA or 160ZZZJ must be completed",
                    Location = "/xbrli:xbrl/tns:FinancialServices.ForeignBankOrQualifyingFinancialEntity.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440204" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS263", Value = GetValueOrEmpty(report.IDS263) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS264", Value = report.IDS264.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS265", Value = report.IDS265.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS266", Value = report.IDS266.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS267", Value = report.IDS267.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440204

            #region VR.ATO.IDS.440205

            /*  VR.ATO.IDS.440205
            This field is Mandatory - must be completed
    
            Legacy Rule Format:
            IF [IDS263] = NULL
            RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS263] = IDS:RP:bafot.02.11:FinancialServices.ForeignBankOrQualifyingFinancialEntity.Indicator

            Technical Business Rule Format:
            ^IDS263 = NULL
    
            Data Elements:
    
            RP:^IDS263 = tns:FinancialServices.ForeignBankOrQualifyingFinancialEntity.Indicator
            */
            assertion = (report.IDS263 == null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001001",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Mandatory field not supplied",
                    Location = "/xbrli:xbrl/tns:FinancialServices.ForeignBankOrQualifyingFinancialEntity.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440205" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS263", Value = GetValueOrEmpty(report.IDS263) });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440205

            #region VR.ATO.IDS.440206

            /*  VR.ATO.IDS.440206
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS264] <> NULL AND [IDS264] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS264] = IDS:RP.Quarterly:bafot.02.11:FinancialServices.NotionalAverageBorrowings.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS264, 'U', 11, 0)
    
            Data Elements:
    
            RP.Quarterly:^IDS264 = tns:FinancialServices.NotionalAverageBorrowings.Amount
            */
            assertion = NotMonetary(report.IDS264, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:FinancialServices.NotionalAverageBorrowings.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440206" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS264", Value = report.IDS264.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440206

            #region VR.ATO.IDS.440207

            /*  VR.ATO.IDS.440207
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS265] <> NULL AND [IDS265] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS265] = IDS:RP:bafot.02.11:FinancialServices.NonOffshoreBankingUnitNotionalInterest.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS265, 'U', 11, 0)
    
            Data Elements:
    
            RP:^IDS265 = tns:FinancialServices.NonOffshoreBankingUnitNotionalInterest.Amount
            */
            assertion = NotMonetary(report.IDS265, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:FinancialServices.NonOffshoreBankingUnitNotionalInterest.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440207" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS265", Value = report.IDS265.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440207

            #region VR.ATO.IDS.440208

            /*  VR.ATO.IDS.440208
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS266] <> NULL AND [IDS266] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS266] = IDS:RP:bafot.02.11:FinancialServices.OffshoreBankingUnitNotionalInterest.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS266, 'U', 11, 0)
    
            Data Elements:
    
            RP:^IDS266 = tns:FinancialServices.OffshoreBankingUnitNotionalInterest.Amount
            */
            assertion = NotMonetary(report.IDS266, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingUnitNotionalInterest.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440208" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS266", Value = report.IDS266.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440208

            #region VR.ATO.IDS.440209

            /*  VR.ATO.IDS.440209
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS267] <> NULL AND [IDS267] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS267] = IDS:RP:bafot.02.11:FinancialServices.NotionalInterestTaxWithholding.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS267, 'U', 11, 0)
    
            Data Elements:
    
            RP:^IDS267 = tns:FinancialServices.NotionalInterestTaxWithholding.Amount
            */
            assertion = NotMonetary(report.IDS267, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:FinancialServices.NotionalInterestTaxWithholding.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440209" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS267", Value = report.IDS267.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440209

            #region VR.ATO.IDS.440210

            /*  VR.ATO.IDS.440210
            If there is a 'No' response to 'Were you an offshore banking unit (OBU) or the head company of a consolidated group that included an OBU?' then assessable OB income, net OB income/loss, assessable OB income from related parties or eligible fraction of foreign income tax on OB income claimed under division 770 should not be completed.
    
            Legacy Rule Format:
            IF [IDS268] = FALSE AND ([IDS269] <> NULL OR [IDS270] <> NULL OR [IDS271] <> NULL OR [IDS272] <> NULL OR [IDS273] <> NULL OR [IDS274] <> NULL OR [IDS275] <> NULL OR [IDS276] <> NULL OR [IDS277] <> NULL OR [IDS278] <> NULL OR [IDS279] <> NULL OR [IDS280] <> NULL OR [IDS281] <> NULL OR [IDS282] <> NULL OR [IDS283] <> NULL OR [IDS284] <> NULL OR [IDS285] <> NULL OR [IDS286] <> NULL OR [IDS287] <> NULL OR [IDS288] <> NULL OR [IDS289] <> NULL OR [IDS290] <> NULL OR [IDS291] <> NULL OR [IDS292] <> NULL OR [IDS293] <> NULL OR [IDS294] <> NULL OR [IDS295] <> NULL OR [IDS296] <> NULL OR [IDS303] <> NULL OR [IDS304] <> NULL OR [IDS305] <> NULL OR [IDS306] <> NULL OR [IDS326] <> NULL OR [IDS327] <> NULL OR [IDS328] <> NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS268] = IDS:RP:bafot.02.11:FinancialServices.OffshoreBankingUnitOrHeadConsolidatedGroup.Indicator
            [IDS269] = IDS:RP.Borrowing:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS270] = IDS:RP.Borrowing:bafot.02.11:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
            [IDS271] = IDS:RP.Borrowing.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS272] = IDS:RP.Lending:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS273] = IDS:RP.Lending:bafot.02.11:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
            [IDS274] = IDS:RP.Lending.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS275] = IDS:RP.GuaranteeType:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS276] = IDS:RP.GuaranteeType:bafot.02.11:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
            [IDS277] = IDS:RP.GuaranteeType.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS278] = IDS:RP.Trading:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS279] = IDS:RP.Trading:bafot.02.11:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
            [IDS280] = IDS:RP.Trading.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS281] = IDS:RP.EligibleContract:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS282] = IDS:RP.EligibleContract:bafot.02.11:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
            [IDS283] = IDS:RP.EligibleContract.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS284] = IDS:RP.Investment:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS285] = IDS:RP.Investment:bafot.02.11:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
            [IDS286] = IDS:RP.Investment.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS287] = IDS:RP.Advisory:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS288] = IDS:RP.Advisory:bafot.02.11:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
            [IDS289] = IDS:RP.Advisory.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS290] = IDS:RP.Hedging:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS291] = IDS:RP.Hedging:bafot.02.11:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
            [IDS292] = IDS:RP.Hedging.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS293] = IDS:RP.Other:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS294] = IDS:RP.Other:bafot.02.11:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
            [IDS295] = IDS:RP.Other.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS296] = IDS:RP.GeneralDeduction:bafot.02.11:FinancialServices.GeneralOffshoreBankingDeductionAndApportionableOffshoreBankingDeduction.Amount
            [IDS303] = IDS:RP.TotalNet:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS304] = IDS:RP.TotalNet:bafot.02.11:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
            [IDS305] = IDS:RP.TotalNet.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS306] = IDS:RP.Division770:bafot.02.11:FinancialServices.OffshoreBankingIncomeForeignIncomeTaxEligibleFractionClaimed.Amount
            [IDS326] = IDS:RP.Leasing:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS327] = IDS:RP.Leasing:bafot.02.11:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
            [IDS328] = IDS:RP.Leasing.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount

            Technical Business Rule Format:
            ^IDS268 = FALSE AND (^IDS269 <> NULL OR ^IDS270 <> NULL OR ^IDS271 <> NULL OR ^IDS272 <> NULL OR ^IDS273 <> NULL OR ^IDS274 <> NULL OR ^IDS275 <> NULL OR ^IDS276 <> NULL OR ^IDS277 <> NULL OR ^IDS278 <> NULL OR ^IDS279 <> NULL OR ^IDS280 <> NULL OR ^IDS281 <> NULL OR ^IDS282 <> NULL OR ^IDS283 <> NULL OR ^IDS284 <> NULL OR ^IDS285 <> NULL OR ^IDS286 <> NULL OR ^IDS287 <> NULL OR ^IDS288 <> NULL OR ^IDS289 <> NULL OR ^IDS290 <> NULL OR ^IDS291 <> NULL OR ^IDS292 <> NULL OR ^IDS293 <> NULL OR ^IDS294 <> NULL OR ^IDS295 <> NULL OR ^IDS296 <> NULL OR ^IDS303 <> NULL OR ^IDS304 <> NULL OR ^IDS305 <> NULL OR ^IDS306 <> NULL OR ^IDS326 <> NULL OR ^IDS327 <> NULL OR ^IDS328 <> NULL)
    
            Data Elements:
    
            RP:^IDS268 = tns:FinancialServices.OffshoreBankingUnitOrHeadConsolidatedGroup.Indicator
    
            RP.Borrowing:^IDS269 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Borrowing:^IDS270 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
    
            RP.Borrowing.RelatedParty:^IDS271 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Lending:^IDS272 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Lending:^IDS273 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
    
            RP.Lending.RelatedParty:^IDS274 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.GuaranteeType:^IDS275 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.GuaranteeType:^IDS276 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
    
            RP.GuaranteeType.RelatedParty:^IDS277 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Trading:^IDS278 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Trading:^IDS279 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
    
            RP.Trading.RelatedParty:^IDS280 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.EligibleContract:^IDS281 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.EligibleContract:^IDS282 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
    
            RP.EligibleContract.RelatedParty:^IDS283 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Investment:^IDS284 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Investment:^IDS285 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
    
            RP.Investment.RelatedParty:^IDS286 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Advisory:^IDS287 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Advisory:^IDS288 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
    
            RP.Advisory.RelatedParty:^IDS289 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Hedging:^IDS290 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Hedging:^IDS291 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
    
            RP.Hedging.RelatedParty:^IDS292 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Other:^IDS293 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Other:^IDS294 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
    
            RP.Other.RelatedParty:^IDS295 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.GeneralDeduction:^IDS296 = tns:FinancialServices.GeneralOffshoreBankingDeductionAndApportionableOffshoreBankingDeduction.Amount
    
            RP.TotalNet:^IDS303 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.TotalNet:^IDS304 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
    
            RP.TotalNet.RelatedParty:^IDS305 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Division770:^IDS306 = tns:FinancialServices.OffshoreBankingIncomeForeignIncomeTaxEligibleFractionClaimed.Amount
    
            RP.Leasing:^IDS326 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Leasing:^IDS327 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
    
            RP.Leasing.RelatedParty:^IDS328 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            */
            assertion = (report.IDS268 == false && (report.IDS269 != null || report.IDS270 != null || report.IDS271 != null || report.IDS272 != null || report.IDS273 != null || report.IDS274 != null || report.IDS275 != null || report.IDS276 != null || report.IDS277 != null || report.IDS278 != null || report.IDS279 != null || report.IDS280 != null || report.IDS281 != null || report.IDS282 != null || report.IDS283 != null || report.IDS284 != null || report.IDS285 != null || report.IDS286 != null || report.IDS287 != null || report.IDS288 != null || report.IDS289 != null || report.IDS290 != null || report.IDS291 != null || report.IDS292 != null || report.IDS293 != null || report.IDS294 != null || report.IDS295 != null || report.IDS296 != null || report.IDS303 != null || report.IDS304 != null || report.IDS305 != null || report.IDS306 != null || report.IDS326 != null || report.IDS327 != null || report.IDS328 != null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440210",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Financial services entities information not required",
                    LongDescription = @"If there is a 'False' response to 'Were you an offshore banking unit (OBU) or the head company of a consolidated group that included an OBU?' then assessable OB income, net OB income/loss, assessable OB income from related parties or eligible fraction of foreign income tax on OB income claimed under division 770 should not be completed",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingUnitOrHeadConsolidatedGroup.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440210" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS268", Value = GetValueOrEmpty(report.IDS268) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS269", Value = report.IDS269.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS270", Value = report.IDS270.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS271", Value = report.IDS271.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS272", Value = report.IDS272.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS273", Value = report.IDS273.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS274", Value = report.IDS274.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS275", Value = report.IDS275.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS276", Value = report.IDS276.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS277", Value = report.IDS277.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS278", Value = report.IDS278.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS279", Value = report.IDS279.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS280", Value = report.IDS280.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS281", Value = report.IDS281.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS282", Value = report.IDS282.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS283", Value = report.IDS283.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS284", Value = report.IDS284.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS285", Value = report.IDS285.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS286", Value = report.IDS286.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS287", Value = report.IDS287.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS288", Value = report.IDS288.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS289", Value = report.IDS289.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS290", Value = report.IDS290.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS291", Value = report.IDS291.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS292", Value = report.IDS292.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS293", Value = report.IDS293.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS294", Value = report.IDS294.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS295", Value = report.IDS295.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS296", Value = report.IDS296.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS303", Value = report.IDS303.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS304", Value = report.IDS304.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS305", Value = report.IDS305.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS306", Value = report.IDS306.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS326", Value = report.IDS326.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS327", Value = report.IDS327.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS328", Value = report.IDS328.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440210

            #region VR.ATO.IDS.440211

            /*  VR.ATO.IDS.440211
            If there is a 'Yes' response to 'Were you an offshore banking unit (OBU) or the head company of a consolidated group that included an OBU?' then assessable OB income, net OB income/loss, assessable OB income from related parties or eligible fraction of foreign income tax on OB income claimed under division 770 must be completed.
    
            Legacy Rule Format:
            IF [IDS268] = TRUE AND ([IDS269] = NULL AND [IDS270] = NULL AND [IDS271] = NULL AND [IDS272] = NULL AND [IDS273] = NULL AND [IDS274] = NULL AND [IDS275] = NULL AND [IDS276] = NULL AND [IDS277] = NULL AND [IDS278] = NULL AND [IDS279] = NULL AND [IDS280] = NULL AND [IDS281] = NULL AND [IDS282] = NULL AND [IDS283] = NULL AND [IDS284] = NULL AND [IDS285] = NULL AND [IDS286] = NULL AND [IDS287] = NULL AND [IDS288] = NULL AND [IDS289] = NULL AND [IDS290] = NULL AND [IDS291] = NULL AND [IDS292] = NULL AND [IDS293] = NULL AND [IDS294] = NULL AND [IDS295] = NULL AND [IDS296] = NULL AND [IDS303] = NULL AND [IDS304] = NULL AND [IDS305] = NULL AND [IDS306] = NULL AND [IDS326] = NULL AND [IDS327] = NULL AND [IDS328] = NULL)
               RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS268] = IDS:RP:bafot.02.11:FinancialServices.OffshoreBankingUnitOrHeadConsolidatedGroup.Indicator
            [IDS269] = IDS:RP.Borrowing:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS270] = IDS:RP.Borrowing:bafot.02.11:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
            [IDS271] = IDS:RP.Borrowing.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS272] = IDS:RP.Lending:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS273] = IDS:RP.Lending:bafot.02.11:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
            [IDS274] = IDS:RP.Lending.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS275] = IDS:RP.GuaranteeType:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS276] = IDS:RP.GuaranteeType:bafot.02.11:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
            [IDS277] = IDS:RP.GuaranteeType.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS278] = IDS:RP.Trading:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS279] = IDS:RP.Trading:bafot.02.11:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
            [IDS280] = IDS:RP.Trading.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS281] = IDS:RP.EligibleContract:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS282] = IDS:RP.EligibleContract:bafot.02.11:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
            [IDS283] = IDS:RP.EligibleContract.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS284] = IDS:RP.Investment:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS285] = IDS:RP.Investment:bafot.02.11:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
            [IDS286] = IDS:RP.Investment.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS287] = IDS:RP.Advisory:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS288] = IDS:RP.Advisory:bafot.02.11:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
            [IDS289] = IDS:RP.Advisory.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS290] = IDS:RP.Hedging:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS291] = IDS:RP.Hedging:bafot.02.11:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
            [IDS292] = IDS:RP.Hedging.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS293] = IDS:RP.Other:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS294] = IDS:RP.Other:bafot.02.11:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
            [IDS295] = IDS:RP.Other.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS296] = IDS:RP.GeneralDeduction:bafot.02.11:FinancialServices.GeneralOffshoreBankingDeductionAndApportionableOffshoreBankingDeduction.Amount
            [IDS303] = IDS:RP.TotalNet:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS304] = IDS:RP.TotalNet:bafot.02.11:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
            [IDS305] = IDS:RP.TotalNet.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS306] = IDS:RP.Division770:bafot.02.11:FinancialServices.OffshoreBankingIncomeForeignIncomeTaxEligibleFractionClaimed.Amount
            [IDS326] = IDS:RP.Leasing:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS327] = IDS:RP.Leasing:bafot.02.11:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
            [IDS328] = IDS:RP.Leasing.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount

            Technical Business Rule Format:
            ^IDS268 = TRUE AND (^IDS269 = NULL AND ^IDS270 = NULL AND ^IDS271 = NULL AND ^IDS272 = NULL AND ^IDS273 = NULL AND ^IDS274 = NULL AND ^IDS275 = NULL AND ^IDS276 = NULL AND ^IDS277 = NULL AND ^IDS278 = NULL AND ^IDS279 = NULL AND ^IDS280 = NULL AND ^IDS281 = NULL AND ^IDS282 = NULL AND ^IDS283 = NULL AND ^IDS284 = NULL AND ^IDS285 = NULL AND ^IDS286 = NULL AND ^IDS287 = NULL AND ^IDS288 = NULL AND ^IDS289 = NULL AND ^IDS290 = NULL AND ^IDS291 = NULL AND ^IDS292 = NULL AND ^IDS293 = NULL AND ^IDS294 = NULL AND ^IDS295 = NULL AND ^IDS296 = NULL AND ^IDS303 = NULL AND ^IDS304 = NULL AND ^IDS305 = NULL AND ^IDS306 = NULL AND ^IDS326 = NULL AND ^IDS327 = NULL AND ^IDS328 = NULL)
    
            Data Elements:
    
            RP:^IDS268 = tns:FinancialServices.OffshoreBankingUnitOrHeadConsolidatedGroup.Indicator
    
            RP.Borrowing:^IDS269 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Borrowing:^IDS270 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
    
            RP.Borrowing.RelatedParty:^IDS271 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Lending:^IDS272 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Lending:^IDS273 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
    
            RP.Lending.RelatedParty:^IDS274 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.GuaranteeType:^IDS275 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.GuaranteeType:^IDS276 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
    
            RP.GuaranteeType.RelatedParty:^IDS277 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Trading:^IDS278 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Trading:^IDS279 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
    
            RP.Trading.RelatedParty:^IDS280 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.EligibleContract:^IDS281 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.EligibleContract:^IDS282 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
    
            RP.EligibleContract.RelatedParty:^IDS283 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Investment:^IDS284 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Investment:^IDS285 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
    
            RP.Investment.RelatedParty:^IDS286 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Advisory:^IDS287 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Advisory:^IDS288 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
    
            RP.Advisory.RelatedParty:^IDS289 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Hedging:^IDS290 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Hedging:^IDS291 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
    
            RP.Hedging.RelatedParty:^IDS292 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Other:^IDS293 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Other:^IDS294 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
    
            RP.Other.RelatedParty:^IDS295 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.GeneralDeduction:^IDS296 = tns:FinancialServices.GeneralOffshoreBankingDeductionAndApportionableOffshoreBankingDeduction.Amount
    
            RP.TotalNet:^IDS303 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.TotalNet:^IDS304 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
    
            RP.TotalNet.RelatedParty:^IDS305 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Division770:^IDS306 = tns:FinancialServices.OffshoreBankingIncomeForeignIncomeTaxEligibleFractionClaimed.Amount
    
            RP.Leasing:^IDS326 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Leasing:^IDS327 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
    
            RP.Leasing.RelatedParty:^IDS328 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            */
            assertion = (report.IDS268 == true && (report.IDS269 == null && report.IDS270 == null && report.IDS271 == null && report.IDS272 == null && report.IDS273 == null && report.IDS274 == null && report.IDS275 == null && report.IDS276 == null && report.IDS277 == null && report.IDS278 == null && report.IDS279 == null && report.IDS280 == null && report.IDS281 == null && report.IDS282 == null && report.IDS283 == null && report.IDS284 == null && report.IDS285 == null && report.IDS286 == null && report.IDS287 == null && report.IDS288 == null && report.IDS289 == null && report.IDS290 == null && report.IDS291 == null && report.IDS292 == null && report.IDS293 == null && report.IDS294 == null && report.IDS295 == null && report.IDS296 == null && report.IDS303 == null && report.IDS304 == null && report.IDS305 == null && report.IDS306 == null && report.IDS326 == null && report.IDS327 == null && report.IDS328 == null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440211",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Financial services entities information required",
                    LongDescription = @"If there is a 'True' response to 'Were you an offshore banking unit (OBU) or the head company of a consolidated group that included an OBU?' then assessable OB income, net OB income/loss, assessable OB income from related parties or eligible fraction of foreign income tax on OB income claimed under division 770 must be completed",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingUnitOrHeadConsolidatedGroup.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440211" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS268", Value = GetValueOrEmpty(report.IDS268) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS269", Value = report.IDS269.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS270", Value = report.IDS270.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS271", Value = report.IDS271.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS272", Value = report.IDS272.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS273", Value = report.IDS273.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS274", Value = report.IDS274.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS275", Value = report.IDS275.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS276", Value = report.IDS276.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS277", Value = report.IDS277.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS278", Value = report.IDS278.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS279", Value = report.IDS279.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS280", Value = report.IDS280.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS281", Value = report.IDS281.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS282", Value = report.IDS282.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS283", Value = report.IDS283.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS284", Value = report.IDS284.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS285", Value = report.IDS285.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS286", Value = report.IDS286.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS287", Value = report.IDS287.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS288", Value = report.IDS288.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS289", Value = report.IDS289.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS290", Value = report.IDS290.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS291", Value = report.IDS291.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS292", Value = report.IDS292.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS293", Value = report.IDS293.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS294", Value = report.IDS294.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS295", Value = report.IDS295.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS296", Value = report.IDS296.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS303", Value = report.IDS303.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS304", Value = report.IDS304.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS305", Value = report.IDS305.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS306", Value = report.IDS306.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS326", Value = report.IDS326.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS327", Value = report.IDS327.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS328", Value = report.IDS328.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440211

            #region VR.ATO.IDS.440212

            /*  VR.ATO.IDS.440212
            If 'Notional amount of interest taken to be paid under section 160ZZZA attributable to OB activities of OBUs' is greater than zero then there must be a 'Yes' response at 'Were you an offshore banking unit (OBU) or the head company of a consolidated group that included an OBU?' and the relevant labels at 'Were you an offshore banking unit (OBU) or the head company of a consolidated group that included an OBU?' must be completed.
    
            Legacy Rule Format:
            IF [IDS266] > 0 AND [IDS268] = FALSE
               RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS266] = IDS:RP:bafot.02.11:FinancialServices.OffshoreBankingUnitNotionalInterest.Amount
            [IDS268] = IDS:RP:bafot.02.11:FinancialServices.OffshoreBankingUnitOrHeadConsolidatedGroup.Indicator

            Technical Business Rule Format:
            ^IDS266 > 0 AND ^IDS268 = FALSE
    
            Data Elements:
    
            RP:^IDS268 = tns:FinancialServices.OffshoreBankingUnitOrHeadConsolidatedGroup.Indicator
    
            RP:^IDS266 = tns:FinancialServices.OffshoreBankingUnitNotionalInterest.Amount
            */
            assertion = (report.IDS266.GetValueOrDefault() > 0 && report.IDS268 == false);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440212",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Incorrect response for an OBU",
                    LongDescription = @"If 'Notional amount of interest taken to be paid under section 160ZZZA attributable to OB activities of OBUs' is greater than zero then there must be a 'True' response at 'Were you an offshore banking unit (OBU) or the head company of a consolidated group that included an OBU?' and the relevant labels in Question 41 must be completed",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingUnitOrHeadConsolidatedGroup.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440212" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS266", Value = report.IDS266.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS268", Value = GetValueOrEmpty(report.IDS268) });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440212

            #region VR.ATO.IDS.440213

            /*  VR.ATO.IDS.440213
            If there is a 'Yes' response to 'Were you an offshore banking unit (OBU) or the head company of a consolidated group that included an OBU?' then amounts other than zero must be completed at Total assessable OB income, Total net OB income/loss and Eligible fraction of foreign income tax on OB income claimed under division 770.
    
            Legacy Rule Format:
            IF [IDS268] = TRUE AND ([IDS303] = NULL OR [IDS304] = NULL OR [IDS306] = NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS268] = IDS:RP:bafot.02.11:FinancialServices.OffshoreBankingUnitOrHeadConsolidatedGroup.Indicator
            [IDS303] = IDS:RP.TotalNet:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS304] = IDS:RP.TotalNet:bafot.02.11:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
            [IDS306] = IDS:RP.Division770:bafot.02.11:FinancialServices.OffshoreBankingIncomeForeignIncomeTaxEligibleFractionClaimed.Amount

            Technical Business Rule Format:
            ^IDS268 = TRUE AND (^IDS303 = NULL OR ^IDS304 = NULL OR ^IDS306 = NULL)
    
            Data Elements:
    
            RP:^IDS268 = tns:FinancialServices.OffshoreBankingUnitOrHeadConsolidatedGroup.Indicator
    
            RP.TotalNet:^IDS303 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.TotalNet:^IDS304 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
    
            RP.Division770:^IDS306 = tns:FinancialServices.OffshoreBankingIncomeForeignIncomeTaxEligibleFractionClaimed.Amount
            */
            assertion = (report.IDS268 == true && (report.IDS303 == null || report.IDS304 == null || report.IDS306 == null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440314",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"OB income required",
                    LongDescription = @"If there is a 'Yes' response to 'Were you an offshore banking unit (OBU) or the head company of a consolidated group that included an OBU?' then amounts must be completed at Total assessable OB income, Total net OB income/loss and Eligible fraction of foreign income tax on OB income claimed under division 770.",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingUnitOrHeadConsolidatedGroup.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440213" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS268", Value = GetValueOrEmpty(report.IDS268) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS303", Value = report.IDS303.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS304", Value = report.IDS304.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS306", Value = report.IDS306.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440213

            #region VR.ATO.IDS.440214

            /*  VR.ATO.IDS.440214
            This field is Mandatory - must be completed
    
            Legacy Rule Format:
            IF [IDS268] = NULL
            RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS268] = IDS:RP:bafot.02.11:FinancialServices.OffshoreBankingUnitOrHeadConsolidatedGroup.Indicator

            Technical Business Rule Format:
            ^IDS268 = NULL
    
            Data Elements:
    
            RP:^IDS268 = tns:FinancialServices.OffshoreBankingUnitOrHeadConsolidatedGroup.Indicator
            */
            assertion = (report.IDS268 == null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001001",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Mandatory field not supplied",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingUnitOrHeadConsolidatedGroup.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440214" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS268", Value = GetValueOrEmpty(report.IDS268) });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440214

            #region VR.ATO.IDS.440215

            /*  VR.ATO.IDS.440215
            If assessable OB income has been completed then the Total assessable OB income less total OB deductions - assessable OB income should equal the sum of amounts at borrowing, lending, guarantee-type, trading, eligible contract, investment, advisory, hedging, leasing and other.
    
            Legacy Rule Format:
            IF [IDS303] <> ([IDS269] + [IDS272] + [IDS275] + [IDS278] + [IDS281] + [IDS284] + [IDS287] + [IDS290] + [IDS293] + [IDS326])
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS269] = IDS:RP.Borrowing:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS272] = IDS:RP.Lending:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS275] = IDS:RP.GuaranteeType:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS278] = IDS:RP.Trading:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS281] = IDS:RP.EligibleContract:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS284] = IDS:RP.Investment:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS287] = IDS:RP.Advisory:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS290] = IDS:RP.Hedging:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS293] = IDS:RP.Other:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS303] = IDS:RP.TotalNet:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS326] = IDS:RP.Leasing:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount

            Technical Business Rule Format:
            ^IDS303 <> (^IDS269 + ^IDS272 + ^IDS275 + ^IDS278 + ^IDS281 + ^IDS284 + ^IDS287 + ^IDS290 + ^IDS293 + ^IDS326)
    
            Data Elements:
    
            RP.TotalNet:^IDS303 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Borrowing:^IDS269 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Lending:^IDS272 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.GuaranteeType:^IDS275 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Trading:^IDS278 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.EligibleContract:^IDS281 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Investment:^IDS284 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Advisory:^IDS287 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Hedging:^IDS290 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Other:^IDS293 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Leasing:^IDS326 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            */
            assertion = (report.IDS303.GetValueOrDefault() != report.IDS269.GetValueOrDefault() + report.IDS272.GetValueOrDefault() + report.IDS275.GetValueOrDefault() + report.IDS278.GetValueOrDefault() + report.IDS281.GetValueOrDefault() + report.IDS284.GetValueOrDefault() + report.IDS287.GetValueOrDefault() + report.IDS290.GetValueOrDefault() + report.IDS293.GetValueOrDefault() + report.IDS326.GetValueOrDefault());
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440315",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Total assessable OB Income / less Total OB deductions - Assessable OB income incorrect",
                    LongDescription = @"If assessable OB income has been completed then 'Total assessable OB Income / less Total OB deductions - Assessable OB income' should equal the sum of amounts at borrowing, lending, guarantee-type, trading, eligible contract, investment, advisory, hedging and other",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount[@contextRef='" + report.RPTotalNetId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440215" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS303", Value = report.IDS303.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS269", Value = report.IDS269.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS272", Value = report.IDS272.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS275", Value = report.IDS275.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS278", Value = report.IDS278.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS281", Value = report.IDS281.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS284", Value = report.IDS284.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS287", Value = report.IDS287.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS290", Value = report.IDS290.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS293", Value = report.IDS293.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS326", Value = report.IDS326.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440215

            #region VR.ATO.IDS.440216

            /*  VR.ATO.IDS.440216
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS269] <> NULL AND [IDS269] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS269] = IDS:RP.Borrowing:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS269, 'U', 11, 0)
    
            Data Elements:
    
            RP.Borrowing:^IDS269 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            */
            assertion = NotMonetary(report.IDS269, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount[@contextRef='" + report.RPBorrowingId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440216" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS269", Value = report.IDS269.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440216

            #region VR.ATO.IDS.440217

            /*  VR.ATO.IDS.440217
            For each OB activity, if Net OB income/loss has been completed then it must be less than or equal to the Assessable OB income.
    
            Legacy Rule Format:
            IF [IDS270] <> NULL AND ([IDS270] > [IDS269])
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS269] = IDS:RP.Borrowing:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS270] = IDS:RP.Borrowing:bafot.02.11:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount

            Technical Business Rule Format:
            ^IDS270 <> NULL AND (^IDS270 > ^IDS269)
    
            Data Elements:
    
            RP.Borrowing:^IDS270 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
    
            RP.Borrowing:^IDS269 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            */
            assertion = (report.IDS270 != null && report.IDS270.GetValueOrDefault() > report.IDS269.GetValueOrDefault());
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440217",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Net OB income/loss incorrect",
                    LongDescription = @"For each OB activity, if Net OB income/loss has been completed then it must be less than or equal to the Assessable OB income",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount[@contextRef='" + report.RPBorrowingId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440217" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS270", Value = report.IDS270.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS269", Value = report.IDS269.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440217

            #region VR.ATO.IDS.440218

            /*  VR.ATO.IDS.440218
            If net OB income/loss has been completed then the total assessable OB income less total OB deductions - net OB income or loss should equal the sum of amounts at borrowing, lending, guarantee-type, trading, eligible contract, investment, advisory, hedging, leasing and other, less the general OB deduction and apportionable OB deductions.
    
            Legacy Rule Format:
            IF [IDS304] <> ([IDS270] + [IDS273] + [IDS276] + [IDS279] + [IDS282] + [IDS285] + [IDS288] + [IDS291] + [IDS327] + [IDS294] - [IDS296])
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS270] = IDS:RP.Borrowing:bafot.02.11:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
            [IDS273] = IDS:RP.Lending:bafot.02.11:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
            [IDS276] = IDS:RP.GuaranteeType:bafot.02.11:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
            [IDS279] = IDS:RP.Trading:bafot.02.11:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
            [IDS282] = IDS:RP.EligibleContract:bafot.02.11:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
            [IDS285] = IDS:RP.Investment:bafot.02.11:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
            [IDS288] = IDS:RP.Advisory:bafot.02.11:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
            [IDS291] = IDS:RP.Hedging:bafot.02.11:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
            [IDS294] = IDS:RP.Other:bafot.02.11:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
            [IDS296] = IDS:RP.GeneralDeduction:bafot.02.11:FinancialServices.GeneralOffshoreBankingDeductionAndApportionableOffshoreBankingDeduction.Amount
            [IDS304] = IDS:RP.TotalNet:bafot.02.11:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
            [IDS327] = IDS:RP.Leasing:bafot.02.11:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount

            Technical Business Rule Format:
            ^IDS304 <> (^IDS270 + ^IDS273 + ^IDS276 + ^IDS279 + ^IDS282 + ^IDS285 + ^IDS288 + ^IDS291 + ^IDS327 + ^IDS294 - ^IDS296)
    
            Data Elements:
    
            RP.TotalNet:^IDS304 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
    
            RP.Borrowing:^IDS270 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
    
            RP.Lending:^IDS273 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
    
            RP.GuaranteeType:^IDS276 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
    
            RP.Trading:^IDS279 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
    
            RP.EligibleContract:^IDS282 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
    
            RP.Investment:^IDS285 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
    
            RP.Advisory:^IDS288 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
    
            RP.Hedging:^IDS291 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
    
            RP.Other:^IDS294 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
    
            RP.GeneralDeduction:^IDS296 = tns:FinancialServices.GeneralOffshoreBankingDeductionAndApportionableOffshoreBankingDeduction.Amount
    
            RP.Leasing:^IDS327 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
            */
            assertion = (report.IDS304.GetValueOrDefault() != report.IDS270.GetValueOrDefault() + report.IDS273.GetValueOrDefault() + report.IDS276.GetValueOrDefault() + report.IDS279.GetValueOrDefault() + report.IDS282.GetValueOrDefault() + report.IDS285.GetValueOrDefault() + report.IDS288.GetValueOrDefault() + report.IDS291.GetValueOrDefault() + report.IDS327.GetValueOrDefault() + report.IDS294.GetValueOrDefault() - report.IDS296.GetValueOrDefault());
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440316",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Total assessable OB Income / less Total OB deductions - Net OB income/loss incorrect",
                    LongDescription = @"If net OB income/loss has been completed then the 'Total assessable OB Income / less Total OB deductions - Net OB income/loss' should equal the sum of amounts at borrowing, lending, guarantee-type, trading, eligible contract, investment, advisory, hedging and other, less the general OB deduction and apportionable OB deductions",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount[@contextRef='" + report.RPTotalNetId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440218" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS304", Value = report.IDS304.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS270", Value = report.IDS270.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS273", Value = report.IDS273.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS276", Value = report.IDS276.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS279", Value = report.IDS279.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS282", Value = report.IDS282.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS285", Value = report.IDS285.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS288", Value = report.IDS288.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS291", Value = report.IDS291.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS327", Value = report.IDS327.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS294", Value = report.IDS294.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS296", Value = report.IDS296.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440218

            #region VR.ATO.IDS.440219

            /*  VR.ATO.IDS.440219
            Monetary field, may be signed, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF bafot.xx.xx:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount <> NULL AND bafot.xx.xx:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount <> MONETARY(S,11,0)
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS288, 'S', 11, 0)
    
            Data Elements:
    
            RP.Advisory:^IDS288 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
            */
            assertion = NotMonetary(report.IDS288, @"S", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount[@contextRef='" + report.RPAdvisoryId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440219" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS288", Value = report.IDS288.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440219

            #region VR.ATO.IDS.440219

            /*  VR.ATO.IDS.440219
            Monetary field, may be signed, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF bafot.xx.xx:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount <> NULL AND bafot.xx.xx:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount <> MONETARY(S,11,0)
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS270, 'S', 11, 0)
    
            Data Elements:
    
            RP.Borrowing:^IDS270 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
            */
            assertion = NotMonetary(report.IDS270, @"S", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount[@contextRef='" + report.RPBorrowingId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440219" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS270", Value = report.IDS270.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440219

            #region VR.ATO.IDS.440219

            /*  VR.ATO.IDS.440219
            Monetary field, may be signed, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF bafot.xx.xx:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount <> NULL AND bafot.xx.xx:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount <> MONETARY(S,11,0)
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS282, 'S', 11, 0)
    
            Data Elements:
    
            RP.EligibleContract:^IDS282 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
            */
            assertion = NotMonetary(report.IDS282, @"S", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount[@contextRef='" + report.RPEligibleContractId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440219" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS282", Value = report.IDS282.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440219

            #region VR.ATO.IDS.440219

            /*  VR.ATO.IDS.440219
            Monetary field, may be signed, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF bafot.xx.xx:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount <> NULL AND bafot.xx.xx:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount <> MONETARY(S,11,0)
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS276, 'S', 11, 0)
    
            Data Elements:
    
            RP.GuaranteeType:^IDS276 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
            */
            assertion = NotMonetary(report.IDS276, @"S", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount[@contextRef='" + report.RPGuaranteeTypeId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440219" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS276", Value = report.IDS276.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440219

            #region VR.ATO.IDS.440219

            /*  VR.ATO.IDS.440219
            Monetary field, may be signed, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF bafot.xx.xx:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount <> NULL AND bafot.xx.xx:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount <> MONETARY(S,11,0)
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS291, 'S', 11, 0)
    
            Data Elements:
    
            RP.Hedging:^IDS291 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
            */
            assertion = NotMonetary(report.IDS291, @"S", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount[@contextRef='" + report.RPHedgingId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440219" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS291", Value = report.IDS291.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440219

            #region VR.ATO.IDS.440219

            /*  VR.ATO.IDS.440219
            Monetary field, may be signed, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF bafot.xx.xx:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount <> NULL AND bafot.xx.xx:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount <> MONETARY(S,11,0)
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS285, 'S', 11, 0)
    
            Data Elements:
    
            RP.Investment:^IDS285 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
            */
            assertion = NotMonetary(report.IDS285, @"S", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount[@contextRef='" + report.RPInvestmentId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440219" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS285", Value = report.IDS285.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440219

            #region VR.ATO.IDS.440219

            /*  VR.ATO.IDS.440219
            Monetary field, may be signed, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF bafot.xx.xx:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount <> NULL AND bafot.xx.xx:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount <> MONETARY(S,11,0)
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS273, 'S', 11, 0)
    
            Data Elements:
    
            RP.Lending:^IDS273 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
            */
            assertion = NotMonetary(report.IDS273, @"S", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount[@contextRef='" + report.RPLendingId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440219" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS273", Value = report.IDS273.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440219

            #region VR.ATO.IDS.440219

            /*  VR.ATO.IDS.440219
            Monetary field, may be signed, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF bafot.xx.xx:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount <> NULL AND bafot.xx.xx:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount <> MONETARY(S,11,0)
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS294, 'S', 11, 0)
    
            Data Elements:
    
            RP.Other:^IDS294 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
            */
            assertion = NotMonetary(report.IDS294, @"S", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount[@contextRef='" + report.RPOtherId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440219" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS294", Value = report.IDS294.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440219

            #region VR.ATO.IDS.440219

            /*  VR.ATO.IDS.440219
            Monetary field, may be signed, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF bafot.xx.xx:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount <> NULL AND bafot.xx.xx:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount <> MONETARY(S,11,0)
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS304, 'S', 11, 0)
    
            Data Elements:
    
            RP.TotalNet:^IDS304 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
            */
            assertion = NotMonetary(report.IDS304, @"S", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount[@contextRef='" + report.RPTotalNetId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440219" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS304", Value = report.IDS304.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440219

            #region VR.ATO.IDS.440219

            /*  VR.ATO.IDS.440219
            Monetary field, may be signed, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF bafot.xx.xx:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount <> NULL AND bafot.xx.xx:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount <> MONETARY(S,11,0)
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS279, 'S', 11, 0)
    
            Data Elements:
    
            RP.Trading:^IDS279 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
            */
            assertion = NotMonetary(report.IDS279, @"S", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount[@contextRef='" + report.RPTradingId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440219" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS279", Value = report.IDS279.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440219

            #region VR.ATO.IDS.440220

            /*  VR.ATO.IDS.440220
            For each OB activity, if Assessable OB income from related parties has been completed then it must be less than or equal to the Assessable OB income.
    
            Legacy Rule Format:
            IF [IDS271] <> NULL AND ([IDS271] > [IDS269])
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS269] = IDS:RP.Borrowing:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS271] = IDS:RP.Borrowing.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount

            Technical Business Rule Format:
            ^IDS271 <> NULL AND (^IDS271 > ^IDS269)
    
            Data Elements:
    
            RP.Borrowing.RelatedParty:^IDS271 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Borrowing:^IDS269 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            */
            assertion = (report.IDS271 != null && report.IDS271.GetValueOrDefault() > report.IDS269.GetValueOrDefault());
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440220",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Assessable OB income from related parties incorrect",
                    LongDescription = @"For each OB activity, if Assessable OB income from related parties has been completed then it must be less than or equal to the Assessable OB income",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount[@contextRef='" + report.RPBorrowingRelatedPartyId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440220" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS271", Value = report.IDS271.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS269", Value = report.IDS269.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440220

            #region VR.ATO.IDS.440221

            /*  VR.ATO.IDS.440221
            If assessable OB income from related parties has been completed then the total assessable OB income less total OB deductions - assessable OB income from related parties should equal the sum of amounts at borrowing, lending, guarantee-type, trading, eligible contract, investment, advisory, hedging, leasing and other.
    
            Legacy Rule Format:
            IF [IDS305] <> ([IDS271] + [IDS274] + [IDS277] + [IDS280] + [IDS283] + [IDS286] + [IDS289] + [IDS292] + [IDS295] + [IDS328])
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS271] = IDS:RP.Borrowing.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS274] = IDS:RP.Lending.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS277] = IDS:RP.GuaranteeType.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS280] = IDS:RP.Trading.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS283] = IDS:RP.EligibleContract.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS286] = IDS:RP.Investment.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS289] = IDS:RP.Advisory.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS292] = IDS:RP.Hedging.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS295] = IDS:RP.Other.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS305] = IDS:RP.TotalNet.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS328] = IDS:RP.Leasing.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount

            Technical Business Rule Format:
            ^IDS305 <> (^IDS271 + ^IDS274 + ^IDS277 + ^IDS280 + ^IDS283 + ^IDS286 + ^IDS289 + ^IDS292 + ^IDS295 + ^IDS328)
    
            Data Elements:
    
            RP.TotalNet.RelatedParty:^IDS305 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Borrowing.RelatedParty:^IDS271 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Lending.RelatedParty:^IDS274 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.GuaranteeType.RelatedParty:^IDS277 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Trading.RelatedParty:^IDS280 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.EligibleContract.RelatedParty:^IDS283 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Investment.RelatedParty:^IDS286 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Advisory.RelatedParty:^IDS289 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Hedging.RelatedParty:^IDS292 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Other.RelatedParty:^IDS295 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Leasing.RelatedParty:^IDS328 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            */
            assertion = (report.IDS305.GetValueOrDefault() != report.IDS271.GetValueOrDefault() + report.IDS274.GetValueOrDefault() + report.IDS277.GetValueOrDefault() + report.IDS280.GetValueOrDefault() + report.IDS283.GetValueOrDefault() + report.IDS286.GetValueOrDefault() + report.IDS289.GetValueOrDefault() + report.IDS292.GetValueOrDefault() + report.IDS295.GetValueOrDefault() + report.IDS328.GetValueOrDefault());
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440317",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Total assessable OB Income / less Total OB deductions - Assessable OB income from related parties incorrect",
                    LongDescription = @"If assessable OB income from related parties has been completed then 'Total assessable OB Income / less Total OB deductions - Assessable OB income from related parties' should equal the sum of amounts at borrowing, lending, guarantee-type, trading, eligible contract, investment, advisory, hedging and other",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount[@contextRef='" + report.RPTotalNetRelatedPartyId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440221" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS305", Value = report.IDS305.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS271", Value = report.IDS271.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS274", Value = report.IDS274.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS277", Value = report.IDS277.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS280", Value = report.IDS280.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS283", Value = report.IDS283.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS286", Value = report.IDS286.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS289", Value = report.IDS289.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS292", Value = report.IDS292.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS295", Value = report.IDS295.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS328", Value = report.IDS328.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440221

            #region VR.ATO.IDS.440222

            /*  VR.ATO.IDS.440222
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS271] <> NULL AND [IDS271] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS271] = IDS:RP.Borrowing.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS271, 'U', 11, 0)
    
            Data Elements:
    
            RP.Borrowing.RelatedParty:^IDS271 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            */
            assertion = NotMonetary(report.IDS271, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount[@contextRef='" + report.RPBorrowingRelatedPartyId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440222" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS271", Value = report.IDS271.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440222

            #region VR.ATO.IDS.440223

            /*  VR.ATO.IDS.440223
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS272] <> NULL AND [IDS272] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS272] = IDS:RP.Lending:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS272, 'U', 11, 0)
    
            Data Elements:
    
            RP.Lending:^IDS272 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            */
            assertion = NotMonetary(report.IDS272, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount[@contextRef='" + report.RPLendingId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440223" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS272", Value = report.IDS272.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440223

            #region VR.ATO.IDS.440224

            /*  VR.ATO.IDS.440224
            For each OB activity, if Net OB income/loss has been completed then it must be less than or equal to the Assessable OB income.
    
            Legacy Rule Format:
            IF [IDS273] <> NULL AND ([IDS273] > [IDS272])
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS272] = IDS:RP.Lending:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS273] = IDS:RP.Lending:bafot.02.11:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount

            Technical Business Rule Format:
            ^IDS273 <> NULL AND (^IDS273 > ^IDS272)
    
            Data Elements:
    
            RP.Lending:^IDS273 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
    
            RP.Lending:^IDS272 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            */
            assertion = (report.IDS273 != null && report.IDS273.GetValueOrDefault() > report.IDS272.GetValueOrDefault());
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440224",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Net OB income/loss incorrect",
                    LongDescription = @"For each OB activity, if Net OB income/loss has been completed then it must be less than or equal to the Assessable OB income.",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount[@contextRef='" + report.RPLendingId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440224" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS273", Value = report.IDS273.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS272", Value = report.IDS272.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440224

            #region VR.ATO.IDS.440226

            /*  VR.ATO.IDS.440226
            For each OB activity, if Assessable OB income from related parties has been completed then it must be less than or equal to the Assessable OB income.
    
            Legacy Rule Format:
            IF [IDS274] <> NULL AND ([IDS274] > [IDS272])
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS272] = IDS:RP.Lending:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS274] = IDS:RP.Lending.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount

            Technical Business Rule Format:
            ^IDS274 <> NULL AND (^IDS274 > ^IDS272)
    
            Data Elements:
    
            RP.Lending.RelatedParty:^IDS274 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Lending:^IDS272 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            */
            assertion = (report.IDS274 != null && report.IDS274.GetValueOrDefault() > report.IDS272.GetValueOrDefault());
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440226",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Assessable OB income from related parties incorrect",
                    LongDescription = @"For each OB activity, if Assessable OB income from related parties has been completed then it must be less than or equal to the Assessable OB income",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount[@contextRef='" + report.RPLendingRelatedPartyId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440226" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS274", Value = report.IDS274.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS272", Value = report.IDS272.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440226

            #region VR.ATO.IDS.440227

            /*  VR.ATO.IDS.440227
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS274] <> NULL AND [IDS274] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS274] = IDS:RP.Lending.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS274, 'U', 11, 0)
    
            Data Elements:
    
            RP.Lending.RelatedParty:^IDS274 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            */
            assertion = NotMonetary(report.IDS274, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount[@contextRef='" + report.RPLendingRelatedPartyId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440227" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS274", Value = report.IDS274.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440227

            #region VR.ATO.IDS.440228

            /*  VR.ATO.IDS.440228
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS275] <> NULL AND [IDS275] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS275] = IDS:RP.GuaranteeType:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS275, 'U', 11, 0)
    
            Data Elements:
    
            RP.GuaranteeType:^IDS275 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            */
            assertion = NotMonetary(report.IDS275, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount[@contextRef='" + report.RPGuaranteeTypeId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440228" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS275", Value = report.IDS275.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440228

            #region VR.ATO.IDS.440229

            /*  VR.ATO.IDS.440229
            For each OB activity, if Net OB income/loss has been completed then it must be less than or equal to the Assessable OB income.
    
            Legacy Rule Format:
            IF [IDS276] <> NULL AND ([IDS276] > [IDS275])
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS275] = IDS:RP.GuaranteeType:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS276] = IDS:RP.GuaranteeType:bafot.02.11:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount

            Technical Business Rule Format:
            ^IDS276 <> NULL AND (^IDS276 > ^IDS275)
    
            Data Elements:
    
            RP.GuaranteeType:^IDS276 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
    
            RP.GuaranteeType:^IDS275 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            */
            assertion = (report.IDS276 != null && report.IDS276.GetValueOrDefault() > report.IDS275.GetValueOrDefault());
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440229",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Net OB income/loss incorrect",
                    LongDescription = @"For each OB activity, if Net OB income/loss has been completed then it must be less than or equal to the Assessable OB income.",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount[@contextRef='" + report.RPGuaranteeTypeId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440229" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS276", Value = report.IDS276.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS275", Value = report.IDS275.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440229

            #region VR.ATO.IDS.440231

            /*  VR.ATO.IDS.440231
            For each OB activity, if Assessable OB income from related parties has been completed then it must be less than or equal to the Assessable OB income.
    
            Legacy Rule Format:
            IF [IDS277] <> NULL AND ([IDS277] > [IDS275])
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS275] = IDS:RP.GuaranteeType:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS277] = IDS:RP.GuaranteeType.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount

            Technical Business Rule Format:
            ^IDS277 <> NULL AND (^IDS277 > ^IDS275)
    
            Data Elements:
    
            RP.GuaranteeType.RelatedParty:^IDS277 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.GuaranteeType:^IDS275 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            */
            assertion = (report.IDS277 != null && report.IDS277.GetValueOrDefault() > report.IDS275.GetValueOrDefault());
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440231",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Assessable OB income from related parties incorrect",
                    LongDescription = @"For each OB activity, if Assessable OB income from related parties has been completed then it must be less than or equal to the Assessable OB income",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount[@contextRef='" + report.RPGuaranteeTypeRelatedPartyId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440231" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS277", Value = report.IDS277.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS275", Value = report.IDS275.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440231

            #region VR.ATO.IDS.440232

            /*  VR.ATO.IDS.440232
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS277] <> NULL AND [IDS277] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS277] = IDS:RP.GuaranteeType.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS277, 'U', 11, 0)
    
            Data Elements:
    
            RP.GuaranteeType.RelatedParty:^IDS277 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            */
            assertion = NotMonetary(report.IDS277, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount[@contextRef='" + report.RPGuaranteeTypeRelatedPartyId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440232" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS277", Value = report.IDS277.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440232

            #region VR.ATO.IDS.440233

            /*  VR.ATO.IDS.440233
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS278] <> NULL AND [IDS278] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS278] = IDS:RP.Trading:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS278, 'U', 11, 0)
    
            Data Elements:
    
            RP.Trading:^IDS278 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            */
            assertion = NotMonetary(report.IDS278, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount[@contextRef='" + report.RPTradingId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440233" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS278", Value = report.IDS278.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440233

            #region VR.ATO.IDS.440234

            /*  VR.ATO.IDS.440234
            For each OB activity, if Net OB income/loss has been completed then it must be less than or equal to the Assessable OB income.
    
            Legacy Rule Format:
            IF [IDS279] <> NULL AND ([IDS279] > [IDS278])
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS278] = IDS:RP.Trading:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS279] = IDS:RP.Trading:bafot.02.11:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount

            Technical Business Rule Format:
            ^IDS279 <> NULL AND (^IDS279 > ^IDS278)
    
            Data Elements:
    
            RP.Trading:^IDS279 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
    
            RP.Trading:^IDS278 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            */
            assertion = (report.IDS279 != null && report.IDS279.GetValueOrDefault() > report.IDS278.GetValueOrDefault());
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440234",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Net OB income/loss incorrect",
                    LongDescription = @"For each OB activity, if Net OB income/loss has been completed then it must be less than or equal to the Assessable OB income.",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount[@contextRef='" + report.RPTradingId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440234" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS279", Value = report.IDS279.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS278", Value = report.IDS278.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440234

            #region VR.ATO.IDS.440236

            /*  VR.ATO.IDS.440236
            For each OB activity, if Assessable OB income from related parties has been completed then it must be less than or equal to the Assessable OB income.
    
            Legacy Rule Format:
            IF [IDS280] <> NULL AND ([IDS280] > [IDS278])
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS278] = IDS:RP.Trading:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS280] = IDS:RP.Trading.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount

            Technical Business Rule Format:
            ^IDS280 <> NULL AND (^IDS280 > ^IDS278)
    
            Data Elements:
    
            RP.Trading.RelatedParty:^IDS280 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Trading:^IDS278 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            */
            assertion = (report.IDS280 != null && report.IDS280.GetValueOrDefault() > report.IDS278.GetValueOrDefault());
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440236",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Assessable OB income from related parties incorrect",
                    LongDescription = @"For each OB activity, if Assessable OB income from related parties has been completed then it must be less than or equal to the Assessable OB income",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount[@contextRef='" + report.RPTradingRelatedPartyId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440236" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS280", Value = report.IDS280.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS278", Value = report.IDS278.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440236

            #region VR.ATO.IDS.440237

            /*  VR.ATO.IDS.440237
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS280] <> NULL AND [IDS280] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS280] = IDS:RP.Trading.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS280, 'U', 11, 0)
    
            Data Elements:
    
            RP.Trading.RelatedParty:^IDS280 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            */
            assertion = NotMonetary(report.IDS280, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount[@contextRef='" + report.RPTradingRelatedPartyId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440237" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS280", Value = report.IDS280.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440237

            #region VR.ATO.IDS.440238

            /*  VR.ATO.IDS.440238
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS281] <> NULL AND [IDS281] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS281] = IDS:RP.EligibleContract:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS281, 'U', 11, 0)
    
            Data Elements:
    
            RP.EligibleContract:^IDS281 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            */
            assertion = NotMonetary(report.IDS281, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount[@contextRef='" + report.RPEligibleContractId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440238" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS281", Value = report.IDS281.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440238

            #region VR.ATO.IDS.440239

            /*  VR.ATO.IDS.440239
            For each OB activity, if Net OB income/loss has been completed then it must be less than or equal to the Assessable OB income.
    
            Legacy Rule Format:
            IF [IDS282] <> NULL AND ([IDS282] > [IDS281])
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS281] = IDS:RP.EligibleContract:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS282] = IDS:RP.EligibleContract:bafot.02.11:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount

            Technical Business Rule Format:
            ^IDS282 <> NULL AND (^IDS282 > ^IDS281)
    
            Data Elements:
    
            RP.EligibleContract:^IDS282 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
    
            RP.EligibleContract:^IDS281 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            */
            assertion = (report.IDS282 != null && report.IDS282.GetValueOrDefault() > report.IDS281.GetValueOrDefault());
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440239",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Net OB income/loss incorrect",
                    LongDescription = @"For each OB activity, if Net OB income/loss has been completed then it must be less than or equal to the Assessable OB income.",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount[@contextRef='" + report.RPEligibleContractId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440239" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS282", Value = report.IDS282.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS281", Value = report.IDS281.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440239

            #region VR.ATO.IDS.440241

            /*  VR.ATO.IDS.440241
            For each OB activity, if Assessable OB income from related parties has been completed then it must be less than or equal to the Assessable OB income.
    
            Legacy Rule Format:
            IF [IDS283] <> NULL AND ([IDS283] > [IDS281])
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS281] = IDS:RP.EligibleContract:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS283] = IDS:RP.EligibleContract.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount

            Technical Business Rule Format:
            ^IDS283 <> NULL AND (^IDS283 > ^IDS281)
    
            Data Elements:
    
            RP.EligibleContract.RelatedParty:^IDS283 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.EligibleContract:^IDS281 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            */
            assertion = (report.IDS283 != null && report.IDS283.GetValueOrDefault() > report.IDS281.GetValueOrDefault());
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440241",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Assessable OB income from related parties incorrect",
                    LongDescription = @"For each OB activity, if Assessable OB income from related parties has been completed then it must be less than or equal to the Assessable OB income",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount[@contextRef='" + report.RPEligibleContractRelatedPartyId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440241" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS283", Value = report.IDS283.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS281", Value = report.IDS281.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440241

            #region VR.ATO.IDS.440242

            /*  VR.ATO.IDS.440242
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS283] <> NULL AND [IDS283] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS283] = IDS:RP.EligibleContract.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS283, 'U', 11, 0)
    
            Data Elements:
    
            RP.EligibleContract.RelatedParty:^IDS283 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            */
            assertion = NotMonetary(report.IDS283, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount[@contextRef='" + report.RPEligibleContractRelatedPartyId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440242" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS283", Value = report.IDS283.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440242

            #region VR.ATO.IDS.440243

            /*  VR.ATO.IDS.440243
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS284] <> NULL AND [IDS284] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS284] = IDS:RP.Investment:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS284, 'U', 11, 0)
    
            Data Elements:
    
            RP.Investment:^IDS284 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            */
            assertion = NotMonetary(report.IDS284, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount[@contextRef='" + report.RPInvestmentId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440243" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS284", Value = report.IDS284.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440243

            #region VR.ATO.IDS.440244

            /*  VR.ATO.IDS.440244
            For each OB activity, if Net OB income/loss has been completed then it must be less than or equal to the Assessable OB income.
    
            Legacy Rule Format:
            IF [IDS285] <> NULL AND ([IDS285] > [IDS284])
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS284] = IDS:RP.Investment:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS285] = IDS:RP.Investment:bafot.02.11:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount

            Technical Business Rule Format:
            ^IDS285 <> NULL AND (^IDS285 > ^IDS284)
    
            Data Elements:
    
            RP.Investment:^IDS285 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
    
            RP.Investment:^IDS284 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            */
            assertion = (report.IDS285 != null && report.IDS285.GetValueOrDefault() > report.IDS284.GetValueOrDefault());
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440244",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Net OB income/loss incorrect",
                    LongDescription = @"For each OB activity, if Net OB income/loss has been completed then it must be less than or equal to the Assessable OB income.",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount[@contextRef='" + report.RPInvestmentId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440244" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS285", Value = report.IDS285.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS284", Value = report.IDS284.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440244

            #region VR.ATO.IDS.440246

            /*  VR.ATO.IDS.440246
            For each OB activity, if Assessable OB income from related parties has been completed then it must be less than or equal to the Assessable OB income.
    
            Legacy Rule Format:
            IF [IDS286] <> NULL AND ([IDS286] > [IDS284])
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS284] = IDS:RP.Investment:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS286] = IDS:RP.Investment.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount

            Technical Business Rule Format:
            ^IDS286 <> NULL AND (^IDS286 > ^IDS284)
    
            Data Elements:
    
            RP.Investment.RelatedParty:^IDS286 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Investment:^IDS284 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            */
            assertion = (report.IDS286 != null && report.IDS286.GetValueOrDefault() > report.IDS284.GetValueOrDefault());
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440246",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Assessable OB income from related parties incorrect",
                    LongDescription = @"For each OB activity, if Assessable OB income from related parties has been completed then it must be less than or equal to the Assessable OB income",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount[@contextRef='" + report.RPInvestmentRelatedPartyId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440246" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS286", Value = report.IDS286.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS284", Value = report.IDS284.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440246

            #region VR.ATO.IDS.440247

            /*  VR.ATO.IDS.440247
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS286] <> NULL AND [IDS286] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS286] = IDS:RP.Investment.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS286, 'U', 11, 0)
    
            Data Elements:
    
            RP.Investment.RelatedParty:^IDS286 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            */
            assertion = NotMonetary(report.IDS286, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount[@contextRef='" + report.RPInvestmentRelatedPartyId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440247" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS286", Value = report.IDS286.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440247

            #region VR.ATO.IDS.440248

            /*  VR.ATO.IDS.440248
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS287] <> NULL AND [IDS287] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS287] = IDS:RP.Advisory:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS287, 'U', 11, 0)
    
            Data Elements:
    
            RP.Advisory:^IDS287 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            */
            assertion = NotMonetary(report.IDS287, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount[@contextRef='" + report.RPAdvisoryId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440248" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS287", Value = report.IDS287.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440248

            #region VR.ATO.IDS.440249

            /*  VR.ATO.IDS.440249
            For each OB activity, if Net OB income/loss has been completed then it must be less than or equal to the Assessable OB income.
    
            Legacy Rule Format:
            IF [IDS288] <> NULL AND ([IDS288] > [IDS287])
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS287] = IDS:RP.Advisory:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS288] = IDS:RP.Advisory:bafot.02.11:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount

            Technical Business Rule Format:
            ^IDS288 <> NULL AND (^IDS288 > ^IDS287)
    
            Data Elements:
    
            RP.Advisory:^IDS288 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
    
            RP.Advisory:^IDS287 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            */
            assertion = (report.IDS288 != null && report.IDS288.GetValueOrDefault() > report.IDS287.GetValueOrDefault());
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440249",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Net OB income/loss incorrect",
                    LongDescription = @"For each OB activity, if Net OB income/loss has been completed then it must be less than or equal to the Assessable OB income.",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount[@contextRef='" + report.RPAdvisoryId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440249" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS288", Value = report.IDS288.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS287", Value = report.IDS287.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440249

            #region VR.ATO.IDS.440251

            /*  VR.ATO.IDS.440251
            For each OB activity, if Assessable OB income from related parties has been completed then it must be less than or equal to the Assessable OB income.
    
            Legacy Rule Format:
            IF [IDS289] <> NULL AND ([IDS289] > [IDS287])
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS287] = IDS:RP.Advisory:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS289] = IDS:RP.Advisory.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount

            Technical Business Rule Format:
            ^IDS289 <> NULL AND (^IDS289 > ^IDS287)
    
            Data Elements:
    
            RP.Advisory.RelatedParty:^IDS289 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Advisory:^IDS287 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            */
            assertion = (report.IDS289 != null && report.IDS289.GetValueOrDefault() > report.IDS287.GetValueOrDefault());
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440251",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Assessable OB income from related parties incorrect",
                    LongDescription = @"For each OB activity, if Assessable OB income from related parties has been completed then it must be less than or equal to the Assessable OB income",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount[@contextRef='" + report.RPAdvisoryRelatedPartyId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440251" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS289", Value = report.IDS289.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS287", Value = report.IDS287.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440251

            #region VR.ATO.IDS.440252

            /*  VR.ATO.IDS.440252
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS289] <> NULL AND [IDS289] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS289] = IDS:RP.Advisory.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS289, 'U', 11, 0)
    
            Data Elements:
    
            RP.Advisory.RelatedParty:^IDS289 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            */
            assertion = NotMonetary(report.IDS289, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount[@contextRef='" + report.RPAdvisoryRelatedPartyId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440252" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS289", Value = report.IDS289.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440252

            #region VR.ATO.IDS.440253

            /*  VR.ATO.IDS.440253
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS290] <> NULL AND [IDS290] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS290] = IDS:RP.Hedging:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS290, 'U', 11, 0)
    
            Data Elements:
    
            RP.Hedging:^IDS290 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            */
            assertion = NotMonetary(report.IDS290, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount[@contextRef='" + report.RPHedgingId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440253" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS290", Value = report.IDS290.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440253

            #region VR.ATO.IDS.440254

            /*  VR.ATO.IDS.440254
            For each OB activity, if Net OB income/loss has been completed then it must be less than or equal to the Assessable OB income.
    
            Legacy Rule Format:
            IF [IDS291] <> NULL AND ([IDS291] > [IDS290])
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS290] = IDS:RP.Hedging:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS291] = IDS:RP.Hedging:bafot.02.11:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount

            Technical Business Rule Format:
            ^IDS291 <> NULL AND (^IDS291 > ^IDS290)
    
            Data Elements:
    
            RP.Hedging:^IDS291 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
    
            RP.Hedging:^IDS290 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            */
            assertion = (report.IDS291 != null && report.IDS291.GetValueOrDefault() > report.IDS290.GetValueOrDefault());
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440254",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Net OB income/loss incorrect",
                    LongDescription = @"For each OB activity, if Net OB income/loss has been completed then it must be less than or equal to the Assessable OB income.",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount[@contextRef='" + report.RPHedgingId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440254" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS291", Value = report.IDS291.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS290", Value = report.IDS290.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440254

            #region VR.ATO.IDS.440256

            /*  VR.ATO.IDS.440256
            For each OB activity, if Assessable OB income from related parties has been completed then it must be less than or equal to the Assessable OB income.
    
            Legacy Rule Format:
            IF [IDS292] <> NULL AND ([IDS292] > [IDS290])
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS290] = IDS:RP.Hedging:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS292] = IDS:RP.Hedging.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount

            Technical Business Rule Format:
            ^IDS292 <> NULL AND (^IDS292 > ^IDS290)
    
            Data Elements:
    
            RP.Hedging.RelatedParty:^IDS292 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Hedging:^IDS290 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            */
            assertion = (report.IDS292 != null && report.IDS292.GetValueOrDefault() > report.IDS290.GetValueOrDefault());
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440256",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Assessable OB income from related parties incorrect",
                    LongDescription = @"For each OB activity, if Assessable OB income from related parties has been completed then it must be less than or equal to the Assessable OB income",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount[@contextRef='" + report.RPHedgingRelatedPartyId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440256" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS292", Value = report.IDS292.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS290", Value = report.IDS290.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440256

            #region VR.ATO.IDS.440257

            /*  VR.ATO.IDS.440257
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS292] <> NULL AND [IDS292] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS292] = IDS:RP.Hedging.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS292, 'U', 11, 0)
    
            Data Elements:
    
            RP.Hedging.RelatedParty:^IDS292 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            */
            assertion = NotMonetary(report.IDS292, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount[@contextRef='" + report.RPHedgingRelatedPartyId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440257" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS292", Value = report.IDS292.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440257

            #region VR.ATO.IDS.440258

            /*  VR.ATO.IDS.440258
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS293] <> NULL AND [IDS293] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS293] = IDS:RP.Other:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS293, 'U', 11, 0)
    
            Data Elements:
    
            RP.Other:^IDS293 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            */
            assertion = NotMonetary(report.IDS293, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount[@contextRef='" + report.RPOtherId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440258" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS293", Value = report.IDS293.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440258

            #region VR.ATO.IDS.440259

            /*  VR.ATO.IDS.440259
            For each OB activity, if Net OB income/loss has been completed then it must be less than or equal to the Assessable OB income.
    
            Legacy Rule Format:
            IF [IDS294] <> NULL AND ([IDS294] > [IDS293])
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS293] = IDS:RP.Other:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS294] = IDS:RP.Other:bafot.02.11:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount

            Technical Business Rule Format:
            ^IDS294 <> NULL AND (^IDS294 > ^IDS293)
    
            Data Elements:
    
            RP.Other:^IDS294 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
    
            RP.Other:^IDS293 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            */
            assertion = (report.IDS294 != null && report.IDS294.GetValueOrDefault() > report.IDS293.GetValueOrDefault());
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440259",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Net OB income/loss incorrect",
                    LongDescription = @"For each OB activity, if Net OB income/loss has been completed then it must be less than or equal to the Assessable OB income.",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount[@contextRef='" + report.RPOtherId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440259" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS294", Value = report.IDS294.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS293", Value = report.IDS293.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440259

            #region VR.ATO.IDS.440261

            /*  VR.ATO.IDS.440261
            For each OB activity, if Assessable OB income from related parties has been completed then it must be less than or equal to the Assessable OB income.
    
            Legacy Rule Format:
            IF [IDS295] <> NULL AND ([IDS295] > [IDS293])
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS293] = IDS:RP.Other:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS295] = IDS:RP.Other.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount

            Technical Business Rule Format:
            ^IDS295 <> NULL AND (^IDS295 > ^IDS293)
    
            Data Elements:
    
            RP.Other.RelatedParty:^IDS295 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Other:^IDS293 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            */
            assertion = (report.IDS295 != null && report.IDS295.GetValueOrDefault() > report.IDS293.GetValueOrDefault());
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440261",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Assessable OB income from related parties incorrect",
                    LongDescription = @"For each OB activity, if Assessable OB income from related parties has been completed then it must be less than or equal to the Assessable OB income",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount[@contextRef='" + report.RPOtherRelatedPartyId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440261" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS295", Value = report.IDS295.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS293", Value = report.IDS293.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440261

            #region VR.ATO.IDS.440262

            /*  VR.ATO.IDS.440262
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS295] <> NULL AND [IDS295] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS295] = IDS:RP.Other.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS295, 'U', 11, 0)
    
            Data Elements:
    
            RP.Other.RelatedParty:^IDS295 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            */
            assertion = NotMonetary(report.IDS295, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount[@contextRef='" + report.RPOtherRelatedPartyId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440262" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS295", Value = report.IDS295.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440262

            #region VR.ATO.IDS.440263

            /*  VR.ATO.IDS.440263
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS296] <> NULL AND [IDS296] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS296] = IDS:RP.GeneralDeduction:bafot.02.11:FinancialServices.GeneralOffshoreBankingDeductionAndApportionableOffshoreBankingDeduction.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS296, 'U', 11, 0)
    
            Data Elements:
    
            RP.GeneralDeduction:^IDS296 = tns:FinancialServices.GeneralOffshoreBankingDeductionAndApportionableOffshoreBankingDeduction.Amount
            */
            assertion = NotMonetary(report.IDS296, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:FinancialServices.GeneralOffshoreBankingDeductionAndApportionableOffshoreBankingDeduction.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440263" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS296", Value = report.IDS296.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440263

            #region VR.ATO.IDS.440273

            /*  VR.ATO.IDS.440273
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS303] <> NULL AND [IDS303] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS303] = IDS:RP.TotalNet:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS303, 'U', 11, 0)
    
            Data Elements:
    
            RP.TotalNet:^IDS303 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            */
            assertion = NotMonetary(report.IDS303, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount[@contextRef='" + report.RPTotalNetId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440273" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS303", Value = report.IDS303.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440273

            #region VR.ATO.IDS.440277

            /*  VR.ATO.IDS.440277
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS305] <> NULL AND [IDS305] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS305] = IDS:RP.TotalNet.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS305, 'U', 11, 0)
    
            Data Elements:
    
            RP.TotalNet.RelatedParty:^IDS305 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            */
            assertion = NotMonetary(report.IDS305, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount[@contextRef='" + report.RPTotalNetRelatedPartyId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440277" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS305", Value = report.IDS305.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440277

            #region VR.ATO.IDS.440278

            /*  VR.ATO.IDS.440278
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS306] <> NULL AND [IDS306] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS306] = IDS:RP.Division770:bafot.02.11:FinancialServices.OffshoreBankingIncomeForeignIncomeTaxEligibleFractionClaimed.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS306, 'U', 11, 0)
    
            Data Elements:
    
            RP.Division770:^IDS306 = tns:FinancialServices.OffshoreBankingIncomeForeignIncomeTaxEligibleFractionClaimed.Amount
            */
            assertion = NotMonetary(report.IDS306, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeForeignIncomeTaxEligibleFractionClaimed.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440278" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS306", Value = report.IDS306.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440278

            #region VR.ATO.IDS.440282

            /*  VR.ATO.IDS.440282
            Maximum three countries per foreign country.
    
            Legacy Rule Format:
            IF COUNT(ForeignCountry) IN SET (RP.{ForeignCountry}.{ActivityCode},{RP.{ForeignCountry}) > 3
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Count(Union(^IDS3, ^IDS353)) > 3
    
            Data Elements:
    
            RP.{ForeignCountry}:^IDS3 = tns:OrganisationDetails.InternationalRelatedPartyCountry.Code
    
            RP.{ForeignCountry}.{ActivityCode}:^IDS353 = tns:Residency.TaxPurposesCountry.Code
            */
            assertion = (Count(Union(report.RPForeignCountryContextCollection == null ? null : report.RPForeignCountryContextCollection.Select(f => f.IDS3), report.RPForeignCountryActivityCodeContextCollection == null ? null : report.RPForeignCountryActivityCodeContextCollection.Select(f => f.IDS353))) > 3);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440282",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Maximum of three foreign countries allowed",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPForeignCountryContextCollection == null ? 0 : (report.RPForeignCountryContextCollection.Count() == 0 ? 0 : report.RPForeignCountryContextCollection.Last().LastOccurrenceIndex)),
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440282" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS3", Value = "IDS3" });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS353", Value = "IDS353" });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440282

            #region VR.ATO.IDS.440284

            /*  VR.ATO.IDS.440284
            In question 'Did you have dealings with international related parties located in foreign countries?'  a foriegn country code has occurred more than once. Delete the duplicate code and input an alternative code.
    
            Legacy Rule Format:
            IF CONTEXT(RP.ForeignCountry) = ANY OTHER OCCURRENCE OF CONTEXT(RP.ForeignCountry)
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            HasDuplicateValues(^IDS3)
    
            Data Elements:
    
            RP.{ForeignCountry}:^IDS3 = tns:OrganisationDetails.InternationalRelatedPartyCountry.Code
            */
            assertion = HasDuplicateValues(report.RPForeignCountryContextCollection == null ? null : report.RPForeignCountryContextCollection.Select(f => f.IDS3).Cast<object>().ToArray());
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440284",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Foreign country code has occurred more than once. Delete the duplicate code and input an alternative code",
                    Location = "/xbrli:xbrl/xbrli:context[@id='" + report.RPForeignCountryContextCollection[DuplicateValueIndex(report.RPForeignCountryContextCollection.Select(f => f.IDS3))].Id + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440284" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440284

            #region VR.ATO.IDS.440285

            /*  VR.ATO.IDS.440285
            Maximum three countries per specified foreign country.
    
            Legacy Rule Format:
            IF COUNT(SpecifiedCountry) IN SET (RP.{SpecifiedCountry}.{ActivityCode},{RP.{SpecifiedCountry}) > 3
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Count(Union(^IDS10, ^IDS354)) > 3
    
            Data Elements:
    
            RP.{SpecifiedCountry}:^IDS10 = tns:OrganisationDetails.InternationalRelatedPartyCountry.Code
    
            RP.{SpecifiedCountry}.{ActivityCode}:^IDS354 = tns:Residency.TaxPurposesCountry.Code
            */
            assertion = (Count(Union(report.RPSpecifiedCountryContextCollection == null ? null : report.RPSpecifiedCountryContextCollection.Select(f => f.IDS10), report.RPSpecifiedCountryActivityCodeContextCollection == null ? null : report.RPSpecifiedCountryActivityCodeContextCollection.Select(f => f.IDS354))) > 3);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440285",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Maximum of three specified countries allowed",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPSpecifiedCountryContextCollection == null ? 0 : (report.RPSpecifiedCountryContextCollection.Count() == 0 ? 0 : report.RPSpecifiedCountryContextCollection.Last().LastOccurrenceIndex)),
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440285" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS10", Value = "IDS10" });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS354", Value = "IDS354" });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440285

            #region VR.ATO.IDS.440287

            /*  VR.ATO.IDS.440287
            In question 'Did you have dealings with international related parties located in specified countries?'  a specified country code has occurred more than once. Delete the duplicate code and input an alternative code.
    
            Legacy Rule Format:
            IF CONTEXT(RP.SpecifiedCountry) = ANY OTHER OCCURRENCE OF CONTEXT(RP.SpecifiedCountry)
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            HasDuplicateValues(^IDS10)
    
            Data Elements:
    
            RP.{SpecifiedCountry}:^IDS10 = tns:OrganisationDetails.InternationalRelatedPartyCountry.Code
            */
            assertion = HasDuplicateValues(report.RPSpecifiedCountryContextCollection == null ? null : report.RPSpecifiedCountryContextCollection.Select(f => f.IDS10).Cast<object>().ToArray());
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440287",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Specified country code has occurred more than once. Delete the duplicate code and input an alternative code",
                    Location = "/xbrli:xbrl/xbrli:context[@id='" + report.RPSpecifiedCountryContextCollection[DuplicateValueIndex(report.RPSpecifiedCountryContextCollection.Select(f => f.IDS10))].Id + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440287" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440287

            #region VR.ATO.IDS.440292

            /*  VR.ATO.IDS.440292
            Maximum of three activity codes per foreign count
    
            Legacy Rule Format:
            IF COUNT(RP.{RestructuringEvent}) > 3
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Count(^Context) > 3
    
            Data Elements:
    
            ^Context = RP:RP.{RestructuringEvent}
            */
            assertion = (Count(report.RPRestructuringEventContextCollection) > 3);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440292",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Maximum of three Restructuring Events",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPRestructuringEventContextCollection == null ? 0 : (report.RPRestructuringEventContextCollection.Count() == 0 ? 0 : report.RPRestructuringEventContextCollection.Last().LastOccurrenceIndex)),
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440292" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440292

            #region VR.ATO.IDS.440293

            /*  VR.ATO.IDS.440293
            Tax time method election codes can only occur up to six times
    
            Legacy Rule Format:
            IF COUNT([IDS178] > 6) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS178] = IDS:RP:rvctc4.02.05:InternationalDealings.TaxTimingMethodElections.Code

            Technical Business Rule Format:
            Count(^IDS178) > 6
    
            Data Elements:
    
            RP:^IDS178 = tns:InternationalDealings.TaxTimingMethodElections.Code
            */
            assertion = (Count(report.IDS178Collection) > 6);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440293",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Tax time method election codes can only occur up to six times",
                    Location = "/xbrli:xbrl/tns:InternationalDealings.TaxTimingMethodElections.Code",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440293" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440293

            #region VR.ATO.IDS.440295

            /*  VR.ATO.IDS.440295
            The tax timing method election code must be unique
    
            Legacy Rule Format:
            IF [IDS178] = ANY OTHER OCCURRENCE OF [IDS178]
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS178] = IDS:RP:rvctc4.02.05:InternationalDealings.TaxTimingMethodElections.Code

            Technical Business Rule Format:
            HasDuplicateValues(^IDS178)
    
            Data Elements:
    
            RP:^IDS178 = tns:InternationalDealings.TaxTimingMethodElections.Code
            */
            assertion = HasDuplicateValues(report.IDS178Collection);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440295",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"TOFA tax timing method elections incorrect",
                    LongDescription = @"The tax timing method election code must be unique",
                    Location = "/xbrli:xbrl/tns:InternationalDealings.TaxTimingMethodElections.Code" + OccurrenceIndex(DuplicateValueIndex(report.IDS178Collection) + 1) + "",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440295" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440295

            #region VR.ATO.IDS.440297

            /*  VR.ATO.IDS.440297
            If there is a 'Yes' response to 'During the last three income years, including the current income year, did you directly or indirectly transfer property, money or services to a non-resident trust, where that non-resident trust was still in existence during that income year?' then transfer amount and exemption code must be completed.
    
            Legacy Rule Format:
            IF [IDS213] = TRUE AND (COUNT(SET(RP.{TrustExemptionCode}):ANY ELEMENT <> NULL) = 0)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS213] = IDS:RP:bafot.02.11:Miscellaneous.TransferPropertyMoneyOrServices.Indicator

            Technical Business Rule Format:
            ^IDS213 = TRUE AND (Count(^Context) = 0 OR AnyOccurrence(^IDS214, ^IDS214 = NULL) OR AnyOccurrence(^IDS215, ^IDS215 = NULL))
    
            Data Elements:
    
            RP:^IDS213 = tns:Miscellaneous.TransferPropertyMoneyOrServices.Indicator
    
            RP:^Context = RP:RP.{TrustExemptionCode}
    
            RP.{TrustExemptionCode}:^IDS214 = tns:Miscellaneous.TransferPropertyMoneyOrServices.Amount
    
            RP.{TrustExemptionCode}:^IDS215 = tns:Report.ItemOrder.Number
            */
            assertion = (report.IDS213 == true && (Count(report.RPTrustExemptionCodeContextCollection) == 0 || (report.RPTrustExemptionCodeContextCollection == null ? false : report.RPTrustExemptionCodeContextCollection.Any(IDS214Repeat => IDS214Repeat.IDS214 == null)) || (report.RPTrustExemptionCodeContextCollection == null ? false : report.RPTrustExemptionCodeContextCollection.Any(IDS215Repeat => IDS215Repeat.IDS215 == null))));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440297",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Transfers information incomplete",
                    LongDescription = @"If there is a 'True' response to 'During the last three income years, including the current income year, did you directly or indirectly transfer property, money or services to a non-resident trust, where that non-resident trust was still in existence during that income year?' then transfer amount and exemption code must be completed",
                    Location = "/xbrli:xbrl/tns:Miscellaneous.TransferPropertyMoneyOrServices.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440297" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS213", Value = GetValueOrEmpty(report.IDS213) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS214", Value = "IDS214" });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS215", Value = "IDS215" });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440297

            #region VR.ATO.IDS.440298

            /*  VR.ATO.IDS.440298
            Maximum of Ninety Nine internally recorded Dealings
    
            Legacy Rule Format:
            IF COUNT(RP.BranchOperations.{InternallyRecordedDealings}) > 99
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Count(^Context) > 99
    
            Data Elements:
    
            ^Context = RP.BranchOperations:RP.BranchOperations.{InternallyRecordedDealings}
            */
            assertion = (Count(report.RPBranchOperationsInternallyRecordedDealingsContextCollection) > 99);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440298",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Maximum of ninety nine internally recorded dealings are allowed",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPBranchOperationsInternallyRecordedDealingsContextCollection == null ? 0 : (report.RPBranchOperationsInternallyRecordedDealingsContextCollection.Count() == 0 ? 0 : report.RPBranchOperationsInternallyRecordedDealingsContextCollection.Last().LastOccurrenceIndex)),
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440298" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440298

            #region VR.ATO.IDS.440299

            /*  VR.ATO.IDS.440299
            Maximum of three transfer to non-resident trust allowed
    
            Legacy Rule Format:
            IF COUNT(RP.{TrustExemptionCode}) > 3
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Count(^Context) > 3
    
            Data Elements:
    
            ^Context = RP:RP.{TrustExemptionCode}
            */
            assertion = (Count(report.RPTrustExemptionCodeContextCollection) > 3);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440299",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Maximum of three transfers to non-resident trust allowed",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPTrustExemptionCodeContextCollection == null ? 0 : (report.RPTrustExemptionCodeContextCollection.Count() == 0 ? 0 : report.RPTrustExemptionCodeContextCollection.Last().LastOccurrenceIndex)),
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440299" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440299

            #region VR.ATO.IDS.440300

            /*  VR.ATO.IDS.440300
            Dec5 must be in the format n.nnnnn i.e. numeric only and the last six characters must be '.nnnnn'. There is no requirement to pad zeros.
    
            Legacy Rule Format:
            IF [IDS258] <> NULL AND ([IDS258] <> NUMBER(U,6,5))
            RETURN VALIDATION MESSAGE
            ENDIF
            
            
            [IDS258] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.WorldwideGroupCapitalRatio.Fraction

            Technical Business Rule Format:
            NotNumeric(^IDS258, 'U', 6, 5)
    
            Data Elements:
    
            RP:^IDS258 = tns:Capital.ThinCapitalisation.WorldwideGroupCapitalRatio.Fraction
            */
            assertion = NotNumeric(report.IDS258, @"U", 6, 5);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Capital.ThinCapitalisation.WorldwideGroupCapitalRatio.Fraction",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440300" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS258", Value = report.IDS258.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440300

            #region VR.ATO.IDS.440301

            /*  VR.ATO.IDS.440301
            Worldwide group capital ratio cannot be larger than "1.00000"
    
            Legacy Rule Format:
            IF [IDS258] <> NULL AND [IDS258] > 1
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS258] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.WorldwideGroupCapitalRatio.Fraction

            Technical Business Rule Format:
            ^IDS258 <> NULL AND ^IDS258 > 1
    
            Data Elements:
    
            RP:^IDS258 = tns:Capital.ThinCapitalisation.WorldwideGroupCapitalRatio.Fraction
            */
            assertion = (report.IDS258 != null && report.IDS258.GetValueOrDefault() > 1);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440301",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"ADI - Worldwide group capital ratio cannot be larger than ""1.00000""",
                    Location = "/xbrli:xbrl/tns:Capital.ThinCapitalisation.WorldwideGroupCapitalRatio.Fraction",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440301" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS258", Value = report.IDS258.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440301

            #region VR.ATO.IDS.440302

            /*  VR.ATO.IDS.440302
            Monetary field, may be signed, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS313] <> NULL AND [IDS313] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS313] = IDS:RP:rvctc4.02.06:InternationalDealings.UnfrankedNonPortfolioDividendAccount.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS313, 'U', 11, 0)
    
            Data Elements:
    
            RP:^IDS313 = tns:InternationalDealings.UnfrankedNonPortfolioDividendAccount.Amount
            */
            assertion = NotMonetary(report.IDS313, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:InternationalDealings.UnfrankedNonPortfolioDividendAccount.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440302" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS313", Value = report.IDS313.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440302

            #region VR.ATO.IDS.440303

            /*  VR.ATO.IDS.440303
            Monetary field, may be signed, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF rvctc.xx.xx:InternationalDealings.NonResidentInterestPaid.Amount <> NULL AND rvctc.xx.xx:InternationalDealings.NonResidentInterestPaid.Amount <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS316,'U',11,0)
    
            Data Elements:
    
            RP.DTA:^IDS316 = tns:InternationalDealings.WithholdingTaxExemptNonResidentInterestPaid.Amount
            */
            assertion = NotMonetary(report.IDS316, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:InternationalDealings.WithholdingTaxExemptNonResidentInterestPaid.Amount[@contextRef='" + report.RPDTAId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440303" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS316", Value = report.IDS316.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440303

            #region VR.ATO.IDS.440306

            /*  VR.ATO.IDS.440306
            When 'Do you have an unfranked non portfolio dividend account (refer section 46FB ITAA )?' has a value of 'Yes', 'Balance of unfranked non-portfolio dividend account at year end' must have a value.
    
            Legacy Rule Format:
            IF [IDS312] = TRUE AND ([IDS313] = NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS312] = IDS:RP:rvctc4.02.06:InternationalDealings.UnfrankedNonPortfolioDividendAccount.Indicator
            [IDS313] = IDS:RP:rvctc4.02.06:InternationalDealings.UnfrankedNonPortfolioDividendAccount.Amount

            Technical Business Rule Format:
            ^IDS312 = TRUE AND (^IDS313 = NULL)
    
            Data Elements:
    
            RP:^IDS313 = tns:InternationalDealings.UnfrankedNonPortfolioDividendAccount.Amount
    
            RP:^IDS312 = tns:InternationalDealings.UnfrankedNonPortfolioDividendAccount.Indicator
            */
            assertion = (report.IDS312 == true && report.IDS313 == null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440306",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"'Balance of unfranked non-portfolio dividend account at year end' must have a value.",
                    LongDescription = @"When 'Do you have an unfranked non portfolio dividend account (refer section 46FB ITAA )?' has a value of 'Yes', 'Balance of unfranked non-portfolio dividend account at year end' must have a value.",
                    Location = "/xbrli:xbrl/tns:InternationalDealings.UnfrankedNonPortfolioDividendAccount.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440306" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS312", Value = GetValueOrEmpty(report.IDS312) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS313", Value = report.IDS313.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440306

            #region VR.ATO.IDS.440307

            /*  VR.ATO.IDS.440307
            Conduit foreign income included in balance of unfranked non-portfolio dividend account at year end - code' is required when 'Do you have an unfranked non portfolio dividend account (refer section 46FB ITAA )?' is 'Yes'.
    
            Legacy Rule Format:
            IF [IDS312] = TRUE AND [IDS314] = NULL
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS312] = IDS:RP:rvctc4.02.06:InternationalDealings.UnfrankedNonPortfolioDividendAccount.Indicator
            [IDS314] = IDS:RP:rvctc4.02.06:InternationalDealings.UnfrankedNonPortfolioAccountConduitForeignIncomeIncluded.Indicator

            Technical Business Rule Format:
            ^IDS312 = TRUE AND ^IDS314 = NULL
    
            Data Elements:
    
            RP:^IDS314 = tns:InternationalDealings.UnfrankedNonPortfolioAccountConduitForeignIncomeIncluded.Indicator
    
            RP:^IDS312 = tns:InternationalDealings.UnfrankedNonPortfolioDividendAccount.Indicator
            */
            assertion = (report.IDS312 == true && report.IDS314 == null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440307",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"'Conduit foreign income included in balance of unfranked non-portfolio dividend account at year end - code' is required.",
                    LongDescription = @"'Conduit foreign income included in balance of unfranked non-portfolio dividend account at year end - code' is required when 'Do you have an unfranked non portfolio dividend account (refer section 46FB ITAA )?' is 'Yes'.",
                    Location = "/xbrli:xbrl/tns:InternationalDealings.UnfrankedNonPortfolioAccountConduitForeignIncomeIncluded.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440307" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS312", Value = GetValueOrEmpty(report.IDS312) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS314", Value = GetValueOrEmpty(report.IDS314) });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440307

            #region VR.ATO.IDS.440308

            /*  VR.ATO.IDS.440308
            Balance of conduit foreign income' or 'Conduit foreign income distributed during income year' is required as 'Did you have a Conduit Foreign Income balance and/or distribute amounts of Conduit Foreign Income during the income year?' is 'Yes'.
    
            Legacy Rule Format:
            IF [IDS309] = TRUE AND ([IDS310] = NULL AND [IDS311] = NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS309] = IDS:RP:rvctc4.02.06:InternationalDealings.ConduitForeignIncome.Indicator
            [IDS310] = IDS:RP:rvctc4.02.01:InternationalDealings.ConduitForeignIncomeBalance.Amount
            [IDS311] = IDS:RP:rvctc4.02.00:InternationalDealings.ConduitForeignIncomeDistributed.Amount

            Technical Business Rule Format:
            ^IDS309 = TRUE AND (^IDS310 = NULL AND ^IDS311 = NULL)
    
            Data Elements:
    
            RP:^IDS309 = tns:InternationalDealings.ConduitForeignIncome.Indicator
    
            RP:^IDS310 = tns:InternationalDealings.ConduitForeignIncomeBalance.Amount
    
            RP:^IDS311 = tns:InternationalDealings.ConduitForeignIncomeDistributed.Amount
            */
            assertion = (report.IDS309 == true && (report.IDS310 == null && report.IDS311 == null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440308",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"'Balance of conduit foreign income' or 'Conduit foreign income distributed during income year' is required.",
                    LongDescription = @"'Balance of conduit foreign income' or 'Conduit foreign income distributed during income year' is required as 'Did you have a Conduit Foreign Income balance and/or distribute amounts of Conduit Foreign Income during the income year?' is 'Yes'.",
                    Location = "/xbrli:xbrl/tns:InternationalDealings.ConduitForeignIncome.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440308" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS309", Value = GetValueOrEmpty(report.IDS309) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS310", Value = report.IDS310.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS311", Value = report.IDS311.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440308

            #region VR.ATO.IDS.440309

            /*  VR.ATO.IDS.440309
            If 'Did you pay amounts of interest exempt from withholding tax during the income year?' is 'Yes', at least one of 'Interest to financial institution exempt from withholding under a DTA', 'Section 128F exempt interest paid' or 'Section 128FA exempt interest paid' must have a value.
    
            Legacy Rule Format:
            IF [IDS315] = TRUE AND (([IDS316] = NULL or [IDS316] = 0)
            AND ([IDS318] = NULL OR [IDS318] = 0)
            AND ([IDS319] = NULL OR [IDS319] = 0))
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS315] = IDS:RP.DTA:rvctc4.02.06:InternationalDealings.WithholdingTaxExemptNonResidentInterestPaid.Indicator
            [IDS316] = IDS:RP.DTA:rvctc4.02.06:InternationalDealings.WithholdingTaxExemptNonResidentInterestPaid.Amount
            [IDS318] = IDS:RP.s128F:rvctc4.02.06:InternationalDealings.WithholdingTaxExemptNonResidentInterestPaid.Amount
            [IDS319] = IDS:RP.s128FA:rvctc4.02.06:InternationalDealings.WithholdingTaxExemptNonResidentInterestPaid.Amount

            Technical Business Rule Format:
            ^IDS315 = TRUE AND ((^IDS316 = NULL or ^IDS316 = 0) AND (^IDS318 = NULL OR ^IDS318 = 0) AND (^IDS319 = NULL OR ^IDS319 = 0))
    
            Data Elements:
    
            RP.DTA:^IDS315 = tns:InternationalDealings.WithholdingTaxExemptNonResidentInterestPaid.Indicator
    
            RP.DTA:^IDS316 = tns:InternationalDealings.WithholdingTaxExemptNonResidentInterestPaid.Amount
    
            RP.s128F:^IDS318 = tns:InternationalDealings.WithholdingTaxExemptNonResidentInterestPaid.Amount
    
            RP.s128FA:^IDS319 = tns:InternationalDealings.WithholdingTaxExemptNonResidentInterestPaid.Amount
            */
            assertion = (report.IDS315 == true && ((report.IDS316 == null || report.IDS316 == 0) && (report.IDS318 == null || report.IDS318 == 0) && (report.IDS319 == null || report.IDS319 == 0)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440309",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"'Interest to financial institution exempt from withholding under a DTA', 'Section 128F exempt interest paid' or 'Section 128FA exempt interest paid' must have a value.",
                    LongDescription = @"'Interest to financial institution exempt from withholding under a DTA', 'Section 128F exempt interest paid' or 'Section 128FA exempt interest paid' is required as 'Did you pay amounts of interest exempt from withholding tax during the income year?' is 'Yes'.",
                    Location = "/xbrli:xbrl/tns:InternationalDealings.WithholdingTaxExemptNonResidentInterestPaid.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440309" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS315", Value = GetValueOrEmpty(report.IDS315) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS316", Value = report.IDS316.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS318", Value = report.IDS318.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS319", Value = report.IDS319.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440309

            #region VR.ATO.IDS.440310

            /*  VR.ATO.IDS.440310
            DTA Country Code' is required when 'Interest to financial institution exempt from withholding under a DTA' has a value.
    
            Legacy Rule Format:
            IF [IDS316] <> NULL AND [IDS317] = NULL
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS316] = IDS:RP.DTA:rvctc4.02.06:InternationalDealings.WithholdingTaxExemptNonResidentInterestPaid.Amount
            [IDS317] = IDS:RP:rvctc4.02.03:InternationalDealings.DoubleTaxAgreementFinancialInstitutionsWithholdingExemptionCountry.Code

            Technical Business Rule Format:
            ^IDS316 <> NULL AND ^IDS317 = NULL
    
            Data Elements:
    
            RP:^IDS317 = tns:InternationalDealings.DoubleTaxAgreementFinancialInstitutionsWithholdingExemptionCountry.Code
    
            RP.DTA:^IDS316 = tns:InternationalDealings.WithholdingTaxExemptNonResidentInterestPaid.Amount
            */
            assertion = (report.IDS316 != null && report.IDS317 == null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440310",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"'DTA Country Code' is required.",
                    LongDescription = @"'DTA Country Code' is required when 'Interest to financial institution exempt from withholding under a DTA' has a value.",
                    Location = "/xbrli:xbrl/tns:InternationalDealings.DoubleTaxAgreementFinancialInstitutionsWithholdingExemptionCountry.Code",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440310" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS316", Value = report.IDS316.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS317", Value = report.IDS317 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440310

            #region VR.ATO.IDS.440311

            /*  VR.ATO.IDS.440311
            Monetary field, may be signed, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS310] <> NULL AND [IDS310] <> MONETARY(S,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS310] = IDS:RP:rvctc4.02.01:InternationalDealings.ConduitForeignIncomeBalance.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS310, 'S', 11, 0)
    
            Data Elements:
    
            RP:^IDS310 = tns:InternationalDealings.ConduitForeignIncomeBalance.Amount
            */
            assertion = NotMonetary(report.IDS310, @"S", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:InternationalDealings.ConduitForeignIncomeBalance.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440311" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS310", Value = report.IDS310.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440311

            #region VR.ATO.IDS.440312

            /*  VR.ATO.IDS.440312
            Monetary field, may be signed, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS311] <> NULL AND [IDS311] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS311] = IDS:RP:rvctc4.02.00:InternationalDealings.ConduitForeignIncomeDistributed.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS311, 'U', 11, 0)
    
            Data Elements:
    
            RP:^IDS311 = tns:InternationalDealings.ConduitForeignIncomeDistributed.Amount
            */
            assertion = NotMonetary(report.IDS311, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:InternationalDealings.ConduitForeignIncomeDistributed.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440312" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS311", Value = report.IDS311.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440312

            #region VR.ATO.IDS.440313

            /*  VR.ATO.IDS.440313
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS207] <> NULL AND [IDS207] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS207] = IDS:RP:rvctc2.02.09:IncomeTax.Deduction.DebtEarningNonAssessableNonExemptForeignIncomeTotal.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS207, 'U', 11, 0)
    
            Data Elements:
    
            RP:^IDS207 = tns:IncomeTax.Deduction.DebtEarningNonAssessableNonExemptForeignIncomeTotal.Amount
            */
            assertion = NotMonetary(report.IDS207, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:IncomeTax.Deduction.DebtEarningNonAssessableNonExemptForeignIncomeTotal.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440313" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS207", Value = report.IDS207.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440313

            #region VR.ATO.IDS.440314

            /*  VR.ATO.IDS.440314
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS320] <> NULL AND [IDS320] <> MONETARY(U,11,0)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS320] = IDS:RP.CFCLC:bafpr1.02.22:Income.NonPortfolioDividendFromForeignCompanyNonAssessableNonExemptIncome.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS320, 'U', 11, 0)
    
            Data Elements:
    
            RP.CFCLC:^IDS320 = tns:Income.NonPortfolioDividendFromForeignCompanyNonAssessableNonExemptIncome.Amount
            */
            assertion = NotMonetary(report.IDS320, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Income.NonPortfolioDividendFromForeignCompanyNonAssessableNonExemptIncome.Amount[@contextRef='" + report.RPCFCLCId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440314" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS320", Value = report.IDS320.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440314

            #region VR.ATO.IDS.440315

            /*  VR.ATO.IDS.440315
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS321] <> NULL AND [IDS321] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS321] = IDS:RP.CFCSP:bafpr1.02.22:Income.NonPortfolioDividendFromForeignCompanyNonAssessableNonExemptIncome.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS321, 'U', 11, 0)
    
            Data Elements:
    
            RP.CFCSP:^IDS321 = tns:Income.NonPortfolioDividendFromForeignCompanyNonAssessableNonExemptIncome.Amount
            */
            assertion = NotMonetary(report.IDS321, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Income.NonPortfolioDividendFromForeignCompanyNonAssessableNonExemptIncome.Amount[@contextRef='" + report.RPCFCSPId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440315" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS321", Value = report.IDS321.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440315

            #region VR.ATO.IDS.440316

            /*  VR.ATO.IDS.440316
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS322] <> NULL AND [IDS322] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS322] = IDS:RP.CFCUC:bafpr1.02.22:Income.NonPortfolioDividendFromForeignCompanyNonAssessableNonExemptIncome.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS322, 'U', 11, 0)
    
            Data Elements:
    
            RP.CFCUC:^IDS322 = tns:Income.NonPortfolioDividendFromForeignCompanyNonAssessableNonExemptIncome.Amount
            */
            assertion = NotMonetary(report.IDS322, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Income.NonPortfolioDividendFromForeignCompanyNonAssessableNonExemptIncome.Amount[@contextRef='" + report.RPCFCUCId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440316" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS322", Value = report.IDS322.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440316

            #region VR.ATO.IDS.440317

            /*  VR.ATO.IDS.440317
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS323] <> NULL AND [IDS323] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS323] = IDS:RP:bafpo6.02.13:Capital.ThinCapitalisation.StatementWorldwideAsset.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS323, 'U', 11, 0)
    
            Data Elements:
    
            RP:^IDS323 = tns:Capital.ThinCapitalisation.StatementWorldwideAsset.Amount
            */
            assertion = NotMonetary(report.IDS323, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Capital.ThinCapitalisation.StatementWorldwideAsset.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440317" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS323", Value = report.IDS323.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440317

            #region VR.ATO.IDS.440318

            /*  VR.ATO.IDS.440318
            Equity capital shortfall amount required
    
            Legacy Rule Format:
            IF ([IDS223] = SET ("7","8")) AND ([IDS228] > 0) AND ([IDS233] = NULL OR [IDS233] = 0)
            RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS223] = IDS:RP:bafpo6.02.13:Liabilities.ThinCapitalisation.EntityType.Code
            [IDS228] = IDS:RP:bafpo6.02.09:Liabilities.ThinCapitalisation.DeductionDebtDisallowed.Amount
            [IDS233] = IDS:RP:bafpo6.02.09:Capital.ThinCapitalisation.EquityShortfall.Amount

            Technical Business Rule Format:
            (InSet(^IDS223, '"7","8"')) AND (^IDS228 > 0) AND (^IDS233 = NULL OR ^IDS233 = 0)
    
            Data Elements:
    
            RP:^IDS228 = tns:Liabilities.ThinCapitalisation.DeductionDebtDisallowed.Amount
    
            RP:^IDS223 = tns:Liabilities.ThinCapitalisation.EntityType.Code
    
            RP:^IDS233 = tns:Capital.ThinCapitalisation.EquityShortfall.Amount
            */
            assertion = (IsMatch(report.IDS223, @"^(7|8)$") && report.IDS228.GetValueOrDefault() > 0 && (report.IDS233 == null || report.IDS233 == 0));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440318",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Equity capital shortfall amount required",
                    LongDescription = @"If entity is an authorised deposit taking institution (ADI) and 'General information - Amount of debt deduction disallowed' is greater than zero then ""Add ADI entities - Equity capital shortfall amount' must be greater than zero",
                    Location = "/xbrli:xbrl/tns:Liabilities.ThinCapitalisation.DeductionDebtDisallowed.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440318" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS223", Value = report.IDS223 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS228", Value = report.IDS228.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS233", Value = report.IDS233.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440318

            #region VR.ATO.IDS.440319

            /*  VR.ATO.IDS.440319
            If the Statement worldwide asset and Average Australian asset are greater than zero, the entity type at the end of the income year must be either 3, 4, 5, 6, 9 or 10.
    
            Legacy Rule Format:
            IF ([IDS323] > 0 AND [IDS324] >0) AND ([IDS223] <> SET ("3","4","5","6","9","10"))
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS223] = IDS:RP:bafpo6.02.13:Liabilities.ThinCapitalisation.EntityType.Code
            [IDS323] = IDS:RP:bafpo6.02.13:Capital.ThinCapitalisation.StatementWorldwideAsset.Amount
            [IDS324] = IDS:RP:bafpo6.02.13:Capital.ThinCapitalisation.AverageAustralianAsset.Amount

            Technical Business Rule Format:
            (^IDS323 > 0 AND ^IDS324 >0) AND (NotInSet(^IDS223, '"3","4","5","6","9","10"'))
    
            Data Elements:
    
            RP:^IDS223 = tns:Liabilities.ThinCapitalisation.EntityType.Code
    
            RP:^IDS323 = tns:Capital.ThinCapitalisation.StatementWorldwideAsset.Amount
    
            RP:^IDS324 = tns:Capital.ThinCapitalisation.AverageAustralianAsset.Amount
            */
            assertion = (report.IDS323.GetValueOrDefault() > 0 && report.IDS324.GetValueOrDefault() > 0 && !(IsMatch(report.IDS223, @"^(3|4|5|6|9|10)$", RegexOptions.IgnoreCase)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440320",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity Type code must be 3, 4, 5, 6, 9 or 10.",
                    LongDescription = @"If there are amounts greater than zero for 'Non-ADI - Statement worldwide asset' or 'Non-ADI - Average Australian asset', then the entity type at the end of the income year must be 3 = Inward investment vehicle (general), 4 = Inward investment vehicle (financial), 5 = Inward investor (general) or 6 = Inward investor (financial), 9 = Outward investor (general) or 10 = Outward investor (financial)",
                    Location = "/xbrli:xbrl/tns:Liabilities.ThinCapitalisation.EntityType.Code",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440319" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS323", Value = report.IDS323.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS324", Value = report.IDS324.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS223", Value = report.IDS223 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440319

            #region VR.ATO.IDS.440399

            /*  VR.ATO.IDS.440399
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS324] <> NULL AND [IDS324] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS324] = IDS:RP:bafpo6.02.13:Capital.ThinCapitalisation.AverageAustralianAsset.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS324, 'U', 11, 0)
    
            Data Elements:
    
            RP:^IDS324 = tns:Capital.ThinCapitalisation.AverageAustralianAsset.Amount
            */
            assertion = NotMonetary(report.IDS324, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Capital.ThinCapitalisation.AverageAustralianAsset.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440399" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS324", Value = report.IDS324.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440399

            #region VR.ATO.IDS.440404

            /*  VR.ATO.IDS.440404
            Section 128F exempt interest paid has a maximum field length of 12
    
            Legacy Rule Format:
            IF [ids318] <> MONETARY(U,12,0)
                 RETURN VALIDATION MESSAGE
            ENDIF
            
            [ids318] = IDS:RP.s128F:rvctc4.02.06:InternationalDealings.WithholdingTaxExemptNonResidentInterestPaid.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS318, 'U', 12, 0)
    
            Data Elements:
    
            RP.s128F:^IDS318 = tns:InternationalDealings.WithholdingTaxExemptNonResidentInterestPaid.Amount
            */
            assertion = NotMonetary(report.IDS318, @"U", 12, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440404",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Section 128F exempt interest paid is not in a valid monetary format",
                    LongDescription = @"Section 128F exempt interest paid must be unsigned, not exceed 12 digits and not contain a decimal point or any other characters",
                    Location = "/xbrli:xbrl/tns:InternationalDealings.WithholdingTaxExemptNonResidentInterestPaid.Amount[@contextRef='" + report.RPs128FId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440404" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS318", Value = report.IDS318.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440404

            #region VR.ATO.IDS.440405

            /*  VR.ATO.IDS.440405
            Section 128FA exempt interest paid has a maximum field length of 12
    
            Legacy Rule Format:
            IF [ids319] <> MONETARY(U,12,0)
                 RETURN VALIDATION MESSAGE
            ENDIF
            
            [ids319] = IDS:RP.s128FA:rvctc4.02.06:InternationalDealings.WithholdingTaxExemptNonResidentInterestPaid.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS319, 'U', 12, 0)
    
            Data Elements:
    
            RP.s128FA:^IDS319 = tns:InternationalDealings.WithholdingTaxExemptNonResidentInterestPaid.Amount
            */
            assertion = NotMonetary(report.IDS319, @"U", 12, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440405",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Section 128FA exempt interest paid is not in a valid monetary format",
                    LongDescription = @"Section 128FA exempt interest paid must be unsigned, not exceed 12 digits and not contain a decimal point or any other characters",
                    Location = "/xbrli:xbrl/tns:InternationalDealings.WithholdingTaxExemptNonResidentInterestPaid.Amount[@contextRef='" + report.RPs128FAId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440405" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS319", Value = report.IDS319.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440405

            #region VR.ATO.IDS.440410

            /*  VR.ATO.IDS.440410
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS326] <> NULL AND [IDS326] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS326] = IDS:RP.Leasing:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS326, 'U', 11, 0)
    
            Data Elements:
    
            RP.Leasing:^IDS326 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            */
            assertion = NotMonetary(report.IDS326, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount[@contextRef='" + report.RPLeasingId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440410" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS326", Value = report.IDS326.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440410

            #region VR.ATO.IDS.440411

            /*  VR.ATO.IDS.440411
            Monetary field, may be signed, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF bafot.xx.xx:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount <> NULL AND bafot.xx.xx:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount <> MONETARY(S,11,0)
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^IDS327, 'S', 11, 0)
    
            Data Elements:
    
            RP.Leasing:^IDS327 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
            */
            assertion = NotMonetary(report.IDS327, @"S", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount[@contextRef='" + report.RPLeasingId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440411" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS327", Value = report.IDS327.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440411

            #region VR.ATO.IDS.440412

            /*  VR.ATO.IDS.440412
            For each OB activity, if Net OB income/loss has been completed then it must be less than or equal to the Assessable OB income.
    
            Legacy Rule Format:
            IF [IDS327] <> NULL AND ([IDS327] > [IDS326])
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS326] = IDS:RP.Leasing:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS327] = IDS:RP.Leasing:bafot.02.11:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount

            Technical Business Rule Format:
            ^IDS327 <> NULL AND (^IDS327 > ^IDS326)
    
            Data Elements:
    
            RP.Leasing:^IDS327 = tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount
    
            RP.Leasing:^IDS326 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            */
            assertion = (report.IDS327 != null && report.IDS327.GetValueOrDefault() > report.IDS326.GetValueOrDefault());
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440254",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Net OB income/loss incorrect",
                    LongDescription = @"For each OB activity, if Net OB income/loss has been completed then it must be less than or equal to the Assessable OB income.",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeOrLossNet.Amount[@contextRef='" + report.RPLeasingId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440412" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS327", Value = report.IDS327.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS326", Value = report.IDS326.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440412

            #region VR.ATO.IDS.440413

            /*  VR.ATO.IDS.440413
            For each OB activity, if Assessable OB income from related parties has been completed then it must be less than or equal to the Assessable OB income.
    
            Legacy Rule Format:
            IF [IDS328] <> NULL AND ([IDS328] > [IDS326])
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS326] = IDS:RP.Leasing:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            [IDS328] = IDS:RP.Leasing.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount

            Technical Business Rule Format:
            ^IDS328 <> NULL AND (^IDS328 > ^IDS326)
    
            Data Elements:
    
            RP.Leasing.RelatedParty:^IDS328 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
    
            RP.Leasing:^IDS326 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            */
            assertion = (report.IDS328 != null && report.IDS328.GetValueOrDefault() > report.IDS326.GetValueOrDefault());
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440256",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Assessable OB income from related parties incorrect",
                    LongDescription = @"For each OB activity, if Assessable OB income from related parties has been completed then it must be less than or equal to the Assessable OB income",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount[@contextRef='" + report.RPLeasingRelatedPartyId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440413" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS328", Value = report.IDS328.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS326", Value = report.IDS326.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440413

            #region VR.ATO.IDS.440414

            /*  VR.ATO.IDS.440414
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS328] <> NULL AND [IDS328] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS328] = IDS:RP.Leasing.RelatedParty:bafot.02.11:FinancialServices.OffshoreBankingIncomeAssessable.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS328, 'U', 11, 0)
    
            Data Elements:
    
            RP.Leasing.RelatedParty:^IDS328 = tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount
            */
            assertion = NotMonetary(report.IDS328, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:FinancialServices.OffshoreBankingIncomeAssessable.Amount[@contextRef='" + report.RPLeasingRelatedPartyId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440414" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS328", Value = report.IDS328.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440414

            #region VR.ATO.IDS.440415

            /*  VR.ATO.IDS.440415
            Number of FHLPs or FHCs you had an interest in has a maximum field length of 4.
    
            Legacy Rule Format:
            IF [IDS218] <> NULL AND [IDS218] <> NUMBER(U,4,0)
               RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS218] = IDS:RP:bafot.02.11:Miscellaneous.ForeignHybridLimitedPartnershipOrForeignHybridCompanyInterestIn.Count

            Technical Business Rule Format:
            NotNumeric(^IDS218, 'U', 4, 0)
    
            Data Elements:
    
            RP:^IDS218 = tns:Miscellaneous.ForeignHybridLimitedPartnershipOrForeignHybridCompanyInterestIn.Count
            */
            assertion = NotNumeric(report.IDS218, @"U", 4, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440400",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Number of FHLPs or FHCs you had an interest in must not exceed 4 characters",
                    LongDescription = @"For Number of FHLPs or FHCs you had an interest in, the maximum allowable characters for this form is 4",
                    Location = "/xbrli:xbrl/tns:Miscellaneous.ForeignHybridLimitedPartnershipOrForeignHybridCompanyInterestIn.Count",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440415" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS218", Value = report.IDS218.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440415

            #region VR.ATO.IDS.440416

            /*  VR.ATO.IDS.440416
            Number of CFCs and CFTs - listed countries has a maximum field length of 3.
    
            Legacy Rule Format:
            IF [IDS185] <> NULL AND [IDS185] <> NUMBER(U,3,0)
               RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS185] = IDS:RP.CFCLC:bafot.02.29:Miscellaneous.ControlledForeignCompaniesTrustsInterest.Count

            Technical Business Rule Format:
            NotNumeric(^IDS185, 'U', 3, 0)
    
            Data Elements:
    
            RP.CFCLC:^IDS185 = tns:Miscellaneous.InterestInControlledForeignCompaniesAndControlledForeignTrusts.Count
            */
            assertion = NotNumeric(report.IDS185, @"U", 3, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440401",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Number of CFCs and CFTs - Listed countries must not exceed 3 characters",
                    LongDescription = @"For Number of CFCs and CFTs - Listed countries, the maximum allowable characters for this form is 3",
                    Location = "/xbrli:xbrl/tns:Miscellaneous.InterestInControlledForeignCompaniesAndControlledForeignTrusts.Count[@contextRef='" + report.RPCFCLCId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440416" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS185", Value = report.IDS185.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440416

            #region VR.ATO.IDS.440417

            /*  VR.ATO.IDS.440417
            Number of CFCs and CFTs - specified countries has a maximum field length of 3.
    
            Legacy Rule Format:
            IF [IDS186] <> NULL AND [IDS186] <> NUMBER(U,3,0)
               RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS186] = IDS:RP.CFCSP:bafot.02.29:Miscellaneous.ControlledForeignCompaniesTrustsInterest.Count

            Technical Business Rule Format:
            NotNumeric(^IDS186, 'U', 3, 0)
    
            Data Elements:
    
            RP.CFCSP:^IDS186 = tns:Miscellaneous.InterestInControlledForeignCompaniesAndControlledForeignTrusts.Count
            */
            assertion = NotNumeric(report.IDS186, @"U", 3, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440402",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Number of CFCs and CFTs - Specified countries must not exceed 3 characters",
                    LongDescription = @"For Number of CFCs and CFTs - Specified countries, the maximum allowable characters for this form is 3",
                    Location = "/xbrli:xbrl/tns:Miscellaneous.InterestInControlledForeignCompaniesAndControlledForeignTrusts.Count[@contextRef='" + report.RPCFCSPId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440417" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS186", Value = report.IDS186.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440417

            #region VR.ATO.IDS.440418

            /*  VR.ATO.IDS.440418
            Number of CFCs and CFTs - other unlisted countries has a maximum field length of 3.
    
            Legacy Rule Format:
            IF [IDS187] <> NULL AND [IDS187] <> NUMBER(U,3,0)
               RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS187] = IDS:RP.CFCUC:bafot.02.29:Miscellaneous.ControlledForeignCompaniesTrustsInterest.Count

            Technical Business Rule Format:
            NotNumeric(^IDS187, 'U', 3, 0)
    
            Data Elements:
    
            RP.CFCUC:^IDS187 = tns:Miscellaneous.InterestInControlledForeignCompaniesAndControlledForeignTrusts.Count
            */
            assertion = NotNumeric(report.IDS187, @"U", 3, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440403",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Number of CFC and CFTs - Other unlisted countries must not exceed 3 characters",
                    LongDescription = @"For Number of CFC and CFTs - Other unlisted countries, the maximum allowable characters for this form is 3",
                    Location = "/xbrli:xbrl/tns:Miscellaneous.InterestInControlledForeignCompaniesAndControlledForeignTrusts.Count[@contextRef='" + report.RPCFCUCId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440418" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS187", Value = report.IDS187.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440418

            #region VR.ATO.IDS.440419

            /*  VR.ATO.IDS.440419
            This field is Mandatory - must be completed
    
            Legacy Rule Format:
            IF [IDS330] = NULL
               RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS330] = IDS:RP:rvctc4.02.13:InternationalDealings.CountryByCountryReportApplicability.Indicator

            Technical Business Rule Format:
            ^IDS330 = NULL
    
            Data Elements:
    
            RP:^IDS330 = tns:InternationalDealings.CountrybyCountryReportApplicability.Indicator
            */
            assertion = (report.IDS330 == null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001001",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Mandatory field not supplied",
                    Location = "/xbrli:xbrl/tns:InternationalDealings.CountrybyCountryReportApplicability.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440419" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS330", Value = GetValueOrEmpty(report.IDS330) });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440419

            #region VR.ATO.IDS.440420

            /*  VR.ATO.IDS.440420
            If there is a 'Yes' response to 'Does Country-by-Country reporting apply to you?' then 'Have you lodged Part A of your local file at the same time as your income tax return?' must be completed.
    
            Legacy Rule Format:
            IF [IDS330] = TRUE AND [IDS331] = NULL
               RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS330] = IDS:RP:rvctc4.02.13:InternationalDealings.CountryByCountryReportApplicability.Indicator
            [IDS331] = IDS:RP:rvctc4.02.13:InternationalDealings.LocalFilePartAVoluntaryLodgment.Indicator

            Technical Business Rule Format:
            ^IDS330 = TRUE AND ^IDS331 = NULL
    
            Data Elements:
    
            RP:^IDS331 = tns:InternationalDealings.LocalFilePartAVoluntaryLodgment.Indicator
    
            RP:^IDS330 = tns:InternationalDealings.CountrybyCountryReportApplicability.Indicator
            */
            assertion = (report.IDS330 == true && report.IDS331 == null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440420",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Mandatory field not supplied",
                    Location = "/xbrli:xbrl/tns:InternationalDealings.LocalFilePartAVoluntaryLodgment.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440420" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS330", Value = GetValueOrEmpty(report.IDS330) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS331", Value = GetValueOrEmpty(report.IDS331) });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440420

            #region VR.ATO.IDS.440421

            /*  VR.ATO.IDS.440421
            If there is a 'No' response to 'Have you lodged Part A of your local file at the same time as your income tax return?' then 'Is the total of your international related party dealings over $2 million?' must be completed
    
            Legacy Rule Format:
            IF [IDS331] = FALSE AND [IDS1] = NULL
               RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS1] = IDS:RP:rvctc4.02.10:InternationalDealings.RelatedPartiesTransactionsExcessAggregateValue.Indicator
            [IDS331] = IDS:RP:rvctc4.02.13:InternationalDealings.LocalFilePartAVoluntaryLodgment.Indicator

            Technical Business Rule Format:
            ^IDS331 = FALSE AND ^IDS1 = NULL
    
            Data Elements:
    
            RP:^IDS1 = tns:InternationalDealings.RelatedPartiesTransactionsExcessAggregateValue.Indicator
    
            RP:^IDS331 = tns:InternationalDealings.LocalFilePartAVoluntaryLodgment.Indicator
            */
            assertion = (report.IDS331 == false && report.IDS1 == null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440421",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Mandatory field not supplied",
                    Location = "/xbrli:xbrl/tns:InternationalDealings.RelatedPartiesTransactionsExcessAggregateValue.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440421" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS331", Value = GetValueOrEmpty(report.IDS331) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS1", Value = GetValueOrEmpty(report.IDS1) });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440421

            #region VR.ATO.IDS.440422

            /*  VR.ATO.IDS.440422
            If there is a 'No' response to 'Does Country-by-Country reporting apply to you?' then 'Is the total of your international related party dealings over $2 million?' must be completed.
    
            Legacy Rule Format:
            IF [IDS330] = FALSE AND [IDS1] = NULL
               RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS1] = IDS:RP:rvctc4.02.10:InternationalDealings.RelatedPartiesTransactionsExcessAggregateValue.Indicator
            [IDS330] = IDS:RP:rvctc4.02.13:InternationalDealings.CountryByCountryReportApplicability.Indicator

            Technical Business Rule Format:
            ^IDS330 = FALSE AND ^IDS1 = NULL
    
            Data Elements:
    
            RP:^IDS1 = tns:InternationalDealings.RelatedPartiesTransactionsExcessAggregateValue.Indicator
    
            RP:^IDS330 = tns:InternationalDealings.CountrybyCountryReportApplicability.Indicator
            */
            assertion = (report.IDS330 == false && report.IDS1 == null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440422",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Mandatory field not supplied",
                    Location = "/xbrli:xbrl/tns:InternationalDealings.RelatedPartiesTransactionsExcessAggregateValue.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440422" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS330", Value = GetValueOrEmpty(report.IDS330) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS1", Value = GetValueOrEmpty(report.IDS1) });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440422

            #region VR.ATO.IDS.440426

            /*  VR.ATO.IDS.440426
            Maximum three types per transaction type.
    
            Legacy Rule Format:
            IF COUNT(TransactionType) IN SET (RP.{TransactionType}.{CurrencyCode},{RP.{TransactionType}) > 3
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Count(Union(^IDS360, ^IDS334)) > 3
    
            Data Elements:
    
            RP.{TransactionType}.{CurrencyCode}:^IDS360 = tns:InternationalDealings.TransactionType.Code
    
            RP.{TransactionType}:^IDS334 = tns:InternationalDealings.TransactionType.Code
            */
            assertion = (Count(Union(report.RPTransactionTypeCurrencyCodeContextCollection == null ? null : report.RPTransactionTypeCurrencyCodeContextCollection.Select(f => f.IDS360), report.RPTransactionTypeContextCollection == null ? null : report.RPTransactionTypeContextCollection.Select(f => f.IDS334))) > 3);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440426",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Duplicate derivative code present for derivative transactions",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPTransactionTypeCurrencyCodeContextCollection == null ? 0 : (report.RPTransactionTypeCurrencyCodeContextCollection.Count() == 0 ? 0 : report.RPTransactionTypeCurrencyCodeContextCollection.Last().LastOccurrenceIndex)),
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440426" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS360", Value = "IDS360" });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS334", Value = "IDS334" });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440426

            #region VR.ATO.IDS.440436

            /*  VR.ATO.IDS.440436
            If an amount of expenditure or revenue is present, both the Main pricing methodology and the code for the percentage of the total dollar value of related party international dealings for which you have documentation must be completed.
    
            Legacy Rule Format:
            IF ([IDS340] <> NULL OR [IDS341] <> NULL OR [IDS342] <> NULL OR [IDS343] <> NULL) AND 
             (([IDS340] = NULL AND [IDS341] = NULL) OR [IDS342] = NULL OR [IDS343] = NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS340] = IDS:RP.OtherNotReportedAssignmentOfIntangibleNonRevenue:bafpo1.02.11:Assets.ConsiderationPaid.Amount
            [IDS341] = IDS:RP.OtherNotReportedAssignmentOfIntangibleNonRevenue:bafpo1.02.11:Assets.ConsiderationReceived.Amount
            [IDS342] = IDS:RP.OtherNotReportedAssignmentOfIntangibleNonRevenue:bafot.02.11:Miscellaneous.AcquisitionsAndDisposalsPricingMethod.Code
            [IDS343] = IDS:RP.OtherNotReportedAssignmentOfIntangibleNonRevenue:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code

            Technical Business Rule Format:
            (^IDS340 <> NULL OR ^IDS341 <> NULL OR ^IDS342 <> NULL OR ^IDS343 <> NULL) AND  ((^IDS340 = NULL AND ^IDS341 = NULL) OR ^IDS342 = NULL OR ^IDS343 = NULL)
    
            Data Elements:
    
            RP.OtherNotReportedAssignmentOfIntangibleNonRevenue:^IDS340 = tns:Assets.ConsiderationPaid.Amount
    
            RP.OtherNotReportedAssignmentOfIntangibleNonRevenue:^IDS341 = tns:Assets.ConsiderationReceived.Amount
    
            RP.OtherNotReportedAssignmentOfIntangibleNonRevenue:^IDS342 = tns:Miscellaneous.AcquisitionsAndDisposalsPricingMethod.Code
    
            RP.OtherNotReportedAssignmentOfIntangibleNonRevenue:^IDS343 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            */
            assertion = ((report.IDS340 != null || report.IDS341 != null || report.IDS342 != null || report.IDS343 != null) && (report.IDS340 == null && report.IDS341 == null || report.IDS342 == null || report.IDS343 == null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440436",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Assignment of intellectual property information incomplete",
                    Location = "/xbrli:xbrl/tns:Assets.ConsiderationPaid.Amount[@contextRef='" + report.RPOtherNotReportedAssignmentOfIntangibleNonRevenueId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440436" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS340", Value = report.IDS340.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS341", Value = report.IDS341.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS342", Value = report.IDS342 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS343", Value = report.IDS343 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440436

            #region VR.ATO.IDS.440437

            /*  VR.ATO.IDS.440437
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS340] <> NULL AND [IDS340] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS340] = IDS:RP.OtherNotReportedAssignmentOfIntangibleNonRevenue:bafpo1.02.11:Assets.ConsiderationPaid.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS340, 'U', 11, 0)
    
            Data Elements:
    
            RP.OtherNotReportedAssignmentOfIntangibleNonRevenue:^IDS340 = tns:Assets.ConsiderationPaid.Amount
            */
            assertion = NotMonetary(report.IDS340, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Assets.ConsiderationPaid.Amount[@contextRef='" + report.RPOtherNotReportedAssignmentOfIntangibleNonRevenueId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440437" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS340", Value = report.IDS340.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440437

            #region VR.ATO.IDS.440438

            /*  VR.ATO.IDS.440438
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS341] <> NULL AND [IDS341] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS341] = IDS:RP.OtherNotReportedAssignmentOfIntangibleNonRevenue:bafpo1.02.11:Assets.ConsiderationReceived.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS341, 'U', 11, 0)
    
            Data Elements:
    
            RP.OtherNotReportedAssignmentOfIntangibleNonRevenue:^IDS341 = tns:Assets.ConsiderationReceived.Amount
            */
            assertion = NotMonetary(report.IDS341, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Assets.ConsiderationReceived.Amount[@contextRef='" + report.RPOtherNotReportedAssignmentOfIntangibleNonRevenueId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440438" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS341", Value = report.IDS341.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440438

            #region VR.ATO.IDS.440439

            /*  VR.ATO.IDS.440439
            If an amount of expenditure or revenue is present, both the Main pricing methodology and the code for the percentage of the total dollar value of related party international dealings for which you have documentation must be completed.
    
            Legacy Rule Format:
            IF ([IDS344] <> NULL OR [IDS345] <> NULL OR [IDS346] <> NULL OR [IDS347] <> NULL) AND 
             (([IDS344] = NULL AND [IDS345] = NULL) OR [IDS346] = NULL OR [IDS347] = NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS344] = IDS:RP.OtherNotReportedAssignmentOfSharesOrEquityInterestsNonRevenue:bafpo1.02.11:Assets.ConsiderationPaid.Amount
            [IDS345] = IDS:RP.OtherNotReportedAssignmentOfSharesOrEquityInterestsNonRevenue:bafpo1.02.11:Assets.ConsiderationReceived.Amount
            [IDS346] = IDS:RP.OtherNotReportedAssignmentOfSharesOrEquityInterestsNonRevenue:bafot.02.11:Miscellaneous.AcquisitionsAndDisposalsPricingMethod.Code
            [IDS347] = IDS:RP.OtherNotReportedAssignmentOfSharesOrEquityInterestsNonRevenue:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code

            Technical Business Rule Format:
            (^IDS344 <> NULL OR ^IDS345 <> NULL OR ^IDS346 <> NULL OR ^IDS347 <> NULL) AND  ((^IDS344 = NULL AND ^IDS345 = NULL) OR ^IDS346 = NULL OR ^IDS347 = NULL)
    
            Data Elements:
    
            RP.OtherNotReportedAssignmentOfSharesOrEquityInterestsNonRevenue:^IDS344 = tns:Assets.ConsiderationPaid.Amount
    
            RP.OtherNotReportedAssignmentOfSharesOrEquityInterestsNonRevenue:^IDS345 = tns:Assets.ConsiderationReceived.Amount
    
            RP.OtherNotReportedAssignmentOfSharesOrEquityInterestsNonRevenue:^IDS346 = tns:Miscellaneous.AcquisitionsAndDisposalsPricingMethod.Code
    
            RP.OtherNotReportedAssignmentOfSharesOrEquityInterestsNonRevenue:^IDS347 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            */
            assertion = ((report.IDS344 != null || report.IDS345 != null || report.IDS346 != null || report.IDS347 != null) && (report.IDS344 == null && report.IDS345 == null || report.IDS346 == null || report.IDS347 == null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440439",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Assignment of shares or other equity interests information incomplete",
                    Location = "/xbrli:xbrl/tns:Assets.ConsiderationPaid.Amount[@contextRef='" + report.RPOtherNotReportedAssignmentOfSharesOrEquityInterestsNonRevenueId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440439" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS344", Value = report.IDS344.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS345", Value = report.IDS345.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS346", Value = report.IDS346 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS347", Value = report.IDS347 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440439

            #region VR.ATO.IDS.440440

            /*  VR.ATO.IDS.440440
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS344] <> NULL AND [IDS344] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS344] = IDS:RP.OtherNotReportedAssignmentOfSharesOrEquityInterestsNonRevenue:bafpo1.02.11:Assets.ConsiderationPaid.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS344, 'U', 11, 0)
    
            Data Elements:
    
            RP.OtherNotReportedAssignmentOfSharesOrEquityInterestsNonRevenue:^IDS344 = tns:Assets.ConsiderationPaid.Amount
            */
            assertion = NotMonetary(report.IDS344, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Assets.ConsiderationPaid.Amount[@contextRef='" + report.RPOtherNotReportedAssignmentOfSharesOrEquityInterestsNonRevenueId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440440" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS344", Value = report.IDS344.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440440

            #region VR.ATO.IDS.440441

            /*  VR.ATO.IDS.440441
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS345] <> NULL AND [IDS345] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS345] = IDS:RP.OtherNotReportedAssignmentOfSharesOrEquityInterestsNonRevenue:bafpo1.02.11:Assets.ConsiderationReceived.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS345, 'U', 11, 0)
    
            Data Elements:
    
            RP.OtherNotReportedAssignmentOfSharesOrEquityInterestsNonRevenue:^IDS345 = tns:Assets.ConsiderationReceived.Amount
            */
            assertion = NotMonetary(report.IDS345, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Assets.ConsiderationReceived.Amount[@contextRef='" + report.RPOtherNotReportedAssignmentOfSharesOrEquityInterestsNonRevenueId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440441" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS345", Value = report.IDS345.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440441

            #region VR.ATO.IDS.440442

            /*  VR.ATO.IDS.440442
            If an amount of expenditure or revenue is present, both the Main pricing methodology and the code for the percentage of the total dollar value of related party international dealings for which you have documentation must be completed.
    
            Legacy Rule Format:
            IF ([IDS348] <> NULL OR [IDS349] <> NULL OR [IDS350] <> NULL OR [IDS351] <> NULL) AND 
             (([IDS348] = NULL AND [IDS349] = NULL) OR [IDS350] = NULL OR [IDS351] = NULL)
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS348] = IDS:RP.OtherNotReportedAssignmentOfLoansOrDebtsNonRevenue:bafpo1.02.11:Assets.ConsiderationPaid.Amount
            [IDS349] = IDS:RP.OtherNotReportedAssignmentOfLoansOrDebtsNonRevenue:bafpo1.02.11:Assets.ConsiderationReceived.Amount
            [IDS350] = IDS:RP.OtherNotReportedAssignmentOfLoansOrDebtsNonRevenue:bafot.02.11:Miscellaneous.AcquisitionsAndDisposalsPricingMethod.Code
            [IDS351] = IDS:RP.OtherNotReportedAssignmentOfLoansOrDebtsNonRevenue:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code

            Technical Business Rule Format:
            (^IDS348 <> NULL OR ^IDS349 <> NULL OR ^IDS350 <> NULL OR ^IDS351 <> NULL) AND  ((^IDS348 = NULL AND ^IDS349 = NULL) OR ^IDS350 = NULL OR ^IDS351 = NULL)
    
            Data Elements:
    
            RP.OtherNotReportedAssignmentOfLoansOrDebtsNonRevenue:^IDS348 = tns:Assets.ConsiderationPaid.Amount
    
            RP.OtherNotReportedAssignmentOfLoansOrDebtsNonRevenue:^IDS349 = tns:Assets.ConsiderationReceived.Amount
    
            RP.OtherNotReportedAssignmentOfLoansOrDebtsNonRevenue:^IDS350 = tns:Miscellaneous.AcquisitionsAndDisposalsPricingMethod.Code
    
            RP.OtherNotReportedAssignmentOfLoansOrDebtsNonRevenue:^IDS351 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            */
            assertion = ((report.IDS348 != null || report.IDS349 != null || report.IDS350 != null || report.IDS351 != null) && (report.IDS348 == null && report.IDS349 == null || report.IDS350 == null || report.IDS351 == null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440442",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Arm's length Debt Test self assessment category cannot be completed if you did not rely on arm's length tests",
                    Location = "/xbrli:xbrl/tns:Assets.ConsiderationPaid.Amount[@contextRef='" + report.RPOtherNotReportedAssignmentOfLoansOrDebtsNonRevenueId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440442" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS348", Value = report.IDS348.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS349", Value = report.IDS349.GetValueOrDefault().ToString() });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS350", Value = report.IDS350 });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS351", Value = report.IDS351 });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440442

            #region VR.ATO.IDS.440443

            /*  VR.ATO.IDS.440443
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS348] <> NULL AND [IDS348] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS348] = IDS:RP.OtherNotReportedAssignmentOfLoansOrDebtsNonRevenue:bafpo1.02.11:Assets.ConsiderationPaid.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS348, 'U', 11, 0)
    
            Data Elements:
    
            RP.OtherNotReportedAssignmentOfLoansOrDebtsNonRevenue:^IDS348 = tns:Assets.ConsiderationPaid.Amount
            */
            assertion = NotMonetary(report.IDS348, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Assets.ConsiderationPaid.Amount[@contextRef='" + report.RPOtherNotReportedAssignmentOfLoansOrDebtsNonRevenueId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440443" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS348", Value = report.IDS348.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440443

            #region VR.ATO.IDS.440444

            /*  VR.ATO.IDS.440444
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS349] <> NULL AND [IDS349] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS349] = IDS:RP.OtherNotReportedAssignmentOfLoansOrDebtsNonRevenue:bafpo1.02.11:Assets.ConsiderationReceived.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS349, 'U', 11, 0)
    
            Data Elements:
    
            RP.OtherNotReportedAssignmentOfLoansOrDebtsNonRevenue:^IDS349 = tns:Assets.ConsiderationReceived.Amount
            */
            assertion = NotMonetary(report.IDS349, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Assets.ConsiderationReceived.Amount[@contextRef='" + report.RPOtherNotReportedAssignmentOfLoansOrDebtsNonRevenueId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440444" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS349", Value = report.IDS349.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440444

            #region VR.ATO.IDS.440445

            /*  VR.ATO.IDS.440445
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS134] <> NULL AND [IDS134] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS134] = IDS:RP.OtherNotReportedIntangibleNonRevenue:bafpo1.02.11:Assets.ConsiderationPaid.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS134, 'U', 11, 0)
    
            Data Elements:
    
            RP.OtherNotReportedIntangibleNonRevenue:^IDS134 = tns:Assets.ConsiderationPaid.Amount
            */
            assertion = NotMonetary(report.IDS134, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Assets.ConsiderationPaid.Amount[@contextRef='" + report.RPOtherNotReportedIntangibleNonRevenueId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440445" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS134", Value = report.IDS134.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440445

            #region VR.ATO.IDS.440446

            /*  VR.ATO.IDS.440446
            Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
            Legacy Rule Format:
            IF [IDS135] <> NULL AND [IDS135] <> MONETARY(U,11,0) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS135] = IDS:RP.OtherNotReportedIntangibleNonRevenue:bafpo1.02.11:Assets.ConsiderationReceived.Amount

            Technical Business Rule Format:
            NotMonetary(^IDS135, 'U', 11, 0)
    
            Data Elements:
    
            RP.OtherNotReportedIntangibleNonRevenue:^IDS135 = tns:Assets.ConsiderationReceived.Amount
            */
            assertion = NotMonetary(report.IDS135, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Assets.ConsiderationReceived.Amount[@contextRef='" + report.RPOtherNotReportedIntangibleNonRevenueId + "']",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440446" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS135", Value = report.IDS135.GetValueOrDefault().ToString() });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440446

            #region VR.ATO.IDS.440447

            /*  VR.ATO.IDS.440447
            Derivative codes can only occur up to three times
    
            Legacy Rule Format:
            IF COUNT([IDS332] > 3) 
             RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS332] = IDS:RP.Derivatives:rvctc4.02.13:InternationalDealings.RelatedPartyTransactionType.Code

            Technical Business Rule Format:
            Count(^IDS332) > 3
    
            Data Elements:
    
            RP.Derivatives:^IDS332 = tns:InternationalDealings.RelatedPartyTransactionType.Code
            */
            assertion = (Count(report.IDS332Collection) > 3);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440447",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Derivative codes can only occur up to three times",
                    Location = "/xbrli:xbrl/tns:InternationalDealings.RelatedPartyTransactionType.Code",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440447" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440447

            #region VR.ATO.IDS.440448

            /*  VR.ATO.IDS.440448
            If there is a 'Yes' response to 'Have you lodged Part A of your local file at the same time as your income tax return?' then international related party dealings information is not required.
    
            Legacy Rule Format:
            IF [IDS331] = TRUE AND ([IDS1] <> NULL OR [IDS151] <> NULL OR [IDS159] <> NULL)
               RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS1] = IDS:RP:rvctc4.02.10:InternationalDealings.RelatedPartiesTransactionsExcessAggregateValue.Indicator
            [IDS151] = IDS:RP:rvctc4.02.05:InternationalDealings.RestructuringEvents.Indicator
            [IDS159] = IDS:RP:rvctc4.02.05:InternationalDealings.TransactionsRestructuringEventsAssetRevaluation.Indicator
            [IDS331] = IDS:RP:rvctc4.02.13:InternationalDealings.LocalFilePartAVoluntaryLodgment.Indicator

            Technical Business Rule Format:
            ^IDS331 = TRUE AND (^IDS1 <> NULL OR ^IDS151 <> NULL OR ^IDS159 <> NULL)
    
            Data Elements:
    
            RP:^IDS331 = tns:InternationalDealings.LocalFilePartAVoluntaryLodgment.Indicator
    
            RP:^IDS1 = tns:InternationalDealings.RelatedPartiesTransactionsExcessAggregateValue.Indicator
    
            RP:^IDS151 = tns:InternationalDealings.RestructuringEvents.Indicator
    
            RP:^IDS159 = tns:InternationalDealings.TransactionsRestructuringEventsAssetRevaluation.Indicator
            */
            assertion = (report.IDS331 == true && (report.IDS1 != null || report.IDS151 != null || report.IDS159 != null));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440448",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"International related party dealings information is not required",
                    Location = "/xbrli:xbrl/tns:InternationalDealings.LocalFilePartAVoluntaryLodgment.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440448" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS331", Value = GetValueOrEmpty(report.IDS331) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS1", Value = GetValueOrEmpty(report.IDS1) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS151", Value = GetValueOrEmpty(report.IDS151) });

                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS159", Value = GetValueOrEmpty(report.IDS159) });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440448

            #region VR.ATO.IDS.440452

            /*  VR.ATO.IDS.440452
            Maximum of one assignment of intellectual property is allowed
    
            Legacy Rule Format:
            IF COUNT(RP.OtherNotReportedAssignmentOfIntangibleNonRevenue) > 1
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Count(^Context) > 1
    
            Data Elements:
    
            ^Context = RP:RP.OtherNotReportedAssignmentOfIntangibleNonRevenue
            */
            assertion = (Count(report.RPOtherNotReportedAssignmentOfIntangibleNonRevenueCount) > 1);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440452",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Maximum of one assignment of intellectual property is allowed",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOtherNotReportedAssignmentOfIntangibleNonRevenueLastOccurrenceIndex),
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440452" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440452

            #region VR.ATO.IDS.440453

            /*  VR.ATO.IDS.440453
            Maximum of one assignment of shares or equity interests is allowed
    
            Legacy Rule Format:
            IF COUNT(RP.OtherNotReportedAssignmentOfSharesOrEquityInterestsNonRevenue) > 1
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Count(^Context) > 1
    
            Data Elements:
    
            ^Context = RP:RP.OtherNotReportedAssignmentOfSharesOrEquityInterestsNonRevenue
            */
            assertion = (Count(report.RPOtherNotReportedAssignmentOfSharesOrEquityInterestsNonRevenueCount) > 1);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440453",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Maximum of one assignment of shares or equity interests is allowed",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOtherNotReportedAssignmentOfSharesOrEquityInterestsNonRevenueLastOccurrenceIndex),
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440453" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440453

            #region VR.ATO.IDS.440454

            /*  VR.ATO.IDS.440454
            Maximum of one assignment of loans or debts is allowed
    
            Legacy Rule Format:
            IF COUNT(RP.OtherNotReportedAssignmentOfLoansOrDebtsNonRevenue) > 1
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Count(^Context) > 1
    
            Data Elements:
    
            ^Context = RP:RP.OtherNotReportedAssignmentOfLoansOrDebtsNonRevenue
            */
            assertion = (Count(report.RPOtherNotReportedAssignmentOfLoansOrDebtsNonRevenueCount) > 1);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.IDS.440454",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Maximum of one assignment of loans or debts is allowed",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOtherNotReportedAssignmentOfLoansOrDebtsNonRevenueLastOccurrenceIndex),
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440454" } },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440454

            #region VR.ATO.IDS.440459

            /*  VR.ATO.IDS.440459
            This field is Mandatory - must be completed
    
            Legacy Rule Format:
            IF [IDS213] = NULL
            RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS213] = IDS:RP:bafot.02.11:Miscellaneous.TransferPropertyMoneyOrServices.Indicator

            Technical Business Rule Format:
            ^IDS213 = NULL
    
            Data Elements:
    
            RP:^IDS213 = tns:Miscellaneous.TransferPropertyMoneyOrServices.Indicator
            */
            assertion = (report.IDS213 == null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001001",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Mandatory field not supplied",
                    Location = "/xbrli:xbrl/tns:Miscellaneous.TransferPropertyMoneyOrServices.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440459" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS213", Value = GetValueOrEmpty(report.IDS213) });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440459

            #region VR.ATO.IDS.440460

            /*  VR.ATO.IDS.440460
            This field is Mandatory - must be completed
    
            Legacy Rule Format:
            IF [IDS216] = NULL
            RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS216] = IDS:RP:bafot.02.11:Miscellaneous.NonResidentTrustInterestEntitlementOrBeneficiary.Indicator

            Technical Business Rule Format:
            ^IDS216 = NULL
    
            Data Elements:
    
            RP:^IDS216 = tns:Miscellaneous.NonResidentTrustInterestEntitlementOrBeneficiary.Indicator
            */
            assertion = (report.IDS216 == null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001001",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Mandatory field not supplied",
                    Location = "/xbrli:xbrl/tns:Miscellaneous.NonResidentTrustInterestEntitlementOrBeneficiary.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440460" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS216", Value = GetValueOrEmpty(report.IDS216) });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440460

            #region VR.ATO.IDS.440461

            /*  VR.ATO.IDS.440461
            This field is Mandatory - must be completed
    
            Legacy Rule Format:
            IF [IDS217] = NULL
            RETURN VALIDATION MESSAGE
            ENDIF
            
            [IDS217] = IDS:RP:bafot.02.11:Miscellaneous.ForeignHybridLimitedPartnershipOrForeignHybridCompanyShareholder.Indicator

            Technical Business Rule Format:
            ^IDS217 = NULL
    
            Data Elements:
    
            RP:^IDS217 = tns:Miscellaneous.ForeignHybridLimitedPartnershipOrForeignHybridCompanyShareholder.Indicator
            */
            assertion = (report.IDS217 == null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001001",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Mandatory field not supplied",
                    Location = "/xbrli:xbrl/tns:Miscellaneous.ForeignHybridLimitedPartnershipOrForeignHybridCompanyShareholder.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440461" } },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "IDS217", Value = GetValueOrEmpty(report.IDS217) });

                response.Add(processMessage);
            }
            #endregion // VR.ATO.IDS.440461

            #region Repeating RPForeignCountryContext
            if (report.RPForeignCountryContextCollection != null)
            {
                int itemIndexContext2 = 0;
                foreach (IDS2017.RPForeignCountryContext rpForeignCountryContext in report.RPForeignCountryContextCollection)
                {
                    itemIndexContext2++;

                    #region VR.ATO.GEN.001021

                    /*  VR.ATO.GEN.001021
                    Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
                    Legacy Rule Format:
                    IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
                       RETURN VALIDATION MESSAGE
                    ENDIF
        
                    Technical Business Rule Format:
                    (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
            
                    Data Elements:
            
                    ^IdentifierScheme = RP:RP.{ForeignCountry}
            
                    ^Context = RP:RP.{ForeignCountry}
                    */
                    assertion = (rpForeignCountryContext.Exists != false && rpForeignCountryContext.IdentifierScheme != @"http://www.ato.gov.au/tfn");
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.001021",
                            Severity = ProcessMessageSeverity.Error,
                            Description = @"Invalid identifier scheme.",
                            LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                            Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(rpForeignCountryContext.OccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                        };
                        response.Add(processMessage);
                    }
                    #endregion // VR.ATO.GEN.001021

                    #region VR.ATO.GEN.001023

                    /*  VR.ATO.GEN.001023
                    TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
                    Legacy Rule Format:
                    IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
                       RETURN VALIDATION MESSAGE
                    ENDIF
        
                    Technical Business Rule Format:
                    ^Context <> NULL AND ^OtherTFN <> ^TFN
            
                    Data Elements:
            
                    ^Context = RP:RP.{ForeignCountry}
            
                    ^OtherTFN = RP:RP.{ForeignCountry}
            
                    ^TFN = RP
                    */
                    assertion = (rpForeignCountryContext.Exists != false && rpForeignCountryContext.IdentifierTFN != report.RPIdentifierTFN);
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.001023",
                            Severity = ProcessMessageSeverity.Error,
                            Description = @"Unexpected TFN mismatch with Reporting Party",
                            LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                            Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(rpForeignCountryContext.OccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                        };
                        response.Add(processMessage);
                    }
                    #endregion // VR.ATO.GEN.001023

                    #region VR.ATO.GEN.438029

                    /*  VR.ATO.GEN.438029
                    Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
                    Legacy Rule Format:
                    IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
                       RETURN VALIDATION MESSAGE
                    ENDIF
        
                    Technical Business Rule Format:
                    (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
            
                    Data Elements:
            
                    ^IdentifierScheme = RP:RP.{ForeignCountry}
            
                    ^Context = RP:RP.{ForeignCountry}
                    */
                    assertion = (rpForeignCountryContext.Exists != false && rpForeignCountryContext.IdentifierScheme != @"http://www.ato.gov.au/tfn");
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.438029",
                            Severity = ProcessMessageSeverity.Error,
                            Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                            Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(rpForeignCountryContext.OccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                        };
                        response.Add(processMessage);
                    }
                    #endregion // VR.ATO.GEN.438029

                    #region VR.ATO.IDS.440008

                    /*  VR.ATO.IDS.440008
                    Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
                    Legacy Rule Format:
                    IF (bafpr1.xx.xx:Expense.Other.Amount <> NULL) AND (bafpr1.xx.xx:Expense.Other.Amount <> MONETARY(U,11,0)) 
                     RETURN VALIDATION MESSAGE
                    ENDIF
        
                    Technical Business Rule Format:
                    NotMonetary(^IDS7, 'U', 11, 0)
            
                    Data Elements:
            
                    RP.{ForeignCountry}:^IDS7 = tns:Expense.Other.Amount
                    */
                    assertion = NotMonetary(rpForeignCountryContext.IDS7, @"U", 11, 0);
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.400011",
                            Severity = ProcessMessageSeverity.Error,
                            Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                            LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                            Location = "/xbrli:xbrl/tns:Expense.Other.Amount[@contextRef='" + rpForeignCountryContext.Id + "']",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440008" } },
                        };
                        processMessage.Parameters.Add(new ProcessMessageParameter
                        { Name = "IDS7", Value = rpForeignCountryContext.IDS7.GetValueOrDefault().ToString() });

                        response.Add(processMessage);
                    }
                    #endregion // VR.ATO.IDS.440008

                    #region VR.ATO.IDS.440009

                    /*  VR.ATO.IDS.440009
                    Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
                    Legacy Rule Format:
                    IF (bafpr1.xx.xx:Revenue.Other.Amount <> NULL) AND (bafpr1.xx.xx:Revenue.Other.Amount <> MONETARY(U,11,0)) 
                     RETURN VALIDATION MESSAGE
                    ENDIF
        
                    Technical Business Rule Format:
                    NotMonetary(^IDS8, 'U', 11, 0)
            
                    Data Elements:
            
                    RP.{ForeignCountry}:^IDS8 = tns:Revenue.Other.Amount
                    */
                    assertion = NotMonetary(rpForeignCountryContext.IDS8, @"U", 11, 0);
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.400011",
                            Severity = ProcessMessageSeverity.Error,
                            Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                            LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                            Location = "/xbrli:xbrl/tns:Revenue.Other.Amount[@contextRef='" + rpForeignCountryContext.Id + "']",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440009" } },
                        };
                        processMessage.Parameters.Add(new ProcessMessageParameter
                        { Name = "IDS8", Value = rpForeignCountryContext.IDS8.GetValueOrDefault().ToString() });

                        response.Add(processMessage);
                    }
                    #endregion // VR.ATO.IDS.440009
                }
            }

            #endregion // Foreach loop

            #region Repeating RPForeignCountryActivityCodeContext
            if (report.RPForeignCountryActivityCodeContextCollection != null)
            {
                int itemIndexContext3 = 0;
                foreach (IDS2017.RPForeignCountryActivityCodeContext rpForeignCountryActivityCodeContext in report.RPForeignCountryActivityCodeContextCollection)
                {
                    itemIndexContext3++;

                    #region VR.ATO.GEN.001021

                    /*  VR.ATO.GEN.001021
                    Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
                    Legacy Rule Format:
                    IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
                       RETURN VALIDATION MESSAGE
                    ENDIF
        
                    Technical Business Rule Format:
                    (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
            
                    Data Elements:
            
                    ^IdentifierScheme = RP.{ForeignCountry}:RP.{ForeignCountry}.{ActivityCode}
            
                    ^Context = RP.{ForeignCountry}:RP.{ForeignCountry}.{ActivityCode}
                    */
                    assertion = (rpForeignCountryActivityCodeContext.Exists != false && rpForeignCountryActivityCodeContext.IdentifierScheme != @"http://www.ato.gov.au/tfn");
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.001021",
                            Severity = ProcessMessageSeverity.Error,
                            Description = @"Invalid identifier scheme.",
                            LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                            Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(rpForeignCountryActivityCodeContext.OccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                        };
                        response.Add(processMessage);
                    }
                    #endregion // VR.ATO.GEN.001021

                    #region VR.ATO.GEN.001023

                    /*  VR.ATO.GEN.001023
                    TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
                    Legacy Rule Format:
                    IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
                       RETURN VALIDATION MESSAGE
                    ENDIF
        
                    Technical Business Rule Format:
                    ^Context <> NULL AND ^OtherTFN <> ^TFN
            
                    Data Elements:
            
                    ^Context = RP.{ForeignCountry}:RP.{ForeignCountry}.{ActivityCode}
            
                    ^OtherTFN = RP.{ForeignCountry}:RP.{ForeignCountry}.{ActivityCode}
            
                    ^TFN = RP
                    */
                    assertion = (rpForeignCountryActivityCodeContext.Exists != false && rpForeignCountryActivityCodeContext.IdentifierTFN != report.RPIdentifierTFN);
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.001023",
                            Severity = ProcessMessageSeverity.Error,
                            Description = @"Unexpected TFN mismatch with Reporting Party",
                            LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                            Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(rpForeignCountryActivityCodeContext.OccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                        };
                        response.Add(processMessage);
                    }
                    #endregion // VR.ATO.GEN.001023

                    #region VR.ATO.GEN.438029

                    /*  VR.ATO.GEN.438029
                    Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
                    Legacy Rule Format:
                    IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
                       RETURN VALIDATION MESSAGE
                    ENDIF
        
                    Technical Business Rule Format:
                    (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
            
                    Data Elements:
            
                    ^IdentifierScheme = RP.{ForeignCountry}:RP.{ForeignCountry}.{ActivityCode}
            
                    ^Context = RP.{ForeignCountry}:RP.{ForeignCountry}.{ActivityCode}
                    */
                    assertion = (rpForeignCountryActivityCodeContext.Exists != false && rpForeignCountryActivityCodeContext.IdentifierScheme != @"http://www.ato.gov.au/tfn");
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.438029",
                            Severity = ProcessMessageSeverity.Error,
                            Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                            Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(rpForeignCountryActivityCodeContext.OccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                        };
                        response.Add(processMessage);
                    }
                    #endregion // VR.ATO.GEN.438029

                    #region VR.ATO.IDS.440006

                    /*  VR.ATO.IDS.440006
                    Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
                    Legacy Rule Format:
                    IF (bafpr1.xx.xx:Expense.Total.Amount <> NULL) AND (bafpr1.xx.xx:Expense.Total.Amount <> MONETARY(U,11,0)) 
                     RETURN VALIDATION MESSAGE
                    ENDIF
        
                    Technical Business Rule Format:
                    NotMonetary(^IDS5, 'U', 11, 0)
            
                    Data Elements:
            
                    RP.{ForeignCountry}.{ActivityCode}:^IDS5 = tns:Expense.Total.Amount
                    */
                    assertion = NotMonetary(rpForeignCountryActivityCodeContext.IDS5, @"U", 11, 0);
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.400011",
                            Severity = ProcessMessageSeverity.Error,
                            Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                            LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                            Location = "/xbrli:xbrl/tns:Expense.Total.Amount[@contextRef='" + rpForeignCountryActivityCodeContext.Id + "']",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440006" } },
                        };
                        processMessage.Parameters.Add(new ProcessMessageParameter
                        { Name = "IDS5", Value = rpForeignCountryActivityCodeContext.IDS5.GetValueOrDefault().ToString() });

                        response.Add(processMessage);
                    }
                    #endregion // VR.ATO.IDS.440006

                    #region VR.ATO.IDS.440007

                    /*  VR.ATO.IDS.440007
                    Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
                    Legacy Rule Format:
                    IF (bafpr1.xx.xx:Revenue.Total.Amount <> NULL) AND (bafpr1.xx.xx:Revenue.Total.Amount <> MONETARY(U,11,0)) 
                     RETURN VALIDATION MESSAGE
                    ENDIF
        
                    Technical Business Rule Format:
                    NotMonetary(^IDS6, 'U', 11, 0)
            
                    Data Elements:
            
                    RP.{ForeignCountry}.{ActivityCode}:^IDS6 = tns:Revenue.Total.Amount
                    */
                    assertion = NotMonetary(rpForeignCountryActivityCodeContext.IDS6, @"U", 11, 0);
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.400011",
                            Severity = ProcessMessageSeverity.Error,
                            Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                            LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                            Location = "/xbrli:xbrl/tns:Revenue.Total.Amount[@contextRef='" + rpForeignCountryActivityCodeContext.Id + "']",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440007" } },
                        };
                        processMessage.Parameters.Add(new ProcessMessageParameter
                        { Name = "IDS6", Value = rpForeignCountryActivityCodeContext.IDS6.GetValueOrDefault().ToString() });

                        response.Add(processMessage);
                    }
                    #endregion // VR.ATO.IDS.440007
                }
            }

            #endregion // Foreach loop

            #region Repeating RPRestructuringEventContext
            if (report.RPRestructuringEventContextCollection != null)
            {
                int itemIndexContext2 = 0;
                foreach (IDS2017.RPRestructuringEventContext rpRestructuringEventContext in report.RPRestructuringEventContextCollection)
                {
                    itemIndexContext2++;

                    #region VR.ATO.GEN.001021

                    /*  VR.ATO.GEN.001021
                    Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
                    Legacy Rule Format:
                    IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
                       RETURN VALIDATION MESSAGE
                    ENDIF
        
                    Technical Business Rule Format:
                    (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
            
                    Data Elements:
            
                    ^IdentifierScheme = RP:RP.{RestructuringEvent}
            
                    ^Context = RP:RP.{RestructuringEvent}
                    */
                    assertion = (rpRestructuringEventContext.Exists != false && rpRestructuringEventContext.IdentifierScheme != @"http://www.ato.gov.au/tfn");
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.001021",
                            Severity = ProcessMessageSeverity.Error,
                            Description = @"Invalid identifier scheme.",
                            LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                            Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(rpRestructuringEventContext.OccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                        };
                        response.Add(processMessage);
                    }
                    #endregion // VR.ATO.GEN.001021

                    #region VR.ATO.GEN.001023

                    /*  VR.ATO.GEN.001023
                    TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
                    Legacy Rule Format:
                    IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
                       RETURN VALIDATION MESSAGE
                    ENDIF
        
                    Technical Business Rule Format:
                    ^Context <> NULL AND ^OtherTFN <> ^TFN
            
                    Data Elements:
            
                    ^Context = RP:RP.{RestructuringEvent}
            
                    ^OtherTFN = RP:RP.{RestructuringEvent}
            
                    ^TFN = RP
                    */
                    assertion = (rpRestructuringEventContext.Exists != false && rpRestructuringEventContext.IdentifierTFN != report.RPIdentifierTFN);
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.001023",
                            Severity = ProcessMessageSeverity.Error,
                            Description = @"Unexpected TFN mismatch with Reporting Party",
                            LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                            Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(rpRestructuringEventContext.OccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                        };
                        response.Add(processMessage);
                    }
                    #endregion // VR.ATO.GEN.001023

                    #region VR.ATO.GEN.438029

                    /*  VR.ATO.GEN.438029
                    Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
                    Legacy Rule Format:
                    IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
                       RETURN VALIDATION MESSAGE
                    ENDIF
        
                    Technical Business Rule Format:
                    (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
            
                    Data Elements:
            
                    ^IdentifierScheme = RP:RP.{RestructuringEvent}
            
                    ^Context = RP:RP.{RestructuringEvent}
                    */
                    assertion = (rpRestructuringEventContext.Exists != false && rpRestructuringEventContext.IdentifierScheme != @"http://www.ato.gov.au/tfn");
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.438029",
                            Severity = ProcessMessageSeverity.Error,
                            Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                            Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(rpRestructuringEventContext.OccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                        };
                        response.Add(processMessage);
                    }
                    #endregion // VR.ATO.GEN.438029

                    #region VR.ATO.IDS.440078

                    /*  VR.ATO.IDS.440078
                    If information has been completed for restructuring events, then for each restructuring event the entity/branch indicator, capital value code, main nature of restructure code, foreign country code, percentage of dealings with documentation code and description must be completed, and a response must be entered at 'Was there a contemporaneous professional valuation study or transfer pricing analysis of the restructuring event undertaken?'.
    
                    Legacy Rule Format:
                    FOR EACH RestructuringEvent IN SET (RP.{RestructuringEvent}) 
                    IF ([IDS152] = NULL OR [IDS153] = NULL OR [IDS154] = NULL OR [IDS155] = NULL OR [IDS156] = NULL OR [IDS158] = NULL)
                     RETURN VALIDATION MESSAGE
                    ENDIF
                    
                    [IDS152] = IDS:RP.{RestructuringEvent}:pyde.02.09:OrganisationDetails.RestructuringEventEntity.Code
                    [IDS153] = IDS:RP.{RestructuringEvent}:bafot.02.11:Miscellaneous.CapitalValue.Code
                    [IDS154] = IDS:RP.{RestructuringEvent}:bafot.02.11:Miscellaneous.NatureOfItem.Code
                    [IDS155] = IDS:RP.{RestructuringEvent}:pyde.02.08:OrganisationDetails.InternationalRelatedPartyCountry.Code
                    [IDS156] = IDS:RP.{RestructuringEvent}:bafot.02.23:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
                    [IDS158] = IDS:RP.{RestructuringEvent}:rvctc4.02.05:InternationalDealings.EventAnalysis.Indicator
        
                    Technical Business Rule Format:
                    ^IDS152 = NULL OR ^IDS153 = NULL OR ^IDS154 = NULL OR ^IDS155 = NULL OR ^IDS156 = NULL OR ^IDS158 = NULL
            
                    Data Elements:
            
                    RP.{RestructuringEvent}:^IDS152 = tns:OrganisationDetails.RestructuringEventEntity.Code
            
                    RP.{RestructuringEvent}:^IDS153 = tns:Miscellaneous.CapitalValue.Code
            
                    RP.{RestructuringEvent}:^IDS154 = tns:Miscellaneous.NatureOfItem.Code
            
                    RP.{RestructuringEvent}:^IDS155 = tns:OrganisationDetails.InternationalRelatedPartyCountry.Code
            
                    RP.{RestructuringEvent}:^IDS156 = tns:Miscellaneous.PercentageOfDealingsWithDocumentation.Code
            
                    RP.{RestructuringEvent}:^IDS158 = tns:InternationalDealings.EventAnalysis.Indicator
                    */
                    assertion = (rpRestructuringEventContext.IDS152 == null || rpRestructuringEventContext.IDS153 == null || rpRestructuringEventContext.IDS154 == null || rpRestructuringEventContext.IDS155 == null || rpRestructuringEventContext.IDS156 == null || rpRestructuringEventContext.IDS158 == null);
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.IDS.440078",
                            Severity = ProcessMessageSeverity.Error,
                            Description = @"Branch operations restructuring event information is incomplete",
                            LongDescription = @"If information has been completed for restructuring events, then for each restructuring event the entity/branch indicator, capital value code, main nature of restructure code, foreign country code, percentage of dealings with documentation code and description must be completed, and a response must be entered at 'Was there a contemporaneous professional valuation study or transfer pricing analysis of the restructuring event undertaken?'",
                            Location = "/xbrli:xbrl/tns:OrganisationDetails.RestructuringEventEntity.Code[@contextRef='" + rpRestructuringEventContext.Id + "']",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440078" } },
                        };
                        processMessage.Parameters.Add(new ProcessMessageParameter
                        { Name = "IDS152", Value = rpRestructuringEventContext.IDS152 });

                        processMessage.Parameters.Add(new ProcessMessageParameter
                        { Name = "IDS153", Value = rpRestructuringEventContext.IDS153 });

                        processMessage.Parameters.Add(new ProcessMessageParameter
                        { Name = "IDS154", Value = rpRestructuringEventContext.IDS154 });

                        processMessage.Parameters.Add(new ProcessMessageParameter
                        { Name = "IDS155", Value = rpRestructuringEventContext.IDS155 });

                        processMessage.Parameters.Add(new ProcessMessageParameter
                        { Name = "IDS156", Value = rpRestructuringEventContext.IDS156 });

                        processMessage.Parameters.Add(new ProcessMessageParameter
                        { Name = "IDS158", Value = GetValueOrEmpty(rpRestructuringEventContext.IDS158) });

                        response.Add(processMessage);
                    }
                    #endregion // VR.ATO.IDS.440078
                }
            }

            #endregion // Foreach loop

            #region Repeating RPSpecifiedCountryContext
            if (report.RPSpecifiedCountryContextCollection != null)
            {
                int itemIndexContext2 = 0;
                foreach (IDS2017.RPSpecifiedCountryContext rpSpecifiedCountryContext in report.RPSpecifiedCountryContextCollection)
                {
                    itemIndexContext2++;

                    #region VR.ATO.GEN.001021

                    /*  VR.ATO.GEN.001021
                    Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
                    Legacy Rule Format:
                    IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
                       RETURN VALIDATION MESSAGE
                    ENDIF
        
                    Technical Business Rule Format:
                    (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
            
                    Data Elements:
            
                    ^IdentifierScheme = RP:RP.{SpecifiedCountry}
            
                    ^Context = RP:RP.{SpecifiedCountry}
                    */
                    assertion = (rpSpecifiedCountryContext.Exists != false && rpSpecifiedCountryContext.IdentifierScheme != @"http://www.ato.gov.au/tfn");
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.001021",
                            Severity = ProcessMessageSeverity.Error,
                            Description = @"Invalid identifier scheme.",
                            LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                            Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(rpSpecifiedCountryContext.OccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                        };
                        response.Add(processMessage);
                    }
                    #endregion // VR.ATO.GEN.001021

                    #region VR.ATO.GEN.001023

                    /*  VR.ATO.GEN.001023
                    TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
                    Legacy Rule Format:
                    IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
                       RETURN VALIDATION MESSAGE
                    ENDIF
        
                    Technical Business Rule Format:
                    ^Context <> NULL AND ^OtherTFN <> ^TFN
            
                    Data Elements:
            
                    ^Context = RP:RP.{SpecifiedCountry}
            
                    ^OtherTFN = RP:RP.{SpecifiedCountry}
            
                    ^TFN = RP
                    */
                    assertion = (rpSpecifiedCountryContext.Exists != false && rpSpecifiedCountryContext.IdentifierTFN != report.RPIdentifierTFN);
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.001023",
                            Severity = ProcessMessageSeverity.Error,
                            Description = @"Unexpected TFN mismatch with Reporting Party",
                            LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                            Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(rpSpecifiedCountryContext.OccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                        };
                        response.Add(processMessage);
                    }
                    #endregion // VR.ATO.GEN.001023

                    #region VR.ATO.GEN.438029

                    /*  VR.ATO.GEN.438029
                    Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
                    Legacy Rule Format:
                    IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
                       RETURN VALIDATION MESSAGE
                    ENDIF
        
                    Technical Business Rule Format:
                    (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
            
                    Data Elements:
            
                    ^IdentifierScheme = RP:RP.{SpecifiedCountry}
            
                    ^Context = RP:RP.{SpecifiedCountry}
                    */
                    assertion = (rpSpecifiedCountryContext.Exists != false && rpSpecifiedCountryContext.IdentifierScheme != @"http://www.ato.gov.au/tfn");
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.438029",
                            Severity = ProcessMessageSeverity.Error,
                            Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                            Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(rpSpecifiedCountryContext.OccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                        };
                        response.Add(processMessage);
                    }
                    #endregion // VR.ATO.GEN.438029

                    #region VR.ATO.IDS.440008

                    /*  VR.ATO.IDS.440008
                    Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
                    Legacy Rule Format:
                    IF (bafpr1.xx.xx:Expense.Other.Amount <> NULL) AND (bafpr1.xx.xx:Expense.Other.Amount <> MONETARY(U,11,0)) 
                     RETURN VALIDATION MESSAGE
                    ENDIF
        
                    Technical Business Rule Format:
                    NotMonetary(^IDS14, 'U', 11, 0)
            
                    Data Elements:
            
                    RP.{SpecifiedCountry}:^IDS14 = tns:Expense.Other.Amount
                    */
                    assertion = NotMonetary(rpSpecifiedCountryContext.IDS14, @"U", 11, 0);
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.400011",
                            Severity = ProcessMessageSeverity.Error,
                            Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                            LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                            Location = "/xbrli:xbrl/tns:Expense.Other.Amount[@contextRef='" + rpSpecifiedCountryContext.Id + "']",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440008" } },
                        };
                        processMessage.Parameters.Add(new ProcessMessageParameter
                        { Name = "IDS14", Value = rpSpecifiedCountryContext.IDS14.GetValueOrDefault().ToString() });

                        response.Add(processMessage);
                    }
                    #endregion // VR.ATO.IDS.440008

                    #region VR.ATO.IDS.440009

                    /*  VR.ATO.IDS.440009
                    Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
                    Legacy Rule Format:
                    IF (bafpr1.xx.xx:Revenue.Other.Amount <> NULL) AND (bafpr1.xx.xx:Revenue.Other.Amount <> MONETARY(U,11,0)) 
                     RETURN VALIDATION MESSAGE
                    ENDIF
        
                    Technical Business Rule Format:
                    NotMonetary(^IDS15, 'U', 11, 0)
            
                    Data Elements:
            
                    RP.{SpecifiedCountry}:^IDS15 = tns:Revenue.Other.Amount
                    */
                    assertion = NotMonetary(rpSpecifiedCountryContext.IDS15, @"U", 11, 0);
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.400011",
                            Severity = ProcessMessageSeverity.Error,
                            Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                            LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                            Location = "/xbrli:xbrl/tns:Revenue.Other.Amount[@contextRef='" + rpSpecifiedCountryContext.Id + "']",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440009" } },
                        };
                        processMessage.Parameters.Add(new ProcessMessageParameter
                        { Name = "IDS15", Value = rpSpecifiedCountryContext.IDS15.GetValueOrDefault().ToString() });

                        response.Add(processMessage);
                    }
                    #endregion // VR.ATO.IDS.440009
                }
            }

            #endregion // Foreach loop

            #region Repeating RPSpecifiedCountryActivityCodeContext
            if (report.RPSpecifiedCountryActivityCodeContextCollection != null)
            {
                int itemIndexContext3 = 0;
                foreach (IDS2017.RPSpecifiedCountryActivityCodeContext rpSpecifiedCountryActivityCodeContext in report.RPSpecifiedCountryActivityCodeContextCollection)
                {
                    itemIndexContext3++;

                    #region VR.ATO.GEN.001021

                    /*  VR.ATO.GEN.001021
                    Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
                    Legacy Rule Format:
                    IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
                       RETURN VALIDATION MESSAGE
                    ENDIF
        
                    Technical Business Rule Format:
                    (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
            
                    Data Elements:
            
                    ^IdentifierScheme = RP.{SpecifiedCountry}:RP.{SpecifiedCountry}.{ActivityCode}
            
                    ^Context = RP.{SpecifiedCountry}:RP.{SpecifiedCountry}.{ActivityCode}
                    */
                    assertion = (rpSpecifiedCountryActivityCodeContext.Exists != false && rpSpecifiedCountryActivityCodeContext.IdentifierScheme != @"http://www.ato.gov.au/tfn");
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.001021",
                            Severity = ProcessMessageSeverity.Error,
                            Description = @"Invalid identifier scheme.",
                            LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                            Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(rpSpecifiedCountryActivityCodeContext.OccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                        };
                        response.Add(processMessage);
                    }
                    #endregion // VR.ATO.GEN.001021

                    #region VR.ATO.GEN.001023

                    /*  VR.ATO.GEN.001023
                    TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
                    Legacy Rule Format:
                    IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
                       RETURN VALIDATION MESSAGE
                    ENDIF
        
                    Technical Business Rule Format:
                    ^Context <> NULL AND ^OtherTFN <> ^TFN
            
                    Data Elements:
            
                    ^Context = RP.{SpecifiedCountry}:RP.{SpecifiedCountry}.{ActivityCode}
            
                    ^OtherTFN = RP.{SpecifiedCountry}:RP.{SpecifiedCountry}.{ActivityCode}
            
                    ^TFN = RP
                    */
                    assertion = (rpSpecifiedCountryActivityCodeContext.Exists != false && rpSpecifiedCountryActivityCodeContext.IdentifierTFN != report.RPIdentifierTFN);
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.001023",
                            Severity = ProcessMessageSeverity.Error,
                            Description = @"Unexpected TFN mismatch with Reporting Party",
                            LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                            Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(rpSpecifiedCountryActivityCodeContext.OccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                        };
                        response.Add(processMessage);
                    }
                    #endregion // VR.ATO.GEN.001023

                    #region VR.ATO.GEN.438029

                    /*  VR.ATO.GEN.438029
                    Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
                    Legacy Rule Format:
                    IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
                       RETURN VALIDATION MESSAGE
                    ENDIF
        
                    Technical Business Rule Format:
                    (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
            
                    Data Elements:
            
                    ^IdentifierScheme = RP.{SpecifiedCountry}:RP.{SpecifiedCountry}.{ActivityCode}
            
                    ^Context = RP.{SpecifiedCountry}:RP.{SpecifiedCountry}.{ActivityCode}
                    */
                    assertion = (rpSpecifiedCountryActivityCodeContext.Exists != false && rpSpecifiedCountryActivityCodeContext.IdentifierScheme != @"http://www.ato.gov.au/tfn");
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.438029",
                            Severity = ProcessMessageSeverity.Error,
                            Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                            Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(rpSpecifiedCountryActivityCodeContext.OccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                        };
                        response.Add(processMessage);
                    }
                    #endregion // VR.ATO.GEN.438029

                    #region VR.ATO.IDS.440006

                    /*  VR.ATO.IDS.440006
                    Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
                    Legacy Rule Format:
                    IF (bafpr1.xx.xx:Expense.Total.Amount <> NULL) AND (bafpr1.xx.xx:Expense.Total.Amount <> MONETARY(U,11,0)) 
                     RETURN VALIDATION MESSAGE
                    ENDIF
        
                    Technical Business Rule Format:
                    NotMonetary(^IDS12, 'U', 11, 0)
            
                    Data Elements:
            
                    RP.{SpecifiedCountry}.{ActivityCode}:^IDS12 = tns:Expense.Total.Amount
                    */
                    assertion = NotMonetary(rpSpecifiedCountryActivityCodeContext.IDS12, @"U", 11, 0);
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.400011",
                            Severity = ProcessMessageSeverity.Error,
                            Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                            LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                            Location = "/xbrli:xbrl/tns:Expense.Total.Amount[@contextRef='" + rpSpecifiedCountryActivityCodeContext.Id + "']",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440006" } },
                        };
                        processMessage.Parameters.Add(new ProcessMessageParameter
                        { Name = "IDS12", Value = rpSpecifiedCountryActivityCodeContext.IDS12.GetValueOrDefault().ToString() });

                        response.Add(processMessage);
                    }
                    #endregion // VR.ATO.IDS.440006

                    #region VR.ATO.IDS.440007

                    /*  VR.ATO.IDS.440007
                    Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
                    Legacy Rule Format:
                    IF (bafpr1.xx.xx:Revenue.Total.Amount <> NULL) AND (bafpr1.xx.xx:Revenue.Total.Amount <> MONETARY(U,11,0)) 
                     RETURN VALIDATION MESSAGE
                    ENDIF
        
                    Technical Business Rule Format:
                    NotMonetary(^IDS13, 'U', 11, 0)
            
                    Data Elements:
            
                    RP.{SpecifiedCountry}.{ActivityCode}:^IDS13 = tns:Revenue.Total.Amount
                    */
                    assertion = NotMonetary(rpSpecifiedCountryActivityCodeContext.IDS13, @"U", 11, 0);
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.400011",
                            Severity = ProcessMessageSeverity.Error,
                            Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                            LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                            Location = "/xbrli:xbrl/tns:Revenue.Total.Amount[@contextRef='" + rpSpecifiedCountryActivityCodeContext.Id + "']",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440007" } },
                        };
                        processMessage.Parameters.Add(new ProcessMessageParameter
                        { Name = "IDS13", Value = rpSpecifiedCountryActivityCodeContext.IDS13.GetValueOrDefault().ToString() });

                        response.Add(processMessage);
                    }
                    #endregion // VR.ATO.IDS.440007
                }
            }

            #endregion // Foreach loop

            #region Repeating RPTransactionTypeContext
            if (report.RPTransactionTypeContextCollection != null)
            {
                int itemIndexContext2 = 0;
                foreach (IDS2017.RPTransactionTypeContext rpTransactionTypeContext in report.RPTransactionTypeContextCollection)
                {
                    itemIndexContext2++;

                    #region VR.ATO.GEN.001021

                    /*  VR.ATO.GEN.001021
                    Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
                    Legacy Rule Format:
                    IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
                       RETURN VALIDATION MESSAGE
                    ENDIF
        
                    Technical Business Rule Format:
                    (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
            
                    Data Elements:
            
                    ^IdentifierScheme = RP:RP.{TransactionType}
            
                    ^Context = RP:RP.{TransactionType}
                    */
                    assertion = (rpTransactionTypeContext.Exists != false && rpTransactionTypeContext.IdentifierScheme != @"http://www.ato.gov.au/tfn");
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.001021",
                            Severity = ProcessMessageSeverity.Error,
                            Description = @"Invalid identifier scheme.",
                            LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                            Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(rpTransactionTypeContext.OccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                        };
                        response.Add(processMessage);
                    }
                    #endregion // VR.ATO.GEN.001021

                    #region VR.ATO.GEN.001023

                    /*  VR.ATO.GEN.001023
                    TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
                    Legacy Rule Format:
                    IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
                       RETURN VALIDATION MESSAGE
                    ENDIF
        
                    Technical Business Rule Format:
                    ^Context <> NULL AND ^OtherTFN <> ^TFN
            
                    Data Elements:
            
                    ^Context = RP:RP.{TransactionType}
            
                    ^OtherTFN = RP:RP.{TransactionType}
            
                    ^TFN = RP
                    */
                    assertion = (rpTransactionTypeContext.Exists != false && rpTransactionTypeContext.IdentifierTFN != report.RPIdentifierTFN);
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.001023",
                            Severity = ProcessMessageSeverity.Error,
                            Description = @"Unexpected TFN mismatch with Reporting Party",
                            LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                            Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(rpTransactionTypeContext.OccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                        };
                        response.Add(processMessage);
                    }
                    #endregion // VR.ATO.GEN.001023

                    #region VR.ATO.GEN.438029

                    /*  VR.ATO.GEN.438029
                    Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
                    Legacy Rule Format:
                    IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
                       RETURN VALIDATION MESSAGE
                    ENDIF
        
                    Technical Business Rule Format:
                    (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
            
                    Data Elements:
            
                    ^IdentifierScheme = RP:RP.{TransactionType}
            
                    ^Context = RP:RP.{TransactionType}
                    */
                    assertion = (rpTransactionTypeContext.Exists != false && rpTransactionTypeContext.IdentifierScheme != @"http://www.ato.gov.au/tfn");
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.438029",
                            Severity = ProcessMessageSeverity.Error,
                            Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                            Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(rpTransactionTypeContext.OccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                        };
                        response.Add(processMessage);
                    }
                    #endregion // VR.ATO.GEN.438029

                    #region VR.ATO.IDS.440429

                    /*  VR.ATO.IDS.440429
                    Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
                    Legacy Rule Format:
                    IF [IDS338] <> NULL AND [IDS338] <> MONETARY(U,11,0) 
                     RETURN VALIDATION MESSAGE
                    ENDIF
                    
                    [IDS338] = IDS:RP.{TransactionType}:rvctc4.02.13:InternationalDealings.ForeignExchangeLossesOther.Amount
        
                    Technical Business Rule Format:
                    NotMonetary(^IDS338, 'U', 11, 0)
            
                    Data Elements:
            
                    RP.{TransactionType}:^IDS338 = tns:InternationalDealings.ForeignExchangeLossesOther.Amount
                    */
                    assertion = NotMonetary(rpTransactionTypeContext.IDS338, @"U", 11, 0);
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.400011",
                            Severity = ProcessMessageSeverity.Error,
                            Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                            LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                            Location = "/xbrli:xbrl/tns:InternationalDealings.ForeignExchangeLossesOther.Amount[@contextRef='" + rpTransactionTypeContext.Id + "']",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440429" } },
                        };
                        processMessage.Parameters.Add(new ProcessMessageParameter
                        { Name = "IDS338", Value = rpTransactionTypeContext.IDS338.GetValueOrDefault().ToString() });

                        response.Add(processMessage);
                    }
                    #endregion // VR.ATO.IDS.440429

                    #region VR.ATO.IDS.440430

                    /*  VR.ATO.IDS.440430
                    Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
                    Legacy Rule Format:
                    IF [IDS339] <> NULL AND [IDS339] <> MONETARY(U,11,0) 
                     RETURN VALIDATION MESSAGE
                    ENDIF
                    
                    [IDS339] = IDS:RP.{TransactionType}:rvctc4.02.13:InternationalDealings.ForeignExchangeGainsOther.Amount
        
                    Technical Business Rule Format:
                    NotMonetary(^IDS339, 'U', 11, 0)
            
                    Data Elements:
            
                    RP.{TransactionType}:^IDS339 = tns:InternationalDealings.ForeignExchangeGainsOther.Amount
                    */
                    assertion = NotMonetary(rpTransactionTypeContext.IDS339, @"U", 11, 0);
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.400011",
                            Severity = ProcessMessageSeverity.Error,
                            Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                            LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                            Location = "/xbrli:xbrl/tns:InternationalDealings.ForeignExchangeGainsOther.Amount[@contextRef='" + rpTransactionTypeContext.Id + "']",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440430" } },
                        };
                        processMessage.Parameters.Add(new ProcessMessageParameter
                        { Name = "IDS339", Value = rpTransactionTypeContext.IDS339.GetValueOrDefault().ToString() });

                        response.Add(processMessage);
                    }
                    #endregion // VR.ATO.IDS.440430
                }
            }

            #endregion // Foreach loop

            #region Repeating RPTransactionTypeCurrencyCodeContext
            if (report.RPTransactionTypeCurrencyCodeContextCollection != null)
            {
                int itemIndexContext3 = 0;
                foreach (IDS2017.RPTransactionTypeCurrencyCodeContext rpTransactionTypeCurrencyCodeContext in report.RPTransactionTypeCurrencyCodeContextCollection)
                {
                    itemIndexContext3++;

                    #region VR.ATO.GEN.001021

                    /*  VR.ATO.GEN.001021
                    Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
                    Legacy Rule Format:
                    IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
                       RETURN VALIDATION MESSAGE
                    ENDIF
        
                    Technical Business Rule Format:
                    (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
            
                    Data Elements:
            
                    ^IdentifierScheme = RP.{TransactionType}:RP.{TransactionType}.{CurrencyCode}
            
                    ^Context = RP.{TransactionType}:RP.{TransactionType}.{CurrencyCode}
                    */
                    assertion = (rpTransactionTypeCurrencyCodeContext.Exists != false && rpTransactionTypeCurrencyCodeContext.IdentifierScheme != @"http://www.ato.gov.au/tfn");
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.001021",
                            Severity = ProcessMessageSeverity.Error,
                            Description = @"Invalid identifier scheme.",
                            LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                            Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(rpTransactionTypeCurrencyCodeContext.OccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                        };
                        response.Add(processMessage);
                    }
                    #endregion // VR.ATO.GEN.001021

                    #region VR.ATO.GEN.001023

                    /*  VR.ATO.GEN.001023
                    TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
                    Legacy Rule Format:
                    IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
                       RETURN VALIDATION MESSAGE
                    ENDIF
        
                    Technical Business Rule Format:
                    ^Context <> NULL AND ^OtherTFN <> ^TFN
            
                    Data Elements:
            
                    ^Context = RP.{TransactionType}:RP.{TransactionType}.{CurrencyCode}
            
                    ^OtherTFN = RP.{TransactionType}:RP.{TransactionType}.{CurrencyCode}
            
                    ^TFN = RP
                    */
                    assertion = (rpTransactionTypeCurrencyCodeContext.Exists != false && rpTransactionTypeCurrencyCodeContext.IdentifierTFN != report.RPIdentifierTFN);
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.001023",
                            Severity = ProcessMessageSeverity.Error,
                            Description = @"Unexpected TFN mismatch with Reporting Party",
                            LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                            Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(rpTransactionTypeCurrencyCodeContext.OccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                        };
                        response.Add(processMessage);
                    }
                    #endregion // VR.ATO.GEN.001023

                    #region VR.ATO.GEN.438029

                    /*  VR.ATO.GEN.438029
                    Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
                    Legacy Rule Format:
                    IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
                       RETURN VALIDATION MESSAGE
                    ENDIF
        
                    Technical Business Rule Format:
                    (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
            
                    Data Elements:
            
                    ^IdentifierScheme = RP.{TransactionType}:RP.{TransactionType}.{CurrencyCode}
            
                    ^Context = RP.{TransactionType}:RP.{TransactionType}.{CurrencyCode}
                    */
                    assertion = (rpTransactionTypeCurrencyCodeContext.Exists != false && rpTransactionTypeCurrencyCodeContext.IdentifierScheme != @"http://www.ato.gov.au/tfn");
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.438029",
                            Severity = ProcessMessageSeverity.Error,
                            Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                            Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(rpTransactionTypeCurrencyCodeContext.OccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                        };
                        response.Add(processMessage);
                    }
                    #endregion // VR.ATO.GEN.438029
                }
            }

            #endregion // Foreach loop

            #region Repeating RPTrustExemptionCodeContext
            if (report.RPTrustExemptionCodeContextCollection != null)
            {
                int itemIndexContext2 = 0;
                foreach (IDS2017.RPTrustExemptionCodeContext rpTrustExemptionCodeContext in report.RPTrustExemptionCodeContextCollection)
                {
                    itemIndexContext2++;

                    #region VR.ATO.GEN.001021

                    /*  VR.ATO.GEN.001021
                    Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
                    Legacy Rule Format:
                    IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
                       RETURN VALIDATION MESSAGE
                    ENDIF
        
                    Technical Business Rule Format:
                    (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
            
                    Data Elements:
            
                    ^IdentifierScheme = RP:RP.{TrustExemptionCode}
            
                    ^Context = RP:RP.{TrustExemptionCode}
                    */
                    assertion = (rpTrustExemptionCodeContext.Exists != false && rpTrustExemptionCodeContext.IdentifierScheme != @"http://www.ato.gov.au/tfn");
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.001021",
                            Severity = ProcessMessageSeverity.Error,
                            Description = @"Invalid identifier scheme.",
                            LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                            Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(rpTrustExemptionCodeContext.OccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                        };
                        response.Add(processMessage);
                    }
                    #endregion // VR.ATO.GEN.001021

                    #region VR.ATO.GEN.001023

                    /*  VR.ATO.GEN.001023
                    TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
                    Legacy Rule Format:
                    IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
                       RETURN VALIDATION MESSAGE
                    ENDIF
        
                    Technical Business Rule Format:
                    ^Context <> NULL AND ^OtherTFN <> ^TFN
            
                    Data Elements:
            
                    ^Context = RP:RP.{TrustExemptionCode}
            
                    ^OtherTFN = RP:RP.{TrustExemptionCode}
            
                    ^TFN = RP
                    */
                    assertion = (rpTrustExemptionCodeContext.Exists != false && rpTrustExemptionCodeContext.IdentifierTFN != report.RPIdentifierTFN);
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.001023",
                            Severity = ProcessMessageSeverity.Error,
                            Description = @"Unexpected TFN mismatch with Reporting Party",
                            LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                            Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(rpTrustExemptionCodeContext.OccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                        };
                        response.Add(processMessage);
                    }
                    #endregion // VR.ATO.GEN.001023

                    #region VR.ATO.GEN.438029

                    /*  VR.ATO.GEN.438029
                    Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
                    Legacy Rule Format:
                    IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
                       RETURN VALIDATION MESSAGE
                    ENDIF
        
                    Technical Business Rule Format:
                    (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
            
                    Data Elements:
            
                    ^IdentifierScheme = RP:RP.{TrustExemptionCode}
            
                    ^Context = RP:RP.{TrustExemptionCode}
                    */
                    assertion = (rpTrustExemptionCodeContext.Exists != false && rpTrustExemptionCodeContext.IdentifierScheme != @"http://www.ato.gov.au/tfn");
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.438029",
                            Severity = ProcessMessageSeverity.Error,
                            Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                            Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(rpTrustExemptionCodeContext.OccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                        };
                        response.Add(processMessage);
                    }
                    #endregion // VR.ATO.GEN.438029

                    #region VR.ATO.IDS.440140

                    /*  VR.ATO.IDS.440140
                    Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
                    Legacy Rule Format:
                    IF [IDS214] <> NULL AND [IDS214] <> MONETARY(U,11,0) 
                     RETURN VALIDATION MESSAGE
                    ENDIF
                    
                    [IDS214] = IDS:RP.{TrustExemptionCode}:bafot.02.11:Miscellaneous.TransferPropertyMoneyOrServices.Amount
        
                    Technical Business Rule Format:
                    NotMonetary(^IDS214, 'U', 11, 0)
            
                    Data Elements:
            
                    RP.{TrustExemptionCode}:^IDS214 = tns:Miscellaneous.TransferPropertyMoneyOrServices.Amount
                    */
                    assertion = NotMonetary(rpTrustExemptionCodeContext.IDS214, @"U", 11, 0);
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.400011",
                            Severity = ProcessMessageSeverity.Error,
                            Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                            LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                            Location = "/xbrli:xbrl/tns:Miscellaneous.TransferPropertyMoneyOrServices.Amount[@contextRef='" + rpTrustExemptionCodeContext.Id + "']",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440140" } },
                        };
                        processMessage.Parameters.Add(new ProcessMessageParameter
                        { Name = "IDS214", Value = rpTrustExemptionCodeContext.IDS214.GetValueOrDefault().ToString() });

                        response.Add(processMessage);
                    }
                    #endregion // VR.ATO.IDS.440140
                }
            }

            #endregion // Foreach loop

            #region Repeating RPBranchOperationsInternallyRecordedDealingsContext
            if (report.RPBranchOperationsInternallyRecordedDealingsContextCollection != null)
            {
                int itemIndexContext3 = 0;
                foreach (IDS2017.RPBranchOperationsInternallyRecordedDealingsContext rpBranchOperationsInternallyRecordedDealingsContext in report.RPBranchOperationsInternallyRecordedDealingsContextCollection)
                {
                    itemIndexContext3++;

                    #region VR.ATO.GEN.001021

                    /*  VR.ATO.GEN.001021
                    Entity Identifier Scheme is not set to http://www.ato.gov.au/tfn
    
                    Legacy Rule Format:
                    IF Identifier Scheme <> “http://www.ato.gov.au/tfn”
                       RETURN VALIDATION MESSAGE
                    ENDIF
        
                    Technical Business Rule Format:
                    (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
            
                    Data Elements:
            
                    ^IdentifierScheme = RP.BranchOperations:RP.BranchOperations.{InternallyRecordedDealings}
            
                    ^Context = RP.BranchOperations:RP.BranchOperations.{InternallyRecordedDealings}
                    */
                    assertion = (rpBranchOperationsInternallyRecordedDealingsContext.Exists != false && rpBranchOperationsInternallyRecordedDealingsContext.IdentifierScheme != @"http://www.ato.gov.au/tfn");
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.001021",
                            Severity = ProcessMessageSeverity.Error,
                            Description = @"Invalid identifier scheme.",
                            LongDescription = @"Invalid identifier scheme.  Indentifier scheme must be set to ""http://www.ato.gov.au/tfn""",
                            Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(rpBranchOperationsInternallyRecordedDealingsContext.OccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001021" } },
                        };
                        response.Add(processMessage);
                    }
                    #endregion // VR.ATO.GEN.001021

                    #region VR.ATO.GEN.001023

                    /*  VR.ATO.GEN.001023
                    TFN in entity identifier of context does not match the TFN provided for the Reporting Party
    
                    Legacy Rule Format:
                    IF (entity.identifier.TFN WHERE CONTEXT(ALL)) <> RP:entity.identifier.TFN
                       RETURN VALIDATION MESSAGE
                    ENDIF
        
                    Technical Business Rule Format:
                    ^Context <> NULL AND ^OtherTFN <> ^TFN
            
                    Data Elements:
            
                    ^Context = RP.BranchOperations:RP.BranchOperations.{InternallyRecordedDealings}
            
                    ^OtherTFN = RP.BranchOperations:RP.BranchOperations.{InternallyRecordedDealings}
            
                    ^TFN = RP
                    */
                    assertion = (rpBranchOperationsInternallyRecordedDealingsContext.Exists != false && rpBranchOperationsInternallyRecordedDealingsContext.IdentifierTFN != report.RPIdentifierTFN);
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.001023",
                            Severity = ProcessMessageSeverity.Error,
                            Description = @"Unexpected TFN mismatch with Reporting Party",
                            LongDescription = @"TFN in entity identifier of context does not match the TFN provided for the Reporting Party",
                            Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(rpBranchOperationsInternallyRecordedDealingsContext.OccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.001023" } },
                        };
                        response.Add(processMessage);
                    }
                    #endregion // VR.ATO.GEN.001023

                    #region VR.ATO.GEN.438029

                    /*  VR.ATO.GEN.438029
                    Entity identifier scheme for ReportingParty must be"http://www.ato.gov.au/tfn"
    
                    Legacy Rule Format:
                    IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:ReportingParty") AND (entity.identifier.scheme <> "http://www.ato.gov.au/tfn")
                       RETURN VALIDATION MESSAGE
                    ENDIF
        
                    Technical Business Rule Format:
                    (^Context <> NULL) AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn')
            
                    Data Elements:
            
                    ^IdentifierScheme = RP.BranchOperations:RP.BranchOperations.{InternallyRecordedDealings}
            
                    ^Context = RP.BranchOperations:RP.BranchOperations.{InternallyRecordedDealings}
                    */
                    assertion = (rpBranchOperationsInternallyRecordedDealingsContext.Exists != false && rpBranchOperationsInternallyRecordedDealingsContext.IdentifierScheme != @"http://www.ato.gov.au/tfn");
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.438029",
                            Severity = ProcessMessageSeverity.Error,
                            Description = @"Entity identifier scheme for ReportingParty must be""http://www.ato.gov.au/tfn""",
                            Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(rpBranchOperationsInternallyRecordedDealingsContext.OccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.GEN.438029" } },
                        };
                        response.Add(processMessage);
                    }
                    #endregion // VR.ATO.GEN.438029

                    #region VR.ATO.IDS.440093

                    /*  VR.ATO.IDS.440093
                    Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
                    Legacy Rule Format:
                    IF [IDS169] <> NULL AND [IDS169] <> MONETARY(U,11,0) 
                     RETURN VALIDATION MESSAGE
                    ENDIF
                    
                    [IDS169] = IDS:RP.BranchOperations.{InternallyRecordedDealings}:bafot.02.11:Miscellaneous.InternallyRecordedDealingsAmountsClaimedTotal.Amount
        
                    Technical Business Rule Format:
                    NotMonetary(^IDS169, 'U', 11, 0)
            
                    Data Elements:
            
                    RP.BranchOperations.{InternallyRecordedDealings}:^IDS169 = tns:Miscellaneous.InternallyRecordedDealingsAmountsClaimedTotal.Amount
                    */
                    assertion = NotMonetary(rpBranchOperationsInternallyRecordedDealingsContext.IDS169, @"U", 11, 0);
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.400011",
                            Severity = ProcessMessageSeverity.Error,
                            Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                            LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                            Location = "/xbrli:xbrl/tns:Miscellaneous.InternallyRecordedDealingsAmountsClaimedTotal.Amount[@contextRef='" + rpBranchOperationsInternallyRecordedDealingsContext.Id + "']",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440093" } },
                        };
                        processMessage.Parameters.Add(new ProcessMessageParameter
                        { Name = "IDS169", Value = rpBranchOperationsInternallyRecordedDealingsContext.IDS169.GetValueOrDefault().ToString() });

                        response.Add(processMessage);
                    }
                    #endregion // VR.ATO.IDS.440093

                    #region VR.ATO.IDS.440094

                    /*  VR.ATO.IDS.440094
                    Monetary field, must be unsigned, maximum of 11 chars, no decimals
    
                    Legacy Rule Format:
                    IF [IDS170] <> NULL AND [IDS170] <> MONETARY(U,11,0) 
                     RETURN VALIDATION MESSAGE
                    ENDIF
                    
                    [IDS170] = IDS:RP.BranchOperations.{InternallyRecordedDealings}:bafot.02.11:Miscellaneous.InternallyRecordedDealingsAmountsReturnedTotal.Amount
        
                    Technical Business Rule Format:
                    NotMonetary(^IDS170, 'U', 11, 0)
            
                    Data Elements:
            
                    RP.BranchOperations.{InternallyRecordedDealings}:^IDS170 = tns:Miscellaneous.InternallyRecordedDealingsAmountsReturnedTotal.Amount
                    */
                    assertion = NotMonetary(rpBranchOperationsInternallyRecordedDealingsContext.IDS170, @"U", 11, 0);
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.400011",
                            Severity = ProcessMessageSeverity.Error,
                            Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                            LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                            Location = "/xbrli:xbrl/tns:Miscellaneous.InternallyRecordedDealingsAmountsReturnedTotal.Amount[@contextRef='" + rpBranchOperationsInternallyRecordedDealingsContext.Id + "']",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440094" } },
                        };
                        processMessage.Parameters.Add(new ProcessMessageParameter
                        { Name = "IDS170", Value = rpBranchOperationsInternallyRecordedDealingsContext.IDS170.GetValueOrDefault().ToString() });

                        response.Add(processMessage);
                    }
                    #endregion // VR.ATO.IDS.440094
                }
            }

            #endregion // Foreach loop

            #region Repeating IDS178Collection
            if (report.IDS178Collection != null)
            {
                int itemIndex1 = 0;
                foreach (string IDS178 in report.IDS178Collection)
                {
                    itemIndex1++;

                    #region VR.ATO.IDS.440294

                    /*  VR.ATO.IDS.440294
                    If the tax timing method election for 'No elections made' is selected then no other tax timing method election should be completed.
    
                    Legacy Rule Format:
                    IF [IDS178] = "G = No elections made" AND (COUNT([IDS178] > 1))
                     RETURN VALIDATION MESSAGE
                    ENDIF
                    
                    [IDS178] = IDS:RP:rvctc4.02.05:InternationalDealings.TaxTimingMethodElections.Code
        
                    Technical Business Rule Format:
                    ^IDS178 = 'G = No elections made' AND (Count(^IDS178) > 1)
            
                    Data Elements:
            
                    RP:^IDS178 = tns:InternationalDealings.TaxTimingMethodElections.Code
                    */
                    assertion = (IDS178 == @"G = No elections made" && Count(report.IDS178Collection) > 1);
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.IDS.440294",
                            Severity = ProcessMessageSeverity.Error,
                            Description = @"TOFA tax timing method elections incorrect",
                            LongDescription = @"If the tax timing method election for 'No elections made' is selected then no other tax timing method election should be completed",
                            Location = "/xbrli:xbrl/tns:InternationalDealings.TaxTimingMethodElections.Code",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440294" } },
                        };
                        processMessage.Parameters.Add(new ProcessMessageParameter
                        { Name = "IDS178", Value = IDS178 });

                        response.Add(processMessage);
                    }
                    #endregion // VR.ATO.IDS.440294
                }
            }

            #endregion // Foreach loop

            #region Repeating IDS332Collection
            if (report.IDS332Collection != null)
            {
                int itemIndex1 = 0;
                foreach (string IDS332 in report.IDS332Collection)
                {
                    itemIndex1++;

                    #region VR.ATO.IDS.440451

                    /*  VR.ATO.IDS.440451
                    Derivate code is invalid
    
                    Legacy Rule Format:
                    IF ([IDS332] <> NULLORBLANK) AND ([IDS332] <> SET(DOMAIN(DERIVATIVECODE CODES)))
                       RETURN VALIDATION MESSAGE
                    ENDIF
                    
                    [IDS332] = IDS:RP.Derivatives:rvctc4.02.13:InternationalDealings.RelatedPartyTransactionType.Code
        
                    Technical Business Rule Format:
                    (^IDS332 <> BLANK) AND (NotInDomain(^IDS332, 'DERIVATIVECODE CODES'))
            
                    Data Elements:
            
                    RP.Derivatives:^IDS332 = tns:InternationalDealings.RelatedPartyTransactionType.Code
                    */
                    assertion = (string.IsNullOrWhiteSpace(IDS332) != true && !(IsMatch(IDS332, @"^(AS|CCIRS|CDCS|CDCSFFO|CDS|FFIRS|OD|OIRD)$", RegexOptions.IgnoreCase)));
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.IDS.440451",
                            Severity = ProcessMessageSeverity.Error,
                            Description = @"Derivative code is invalid",
                            Location = "/xbrli:xbrl/tns:InternationalDealings.RelatedPartyTransactionType.Code[" + itemIndex1 + "]",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.IDS.440451" } },
                        };
                        processMessage.Parameters.Add(new ProcessMessageParameter
                        { Name = "IDS332", Value = IDS332 });

                        response.Add(processMessage);
                    }
                    #endregion // VR.ATO.IDS.440451
                }
            }

            #endregion // Foreach loop

            foreach (ProcessMessageDocument currentProcessMessage in response)
            {
                if (currentProcessMessage.Parameters != null)
                {
                    foreach (ProcessMessageParameter currentParameter in currentProcessMessage.Parameters)
                    {
                        if (string.IsNullOrEmpty(currentParameter.Name))
                        {
                            currentParameter.Name = _emptyParameterValue;
                        }

                        if (currentParameter.Name.Length > _maxParameterNameLength)
                        {
                            currentParameter.Name = currentParameter.Name.Substring(0, _maxParameterNameLength - 1);
                        }

                        if (string.IsNullOrEmpty(currentParameter.Value))
                        {
                            currentParameter.Value = _emptyParameterValue;
                        }

                        if (currentParameter.Value.Length > _maxParameterValueLength)
                        {
                            currentParameter.Value = currentParameter.Value.Substring(0, _maxParameterValueLength - 1);
                        }
                    }
                }
            }

            return response;
        }


    }
}
